Class: SDM::AKSBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AKSBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AKSBasicAuth

Returns a new instance of AKSBasicAuth.



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/models/porcelain.rb', line 403

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



373
374
375
# File 'lib/models/porcelain.rb', line 373

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



375
376
377
# File 'lib/models/porcelain.rb', line 375

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



377
378
379
# File 'lib/models/porcelain.rb', line 377

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



379
380
381
# File 'lib/models/porcelain.rb', line 379

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



381
382
383
# File 'lib/models/porcelain.rb', line 381

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



383
384
385
# File 'lib/models/porcelain.rb', line 383

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



385
386
387
# File 'lib/models/porcelain.rb', line 385

def name
  @name
end

#passwordObject

The password to authenticate with.



387
388
389
# File 'lib/models/porcelain.rb', line 387

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



389
390
391
# File 'lib/models/porcelain.rb', line 389

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



391
392
393
# File 'lib/models/porcelain.rb', line 391

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



393
394
395
# File 'lib/models/porcelain.rb', line 393

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



395
396
397
# File 'lib/models/porcelain.rb', line 395

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



397
398
399
# File 'lib/models/porcelain.rb', line 397

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



399
400
401
# File 'lib/models/porcelain.rb', line 399

def tags
  @tags
end

#usernameObject

The username to authenticate with.



401
402
403
# File 'lib/models/porcelain.rb', line 401

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



437
438
439
440
441
442
443
# File 'lib/models/porcelain.rb', line 437

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end