Class: SDM::AKSServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AKSServiceAccountUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ AKSServiceAccountUserImpersonation

Returns a new instance of AKSServiceAccountUserImpersonation.



574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
# File 'lib/models/porcelain.rb', line 574

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



546
547
548
# File 'lib/models/porcelain.rb', line 546

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



548
549
550
# File 'lib/models/porcelain.rb', line 548

def egress_filter
  @egress_filter
end

#healthcheck_namespace ⇒ Object

The path used to check the health of your connection. Defaults to default.



550
551
552
# File 'lib/models/porcelain.rb', line 550

def healthcheck_namespace
  @healthcheck_namespace
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



552
553
554
# File 'lib/models/porcelain.rb', line 552

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



554
555
556
# File 'lib/models/porcelain.rb', line 554

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



556
557
558
# File 'lib/models/porcelain.rb', line 556

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



558
559
560
# File 'lib/models/porcelain.rb', line 558

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



560
561
562
# File 'lib/models/porcelain.rb', line 560

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



562
563
564
# File 'lib/models/porcelain.rb', line 562

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



564
565
566
# File 'lib/models/porcelain.rb', line 564

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



566
567
568
# File 'lib/models/porcelain.rb', line 566

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



568
569
570
# File 'lib/models/porcelain.rb', line 568

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



570
571
572
# File 'lib/models/porcelain.rb', line 570

def tags
  @tags
end

#token ⇒ Object

The API token to authenticate with.



572
573
574
# File 'lib/models/porcelain.rb', line 572

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



606
607
608
609
610
611
612
# File 'lib/models/porcelain.rb', line 606

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end