Class: SDM::AKSUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AKSUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AKSUserImpersonation

Returns a new instance of AKSUserImpersonation.



646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
# File 'lib/models/porcelain.rb', line 646

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



614
615
616
# File 'lib/models/porcelain.rb', line 614

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



616
617
618
# File 'lib/models/porcelain.rb', line 616

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



618
619
620
# File 'lib/models/porcelain.rb', line 618

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



620
621
622
# File 'lib/models/porcelain.rb', line 620

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



622
623
624
# File 'lib/models/porcelain.rb', line 622

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



624
625
626
# File 'lib/models/porcelain.rb', line 624

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



626
627
628
# File 'lib/models/porcelain.rb', line 626

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



628
629
630
# File 'lib/models/porcelain.rb', line 628

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



630
631
632
# File 'lib/models/porcelain.rb', line 630

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



632
633
634
# File 'lib/models/porcelain.rb', line 632

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



634
635
636
# File 'lib/models/porcelain.rb', line 634

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



636
637
638
# File 'lib/models/porcelain.rb', line 636

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



638
639
640
# File 'lib/models/porcelain.rb', line 638

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



640
641
642
# File 'lib/models/porcelain.rb', line 640

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



642
643
644
# File 'lib/models/porcelain.rb', line 642

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



644
645
646
# File 'lib/models/porcelain.rb', line 644

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



682
683
684
685
686
687
688
# File 'lib/models/porcelain.rb', line 682

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end