Class: SDM::AccessRequestConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccessRequestConfig holds the information required to request access to a resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(duration: nil, reason: nil, resource_id: nil, start_from: nil) ⇒ AccessRequestConfig

Returns a new instance of AccessRequestConfig.



1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/models/porcelain.rb', line 1312

def initialize(
  duration: nil,
  reason: nil,
  resource_id: nil,
  start_from: nil
)
  @duration = duration == nil ? "" : duration
  @reason = reason == nil ? "" : reason
  @resource_id = resource_id == nil ? "" : resource_id
  @start_from = start_from == nil ? nil : start_from
end

Instance Attribute Details

#durationObject

The time access should end, defaults to the next occurance of 5 pm



1304
1305
1306
# File 'lib/models/porcelain.rb', line 1304

def duration
  @duration
end

#reasonObject

The reason for access



1306
1307
1308
# File 'lib/models/porcelain.rb', line 1306

def reason
  @reason
end

#resource_idObject

The resource for which access is being requested



1308
1309
1310
# File 'lib/models/porcelain.rb', line 1308

def resource_id
  @resource_id
end

#start_fromObject

The time access should start, defaults to now



1310
1311
1312
# File 'lib/models/porcelain.rb', line 1310

def start_from
  @start_from
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1324
1325
1326
1327
1328
1329
1330
# File 'lib/models/porcelain.rb', line 1324

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end