Class: SDM::AccessRequestEventHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccessRequestEventHistory records the state of a AccessRequest at a given point in time, where every change (create, update and delete) to a AccessRequest produces an AccessRequestEventHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_request_event: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccessRequestEventHistory

Returns a new instance of AccessRequestEventHistory.



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
# File 'lib/models/porcelain.rb', line 1382

def initialize(
  access_request_event: nil,
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil
)
  @access_request_event = access_request_event == nil ? nil : access_request_event
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#access_request_eventObject

The complete AccessRequestEvent state at this time.



1373
1374
1375
# File 'lib/models/porcelain.rb', line 1373

def access_request_event
  @access_request_event
end

#activity_idObject

The unique identifier of the Activity that produced this change to the AccessRequest. May be empty for some system-initiated updates.



1376
1377
1378
# File 'lib/models/porcelain.rb', line 1376

def activity_id
  @activity_id
end

#deleted_atObject

If this Workflow was deleted, the time it was deleted.



1378
1379
1380
# File 'lib/models/porcelain.rb', line 1378

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the AccessRequest state was recorded.



1380
1381
1382
# File 'lib/models/porcelain.rb', line 1380

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1394
1395
1396
1397
1398
1399
1400
# File 'lib/models/porcelain.rb', line 1394

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end