Class: SDM::AccessRequestHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccessRequestHistory records the state of a AccessRequest at a given point in time, where every change (create, update and delete) to a AccessRequest produces an AccessRequestHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_request: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccessRequestHistory

Returns a new instance of AccessRequestHistory.



1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/models/porcelain.rb', line 1421

def initialize(
  access_request: nil,
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil
)
  @access_request = access_request == nil ? nil : access_request
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#access_request ⇒ Object

The complete AccessRequest state at this time.



1412
1413
1414
# File 'lib/models/porcelain.rb', line 1412

def access_request
  @access_request
end

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the AccessRequest. May be empty for some system-initiated updates.



1415
1416
1417
# File 'lib/models/porcelain.rb', line 1415

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this Workflow was deleted, the time it was deleted.



1417
1418
1419
# File 'lib/models/porcelain.rb', line 1417

def deleted_at
  @deleted_at
end

#timestamp ⇒ Object

The time at which the AccessRequest state was recorded.



1419
1420
1421
# File 'lib/models/porcelain.rb', line 1419

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1433
1434
1435
1436
1437
1438
1439
# File 'lib/models/porcelain.rb', line 1433

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end