Class: SDM::AccountCreateResponse
- Inherits:
-
Object
- Object
- SDM::AccountCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
AccountCreateResponse reports how the Accounts were created in the system.
Instance Attribute Summary collapse
-
#account ⇒ Object
The created Account.
-
#meta ⇒ Object
Reserved for future use.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Account.
Instance Method Summary collapse
-
#initialize(account: nil, meta: nil, rate_limit: nil, token: nil) ⇒ AccountCreateResponse
constructor
A new instance of AccountCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account: nil, meta: nil, rate_limit: nil, token: nil) ⇒ AccountCreateResponse
Returns a new instance of AccountCreateResponse.
781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/models/porcelain.rb', line 781 def initialize( account: nil, meta: nil, rate_limit: nil, token: nil ) @account = account == nil ? nil : account @meta = == nil ? nil : @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#account ⇒ Object
The created Account.
772 773 774 |
# File 'lib/models/porcelain.rb', line 772 def account @account end |
#meta ⇒ Object
Reserved for future use.
774 775 776 |
# File 'lib/models/porcelain.rb', line 774 def @meta end |
#rate_limit ⇒ Object
Rate limit information.
776 777 778 |
# File 'lib/models/porcelain.rb', line 776 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Account. The Account will use this token to authenticate with the strongDM API.
779 780 781 |
# File 'lib/models/porcelain.rb', line 779 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
793 794 795 796 797 798 799 |
# File 'lib/models/porcelain.rb', line 793 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |