Class: SDM::AccountGrant
- Inherits:
-
Object
- Object
- SDM::AccountGrant
- Defined in:
- lib/models/porcelain.rb
Overview
AccountGrants connect a resource directly to an account, giving the account the permission to connect to that resource.
Instance Attribute Summary collapse
-
#access_rule ⇒ Object
The access rule associated with this AccountGrant.
-
#account_id ⇒ Object
The account ID of this AccountGrant.
-
#id ⇒ Object
Unique identifier of the AccountGrant.
-
#resource_id ⇒ Object
The resource ID of this AccountGrant.
-
#start_from ⇒ Object
The timestamp when the resource will be granted.
-
#valid_until ⇒ Object
The timestamp when the resource grant will expire.
Instance Method Summary collapse
-
#initialize(access_rule: nil, account_id: nil, id: nil, resource_id: nil, start_from: nil, valid_until: nil) ⇒ AccountGrant
constructor
A new instance of AccountGrant.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rule: nil, account_id: nil, id: nil, resource_id: nil, start_from: nil, valid_until: nil) ⇒ AccountGrant
Returns a new instance of AccountGrant.
1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 |
# File 'lib/models/porcelain.rb', line 1720 def initialize( access_rule: nil, account_id: nil, id: nil, resource_id: nil, start_from: nil, valid_until: nil ) @access_rule = access_rule == nil ? SDM::_porcelain_zero_value_access_rule() : access_rule @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @resource_id = resource_id == nil ? "" : resource_id @start_from = start_from == nil ? nil : start_from @valid_until = valid_until == nil ? nil : valid_until end |
Instance Attribute Details
#access_rule ⇒ Object
The access rule associated with this AccountGrant.
1708 1709 1710 |
# File 'lib/models/porcelain.rb', line 1708 def access_rule @access_rule end |
#account_id ⇒ Object
The account ID of this AccountGrant.
1710 1711 1712 |
# File 'lib/models/porcelain.rb', line 1710 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the AccountGrant.
1712 1713 1714 |
# File 'lib/models/porcelain.rb', line 1712 def id @id end |
#resource_id ⇒ Object
The resource ID of this AccountGrant.
1714 1715 1716 |
# File 'lib/models/porcelain.rb', line 1714 def resource_id @resource_id end |
#start_from ⇒ Object
The timestamp when the resource will be granted. When creating an AccountGrant, if this field is not specified, it will default to the current time.
1716 1717 1718 |
# File 'lib/models/porcelain.rb', line 1716 def start_from @start_from end |
#valid_until ⇒ Object
The timestamp when the resource grant will expire.
1718 1719 1720 |
# File 'lib/models/porcelain.rb', line 1718 def valid_until @valid_until end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1736 1737 1738 1739 1740 1741 1742 |
# File 'lib/models/porcelain.rb', line 1736 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |