Class: SDM::AccountResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountResourceHistory records the state of a AccountResource at a given point in time, where every change (create or delete) to a AccountResource produces an AccountResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_resource: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountResourceHistory

Returns a new instance of AccountResourceHistory.



2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
# File 'lib/models/porcelain.rb', line 2258

def initialize(
  account_resource: nil,
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil
)
  @account_resource =  == nil ? nil : 
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_resource ⇒ Object

The complete AccountResource state at this time.



2249
2250
2251
# File 'lib/models/porcelain.rb', line 2249

def 
  @account_resource
end

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the AccountResource. May be empty for some system-initiated updates.



2252
2253
2254
# File 'lib/models/porcelain.rb', line 2252

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this AccountResource was deleted, the time it was deleted.



2254
2255
2256
# File 'lib/models/porcelain.rb', line 2254

def deleted_at
  @deleted_at
end

#timestamp ⇒ Object

The time at which the AccountResource state was recorded.



2256
2257
2258
# File 'lib/models/porcelain.rb', line 2256

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2270
2271
2272
2273
2274
2275
2276
# File 'lib/models/porcelain.rb', line 2270

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end