Class: SDM::ActiveDirectoryEngine
- Inherits:
-
Object
- Object
- SDM::ActiveDirectoryEngine
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#after_read_ttl ⇒ Object
The default time-to-live duration of the password after it's read.
-
#binddn ⇒ Object
Distinguished name of object to bind when performing user and group search.
-
#bindpass ⇒ Object
Password to use along with binddn when performing user search.
-
#certificate ⇒ Object
CA certificate to use when verifying LDAP server certificate, must be x509 PEM encoded.
-
#connection_timeout ⇒ Object
Timeout, in seconds, when attempting to connect to the LDAP server before trying the next URL in the configuration.
-
#do_not_validate_timestamps ⇒ Object
If set to true this will prevent password change timestamp validation in Active Directory when validating credentials.
-
#id ⇒ Object
Unique identifier of the Secret Engine.
-
#insecure_tls ⇒ Object
If true, skips LDAP server SSL certificate verification - insecure, use with caution!.
-
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days.
-
#max_backoff_duration ⇒ Object
The maximum retry duration in case of automatic failure.
-
#name ⇒ Object
Unique human-readable name of the Secret Engine.
-
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine.
-
#policy ⇒ Object
Policy for password creation.
-
#public_key ⇒ Object
Public key linked with a secret engine.
-
#request_timeout ⇒ Object
Timeout, in seconds, for the connection when making requests against the server before returning back an error.
-
#secret_store_id ⇒ Object
Backing secret store identifier.
-
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored.
-
#start_tls ⇒ Object
If true, issues a StartTLS command after establishing an unencrypted connection.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#ttl ⇒ Object
The default password time-to-live duration.
-
#upndomain ⇒ Object
The domain (userPrincipalDomain) used to construct a UPN string for authentication.
-
#url ⇒ Object
The LDAP server to connect to.
-
#userdn ⇒ Object
Base DN under which to perform user search.
Instance Method Summary collapse
-
#initialize(after_read_ttl: nil, binddn: nil, bindpass: nil, certificate: nil, connection_timeout: nil, do_not_validate_timestamps: nil, id: nil, insecure_tls: nil, key_rotation_interval_days: nil, max_backoff_duration: nil, name: nil, node_selector: nil, policy: nil, public_key: nil, request_timeout: nil, secret_store_id: nil, secret_store_root_path: nil, start_tls: nil, tags: nil, ttl: nil, upndomain: nil, url: nil, userdn: nil) ⇒ ActiveDirectoryEngine
constructor
A new instance of ActiveDirectoryEngine.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(after_read_ttl: nil, binddn: nil, bindpass: nil, certificate: nil, connection_timeout: nil, do_not_validate_timestamps: nil, id: nil, insecure_tls: nil, key_rotation_interval_days: nil, max_backoff_duration: nil, name: nil, node_selector: nil, policy: nil, public_key: nil, request_timeout: nil, secret_store_id: nil, secret_store_root_path: nil, start_tls: nil, tags: nil, ttl: nil, upndomain: nil, url: nil, userdn: nil) ⇒ ActiveDirectoryEngine
Returns a new instance of ActiveDirectoryEngine.
2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 |
# File 'lib/models/porcelain.rb', line 2355 def initialize( after_read_ttl: nil, binddn: nil, bindpass: nil, certificate: nil, connection_timeout: nil, do_not_validate_timestamps: nil, id: nil, insecure_tls: nil, key_rotation_interval_days: nil, max_backoff_duration: nil, name: nil, node_selector: nil, policy: nil, public_key: nil, request_timeout: nil, secret_store_id: nil, secret_store_root_path: nil, start_tls: nil, tags: nil, ttl: nil, upndomain: nil, url: nil, userdn: nil ) @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl @binddn = binddn == nil ? "" : binddn @bindpass = bindpass == nil ? "" : bindpass @certificate = certificate == nil ? "" : certificate @connection_timeout = connection_timeout == nil ? 0 : connection_timeout @do_not_validate_timestamps = == nil ? false : @id = id == nil ? "" : id @insecure_tls = insecure_tls == nil ? false : insecure_tls @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days @max_backoff_duration = max_backoff_duration == nil ? nil : max_backoff_duration @name = name == nil ? "" : name @node_selector = node_selector == nil ? "" : node_selector @policy = policy == nil ? nil : policy @public_key = public_key == nil ? "" : public_key @request_timeout = request_timeout == nil ? 0 : request_timeout @secret_store_id = secret_store_id == nil ? "" : secret_store_id @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path @start_tls = start_tls == nil ? false : start_tls @tags = == nil ? SDM::() : @ttl = ttl == nil ? nil : ttl @upndomain = upndomain == nil ? "" : upndomain @url = url == nil ? "" : url @userdn = userdn == nil ? "" : userdn end |
Instance Attribute Details
#after_read_ttl ⇒ Object
The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.
2308 2309 2310 |
# File 'lib/models/porcelain.rb', line 2308 def after_read_ttl @after_read_ttl end |
#binddn ⇒ Object
Distinguished name of object to bind when performing user and group search. Example: cn=vault,ou=Users,dc=example,dc=com
2310 2311 2312 |
# File 'lib/models/porcelain.rb', line 2310 def binddn @binddn end |
#bindpass ⇒ Object
Password to use along with binddn when performing user search.
2312 2313 2314 |
# File 'lib/models/porcelain.rb', line 2312 def bindpass @bindpass end |
#certificate ⇒ Object
CA certificate to use when verifying LDAP server certificate, must be x509 PEM encoded.
2314 2315 2316 |
# File 'lib/models/porcelain.rb', line 2314 def certificate @certificate end |
#connection_timeout ⇒ Object
Timeout, in seconds, when attempting to connect to the LDAP server before trying the next URL in the configuration.
2316 2317 2318 |
# File 'lib/models/porcelain.rb', line 2316 def connection_timeout @connection_timeout end |
#do_not_validate_timestamps ⇒ Object
If set to true this will prevent password change timestamp validation in Active Directory when validating credentials
2318 2319 2320 |
# File 'lib/models/porcelain.rb', line 2318 def @do_not_validate_timestamps end |
#id ⇒ Object
Unique identifier of the Secret Engine.
2320 2321 2322 |
# File 'lib/models/porcelain.rb', line 2320 def id @id end |
#insecure_tls ⇒ Object
If true, skips LDAP server SSL certificate verification - insecure, use with caution!
2322 2323 2324 |
# File 'lib/models/porcelain.rb', line 2322 def insecure_tls @insecure_tls end |
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days
2324 2325 2326 |
# File 'lib/models/porcelain.rb', line 2324 def key_rotation_interval_days @key_rotation_interval_days end |
#max_backoff_duration ⇒ Object
The maximum retry duration in case of automatic failure. On failed ttl rotation attempt it will be retried in an increasing intervals until it reaches max_backoff_duration
2327 2328 2329 |
# File 'lib/models/porcelain.rb', line 2327 def max_backoff_duration @max_backoff_duration end |
#name ⇒ Object
Unique human-readable name of the Secret Engine.
2329 2330 2331 |
# File 'lib/models/porcelain.rb', line 2329 def name @name end |
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine
2331 2332 2333 |
# File 'lib/models/porcelain.rb', line 2331 def node_selector @node_selector end |
#policy ⇒ Object
Policy for password creation
2333 2334 2335 |
# File 'lib/models/porcelain.rb', line 2333 def policy @policy end |
#public_key ⇒ Object
Public key linked with a secret engine
2335 2336 2337 |
# File 'lib/models/porcelain.rb', line 2335 def public_key @public_key end |
#request_timeout ⇒ Object
Timeout, in seconds, for the connection when making requests against the server before returning back an error.
2337 2338 2339 |
# File 'lib/models/porcelain.rb', line 2337 def request_timeout @request_timeout end |
#secret_store_id ⇒ Object
Backing secret store identifier
2339 2340 2341 |
# File 'lib/models/porcelain.rb', line 2339 def secret_store_id @secret_store_id end |
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored
2341 2342 2343 |
# File 'lib/models/porcelain.rb', line 2341 def secret_store_root_path @secret_store_root_path end |
#start_tls ⇒ Object
If true, issues a StartTLS command after establishing an unencrypted connection.
2343 2344 2345 |
# File 'lib/models/porcelain.rb', line 2343 def start_tls @start_tls end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2345 2346 2347 |
# File 'lib/models/porcelain.rb', line 2345 def @tags end |
#ttl ⇒ Object
The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.
2347 2348 2349 |
# File 'lib/models/porcelain.rb', line 2347 def ttl @ttl end |
#upndomain ⇒ Object
The domain (userPrincipalDomain) used to construct a UPN string for authentication.
2349 2350 2351 |
# File 'lib/models/porcelain.rb', line 2349 def upndomain @upndomain end |
#url ⇒ Object
The LDAP server to connect to.
2351 2352 2353 |
# File 'lib/models/porcelain.rb', line 2351 def url @url end |
#userdn ⇒ Object
Base DN under which to perform user search. Example: ou=Users,dc=example,dc=com
2353 2354 2355 |
# File 'lib/models/porcelain.rb', line 2353 def userdn @userdn end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/models/porcelain.rb', line 2405 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |