Class: SDM::ActivityActor

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_external_id: nil, email: nil, first_name: nil, id: nil, last_name: nil) ⇒ ActivityActor

Returns a new instance of ActivityActor.



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
# File 'lib/models/porcelain.rb', line 2510

def initialize(
  activity_external_id: nil,
  email: nil,
  first_name: nil,
  id: nil,
  last_name: nil
)
  @activity_external_id = activity_external_id == nil ? "" : activity_external_id
  @email = email == nil ? "" : email
  @first_name = first_name == nil ? "" : first_name
  @id = id == nil ? "" : id
  @last_name = last_name == nil ? "" : last_name
end

Instance Attribute Details

#activity_external_idObject

The external ID of the actor at the time this activity occurred.



2500
2501
2502
# File 'lib/models/porcelain.rb', line 2500

def activity_external_id
  @activity_external_id
end

#emailObject

The email of the actor at the time this activity occurred.



2502
2503
2504
# File 'lib/models/porcelain.rb', line 2502

def email
  @email
end

#first_nameObject

The first name of the actor at the time this activity occurred.



2504
2505
2506
# File 'lib/models/porcelain.rb', line 2504

def first_name
  @first_name
end

#idObject

Unique identifier of the actor. Immutable.



2506
2507
2508
# File 'lib/models/porcelain.rb', line 2506

def id
  @id
end

#last_nameObject

The last name of the actor at the time this activity occurred.



2508
2509
2510
# File 'lib/models/porcelain.rb', line 2508

def last_name
  @last_name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2524
2525
2526
2527
2528
2529
2530
# File 'lib/models/porcelain.rb', line 2524

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end