Class: SDM::ActivityEntity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(email: nil, external_id: nil, id: nil, name: nil, type: nil) ⇒ ActivityEntity

Returns a new instance of ActivityEntity.



2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
# File 'lib/models/porcelain.rb', line 2545

def initialize(
  email: nil,
  external_id: nil,
  id: nil,
  name: nil,
  type: nil
)
  @email = email == nil ? "" : email
  @external_id = external_id == nil ? "" : external_id
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @type = type == nil ? "" : type
end

Instance Attribute Details

#emailObject

The email of the affected entity, if it has one (for example, if it is an account).



2535
2536
2537
# File 'lib/models/porcelain.rb', line 2535

def email
  @email
end

#external_idObject

The external ID of the affected entity, if it has one (for example, if it is an account).



2537
2538
2539
# File 'lib/models/porcelain.rb', line 2537

def external_id
  @external_id
end

#idObject

The unique identifier of the entity this activity affected.



2539
2540
2541
# File 'lib/models/porcelain.rb', line 2539

def id
  @id
end

#nameObject

A display name representing the affected entity.



2541
2542
2543
# File 'lib/models/porcelain.rb', line 2541

def name
  @name
end

#typeObject

The type of entity affected, one of the ActivityEntityType constants.



2543
2544
2545
# File 'lib/models/porcelain.rb', line 2543

def type
  @type
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2559
2560
2561
2562
2563
2564
2565
# File 'lib/models/porcelain.rb', line 2559

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end