Class: SDM::Aerospike

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_services_alternate: nil, username: nil) ⇒ Aerospike

Returns a new instance of Aerospike.



2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
# File 'lib/models/porcelain.rb', line 2628

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_services_alternate: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_services_alternate = use_services_alternate == nil ? false : use_services_alternate
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



2598
2599
2600
# File 'lib/models/porcelain.rb', line 2598

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2600
2601
2602
# File 'lib/models/porcelain.rb', line 2600

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2602
2603
2604
# File 'lib/models/porcelain.rb', line 2602

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2604
2605
2606
# File 'lib/models/porcelain.rb', line 2604

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2606
2607
2608
# File 'lib/models/porcelain.rb', line 2606

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2608
2609
2610
# File 'lib/models/porcelain.rb', line 2608

def name
  @name
end

#passwordObject

The password to authenticate with.



2610
2611
2612
# File 'lib/models/porcelain.rb', line 2610

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2612
2613
2614
# File 'lib/models/porcelain.rb', line 2612

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



2614
2615
2616
# File 'lib/models/porcelain.rb', line 2614

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



2616
2617
2618
# File 'lib/models/porcelain.rb', line 2616

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2618
2619
2620
# File 'lib/models/porcelain.rb', line 2618

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



2620
2621
2622
# File 'lib/models/porcelain.rb', line 2620

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2622
2623
2624
# File 'lib/models/porcelain.rb', line 2622

def tags
  @tags
end

#use_services_alternateObject

If true, uses UseServicesAlternates directive for Aerospike connection



2624
2625
2626
# File 'lib/models/porcelain.rb', line 2624

def use_services_alternate
  @use_services_alternate
end

#usernameObject

The username to authenticate with.



2626
2627
2628
# File 'lib/models/porcelain.rb', line 2626

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2662
2663
2664
2665
2666
2667
2668
# File 'lib/models/porcelain.rb', line 2662

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end