Class: SDM::AmazonEKS

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKS



2707
2708
2709
2710
2711
2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
# File 'lib/models/porcelain.rb', line 2707

def initialize(
  access_key: nil,
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



2657
2658
2659
# File 'lib/models/porcelain.rb', line 2657

def access_key
  @access_key
end

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



2660
2661
2662
# File 'lib/models/porcelain.rb', line 2660

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



2662
2663
2664
# File 'lib/models/porcelain.rb', line 2662

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



2664
2665
2666
# File 'lib/models/porcelain.rb', line 2664

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



2666
2667
2668
# File 'lib/models/porcelain.rb', line 2666

def cluster_name
  @cluster_name
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



2668
2669
2670
# File 'lib/models/porcelain.rb', line 2668

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



2671
2672
2673
# File 'lib/models/porcelain.rb', line 2671

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2673
2674
2675
# File 'lib/models/porcelain.rb', line 2673

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



2675
2676
2677
# File 'lib/models/porcelain.rb', line 2675

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



2677
2678
2679
# File 'lib/models/porcelain.rb', line 2677

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2679
2680
2681
# File 'lib/models/porcelain.rb', line 2679

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2681
2682
2683
# File 'lib/models/porcelain.rb', line 2681

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



2683
2684
2685
# File 'lib/models/porcelain.rb', line 2683

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



2685
2686
2687
# File 'lib/models/porcelain.rb', line 2685

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



2687
2688
2689
# File 'lib/models/porcelain.rb', line 2687

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



2689
2690
2691
# File 'lib/models/porcelain.rb', line 2689

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



2691
2692
2693
# File 'lib/models/porcelain.rb', line 2691

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



2693
2694
2695
# File 'lib/models/porcelain.rb', line 2693

def region
  @region
end

#role_arnObject

The role to assume after logging in.



2695
2696
2697
# File 'lib/models/porcelain.rb', line 2695

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2697
2698
2699
# File 'lib/models/porcelain.rb', line 2697

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



2699
2700
2701
# File 'lib/models/porcelain.rb', line 2699

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2701
2702
2703
# File 'lib/models/porcelain.rb', line 2701

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



2703
2704
2705
# File 'lib/models/porcelain.rb', line 2703

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2705
2706
2707
# File 'lib/models/porcelain.rb', line 2705

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2759
2760
2761
2762
2763
2764
2765
# File 'lib/models/porcelain.rb', line 2759

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end