Class: SDM::AmazonEKSInstanceProfile

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfile

Returns a new instance of AmazonEKSInstanceProfile.



2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
# File 'lib/models/porcelain.rb', line 2836

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypass ⇒ Object

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



2791
2792
2793
# File 'lib/models/porcelain.rb', line 2791

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



2793
2794
2795
# File 'lib/models/porcelain.rb', line 2793

def bind_interface
  @bind_interface
end

#certificate_authority ⇒ Object

The CA to authenticate TLS connections with.



2795
2796
2797
# File 'lib/models/porcelain.rb', line 2795

def certificate_authority
  @certificate_authority
end

#cluster_name ⇒ Object

The name of the cluster to connect to.



2797
2798
2799
# File 'lib/models/porcelain.rb', line 2797

def cluster_name
  @cluster_name
end

#discovery_enabled ⇒ Object

If true, configures discovery of a cluster to be run from a node.



2799
2800
2801
# File 'lib/models/porcelain.rb', line 2799

def discovery_enabled
  @discovery_enabled
end

#discovery_username ⇒ Object

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



2802
2803
2804
# File 'lib/models/porcelain.rb', line 2802

def discovery_username
  @discovery_username
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



2804
2805
2806
# File 'lib/models/porcelain.rb', line 2804

def egress_filter
  @egress_filter
end

#endpoint ⇒ Object

The endpoint to dial.



2806
2807
2808
# File 'lib/models/porcelain.rb', line 2806

def endpoint
  @endpoint
end

#healthcheck_namespace ⇒ Object

The path used to check the health of your connection. Defaults to default.



2808
2809
2810
# File 'lib/models/porcelain.rb', line 2808

def healthcheck_namespace
  @healthcheck_namespace
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



2810
2811
2812
# File 'lib/models/porcelain.rb', line 2810

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



2812
2813
2814
# File 'lib/models/porcelain.rb', line 2812

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



2814
2815
2816
# File 'lib/models/porcelain.rb', line 2814

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



2816
2817
2818
# File 'lib/models/porcelain.rb', line 2816

def identity_set_id
  @identity_set_id
end

#name ⇒ Object

Unique human-readable name of the Resource.



2818
2819
2820
# File 'lib/models/porcelain.rb', line 2818

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



2820
2821
2822
# File 'lib/models/porcelain.rb', line 2820

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



2822
2823
2824
# File 'lib/models/porcelain.rb', line 2822

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to connect to e.g. us-east-1.



2824
2825
2826
# File 'lib/models/porcelain.rb', line 2824

def region
  @region
end

#role_arn ⇒ Object

The role to assume after logging in.



2826
2827
2828
# File 'lib/models/porcelain.rb', line 2826

def role_arn
  @role_arn
end

#role_external_id ⇒ Object

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2828
2829
2830
# File 'lib/models/porcelain.rb', line 2828

def role_external_id
  @role_external_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



2830
2831
2832
# File 'lib/models/porcelain.rb', line 2830

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



2832
2833
2834
# File 'lib/models/porcelain.rb', line 2832

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



2834
2835
2836
# File 'lib/models/porcelain.rb', line 2834

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2884
2885
2886
2887
2888
2889
2890
# File 'lib/models/porcelain.rb', line 2884

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end