Class: SDM::AmazonES

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonES

Returns a new instance of AmazonES.



3103
3104
3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
# File 'lib/models/porcelain.rb', line 3103

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_key ⇒ Object

The Access Key ID to use to authenticate.



3071
3072
3073
# File 'lib/models/porcelain.rb', line 3071

def access_key
  @access_key
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



3073
3074
3075
# File 'lib/models/porcelain.rb', line 3073

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



3075
3076
3077
# File 'lib/models/porcelain.rb', line 3075

def egress_filter
  @egress_filter
end

#endpoint ⇒ Object

The endpoint to dial e.g. search-?.region.es.amazonaws.com"



3077
3078
3079
# File 'lib/models/porcelain.rb', line 3077

def endpoint
  @endpoint
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



3079
3080
3081
# File 'lib/models/porcelain.rb', line 3079

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



3081
3082
3083
# File 'lib/models/porcelain.rb', line 3081

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



3083
3084
3085
# File 'lib/models/porcelain.rb', line 3083

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



3085
3086
3087
# File 'lib/models/porcelain.rb', line 3085

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



3087
3088
3089
# File 'lib/models/porcelain.rb', line 3087

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to connect to e.g. us-east-1.



3089
3090
3091
# File 'lib/models/porcelain.rb', line 3089

def region
  @region
end

#role_arn ⇒ Object

The role to assume after logging in.



3091
3092
3093
# File 'lib/models/porcelain.rb', line 3091

def role_arn
  @role_arn
end

#role_external_id ⇒ Object

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



3093
3094
3095
# File 'lib/models/porcelain.rb', line 3093

def role_external_id
  @role_external_id
end

#secret_access_key ⇒ Object

The Secret Access Key to use to authenticate.



3095
3096
3097
# File 'lib/models/porcelain.rb', line 3095

def secret_access_key
  @secret_access_key
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



3097
3098
3099
# File 'lib/models/porcelain.rb', line 3097

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



3099
3100
3101
# File 'lib/models/porcelain.rb', line 3099

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



3101
3102
3103
# File 'lib/models/porcelain.rb', line 3101

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3139
3140
3141
3142
3143
3144
3145
# File 'lib/models/porcelain.rb', line 3139

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end