Class: SDM::ApprovalFlowStep

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

An approval step for an approval workflow. Specifies approvers and conditions for approval to be granted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(approvers: nil, quantifier: nil, skip_after: nil) ⇒ ApprovalFlowStep

Returns a new instance of ApprovalFlowStep.



3336
3337
3338
3339
3340
3341
3342
3343
3344
# File 'lib/models/porcelain.rb', line 3336

def initialize(
  approvers: nil,
  quantifier: nil,
  skip_after: nil
)
  @approvers = approvers == nil ? [] : approvers
  @quantifier = quantifier == nil ? "" : quantifier
  @skip_after = skip_after == nil ? nil : skip_after
end

Instance Attribute Details

#approversObject

The approvers for this approval step



3330
3331
3332
# File 'lib/models/porcelain.rb', line 3330

def approvers
  @approvers
end

#quantifierObject

Whether "any" or "all" approvers must approve for this approval step to pass. Optional, defaults to "any".



3332
3333
3334
# File 'lib/models/porcelain.rb', line 3332

def quantifier
  @quantifier
end

#skip_afterObject

Duration after which this approval step will be skipped if no approval is given. Optional, if not provided an approver must approve before the step passes.



3334
3335
3336
# File 'lib/models/porcelain.rb', line 3334

def skip_after
  @skip_after
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3346
3347
3348
3349
3350
3351
3352
# File 'lib/models/porcelain.rb', line 3346

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end