Class: SDM::ApprovalWorkflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized approvers and be approved or denied.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(approval_mode: nil, approval_workflow_steps: nil, description: nil, id: nil, name: nil) ⇒ ApprovalWorkflow

Returns a new instance of ApprovalWorkflow.



3369
3370
3371
3372
3373
3374
3375
3376
3377
3378
3379
3380
3381
# File 'lib/models/porcelain.rb', line 3369

def initialize(
  approval_mode: nil,
  approval_workflow_steps: nil,
  description: nil,
  id: nil,
  name: nil
)
  @approval_mode = approval_mode == nil ? "" : approval_mode
  @approval_workflow_steps = approval_workflow_steps == nil ? [] : approval_workflow_steps
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
end

Instance Attribute Details

#approval_modeObject

Approval mode of the ApprovalWorkflow



3359
3360
3361
# File 'lib/models/porcelain.rb', line 3359

def approval_mode
  @approval_mode
end

#approval_workflow_stepsObject

The approval steps of this approval workflow



3361
3362
3363
# File 'lib/models/porcelain.rb', line 3361

def approval_workflow_steps
  @approval_workflow_steps
end

#descriptionObject

Optional description of the ApprovalWorkflow.



3363
3364
3365
# File 'lib/models/porcelain.rb', line 3363

def description
  @description
end

#idObject

Unique identifier of the ApprovalWorkflow.



3365
3366
3367
# File 'lib/models/porcelain.rb', line 3365

def id
  @id
end

#nameObject

Unique human-readable name of the ApprovalWorkflow.



3367
3368
3369
# File 'lib/models/porcelain.rb', line 3367

def name
  @name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3383
3384
3385
3386
3387
3388
3389
# File 'lib/models/porcelain.rb', line 3383

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end