Class: SDM::ApprovalWorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowApprover links an approval workflow approver to an ApprovalWorkflowStep ApprovalWorkflowApprover is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, approval_flow_id: nil, approval_step_id: nil, id: nil, reference: nil, role_id: nil) ⇒ ApprovalWorkflowApprover

Returns a new instance of ApprovalWorkflowApprover.



3414
3415
3416
3417
3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
3428
# File 'lib/models/porcelain.rb', line 3414

def initialize(
  account_id: nil,
  approval_flow_id: nil,
  approval_step_id: nil,
  id: nil,
  reference: nil,
  role_id: nil
)
  @account_id =  == nil ? "" : 
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @approval_step_id = approval_step_id == nil ? "" : approval_step_id
  @id = id == nil ? "" : id
  @reference = reference == nil ? "" : reference
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#account_id ⇒ Object

The approver account id.



3400
3401
3402
# File 'lib/models/porcelain.rb', line 3400

def 
  @account_id
end

#approval_flow_id ⇒ Object

The approval flow id specified the approval workflow that this approver belongs to



3402
3403
3404
# File 'lib/models/porcelain.rb', line 3402

def approval_flow_id
  @approval_flow_id
end

#approval_step_id ⇒ Object

The approval step id specified the approval flow step that this approver belongs to



3404
3405
3406
# File 'lib/models/porcelain.rb', line 3404

def approval_step_id
  @approval_step_id
end

#id ⇒ Object

Unique identifier of the ApprovalWorkflowApprover.



3406
3407
3408
# File 'lib/models/porcelain.rb', line 3406

def id
  @id
end

#reference ⇒ Object

A reference to an approver. Will be one of ApproverReference constants. This field is only populated when reading historical Approval Workflow Approvers data through the Approval Workflows History API. For the deprecated Approval Workflow Approvers API no value is returned for this field and it is non-settable.



3410
3411
3412
# File 'lib/models/porcelain.rb', line 3410

def reference
  @reference
end

#role_id ⇒ Object

The approver role id



3412
3413
3414
# File 'lib/models/porcelain.rb', line 3412

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3430
3431
3432
3433
3434
3435
3436
# File 'lib/models/porcelain.rb', line 3430

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end