Class: SDM::ApprovalWorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowApproverHistory records the state of an ApprovalWorkflowApprover at a given point in time, where every change (create or delete) to an ApprovalWorkflowApprover produces an ApprovalWorkflowApproverHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, approval_workflow_approver: nil, deleted_at: nil, timestamp: nil) ⇒ ApprovalWorkflowApproverHistory



3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
# File 'lib/models/porcelain.rb', line 3509

def initialize(
  activity_id: nil,
  approval_workflow_approver: nil,
  deleted_at: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @approval_workflow_approver = approval_workflow_approver == nil ? nil : approval_workflow_approver
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the ApprovalWorkflowApprover. May be empty for some system-initiated updates.



3501
3502
3503
# File 'lib/models/porcelain.rb', line 3501

def activity_id
  @activity_id
end

#approval_workflow_approverObject

The complete ApprovalWorkflowApprover state at this time.



3503
3504
3505
# File 'lib/models/porcelain.rb', line 3503

def approval_workflow_approver
  @approval_workflow_approver
end

#deleted_atObject

If this ApprovalWorkflowApprover was deleted, the time it was deleted.



3505
3506
3507
# File 'lib/models/porcelain.rb', line 3505

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the ApprovalWorkflowApprover state was recorded.



3507
3508
3509
# File 'lib/models/porcelain.rb', line 3507

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3521
3522
3523
3524
3525
3526
3527
# File 'lib/models/porcelain.rb', line 3521

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end