Class: SDM::ApprovalWorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowHistory records the state of an ApprovalWorkflow at a given point in time, where every change (create, update and delete) to an ApprovalWorkflow produces an ApprovalWorkflowHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, approval_workflow: nil, deleted_at: nil, timestamp: nil) ⇒ ApprovalWorkflowHistory

Returns a new instance of ApprovalWorkflowHistory.



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
# File 'lib/models/porcelain.rb', line 2865

def initialize(
  activity_id: nil,
  approval_workflow: nil,
  deleted_at: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @approval_workflow = approval_workflow == nil ? nil : approval_workflow
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the ApprovalWorkflow. May be empty for some system-initiated updates.



2857
2858
2859
# File 'lib/models/porcelain.rb', line 2857

def activity_id
  @activity_id
end

#approval_workflowObject

The complete ApprovalWorkflow state at this time.



2859
2860
2861
# File 'lib/models/porcelain.rb', line 2859

def approval_workflow
  @approval_workflow
end

#deleted_atObject

If this ApprovalWorkflow was deleted, the time it was deleted.



2861
2862
2863
# File 'lib/models/porcelain.rb', line 2861

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the ApprovalWorkflow state was recorded.



2863
2864
2865
# File 'lib/models/porcelain.rb', line 2863

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2877
2878
2879
2880
2881
2882
2883
# File 'lib/models/porcelain.rb', line 2877

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end