Class: SDM::ApprovalWorkflowStep
- Inherits:
-
Object
- Object
- SDM::ApprovalWorkflowStep
- Defined in:
- lib/models/porcelain.rb
Overview
ApprovalWorkflowStep links an approval workflow step to an ApprovalWorkflow ApprovalWorkflowStep is deprecated, see docs for more info.
Instance Attribute Summary collapse
-
#approval_flow_id ⇒ Object
The approval flow id specified the approval workflow that this step belongs to.
-
#id ⇒ Object
Unique identifier of the ApprovalWorkflowStep.
-
#quantifier ⇒ Object
Whether "any" or "all" approvers must approve for this approval step to pass.
-
#skip_after ⇒ Object
Duration after which this approval step will be skipped if no approval is given.
-
#step_order ⇒ Object
The position of the approval step in a sequence of approval steps for an approval workflow.
Instance Method Summary collapse
-
#initialize(approval_flow_id: nil, id: nil, quantifier: nil, skip_after: nil, step_order: nil) ⇒ ApprovalWorkflowStep
constructor
A new instance of ApprovalWorkflowStep.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(approval_flow_id: nil, id: nil, quantifier: nil, skip_after: nil, step_order: nil) ⇒ ApprovalWorkflowStep
Returns a new instance of ApprovalWorkflowStep.
3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 |
# File 'lib/models/porcelain.rb', line 3713 def initialize( approval_flow_id: nil, id: nil, quantifier: nil, skip_after: nil, step_order: nil ) @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id @id = id == nil ? "" : id @quantifier = quantifier == nil ? "" : quantifier @skip_after = skip_after == nil ? nil : skip_after @step_order = step_order == nil ? 0 : step_order end |
Instance Attribute Details
#approval_flow_id ⇒ Object
The approval flow id specified the approval workflow that this step belongs to
3703 3704 3705 |
# File 'lib/models/porcelain.rb', line 3703 def approval_flow_id @approval_flow_id end |
#id ⇒ Object
Unique identifier of the ApprovalWorkflowStep.
3705 3706 3707 |
# File 'lib/models/porcelain.rb', line 3705 def id @id end |
#quantifier ⇒ Object
Whether "any" or "all" approvers must approve for this approval step to pass. Read only field for history commands.
3707 3708 3709 |
# File 'lib/models/porcelain.rb', line 3707 def quantifier @quantifier end |
#skip_after ⇒ Object
Duration after which this approval step will be skipped if no approval is given. Read only field for history commands.
3709 3710 3711 |
# File 'lib/models/porcelain.rb', line 3709 def skip_after @skip_after end |
#step_order ⇒ Object
The position of the approval step in a sequence of approval steps for an approval workflow. Read only field for history commands.
3711 3712 3713 |
# File 'lib/models/porcelain.rb', line 3711 def step_order @step_order end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3727 3728 3729 3730 3731 3732 3733 |
# File 'lib/models/porcelain.rb', line 3727 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |