Class: SDM::ApprovalWorkflowStepHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowStepHistory records the state of an ApprovalWorkflowStep at a given point in time, where every change (create or delete) to an ApprovalWorkflowStep produces an ApprovalWorkflowStepHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, approval_workflow_step: nil, deleted_at: nil, timestamp: nil) ⇒ ApprovalWorkflowStepHistory

Returns a new instance of ApprovalWorkflowStepHistory.



3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
3821
# File 'lib/models/porcelain.rb', line 3811

def initialize(
  activity_id: nil,
  approval_workflow_step: nil,
  deleted_at: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @approval_workflow_step = approval_workflow_step == nil ? nil : approval_workflow_step
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the ApprovalWorkflowStep. May be empty for some system-initiated updates.



3803
3804
3805
# File 'lib/models/porcelain.rb', line 3803

def activity_id
  @activity_id
end

#approval_workflow_stepObject

The complete ApprovalWorkflowStep state at this time.



3805
3806
3807
# File 'lib/models/porcelain.rb', line 3805

def approval_workflow_step
  @approval_workflow_step
end

#deleted_atObject

If this ApprovalWorkflowStep was deleted, the time it was deleted.



3807
3808
3809
# File 'lib/models/porcelain.rb', line 3807

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the ApprovalWorkflowStep state was recorded.



3809
3810
3811
# File 'lib/models/porcelain.rb', line 3809

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3823
3824
3825
3826
3827
3828
3829
# File 'lib/models/porcelain.rb', line 3823

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end