Class: SDM::AuroraPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres

Returns a new instance of AuroraPostgres.



4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
# File 'lib/models/porcelain.rb', line 4239

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4207
4208
4209
# File 'lib/models/porcelain.rb', line 4207

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4209
4210
4211
# File 'lib/models/porcelain.rb', line 4209

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4211
4212
4213
# File 'lib/models/porcelain.rb', line 4211

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4213
4214
4215
# File 'lib/models/porcelain.rb', line 4213

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4215
4216
4217
# File 'lib/models/porcelain.rb', line 4215

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4217
4218
4219
# File 'lib/models/porcelain.rb', line 4217

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4219
4220
4221
# File 'lib/models/porcelain.rb', line 4219

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4221
4222
4223
# File 'lib/models/porcelain.rb', line 4221

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4223
4224
4225
# File 'lib/models/porcelain.rb', line 4223

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4225
4226
4227
# File 'lib/models/porcelain.rb', line 4225

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4227
4228
4229
# File 'lib/models/porcelain.rb', line 4227

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4229
4230
4231
# File 'lib/models/porcelain.rb', line 4229

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4231
4232
4233
# File 'lib/models/porcelain.rb', line 4231

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4233
4234
4235
# File 'lib/models/porcelain.rb', line 4233

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4235
4236
4237
# File 'lib/models/porcelain.rb', line 4235

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4237
4238
4239
# File 'lib/models/porcelain.rb', line 4237

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4275
4276
4277
4278
4279
4280
4281
# File 'lib/models/porcelain.rb', line 4275

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end