Class: SDM::AuroraPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgresIAM

Returns a new instance of AuroraPostgresIAM.



4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
4358
4359
4360
# File 'lib/models/porcelain.rb', line 4324

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4290
4291
4292
# File 'lib/models/porcelain.rb', line 4290

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4292
4293
4294
# File 'lib/models/porcelain.rb', line 4292

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



4294
4295
4296
# File 'lib/models/porcelain.rb', line 4294

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



4296
4297
4298
# File 'lib/models/porcelain.rb', line 4296

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



4298
4299
4300
# File 'lib/models/porcelain.rb', line 4298

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



4300
4301
4302
# File 'lib/models/porcelain.rb', line 4300

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



4302
4303
4304
# File 'lib/models/porcelain.rb', line 4302

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4304
4305
4306
# File 'lib/models/porcelain.rb', line 4304

def override_database
  @override_database
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



4306
4307
4308
# File 'lib/models/porcelain.rb', line 4306

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4308
4309
4310
# File 'lib/models/porcelain.rb', line 4308

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



4310
4311
4312
# File 'lib/models/porcelain.rb', line 4310

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to connect to.



4312
4313
4314
# File 'lib/models/porcelain.rb', line 4312

def region
  @region
end

#role_assumption_arn ⇒ Object

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



4314
4315
4316
# File 'lib/models/porcelain.rb', line 4314

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



4316
4317
4318
# File 'lib/models/porcelain.rb', line 4316

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4318
4319
4320
# File 'lib/models/porcelain.rb', line 4318

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



4320
4321
4322
# File 'lib/models/porcelain.rb', line 4320

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



4322
4323
4324
# File 'lib/models/porcelain.rb', line 4322

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4362
4363
4364
4365
4366
4367
4368
# File 'lib/models/porcelain.rb', line 4362

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end