Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
4415
# File 'lib/models/porcelain.rb', line 4387

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



4361
4362
4363
# File 'lib/models/porcelain.rb', line 4361

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4363
4364
4365
# File 'lib/models/porcelain.rb', line 4363

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4365
4366
4367
# File 'lib/models/porcelain.rb', line 4365

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4367
4368
4369
# File 'lib/models/porcelain.rb', line 4367

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4369
4370
4371
# File 'lib/models/porcelain.rb', line 4369

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4371
4372
4373
# File 'lib/models/porcelain.rb', line 4371

def name
  @name
end

#passwordObject

The password to authenticate with.



4373
4374
4375
# File 'lib/models/porcelain.rb', line 4373

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4375
4376
4377
# File 'lib/models/porcelain.rb', line 4375

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4377
4378
4379
# File 'lib/models/porcelain.rb', line 4377

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4379
4380
4381
# File 'lib/models/porcelain.rb', line 4379

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4381
4382
4383
# File 'lib/models/porcelain.rb', line 4381

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4383
4384
4385
# File 'lib/models/porcelain.rb', line 4383

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



4385
4386
4387
# File 'lib/models/porcelain.rb', line 4385

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4417
4418
4419
4420
4421
4422
4423
# File 'lib/models/porcelain.rb', line 4417

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end