Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



4466
4467
4468
4469
4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
4481
4482
4483
4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
# File 'lib/models/porcelain.rb', line 4466

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_id ⇒ Object

The application ID to authenticate with.



4440
4441
4442
# File 'lib/models/porcelain.rb', line 4440

def app_id
  @app_id
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4442
4443
4444
# File 'lib/models/porcelain.rb', line 4442

def bind_interface
  @bind_interface
end

#client_certificate ⇒ Object

The service Principal certificate file, both private and public key included.



4444
4445
4446
# File 'lib/models/porcelain.rb', line 4444

def client_certificate
  @client_certificate
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



4446
4447
4448
# File 'lib/models/porcelain.rb', line 4446

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



4448
4449
4450
# File 'lib/models/porcelain.rb', line 4448

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



4450
4451
4452
# File 'lib/models/porcelain.rb', line 4450

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



4452
4453
4454
# File 'lib/models/porcelain.rb', line 4452

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4454
4455
4456
# File 'lib/models/porcelain.rb', line 4454

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



4456
4457
4458
# File 'lib/models/porcelain.rb', line 4456

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



4458
4459
4460
# File 'lib/models/porcelain.rb', line 4458

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4460
4461
4462
# File 'lib/models/porcelain.rb', line 4460

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



4462
4463
4464
# File 'lib/models/porcelain.rb', line 4462

def tags
  @tags
end

#tenant_id ⇒ Object

The tenant ID to authenticate to.



4464
4465
4466
# File 'lib/models/porcelain.rb', line 4464

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4496
4497
4498
4499
4500
4501
4502
# File 'lib/models/porcelain.rb', line 4496

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end