Class: SDM::AzureConnector

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_id: nil, description: nil, exclude_tags: nil, id: nil, include_tags: nil, name: nil, scan_period: nil, services: nil, subscription_ids: nil, tenant_id: nil) ⇒ AzureConnector

Returns a new instance of AzureConnector.



4525
4526
4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
# File 'lib/models/porcelain.rb', line 4525

def initialize(
  client_id: nil,
  description: nil,
  exclude_tags: nil,
  id: nil,
  include_tags: nil,
  name: nil,
  scan_period: nil,
  services: nil,
  subscription_ids: nil,
  tenant_id: nil
)
  @client_id = client_id == nil ? "" : client_id
  @description = description == nil ? "" : description
  @exclude_tags = exclude_tags == nil ? [] : exclude_tags
  @id = id == nil ? "" : id
  @include_tags = include_tags == nil ? [] : include_tags
  @name = name == nil ? "" : name
  @scan_period = scan_period == nil ? "" : scan_period
  @services = services == nil ? [] : services
  @subscription_ids = subscription_ids == nil ? [] : subscription_ids
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#client_idObject

ClientId is the ID of the Application / Service Account we're acting as



4503
4504
4505
# File 'lib/models/porcelain.rb', line 4503

def client_id
  @client_id
end

#descriptionObject

Description of the Connector.



4505
4506
4507
# File 'lib/models/porcelain.rb', line 4505

def description
  @description
end

#exclude_tagsObject

ExcludeTags filters out discovered resources that have the tag and value. We do allow duplicate tag names for ExcludeTags to support multiple excluded values for the tag.



4508
4509
4510
# File 'lib/models/porcelain.rb', line 4508

def exclude_tags
  @exclude_tags
end

#idObject

Unique identifier of the Connector.



4510
4511
4512
# File 'lib/models/porcelain.rb', line 4510

def id
  @id
end

#include_tagsObject

IncludeTags only discovers cloud resources that have one of the included tags. We do not allow duplicate tag names for IncludeTags



4513
4514
4515
# File 'lib/models/porcelain.rb', line 4513

def include_tags
  @include_tags
end

#nameObject

Unique human-readable name of the Connector.



4515
4516
4517
# File 'lib/models/porcelain.rb', line 4515

def name
  @name
end

#scan_periodObject

ScanPeriod identifies which remote system this Connector discovers



4517
4518
4519
# File 'lib/models/porcelain.rb', line 4517

def scan_period
  @scan_period
end

#servicesObject

Services is a list of services this connector should scan.



4519
4520
4521
# File 'lib/models/porcelain.rb', line 4519

def services
  @services
end

#subscription_idsObject

SubscriptionIds are the targets of discovery.



4521
4522
4523
# File 'lib/models/porcelain.rb', line 4521

def subscription_ids
  @subscription_ids
end

#tenant_idObject

TenantId is the Azure Tenant we're discovering in



4523
4524
4525
# File 'lib/models/porcelain.rb', line 4523

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4549
4550
4551
4552
4553
4554
4555
# File 'lib/models/porcelain.rb', line 4549

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end