Class: SDM::AzureMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzureMysql

Returns a new instance of AzureMysql.



4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
4615
# File 'lib/models/porcelain.rb', line 4579

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4545
4546
4547
# File 'lib/models/porcelain.rb', line 4545

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



4547
4548
4549
# File 'lib/models/porcelain.rb', line 4547

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4549
4550
4551
# File 'lib/models/porcelain.rb', line 4549

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4551
4552
4553
# File 'lib/models/porcelain.rb', line 4551

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4553
4554
4555
# File 'lib/models/porcelain.rb', line 4553

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4555
4556
4557
# File 'lib/models/porcelain.rb', line 4555

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4557
4558
4559
# File 'lib/models/porcelain.rb', line 4557

def name
  @name
end

#passwordObject

The password to authenticate with.



4559
4560
4561
# File 'lib/models/porcelain.rb', line 4559

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4561
4562
4563
# File 'lib/models/porcelain.rb', line 4561

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4563
4564
4565
# File 'lib/models/porcelain.rb', line 4563

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4565
4566
4567
# File 'lib/models/porcelain.rb', line 4565

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



4567
4568
4569
# File 'lib/models/porcelain.rb', line 4567

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4569
4570
4571
# File 'lib/models/porcelain.rb', line 4569

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4571
4572
4573
# File 'lib/models/porcelain.rb', line 4571

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4573
4574
4575
# File 'lib/models/porcelain.rb', line 4573

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4575
4576
4577
# File 'lib/models/porcelain.rb', line 4575

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4577
4578
4579
# File 'lib/models/porcelain.rb', line 4577

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4617
4618
4619
4620
4621
4622
4623
# File 'lib/models/porcelain.rb', line 4617

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end