Class: SDM::AzurePostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres

Returns a new instance of AzurePostgres.



4754
4755
4756
4757
4758
4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
# File 'lib/models/porcelain.rb', line 4754

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4722
4723
4724
# File 'lib/models/porcelain.rb', line 4722

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4724
4725
4726
# File 'lib/models/porcelain.rb', line 4724

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4726
4727
4728
# File 'lib/models/porcelain.rb', line 4726

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4728
4729
4730
# File 'lib/models/porcelain.rb', line 4728

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4730
4731
4732
# File 'lib/models/porcelain.rb', line 4730

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4732
4733
4734
# File 'lib/models/porcelain.rb', line 4732

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4734
4735
4736
# File 'lib/models/porcelain.rb', line 4734

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4736
4737
4738
# File 'lib/models/porcelain.rb', line 4736

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4738
4739
4740
# File 'lib/models/porcelain.rb', line 4738

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4740
4741
4742
# File 'lib/models/porcelain.rb', line 4740

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4742
4743
4744
# File 'lib/models/porcelain.rb', line 4742

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4744
4745
4746
# File 'lib/models/porcelain.rb', line 4744

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4746
4747
4748
# File 'lib/models/porcelain.rb', line 4746

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4748
4749
4750
# File 'lib/models/porcelain.rb', line 4748

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4750
4751
4752
# File 'lib/models/porcelain.rb', line 4750

def tags
  @tags
end

#usernameObject

The username to authenticate with. For Azure Postgres, this also will include the hostname of the target server for Azure Single Server compatibility. For Flexible servers, use the normal Postgres type.



4752
4753
4754
# File 'lib/models/porcelain.rb', line 4752

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4790
4791
4792
4793
4794
4795
4796
# File 'lib/models/porcelain.rb', line 4790

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end