Class: SDM::AzurePostgresManagedIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzurePostgresManagedIdentity



4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/models/porcelain.rb', line 4827

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4793
4794
4795
# File 'lib/models/porcelain.rb', line 4793

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4795
4796
4797
# File 'lib/models/porcelain.rb', line 4795

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4797
4798
4799
# File 'lib/models/porcelain.rb', line 4797

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4799
4800
4801
# File 'lib/models/porcelain.rb', line 4799

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4801
4802
4803
# File 'lib/models/porcelain.rb', line 4801

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4803
4804
4805
# File 'lib/models/porcelain.rb', line 4803

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4805
4806
4807
# File 'lib/models/porcelain.rb', line 4805

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4807
4808
4809
# File 'lib/models/porcelain.rb', line 4807

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4809
4810
4811
# File 'lib/models/porcelain.rb', line 4809

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4811
4812
4813
# File 'lib/models/porcelain.rb', line 4811

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4813
4814
4815
# File 'lib/models/porcelain.rb', line 4813

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4815
4816
4817
# File 'lib/models/porcelain.rb', line 4815

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4817
4818
4819
# File 'lib/models/porcelain.rb', line 4817

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4819
4820
4821
# File 'lib/models/porcelain.rb', line 4819

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4821
4822
4823
# File 'lib/models/porcelain.rb', line 4821

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4823
4824
4825
# File 'lib/models/porcelain.rb', line 4823

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4825
4826
4827
# File 'lib/models/porcelain.rb', line 4825

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4865
4866
4867
4868
4869
4870
4871
# File 'lib/models/porcelain.rb', line 4865

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end