Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery



4935
4936
4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
# File 'lib/models/porcelain.rb', line 4935

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4907
4908
4909
# File 'lib/models/porcelain.rb', line 4907

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4909
4910
4911
# File 'lib/models/porcelain.rb', line 4909

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



4911
4912
4913
# File 'lib/models/porcelain.rb', line 4911

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4913
4914
4915
# File 'lib/models/porcelain.rb', line 4913

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4915
4916
4917
# File 'lib/models/porcelain.rb', line 4915

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4917
4918
4919
# File 'lib/models/porcelain.rb', line 4917

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4919
4920
4921
# File 'lib/models/porcelain.rb', line 4919

def port_override
  @port_override
end

#private_keyObject

The JSON Private key to authenticate with.



4921
4922
4923
# File 'lib/models/porcelain.rb', line 4921

def private_key
  @private_key
end

#projectObject

The project to connect to.



4923
4924
4925
# File 'lib/models/porcelain.rb', line 4923

def project
  @project
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4925
4926
4927
# File 'lib/models/porcelain.rb', line 4925

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4927
4928
4929
# File 'lib/models/porcelain.rb', line 4927

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4929
4930
4931
# File 'lib/models/porcelain.rb', line 4929

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4931
4932
4933
# File 'lib/models/porcelain.rb', line 4931

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4933
4934
4935
# File 'lib/models/porcelain.rb', line 4933

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4967
4968
4969
4970
4971
4972
4973
# File 'lib/models/porcelain.rb', line 4967

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end