Class: SDM::ClickHouseMySQL

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ ClickHouseMySQL

Returns a new instance of ClickHouseMySQL.



5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
# File 'lib/models/porcelain.rb', line 5239

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



5207
5208
5209
# File 'lib/models/porcelain.rb', line 5207

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



5209
5210
5211
# File 'lib/models/porcelain.rb', line 5209

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5211
5212
5213
# File 'lib/models/porcelain.rb', line 5211

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5213
5214
5215
# File 'lib/models/porcelain.rb', line 5213

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5215
5216
5217
# File 'lib/models/porcelain.rb', line 5215

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5217
5218
5219
# File 'lib/models/porcelain.rb', line 5217

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5219
5220
5221
# File 'lib/models/porcelain.rb', line 5219

def name
  @name
end

#passwordObject

The password to authenticate with.



5221
5222
5223
# File 'lib/models/porcelain.rb', line 5221

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5223
5224
5225
# File 'lib/models/porcelain.rb', line 5223

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



5225
5226
5227
# File 'lib/models/porcelain.rb', line 5225

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5227
5228
5229
# File 'lib/models/porcelain.rb', line 5227

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



5229
5230
5231
# File 'lib/models/porcelain.rb', line 5229

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5231
5232
5233
# File 'lib/models/porcelain.rb', line 5231

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



5233
5234
5235
# File 'lib/models/porcelain.rb', line 5233

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5235
5236
5237
# File 'lib/models/porcelain.rb', line 5235

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5237
5238
5239
# File 'lib/models/porcelain.rb', line 5237

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5275
5276
5277
5278
5279
5280
5281
# File 'lib/models/porcelain.rb', line 5275

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end