Class: SDM::ClickHouseTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ClickHouseTCP

Returns a new instance of ClickHouseTCP.



5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
# File 'lib/models/porcelain.rb', line 5318

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



5286
5287
5288
# File 'lib/models/porcelain.rb', line 5286

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



5288
5289
5290
# File 'lib/models/porcelain.rb', line 5288

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5290
5291
5292
# File 'lib/models/porcelain.rb', line 5290

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5292
5293
5294
# File 'lib/models/porcelain.rb', line 5292

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5294
5295
5296
# File 'lib/models/porcelain.rb', line 5294

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5296
5297
5298
# File 'lib/models/porcelain.rb', line 5296

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5298
5299
5300
# File 'lib/models/porcelain.rb', line 5298

def name
  @name
end

#passwordObject

The password to authenticate with.



5300
5301
5302
# File 'lib/models/porcelain.rb', line 5300

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5302
5303
5304
# File 'lib/models/porcelain.rb', line 5302

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



5304
5305
5306
# File 'lib/models/porcelain.rb', line 5304

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5306
5307
5308
# File 'lib/models/porcelain.rb', line 5306

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5308
5309
5310
# File 'lib/models/porcelain.rb', line 5308

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



5310
5311
5312
# File 'lib/models/porcelain.rb', line 5310

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5312
5313
5314
# File 'lib/models/porcelain.rb', line 5312

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5314
5315
5316
# File 'lib/models/porcelain.rb', line 5314

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5316
5317
5318
# File 'lib/models/porcelain.rb', line 5316

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5354
5355
5356
5357
5358
5359
5360
# File 'lib/models/porcelain.rb', line 5354

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end