Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



5411
5412
5413
5414
5415
5416
5417
5418
5419
5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
5438
5439
5440
5441
5442
5443
5444
5445
5446
5447
# File 'lib/models/porcelain.rb', line 5411

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



5377
5378
5379
# File 'lib/models/porcelain.rb', line 5377

def bind_interface
  @bind_interface
end

#database ⇒ Object

The database for healthchecks. Does not affect client requests.



5379
5380
5381
# File 'lib/models/porcelain.rb', line 5379

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



5381
5382
5383
# File 'lib/models/porcelain.rb', line 5381

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



5383
5384
5385
# File 'lib/models/porcelain.rb', line 5383

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



5385
5386
5387
# File 'lib/models/porcelain.rb', line 5385

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



5387
5388
5389
# File 'lib/models/porcelain.rb', line 5387

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



5389
5390
5391
# File 'lib/models/porcelain.rb', line 5389

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



5391
5392
5393
# File 'lib/models/porcelain.rb', line 5391

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



5393
5394
5395
# File 'lib/models/porcelain.rb', line 5393

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



5395
5396
5397
# File 'lib/models/porcelain.rb', line 5395

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



5397
5398
5399
# File 'lib/models/porcelain.rb', line 5397

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_auth ⇒ Object

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



5399
5400
5401
# File 'lib/models/porcelain.rb', line 5399

def require_native_auth
  @require_native_auth
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



5401
5402
5403
# File 'lib/models/porcelain.rb', line 5401

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



5403
5404
5405
# File 'lib/models/porcelain.rb', line 5403

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



5405
5406
5407
# File 'lib/models/porcelain.rb', line 5405

def tags
  @tags
end

#use_azure_single_server_usernames ⇒ Object

If true, appends the hostname to the username when hitting a database.azure.com address



5407
5408
5409
# File 'lib/models/porcelain.rb', line 5407

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#username ⇒ Object

The username to authenticate with.



5409
5410
5411
# File 'lib/models/porcelain.rb', line 5409

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5449
5450
5451
5452
5453
5454
5455
# File 'lib/models/porcelain.rb', line 5449

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end