Class: SDM::DB2I

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I

Returns a new instance of DB2I.



6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
6243
# File 'lib/models/porcelain.rb', line 6211

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6181
6182
6183
# File 'lib/models/porcelain.rb', line 6181

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6183
6184
6185
# File 'lib/models/porcelain.rb', line 6183

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6185
6186
6187
# File 'lib/models/porcelain.rb', line 6185

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6187
6188
6189
# File 'lib/models/porcelain.rb', line 6187

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6189
6190
6191
# File 'lib/models/porcelain.rb', line 6189

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6191
6192
6193
# File 'lib/models/porcelain.rb', line 6191

def name
  @name
end

#passwordObject

The password to authenticate with.



6193
6194
6195
# File 'lib/models/porcelain.rb', line 6193

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6195
6196
6197
# File 'lib/models/porcelain.rb', line 6195

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6197
6198
6199
# File 'lib/models/porcelain.rb', line 6197

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6199
6200
6201
# File 'lib/models/porcelain.rb', line 6199

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6201
6202
6203
# File 'lib/models/porcelain.rb', line 6201

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6203
6204
6205
# File 'lib/models/porcelain.rb', line 6203

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6205
6206
6207
# File 'lib/models/porcelain.rb', line 6205

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



6207
6208
6209
# File 'lib/models/porcelain.rb', line 6207

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



6209
6210
6211
# File 'lib/models/porcelain.rb', line 6209

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6245
6246
6247
6248
6249
6250
6251
# File 'lib/models/porcelain.rb', line 6245

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end