Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
6565
6566
6567
6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
6579
6580
# File 'lib/models/porcelain.rb', line 6548

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_database ⇒ Object

The authentication database to use.



6518
6519
6520
# File 'lib/models/porcelain.rb', line 6518

def auth_database
  @auth_database
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6520
6521
6522
# File 'lib/models/porcelain.rb', line 6520

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



6522
6523
6524
# File 'lib/models/porcelain.rb', line 6522

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



6524
6525
6526
# File 'lib/models/porcelain.rb', line 6524

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



6526
6527
6528
# File 'lib/models/porcelain.rb', line 6526

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



6528
6529
6530
# File 'lib/models/porcelain.rb', line 6528

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



6530
6531
6532
# File 'lib/models/porcelain.rb', line 6530

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



6532
6533
6534
# File 'lib/models/porcelain.rb', line 6532

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



6534
6535
6536
# File 'lib/models/porcelain.rb', line 6534

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6536
6537
6538
# File 'lib/models/porcelain.rb', line 6536

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



6538
6539
6540
# File 'lib/models/porcelain.rb', line 6538

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



6540
6541
6542
# File 'lib/models/porcelain.rb', line 6540

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6542
6543
6544
# File 'lib/models/porcelain.rb', line 6542

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



6544
6545
6546
# File 'lib/models/porcelain.rb', line 6544

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



6546
6547
6548
# File 'lib/models/porcelain.rb', line 6546

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6582
6583
6584
6585
6586
6587
6588
# File 'lib/models/porcelain.rb', line 6582

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end