Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



6613
6614
6615
6616
6617
6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
6639
6640
6641
6642
6643
6644
6645
# File 'lib/models/porcelain.rb', line 6613

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



6583
6584
6585
# File 'lib/models/porcelain.rb', line 6583

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6585
6586
6587
# File 'lib/models/porcelain.rb', line 6585

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



6587
6588
6589
# File 'lib/models/porcelain.rb', line 6587

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6589
6590
6591
# File 'lib/models/porcelain.rb', line 6589

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6591
6592
6593
# File 'lib/models/porcelain.rb', line 6591

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



6593
6594
6595
# File 'lib/models/porcelain.rb', line 6593

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6595
6596
6597
# File 'lib/models/porcelain.rb', line 6595

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6597
6598
6599
# File 'lib/models/porcelain.rb', line 6597

def name
  @name
end

#passwordObject

The password to authenticate with.



6599
6600
6601
# File 'lib/models/porcelain.rb', line 6599

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6601
6602
6603
# File 'lib/models/porcelain.rb', line 6601

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6603
6604
6605
# File 'lib/models/porcelain.rb', line 6603

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6605
6606
6607
# File 'lib/models/porcelain.rb', line 6605

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6607
6608
6609
# File 'lib/models/porcelain.rb', line 6607

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6609
6610
6611
# File 'lib/models/porcelain.rb', line 6609

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6611
6612
6613
# File 'lib/models/porcelain.rb', line 6611

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6647
6648
6649
6650
6651
6652
6653
# File 'lib/models/porcelain.rb', line 6647

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end