Class: SDM::DynamoDBIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM

Returns a new instance of DynamoDBIAM.



6981
6982
6983
6984
6985
6986
6987
6988
6989
6990
6991
6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
# File 'lib/models/porcelain.rb', line 6981

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6953
6954
6955
# File 'lib/models/porcelain.rb', line 6953

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



6955
6956
6957
# File 'lib/models/porcelain.rb', line 6955

def egress_filter
  @egress_filter
end

#endpoint ⇒ Object

The endpoint to dial e.g. dynamodb.region.amazonaws.com



6957
6958
6959
# File 'lib/models/porcelain.rb', line 6957

def endpoint
  @endpoint
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



6959
6960
6961
# File 'lib/models/porcelain.rb', line 6959

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



6961
6962
6963
# File 'lib/models/porcelain.rb', line 6961

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



6963
6964
6965
# File 'lib/models/porcelain.rb', line 6963

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6965
6966
6967
# File 'lib/models/porcelain.rb', line 6965

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



6967
6968
6969
# File 'lib/models/porcelain.rb', line 6967

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The region to authenticate requests against e.g. us-east-1



6969
6970
6971
# File 'lib/models/porcelain.rb', line 6969

def region
  @region
end

#role_arn ⇒ Object

The role to assume after logging in.



6971
6972
6973
# File 'lib/models/porcelain.rb', line 6971

def role_arn
  @role_arn
end

#role_external_id ⇒ Object

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



6973
6974
6975
# File 'lib/models/porcelain.rb', line 6973

def role_external_id
  @role_external_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



6975
6976
6977
# File 'lib/models/porcelain.rb', line 6975

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6977
6978
6979
# File 'lib/models/porcelain.rb', line 6977

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



6979
6980
6981
# File 'lib/models/porcelain.rb', line 6979

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7013
7014
7015
7016
7017
7018
7019
# File 'lib/models/porcelain.rb', line 7013

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end