Class: SDM::Elastic

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic

Returns a new instance of Elastic.



7054
7055
7056
7057
7058
7059
7060
7061
7062
7063
7064
7065
7066
7067
7068
7069
7070
7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
# File 'lib/models/porcelain.rb', line 7054

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7024
7025
7026
# File 'lib/models/porcelain.rb', line 7024

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



7026
7027
7028
# File 'lib/models/porcelain.rb', line 7026

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



7028
7029
7030
# File 'lib/models/porcelain.rb', line 7028

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



7030
7031
7032
# File 'lib/models/porcelain.rb', line 7030

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



7032
7033
7034
# File 'lib/models/porcelain.rb', line 7032

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



7034
7035
7036
# File 'lib/models/porcelain.rb', line 7034

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



7036
7037
7038
# File 'lib/models/porcelain.rb', line 7036

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



7038
7039
7040
# File 'lib/models/porcelain.rb', line 7038

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7040
7041
7042
# File 'lib/models/porcelain.rb', line 7040

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



7042
7043
7044
# File 'lib/models/porcelain.rb', line 7042

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



7044
7045
7046
# File 'lib/models/porcelain.rb', line 7044

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7046
7047
7048
# File 'lib/models/porcelain.rb', line 7046

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



7048
7049
7050
# File 'lib/models/porcelain.rb', line 7048

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



7050
7051
7052
# File 'lib/models/porcelain.rb', line 7050

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



7052
7053
7054
# File 'lib/models/porcelain.rb', line 7052

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7088
7089
7090
7091
7092
7093
7094
# File 'lib/models/porcelain.rb', line 7088

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end