Class: SDM::ElasticacheRedis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis

Returns a new instance of ElasticacheRedis.



7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
7062
7063
7064
7065
7066
7067
7068
7069
7070
7071
7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/models/porcelain.rb', line 7051

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7021
7022
7023
# File 'lib/models/porcelain.rb', line 7021

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7023
7024
7025
# File 'lib/models/porcelain.rb', line 7023

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7025
7026
7027
# File 'lib/models/porcelain.rb', line 7025

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7027
7028
7029
# File 'lib/models/porcelain.rb', line 7027

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7029
7030
7031
# File 'lib/models/porcelain.rb', line 7029

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7031
7032
7033
# File 'lib/models/porcelain.rb', line 7031

def name
  @name
end

#passwordObject

The password to authenticate with.



7033
7034
7035
# File 'lib/models/porcelain.rb', line 7033

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7035
7036
7037
# File 'lib/models/porcelain.rb', line 7035

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7037
7038
7039
# File 'lib/models/porcelain.rb', line 7037

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7039
7040
7041
# File 'lib/models/porcelain.rb', line 7039

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7041
7042
7043
# File 'lib/models/porcelain.rb', line 7041

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7043
7044
7045
# File 'lib/models/porcelain.rb', line 7043

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7045
7046
7047
# File 'lib/models/porcelain.rb', line 7045

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7047
7048
7049
# File 'lib/models/porcelain.rb', line 7047

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7049
7050
7051
# File 'lib/models/porcelain.rb', line 7049

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7085
7086
7087
7088
7089
7090
7091
# File 'lib/models/porcelain.rb', line 7085

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end