Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
7314
# File 'lib/models/porcelain.rb', line 7288

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7264
7265
7266
# File 'lib/models/porcelain.rb', line 7264

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7266
7267
7268
# File 'lib/models/porcelain.rb', line 7266

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7268
7269
7270
# File 'lib/models/porcelain.rb', line 7268

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7270
7271
7272
# File 'lib/models/porcelain.rb', line 7270

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



7272
7273
7274
# File 'lib/models/porcelain.rb', line 7272

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



7274
7275
7276
# File 'lib/models/porcelain.rb', line 7274

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7276
7277
7278
# File 'lib/models/porcelain.rb', line 7276

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7278
7279
7280
# File 'lib/models/porcelain.rb', line 7278

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



7280
7281
7282
# File 'lib/models/porcelain.rb', line 7280

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7282
7283
7284
# File 'lib/models/porcelain.rb', line 7282

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7284
7285
7286
# File 'lib/models/porcelain.rb', line 7284

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7286
7287
7288
# File 'lib/models/porcelain.rb', line 7286

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7316
7317
7318
7319
7320
7321
7322
# File 'lib/models/porcelain.rb', line 7316

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end