Class: SDM::GCPConsole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole

Returns a new instance of GCPConsole.



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
# File 'lib/models/porcelain.rb', line 7546

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  session_expiry: nil,
  subdomain: nil,
  tags: nil,
  workforce_pool_id: nil,
  workforce_provider_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @session_expiry = session_expiry == nil ? 0 : session_expiry
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id
  @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7516
7517
7518
# File 'lib/models/porcelain.rb', line 7516

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



7518
7519
7520
# File 'lib/models/porcelain.rb', line 7518

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



7520
7521
7522
# File 'lib/models/porcelain.rb', line 7520

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



7522
7523
7524
# File 'lib/models/porcelain.rb', line 7522

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



7524
7525
7526
# File 'lib/models/porcelain.rb', line 7524

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



7526
7527
7528
# File 'lib/models/porcelain.rb', line 7526

def identity_set_id
  @identity_set_id
end

#name ⇒ Object

Unique human-readable name of the Resource.



7528
7529
7530
# File 'lib/models/porcelain.rb', line 7528

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7530
7531
7532
# File 'lib/models/porcelain.rb', line 7530

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



7532
7533
7534
# File 'lib/models/porcelain.rb', line 7532

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



7534
7535
7536
# File 'lib/models/porcelain.rb', line 7534

def secret_store_id
  @secret_store_id
end

#session_expiry ⇒ Object

The length of time in seconds console sessions will live before needing to reauthenticate.



7536
7537
7538
# File 'lib/models/porcelain.rb', line 7536

def session_expiry
  @session_expiry
end

#subdomain ⇒ Object

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7538
7539
7540
# File 'lib/models/porcelain.rb', line 7538

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



7540
7541
7542
# File 'lib/models/porcelain.rb', line 7540

def tags
  @tags
end

#workforce_pool_id ⇒ Object

The ID of the Workforce Identity Pool in GCP to use for federated authentication.



7542
7543
7544
# File 'lib/models/porcelain.rb', line 7542

def workforce_pool_id
  @workforce_pool_id
end

#workforce_provider_id ⇒ Object

The ID of the Workforce Identity Provider in GCP to use for federated authentication.



7544
7545
7546
# File 'lib/models/porcelain.rb', line 7544

def workforce_provider_id
  @workforce_provider_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7580
7581
7582
7583
7584
7585
7586
# File 'lib/models/porcelain.rb', line 7580

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end