Class: SDM::Gateway

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Gateway represents a StrongDM CLI installation running in gateway mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_address: nil, device: nil, gateway_filter: nil, id: nil, listen_address: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Gateway

Returns a new instance of Gateway.



7745
7746
7747
7748
7749
7750
7751
7752
7753
7754
7755
7756
7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
# File 'lib/models/porcelain.rb', line 7745

def initialize(
  bind_address: nil,
  device: nil,
  gateway_filter: nil,
  id: nil,
  listen_address: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @bind_address = bind_address == nil ? "" : bind_address
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @listen_address = listen_address == nil ? "" : listen_address
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#bind_address ⇒ Object

The hostname/port tuple which the gateway daemon will bind to. If not provided on create, set to "0.0.0.0:listen_address_port".



7707
7708
7709
# File 'lib/models/porcelain.rb', line 7707

def bind_address
  @bind_address
end

#device ⇒ Object

Device is a read only device name uploaded by the gateway process when it comes online.



7710
7711
7712
# File 'lib/models/porcelain.rb', line 7710

def device
  @device
end

#gateway_filter ⇒ Object

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



7713
7714
7715
# File 'lib/models/porcelain.rb', line 7713

def gateway_filter
  @gateway_filter
end

#id ⇒ Object

Unique identifier of the Gateway.



7715
7716
7717
# File 'lib/models/porcelain.rb', line 7715

def id
  @id
end

#listen_address ⇒ Object

The public hostname/port tuple at which the gateway will be accessible to clients.



7717
7718
7719
# File 'lib/models/porcelain.rb', line 7717

def listen_address
  @listen_address
end

#location ⇒ Object

Location is a read only network location uploaded by the gateway process when it comes online.



7720
7721
7722
# File 'lib/models/porcelain.rb', line 7720

def location
  @location
end

#maintenance_windows ⇒ Object

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



7733
7734
7735
# File 'lib/models/porcelain.rb', line 7733

def maintenance_windows
  @maintenance_windows
end

#name ⇒ Object

Unique human-readable name of the Gateway. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



7735
7736
7737
# File 'lib/models/porcelain.rb', line 7735

def name
  @name
end

#state ⇒ Object

The current state of the gateway. One of: "new", "verifying_restart", "restarting", "started", "stopped", "dead", "unknown"



7738
7739
7740
# File 'lib/models/porcelain.rb', line 7738

def state
  @state
end

#tags ⇒ Object

Tags is a map of key, value pairs.



7740
7741
7742
# File 'lib/models/porcelain.rb', line 7740

def tags
  @tags
end

#version ⇒ Object

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



7743
7744
7745
# File 'lib/models/porcelain.rb', line 7743

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7771
7772
7773
7774
7775
7776
7777
# File 'lib/models/porcelain.rb', line 7771

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end