Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



7889
7890
7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
# File 'lib/models/porcelain.rb', line 7889

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypass ⇒ Object

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



7850
7851
7852
# File 'lib/models/porcelain.rb', line 7850

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7852
7853
7854
# File 'lib/models/porcelain.rb', line 7852

def bind_interface
  @bind_interface
end

#certificate_authority ⇒ Object

The CA to authenticate TLS connections with.



7854
7855
7856
# File 'lib/models/porcelain.rb', line 7854

def certificate_authority
  @certificate_authority
end

#discovery_enabled ⇒ Object

If true, configures discovery of a cluster to be run from a node.



7856
7857
7858
# File 'lib/models/porcelain.rb', line 7856

def discovery_enabled
  @discovery_enabled
end

#discovery_username ⇒ Object

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



7859
7860
7861
# File 'lib/models/porcelain.rb', line 7859

def discovery_username
  @discovery_username
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



7861
7862
7863
# File 'lib/models/porcelain.rb', line 7861

def egress_filter
  @egress_filter
end

#endpoint ⇒ Object

The endpoint to dial.



7863
7864
7865
# File 'lib/models/porcelain.rb', line 7863

def endpoint
  @endpoint
end

#healthcheck_namespace ⇒ Object

The path used to check the health of your connection. Defaults to default.



7865
7866
7867
# File 'lib/models/porcelain.rb', line 7865

def healthcheck_namespace
  @healthcheck_namespace
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



7867
7868
7869
# File 'lib/models/porcelain.rb', line 7867

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



7869
7870
7871
# File 'lib/models/porcelain.rb', line 7869

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



7871
7872
7873
# File 'lib/models/porcelain.rb', line 7871

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



7873
7874
7875
# File 'lib/models/porcelain.rb', line 7873

def identity_set_id
  @identity_set_id
end

#name ⇒ Object

Unique human-readable name of the Resource.



7875
7876
7877
# File 'lib/models/porcelain.rb', line 7875

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7877
7878
7879
# File 'lib/models/porcelain.rb', line 7877

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



7879
7880
7881
# File 'lib/models/porcelain.rb', line 7879

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



7881
7882
7883
# File 'lib/models/porcelain.rb', line 7881

def secret_store_id
  @secret_store_id
end

#service_account_key ⇒ Object

The service account key to authenticate with.



7883
7884
7885
# File 'lib/models/porcelain.rb', line 7883

def 
  @service_account_key
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7885
7886
7887
# File 'lib/models/porcelain.rb', line 7885

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



7887
7888
7889
# File 'lib/models/porcelain.rb', line 7887

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7931
7932
7933
7934
7935
7936
7937
# File 'lib/models/porcelain.rb', line 7931

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end