Class: SDM::GoogleGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_emails: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GoogleGroups

Returns a new instance of GoogleGroups.



8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
8060
8061
8062
8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
# File 'lib/models/porcelain.rb', line 8046

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_emails: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_emails = group_emails == nil ? "" : group_emails
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8014
8015
8016
# File 'lib/models/porcelain.rb', line 8014

def bind_interface
  @bind_interface
end

#discovery_enabled ⇒ Object

If true, configures discovery of the Google Workspace account to be run from a node.



8017
8018
8019
# File 'lib/models/porcelain.rb', line 8017

def discovery_enabled
  @discovery_enabled
end

#domain ⇒ Object

The Google Workspace domain that owns the groups. Only groups whose email address is at this exact domain are discovered; add one resource per secondary domain.



8021
8022
8023
# File 'lib/models/porcelain.rb', line 8021

def domain
  @domain
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



8023
8024
8025
# File 'lib/models/porcelain.rb', line 8023

def egress_filter
  @egress_filter
end

#group_emails ⇒ Object

comma separated list of group email addresses to filter by. Supports wildcards (*)



8026
8027
8028
# File 'lib/models/porcelain.rb', line 8026

def group_emails
  @group_emails
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



8028
8029
8030
# File 'lib/models/porcelain.rb', line 8028

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



8030
8031
8032
# File 'lib/models/porcelain.rb', line 8030

def id
  @id
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



8032
8033
8034
# File 'lib/models/porcelain.rb', line 8032

def identity_set_id
  @identity_set_id
end

#name ⇒ Object

Unique human-readable name of the Resource.



8034
8035
8036
# File 'lib/models/porcelain.rb', line 8034

def name
  @name
end

#privilege_levels ⇒ Object

The privilege levels specify which Groups are managed externally



8036
8037
8038
# File 'lib/models/porcelain.rb', line 8036

def privilege_levels
  @privilege_levels
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



8038
8039
8040
# File 'lib/models/porcelain.rb', line 8038

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



8040
8041
8042
# File 'lib/models/porcelain.rb', line 8040

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



8042
8043
8044
# File 'lib/models/porcelain.rb', line 8042

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



8044
8045
8046
# File 'lib/models/porcelain.rb', line 8044

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8078
8079
8080
8081
8082
8083
8084
# File 'lib/models/porcelain.rb', line 8078

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end