Class: SDM::GrantedAccountEntitlement
- Inherits:
-
Object
- Object
- SDM::GrantedAccountEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
GrantedAccountEntitlement represents an individual entitlement of an Account to a Resource that has been granted.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#last_accessed ⇒ Object
The most recent time at which the account accessed this resource.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., a Role or AccountGrant ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
Instance Method Summary collapse
-
#initialize(group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ GrantedAccountEntitlement
constructor
A new instance of GrantedAccountEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ GrantedAccountEntitlement
Returns a new instance of GrantedAccountEntitlement.
8181 8182 8183 8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 |
# File 'lib/models/porcelain.rb', line 8181 def initialize( group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @last_accessed = last_accessed == nil ? nil : last_accessed @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
8171 8172 8173 |
# File 'lib/models/porcelain.rb', line 8171 def group_id @group_id end |
#last_accessed ⇒ Object
The most recent time at which the account accessed this resource. Empty if the resource has never been accessed.
8173 8174 8175 |
# File 'lib/models/porcelain.rb', line 8173 def last_accessed @last_accessed end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
8175 8176 8177 |
# File 'lib/models/porcelain.rb', line 8175 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., a Role or AccountGrant ID).
8177 8178 8179 |
# File 'lib/models/porcelain.rb', line 8177 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
8179 8180 8181 |
# File 'lib/models/porcelain.rb', line 8179 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8195 8196 8197 8198 8199 8200 8201 |
# File 'lib/models/porcelain.rb', line 8195 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |