Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



8329
8330
8331
8332
8333
8334
8335
8336
8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
8357
8358
8359
8360
8361
8362
8363
# File 'lib/models/porcelain.rb', line 8329

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8297
8298
8299
# File 'lib/models/porcelain.rb', line 8297

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8299
8300
8301
# File 'lib/models/porcelain.rb', line 8299

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



8301
8302
8303
# File 'lib/models/porcelain.rb', line 8301

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



8303
8304
8305
# File 'lib/models/porcelain.rb', line 8303

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



8305
8306
8307
# File 'lib/models/porcelain.rb', line 8305

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



8307
8308
8309
# File 'lib/models/porcelain.rb', line 8307

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



8309
8310
8311
# File 'lib/models/porcelain.rb', line 8309

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8311
8312
8313
# File 'lib/models/porcelain.rb', line 8311

def override_database
  @override_database
end

#password ⇒ Object

The password to authenticate with.



8313
8314
8315
# File 'lib/models/porcelain.rb', line 8313

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



8315
8316
8317
# File 'lib/models/porcelain.rb', line 8315

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8317
8318
8319
# File 'lib/models/porcelain.rb', line 8317

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



8319
8320
8321
# File 'lib/models/porcelain.rb', line 8319

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



8321
8322
8323
# File 'lib/models/porcelain.rb', line 8321

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



8323
8324
8325
# File 'lib/models/porcelain.rb', line 8323

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



8325
8326
8327
# File 'lib/models/porcelain.rb', line 8325

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



8327
8328
8329
# File 'lib/models/porcelain.rb', line 8327

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8365
8366
8367
8368
8369
8370
8371
# File 'lib/models/porcelain.rb', line 8365

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end