Class: SDM::GroupCreateFromRolesRequest
- Inherits:
-
Object
- Object
- SDM::GroupCreateFromRolesRequest
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#commit ⇒ Object
Commit.
-
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
Instance Method Summary collapse
-
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
constructor
A new instance of GroupCreateFromRolesRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
Returns a new instance of GroupCreateFromRolesRequest.
8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/models/porcelain.rb', line 8278 def initialize( commit: nil, role_ids: nil ) @commit = commit == nil ? false : commit @role_ids = role_ids == nil ? [] : role_ids end |
Instance Attribute Details
#commit ⇒ Object
Commit
8274 8275 8276 |
# File 'lib/models/porcelain.rb', line 8274 def commit @commit end |
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
8276 8277 8278 |
# File 'lib/models/porcelain.rb', line 8276 def role_ids @role_ids end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8286 8287 8288 8289 8290 8291 8292 |
# File 'lib/models/porcelain.rb', line 8286 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |