Class: SDM::GroupHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GroupHistory records the state of a Group at a given point in time, where every change (create, update and delete) to a Group produces a GroupHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, group: nil, timestamp: nil) ⇒ GroupHistory

Returns a new instance of GroupHistory.



8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
# File 'lib/models/porcelain.rb', line 8503

def initialize(
  activity_id: nil,
  deleted_at: nil,
  group: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @group = group == nil ? nil : group
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Group. May be empty for some system-initiated updates.



8495
8496
8497
# File 'lib/models/porcelain.rb', line 8495

def activity_id
  @activity_id
end

#deleted_atObject

If this Group was deleted, the time it was deleted.



8497
8498
8499
# File 'lib/models/porcelain.rb', line 8497

def deleted_at
  @deleted_at
end

#groupObject

The complete Group state at this time.



8499
8500
8501
# File 'lib/models/porcelain.rb', line 8499

def group
  @group
end

#timestampObject

The time at which the Group state was recorded.



8501
8502
8503
# File 'lib/models/porcelain.rb', line 8501

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8515
8516
8517
8518
8519
8520
8521
# File 'lib/models/porcelain.rb', line 8515

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end