Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



8892
8893
8894
8895
8896
8897
8898
8899
8900
8901
8902
8903
8904
8905
8906
8907
8908
8909
8910
8911
8912
8913
8914
8915
8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
# File 'lib/models/porcelain.rb', line 8892

def initialize(
  auth_header: nil,
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



8856
8857
8858
# File 'lib/models/porcelain.rb', line 8856

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8858
8859
8860
# File 'lib/models/porcelain.rb', line 8858

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8860
8861
8862
# File 'lib/models/porcelain.rb', line 8860

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8862
8863
8864
# File 'lib/models/porcelain.rb', line 8862

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8864
8865
8866
# File 'lib/models/porcelain.rb', line 8864

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8866
8867
8868
# File 'lib/models/porcelain.rb', line 8866

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8868
8869
8870
# File 'lib/models/porcelain.rb', line 8868

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8870
8871
8872
# File 'lib/models/porcelain.rb', line 8870

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8872
8873
8874
# File 'lib/models/porcelain.rb', line 8872

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8874
8875
8876
# File 'lib/models/porcelain.rb', line 8874

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8876
8877
8878
# File 'lib/models/porcelain.rb', line 8876

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8878
8879
8880
# File 'lib/models/porcelain.rb', line 8878

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8880
8881
8882
# File 'lib/models/porcelain.rb', line 8880

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8882
8883
8884
# File 'lib/models/porcelain.rb', line 8882

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8884
8885
8886
# File 'lib/models/porcelain.rb', line 8884

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8886
8887
8888
# File 'lib/models/porcelain.rb', line 8886

def tags
  @tags
end

#tls_requiredObject

This option enforces HTTPS on the client, not resource connection.



8888
8889
8890
# File 'lib/models/porcelain.rb', line 8888

def tls_required
  @tls_required
end

#urlObject

The base address of your website without the path.



8890
8891
8892
# File 'lib/models/porcelain.rb', line 8890

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8932
8933
8934
8935
8936
8937
8938
# File 'lib/models/porcelain.rb', line 8932

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end