Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



8981
8982
8983
8984
8985
8986
8987
8988
8989
8990
8991
8992
8993
8994
8995
8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
9006
9007
9008
9009
9010
9011
9012
9013
9014
9015
9016
9017
9018
9019
9020
9021
# File 'lib/models/porcelain.rb', line 8981

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8943
8944
8945
# File 'lib/models/porcelain.rb', line 8943

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8945
8946
8947
# File 'lib/models/porcelain.rb', line 8945

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8947
8948
8949
# File 'lib/models/porcelain.rb', line 8947

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8949
8950
8951
# File 'lib/models/porcelain.rb', line 8949

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8951
8952
8953
# File 'lib/models/porcelain.rb', line 8951

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8953
8954
8955
# File 'lib/models/porcelain.rb', line 8953

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8955
8956
8957
# File 'lib/models/porcelain.rb', line 8955

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8957
8958
8959
# File 'lib/models/porcelain.rb', line 8957

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8959
8960
8961
# File 'lib/models/porcelain.rb', line 8959

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8961
8962
8963
# File 'lib/models/porcelain.rb', line 8961

def name
  @name
end

#passwordObject

The password to authenticate with.



8963
8964
8965
# File 'lib/models/porcelain.rb', line 8963

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8965
8966
8967
# File 'lib/models/porcelain.rb', line 8965

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8967
8968
8969
# File 'lib/models/porcelain.rb', line 8967

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8969
8970
8971
# File 'lib/models/porcelain.rb', line 8969

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8971
8972
8973
# File 'lib/models/porcelain.rb', line 8971

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8973
8974
8975
# File 'lib/models/porcelain.rb', line 8973

def tags
  @tags
end

#tls_requiredObject

This option enforces HTTPS on the client, not resource connection.



8975
8976
8977
# File 'lib/models/porcelain.rb', line 8975

def tls_required
  @tls_required
end

#urlObject

The base address of your website without the path.



8977
8978
8979
# File 'lib/models/porcelain.rb', line 8977

def url
  @url
end

#usernameObject

The username to authenticate with.



8979
8980
8981
# File 'lib/models/porcelain.rb', line 8979

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9023
9024
9025
9026
9027
9028
9029
# File 'lib/models/porcelain.rb', line 9023

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end