Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
9080
9081
9082
9083
9084
9085
9086
9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
# File 'lib/models/porcelain.rb', line 9068

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9034
9035
9036
# File 'lib/models/porcelain.rb', line 9034

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



9036
9037
9038
# File 'lib/models/porcelain.rb', line 9036

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



9038
9039
9040
# File 'lib/models/porcelain.rb', line 9038

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9040
9041
9042
# File 'lib/models/porcelain.rb', line 9040

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



9042
9043
9044
# File 'lib/models/porcelain.rb', line 9042

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



9044
9045
9046
# File 'lib/models/porcelain.rb', line 9044

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9046
9047
9048
# File 'lib/models/porcelain.rb', line 9046

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



9048
9049
9050
# File 'lib/models/porcelain.rb', line 9048

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



9050
9051
9052
# File 'lib/models/porcelain.rb', line 9050

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9052
9053
9054
# File 'lib/models/porcelain.rb', line 9052

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9054
9055
9056
# File 'lib/models/porcelain.rb', line 9054

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9056
9057
9058
# File 'lib/models/porcelain.rb', line 9056

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9058
9059
9060
# File 'lib/models/porcelain.rb', line 9058

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9060
9061
9062
# File 'lib/models/porcelain.rb', line 9060

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9062
9063
9064
# File 'lib/models/porcelain.rb', line 9062

def tags
  @tags
end

#tls_requiredObject

This option enforces HTTPS on the client, not resource connection.



9064
9065
9066
# File 'lib/models/porcelain.rb', line 9064

def tls_required
  @tls_required
end

#urlObject

The base address of your website without the path.



9066
9067
9068
# File 'lib/models/porcelain.rb', line 9066

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9106
9107
9108
9109
9110
9111
9112
# File 'lib/models/porcelain.rb', line 9106

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end