Class: SDM::HealthcheckResponse
- Inherits:
-
Object
- Object
- SDM::HealthcheckResponse
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#rate_limit ⇒ Object
Rate limit information.
-
#status ⇒ Object
Array of statuses of all nodes serving a secret engine.
Instance Method Summary collapse
-
#initialize(rate_limit: nil, status: nil) ⇒ HealthcheckResponse
constructor
A new instance of HealthcheckResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(rate_limit: nil, status: nil) ⇒ HealthcheckResponse
Returns a new instance of HealthcheckResponse.
6869 6870 6871 6872 6873 6874 6875 |
# File 'lib/models/porcelain.rb', line 6869 def initialize( rate_limit: nil, status: nil ) @rate_limit = rate_limit == nil ? nil : rate_limit @status = status == nil ? [] : status end |
Instance Attribute Details
#rate_limit ⇒ Object
Rate limit information.
6865 6866 6867 |
# File 'lib/models/porcelain.rb', line 6865 def rate_limit @rate_limit end |
#status ⇒ Object
Array of statuses of all nodes serving a secret engine
6867 6868 6869 |
# File 'lib/models/porcelain.rb', line 6867 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6877 6878 6879 6880 6881 6882 6883 |
# File 'lib/models/porcelain.rb', line 6877 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |