Class: SDM::IdentityAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias

Returns a new instance of IdentityAlias.



9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
# File 'lib/models/porcelain.rb', line 9423

def initialize(
  account_id: nil,
  id: nil,
  identity_set_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_id ⇒ Object

The account for this identity alias.



9415
9416
9417
# File 'lib/models/porcelain.rb', line 9415

def 
  @account_id
end

#id ⇒ Object

Unique identifier of the IdentityAlias.



9417
9418
9419
# File 'lib/models/porcelain.rb', line 9417

def id
  @id
end

#identity_set_id ⇒ Object

The identity set.



9419
9420
9421
# File 'lib/models/porcelain.rb', line 9419

def identity_set_id
  @identity_set_id
end

#username ⇒ Object

The username to be used as the identity alias for this account.



9421
9422
9423
# File 'lib/models/porcelain.rb', line 9421

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9435
9436
9437
9438
9439
9440
9441
# File 'lib/models/porcelain.rb', line 9435

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end