Class: SDM::KeyfactorSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorSSHStore

Returns a new instance of KeyfactorSSHStore.



9675
9676
9677
9678
9679
9680
9681
9682
9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
9694
9695
9696
9697
9698
9699
9700
9701
# File 'lib/models/porcelain.rb', line 9675

def initialize(
  ca_file_path: nil,
  certificate_file_path: nil,
  default_certificate_authority_name: nil,
  default_certificate_profile_name: nil,
  default_end_entity_profile_name: nil,
  enrollment_code_env_var: nil,
  enrollment_username_env_var: nil,
  id: nil,
  key_file_path: nil,
  name: nil,
  server_address: nil,
  tags: nil
)
  @ca_file_path = ca_file_path == nil ? "" : ca_file_path
  @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path
  @default_certificate_authority_name = default_certificate_authority_name == nil ? "" : default_certificate_authority_name
  @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name
  @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name
  @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var
  @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var
  @id = id == nil ? "" : id
  @key_file_path = key_file_path == nil ? "" : key_file_path
  @name = name == nil ? "" : name
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_file_pathObject

Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.



9647
9648
9649
# File 'lib/models/porcelain.rb', line 9647

def ca_file_path
  @ca_file_path
end

#certificate_file_pathObject

Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.



9651
9652
9653
# File 'lib/models/porcelain.rb', line 9651

def certificate_file_path
  @certificate_file_path
end

#default_certificate_authority_nameObject

Name of EJBCA certificate authority that will enroll CSR.



9653
9654
9655
# File 'lib/models/porcelain.rb', line 9653

def default_certificate_authority_name
  @default_certificate_authority_name
end

#default_certificate_profile_nameObject

Certificate profile name that EJBCA will enroll the CSR with.



9655
9656
9657
# File 'lib/models/porcelain.rb', line 9655

def default_certificate_profile_name
  @default_certificate_profile_name
end

#default_end_entity_profile_nameObject

End entity profile that EJBCA will enroll the CSR with.



9657
9658
9659
# File 'lib/models/porcelain.rb', line 9657

def default_end_entity_profile_name
  @default_end_entity_profile_name
end

#enrollment_code_env_varObject

code used by EJBCA during enrollment. May be left blank if no code is required.



9659
9660
9661
# File 'lib/models/porcelain.rb', line 9659

def enrollment_code_env_var
  @enrollment_code_env_var
end

#enrollment_username_env_varObject

username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.



9662
9663
9664
# File 'lib/models/porcelain.rb', line 9662

def enrollment_username_env_var
  @enrollment_username_env_var
end

#idObject

Unique identifier of the SecretStore.



9664
9665
9666
# File 'lib/models/porcelain.rb', line 9664

def id
  @id
end

#key_file_pathObject

Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.



9667
9668
9669
# File 'lib/models/porcelain.rb', line 9667

def key_file_path
  @key_file_path
end

#nameObject

Unique human-readable name of the SecretStore.



9669
9670
9671
# File 'lib/models/porcelain.rb', line 9669

def name
  @name
end

#server_addressObject

the host of the Key Factor CA



9671
9672
9673
# File 'lib/models/porcelain.rb', line 9671

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



9673
9674
9675
# File 'lib/models/porcelain.rb', line 9673

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9703
9704
9705
9706
9707
9708
9709
# File 'lib/models/porcelain.rb', line 9703

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end