Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
9815
9816
9817
9818
9819
9820
9821
9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
9840
9841
9842
9843
9844
# File 'lib/models/porcelain.rb', line 9800

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



9757
9758
9759
# File 'lib/models/porcelain.rb', line 9757

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9759
9760
9761
# File 'lib/models/porcelain.rb', line 9759

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



9761
9762
9763
# File 'lib/models/porcelain.rb', line 9761

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



9763
9764
9765
# File 'lib/models/porcelain.rb', line 9763

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



9765
9766
9767
# File 'lib/models/porcelain.rb', line 9765

def client_key
  @client_key
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



9767
9768
9769
# File 'lib/models/porcelain.rb', line 9767

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



9770
9771
9772
# File 'lib/models/porcelain.rb', line 9770

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9772
9773
9774
# File 'lib/models/porcelain.rb', line 9772

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



9774
9775
9776
# File 'lib/models/porcelain.rb', line 9774

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9776
9777
9778
# File 'lib/models/porcelain.rb', line 9776

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9778
9779
9780
# File 'lib/models/porcelain.rb', line 9778

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9780
9781
9782
# File 'lib/models/porcelain.rb', line 9780

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



9782
9783
9784
# File 'lib/models/porcelain.rb', line 9782

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



9784
9785
9786
# File 'lib/models/porcelain.rb', line 9784

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



9786
9787
9788
# File 'lib/models/porcelain.rb', line 9786

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9788
9789
9790
# File 'lib/models/porcelain.rb', line 9788

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9790
9791
9792
# File 'lib/models/porcelain.rb', line 9790

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9792
9793
9794
# File 'lib/models/porcelain.rb', line 9792

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9794
9795
9796
# File 'lib/models/porcelain.rb', line 9794

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



9796
9797
9798
# File 'lib/models/porcelain.rb', line 9796

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9798
9799
9800
# File 'lib/models/porcelain.rb', line 9798

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9846
9847
9848
9849
9850
9851
9852
# File 'lib/models/porcelain.rb', line 9846

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end