Class: SDM::KubernetesBasicAuth
- Inherits:
-
Object
- Object
- SDM::KubernetesBasicAuth
- Defined in:
- lib/models/porcelain.rb
Overview
KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth
constructor
A new instance of KubernetesBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth
Returns a new instance of KubernetesBasicAuth.
9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 9905 9906 9907 9908 9909 9910 9911 9912 9913 9914 9915 9916 9917 9918 9919 9920 9921 9922 9923 9924 9925 9926 9927 |
# File 'lib/models/porcelain.rb', line 9895 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
9865 9866 9867 |
# File 'lib/models/porcelain.rb', line 9865 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9867 9868 9869 |
# File 'lib/models/porcelain.rb', line 9867 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
9869 9870 9871 |
# File 'lib/models/porcelain.rb', line 9869 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9871 9872 9873 |
# File 'lib/models/porcelain.rb', line 9871 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9873 9874 9875 |
# File 'lib/models/porcelain.rb', line 9873 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9875 9876 9877 |
# File 'lib/models/porcelain.rb', line 9875 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9877 9878 9879 |
# File 'lib/models/porcelain.rb', line 9877 def name @name end |
#password ⇒ Object
The password to authenticate with.
9879 9880 9881 |
# File 'lib/models/porcelain.rb', line 9879 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9881 9882 9883 |
# File 'lib/models/porcelain.rb', line 9881 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
9883 9884 9885 |
# File 'lib/models/porcelain.rb', line 9883 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9885 9886 9887 |
# File 'lib/models/porcelain.rb', line 9885 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9887 9888 9889 |
# File 'lib/models/porcelain.rb', line 9887 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
9889 9890 9891 |
# File 'lib/models/porcelain.rb', line 9889 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9891 9892 9893 |
# File 'lib/models/porcelain.rb', line 9891 def end |
#username ⇒ Object
The username to authenticate with.
9893 9894 9895 |
# File 'lib/models/porcelain.rb', line 9893 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9929 9930 9931 9932 9933 9934 9935 |
# File 'lib/models/porcelain.rb', line 9929 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |