Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



10246
10247
10248
10249
10250
10251
10252
10253
10254
10255
10256
10257
10258
10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
10281
10282
10283
10284
10285
10286
# File 'lib/models/porcelain.rb', line 10246

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#allow_resource_role_bypass ⇒ Object

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



10207
10208
10209
# File 'lib/models/porcelain.rb', line 10207

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10209
10210
10211
# File 'lib/models/porcelain.rb', line 10209

def bind_interface
  @bind_interface
end

#discovery_enabled ⇒ Object

If true, configures discovery of a cluster to be run from a node.



10211
10212
10213
# File 'lib/models/porcelain.rb', line 10211

def discovery_enabled
  @discovery_enabled
end

#discovery_username ⇒ Object

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



10214
10215
10216
# File 'lib/models/porcelain.rb', line 10214

def discovery_username
  @discovery_username
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



10216
10217
10218
# File 'lib/models/porcelain.rb', line 10216

def egress_filter
  @egress_filter
end

#healthcheck_namespace ⇒ Object

The path used to check the health of your connection. Defaults to default.



10218
10219
10220
# File 'lib/models/porcelain.rb', line 10218

def healthcheck_namespace
  @healthcheck_namespace
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



10220
10221
10222
# File 'lib/models/porcelain.rb', line 10220

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



10222
10223
10224
# File 'lib/models/porcelain.rb', line 10222

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



10224
10225
10226
# File 'lib/models/porcelain.rb', line 10224

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



10226
10227
10228
# File 'lib/models/porcelain.rb', line 10226

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



10228
10229
10230
# File 'lib/models/porcelain.rb', line 10228

def identity_set_id
  @identity_set_id
end

#name ⇒ Object

Unique human-readable name of the Resource.



10230
10231
10232
# File 'lib/models/porcelain.rb', line 10230

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



10232
10233
10234
# File 'lib/models/porcelain.rb', line 10232

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10234
10235
10236
# File 'lib/models/porcelain.rb', line 10234

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



10236
10237
10238
# File 'lib/models/porcelain.rb', line 10236

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



10238
10239
10240
# File 'lib/models/porcelain.rb', line 10238

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10240
10241
10242
# File 'lib/models/porcelain.rb', line 10240

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



10242
10243
10244
# File 'lib/models/porcelain.rb', line 10242

def tags
  @tags
end

#token ⇒ Object

The API token to authenticate with.



10244
10245
10246
# File 'lib/models/porcelain.rb', line 10244

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10288
10289
10290
10291
10292
10293
10294
# File 'lib/models/porcelain.rb', line 10288

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end