Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesServiceAccountUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



10143
10144
10145
10146
10147
10148
10149
10150
10151
10152
10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
# File 'lib/models/porcelain.rb', line 10143

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10115
10116
10117
# File 'lib/models/porcelain.rb', line 10115

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10117
10118
10119
# File 'lib/models/porcelain.rb', line 10117

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



10119
10120
10121
# File 'lib/models/porcelain.rb', line 10119

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10121
10122
10123
# File 'lib/models/porcelain.rb', line 10121

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10123
10124
10125
# File 'lib/models/porcelain.rb', line 10123

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10125
10126
10127
# File 'lib/models/porcelain.rb', line 10125

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10127
10128
10129
# File 'lib/models/porcelain.rb', line 10127

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10129
10130
10131
# File 'lib/models/porcelain.rb', line 10129

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10131
10132
10133
# File 'lib/models/porcelain.rb', line 10131

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10133
10134
10135
# File 'lib/models/porcelain.rb', line 10133

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10135
10136
10137
# File 'lib/models/porcelain.rb', line 10135

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10137
10138
10139
# File 'lib/models/porcelain.rb', line 10137

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10139
10140
10141
# File 'lib/models/porcelain.rb', line 10139

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



10141
10142
10143
# File 'lib/models/porcelain.rb', line 10141

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10175
10176
10177
10178
10179
10180
10181
# File 'lib/models/porcelain.rb', line 10175

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end