Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



10405
10406
10407
10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
10426
10427
10428
10429
10430
10431
10432
10433
10434
10435
10436
10437
10438
10439
# File 'lib/models/porcelain.rb', line 10405

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10373
10374
10375
# File 'lib/models/porcelain.rb', line 10373

def bind_interface
  @bind_interface
end

#certificate_authority ⇒ Object

The CA to authenticate TLS connections with.



10375
10376
10377
# File 'lib/models/porcelain.rb', line 10375

def certificate_authority
  @certificate_authority
end

#client_certificate ⇒ Object

The certificate to authenticate TLS connections with.



10377
10378
10379
# File 'lib/models/porcelain.rb', line 10377

def client_certificate
  @client_certificate
end

#client_key ⇒ Object

The key to authenticate TLS connections with.



10379
10380
10381
# File 'lib/models/porcelain.rb', line 10379

def client_key
  @client_key
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



10381
10382
10383
# File 'lib/models/porcelain.rb', line 10381

def egress_filter
  @egress_filter
end

#healthcheck_namespace ⇒ Object

The path used to check the health of your connection. Defaults to default.



10383
10384
10385
# File 'lib/models/porcelain.rb', line 10383

def healthcheck_namespace
  @healthcheck_namespace
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



10385
10386
10387
# File 'lib/models/porcelain.rb', line 10385

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



10387
10388
10389
# File 'lib/models/porcelain.rb', line 10387

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



10389
10390
10391
# File 'lib/models/porcelain.rb', line 10389

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



10391
10392
10393
# File 'lib/models/porcelain.rb', line 10391

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



10393
10394
10395
# File 'lib/models/porcelain.rb', line 10393

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10395
10396
10397
# File 'lib/models/porcelain.rb', line 10395

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



10397
10398
10399
# File 'lib/models/porcelain.rb', line 10397

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



10399
10400
10401
# File 'lib/models/porcelain.rb', line 10399

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10401
10402
10403
# File 'lib/models/porcelain.rb', line 10401

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



10403
10404
10405
# File 'lib/models/porcelain.rb', line 10403

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10441
10442
10443
10444
10445
10446
10447
# File 'lib/models/porcelain.rb', line 10441

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end