Class: SDM::LLM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

LLM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, models: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ LLM

Returns a new instance of LLM.



10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/models/porcelain.rb', line 10479

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  models: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @models = models == nil ? "" : models
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10453
10454
10455
# File 'lib/models/porcelain.rb', line 10453

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



10455
10456
10457
# File 'lib/models/porcelain.rb', line 10455

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



10457
10458
10459
# File 'lib/models/porcelain.rb', line 10457

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



10459
10460
10461
# File 'lib/models/porcelain.rb', line 10459

def id
  @id
end

#models ⇒ Object

Space-separated list of model names this resource accepts. Requests for unlisted models are rejected. Leave empty to allow all models.



10461
10462
10463
# File 'lib/models/porcelain.rb', line 10461

def models
  @models
end

#name ⇒ Object

Unique human-readable name of the Resource.



10463
10464
10465
# File 'lib/models/porcelain.rb', line 10463

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



10465
10466
10467
# File 'lib/models/porcelain.rb', line 10465

def password
  @password
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10467
10468
10469
# File 'lib/models/porcelain.rb', line 10467

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



10469
10470
10471
# File 'lib/models/porcelain.rb', line 10469

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



10471
10472
10473
# File 'lib/models/porcelain.rb', line 10471

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10473
10474
10475
# File 'lib/models/porcelain.rb', line 10473

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



10475
10476
10477
# File 'lib/models/porcelain.rb', line 10475

def tags
  @tags
end

#url ⇒ Object

The URL to dial to initiate a connection from the egress node to this resource.



10477
10478
10479
# File 'lib/models/porcelain.rb', line 10477

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10509
10510
10511
10512
10513
10514
10515
# File 'lib/models/porcelain.rb', line 10509

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end