Class: SDM::LogCategoryConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(remote_discard_replays: nil, remote_encoder: nil) ⇒ LogCategoryConfig

Returns a new instance of LogCategoryConfig.



10142
10143
10144
10145
10146
10147
10148
# File 'lib/models/porcelain.rb', line 10142

def initialize(
  remote_discard_replays: nil,
  remote_encoder: nil
)
  @remote_discard_replays = remote_discard_replays == nil ? false : remote_discard_replays
  @remote_encoder = remote_encoder == nil ? "" : remote_encoder
end

Instance Attribute Details

#remote_discard_replaysObject

Indicates if the Organization should exclude replay data from remote logging for the log category.



10138
10139
10140
# File 'lib/models/porcelain.rb', line 10138

def remote_discard_replays
  @remote_discard_replays
end

#remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.



10140
10141
10142
# File 'lib/models/porcelain.rb', line 10140

def remote_encoder
  @remote_encoder
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10150
10151
10152
10153
10154
10155
10156
# File 'lib/models/porcelain.rb', line 10150

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end