Class: SDM::LogConfig
- Inherits:
-
Object
- Object
- SDM::LogConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#categories ⇒ Object
The Organization's log category configuration settings.
-
#local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
-
#local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
-
#local_socket_path ⇒ Object
The Organization's local log socket path.
-
#local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
-
#local_tcp_address ⇒ Object
The Organization's local log TCP address.
-
#public_key ⇒ Object
The Organization's public key in PEM format for encrypting logs.
Instance Method Summary collapse
-
#initialize(categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil) ⇒ LogConfig
constructor
A new instance of LogConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil) ⇒ LogConfig
Returns a new instance of LogConfig.
10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/models/porcelain.rb', line 10327 def initialize( categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil ) @categories = categories == nil ? SDM::_porcelain_zero_value_log_category_config_map() : categories @local_encoder = local_encoder == nil ? "" : local_encoder @local_format = local_format == nil ? "" : local_format @local_socket_path = local_socket_path == nil ? "" : local_socket_path @local_storage = local_storage == nil ? "" : local_storage @local_tcp_address = local_tcp_address == nil ? "" : local_tcp_address @public_key = public_key == nil ? "" : public_key end |
Instance Attribute Details
#categories ⇒ Object
The Organization's log category configuration settings.
10313 10314 10315 |
# File 'lib/models/porcelain.rb', line 10313 def categories @categories end |
#local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
10315 10316 10317 |
# File 'lib/models/porcelain.rb', line 10315 def local_encoder @local_encoder end |
#local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
10317 10318 10319 |
# File 'lib/models/porcelain.rb', line 10317 def local_format @local_format end |
#local_socket_path ⇒ Object
The Organization's local log socket path.
10319 10320 10321 |
# File 'lib/models/porcelain.rb', line 10319 def local_socket_path @local_socket_path end |
#local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
10321 10322 10323 |
# File 'lib/models/porcelain.rb', line 10321 def local_storage @local_storage end |
#local_tcp_address ⇒ Object
The Organization's local log TCP address.
10323 10324 10325 |
# File 'lib/models/porcelain.rb', line 10323 def local_tcp_address @local_tcp_address end |
#public_key ⇒ Object
The Organization's public key in PEM format for encrypting logs.
10325 10326 10327 |
# File 'lib/models/porcelain.rb', line 10325 def public_key @public_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10345 10346 10347 10348 10349 10350 10351 |
# File 'lib/models/porcelain.rb', line 10345 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |