Class: SDM::MCPDCR

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MCPDCR is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ MCPDCR

Returns a new instance of MCPDCR.



10309
10310
10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
10331
10332
10333
10334
10335
10336
10337
10338
10339
# File 'lib/models/porcelain.rb', line 10309

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  oauth_auth_endpoint: nil,
  oauth_register_endpoint: nil,
  oauth_token_endpoint: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint
  @oauth_register_endpoint = oauth_register_endpoint == nil ? "" : oauth_register_endpoint
  @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10281
10282
10283
# File 'lib/models/porcelain.rb', line 10281

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10283
10284
10285
# File 'lib/models/porcelain.rb', line 10283

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10285
10286
10287
# File 'lib/models/porcelain.rb', line 10285

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10287
10288
10289
# File 'lib/models/porcelain.rb', line 10287

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10289
10290
10291
# File 'lib/models/porcelain.rb', line 10289

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10291
10292
10293
# File 'lib/models/porcelain.rb', line 10291

def name
  @name
end

#oauth_auth_endpointObject

The OAuth 2.0 authorization endpoint URL.



10293
10294
10295
# File 'lib/models/porcelain.rb', line 10293

def oauth_auth_endpoint
  @oauth_auth_endpoint
end

#oauth_register_endpointObject

The OAuth 2.0 dynamic client registration endpoint URL.



10295
10296
10297
# File 'lib/models/porcelain.rb', line 10295

def oauth_register_endpoint
  @oauth_register_endpoint
end

#oauth_token_endpointObject

The OAuth 2.0 token endpoint URL.



10297
10298
10299
# File 'lib/models/porcelain.rb', line 10297

def oauth_token_endpoint
  @oauth_token_endpoint
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10299
10300
10301
# File 'lib/models/porcelain.rb', line 10299

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10301
10302
10303
# File 'lib/models/porcelain.rb', line 10301

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10303
10304
10305
# File 'lib/models/porcelain.rb', line 10303

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10305
10306
10307
# File 'lib/models/porcelain.rb', line 10305

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10307
10308
10309
# File 'lib/models/porcelain.rb', line 10307

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10341
10342
10343
10344
10345
10346
10347
# File 'lib/models/porcelain.rb', line 10341

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end