Class: SDM::MCPGatewayOAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_scopes: nil, oauth_token_endpoint: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil, username: nil) ⇒ MCPGatewayOAuth

Returns a new instance of MCPGatewayOAuth.



10689
10690
10691
10692
10693
10694
10695
10696
10697
10698
10699
10700
10701
10702
10703
10704
10705
10706
10707
10708
10709
10710
10711
10712
10713
10714
10715
10716
10717
10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
# File 'lib/models/porcelain.rb', line 10689

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  oauth_auth_endpoint: nil,
  oauth_scopes: nil,
  oauth_token_endpoint: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint
  @oauth_scopes = oauth_scopes == nil ? "" : oauth_scopes
  @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10653
10654
10655
# File 'lib/models/porcelain.rb', line 10653

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



10655
10656
10657
# File 'lib/models/porcelain.rb', line 10655

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



10657
10658
10659
# File 'lib/models/porcelain.rb', line 10657

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



10659
10660
10661
# File 'lib/models/porcelain.rb', line 10659

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



10661
10662
10663
# File 'lib/models/porcelain.rb', line 10661

def name
  @name
end

#oauth_auth_endpoint ⇒ Object

The OAuth 2.0 authorization endpoint URL.



10663
10664
10665
# File 'lib/models/porcelain.rb', line 10663

def oauth_auth_endpoint
  @oauth_auth_endpoint
end

#oauth_scopes ⇒ Object

Space-separated list of OAuth scopes to request.



10665
10666
10667
# File 'lib/models/porcelain.rb', line 10665

def oauth_scopes
  @oauth_scopes
end

#oauth_token_endpoint ⇒ Object

The OAuth 2.0 token endpoint URL.



10667
10668
10669
# File 'lib/models/porcelain.rb', line 10667

def oauth_token_endpoint
  @oauth_token_endpoint
end

#password ⇒ Object

OAuth App Client Secret



10669
10670
10671
# File 'lib/models/porcelain.rb', line 10669

def password
  @password
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10671
10672
10673
# File 'lib/models/porcelain.rb', line 10671

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



10673
10674
10675
# File 'lib/models/porcelain.rb', line 10673

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



10675
10676
10677
# File 'lib/models/porcelain.rb', line 10675

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10677
10678
10679
# File 'lib/models/porcelain.rb', line 10677

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



10679
10680
10681
# File 'lib/models/porcelain.rb', line 10679

def tags
  @tags
end

#tls_cert ⇒ Object

Custom TLS certificate for upstream connection.



10681
10682
10683
# File 'lib/models/porcelain.rb', line 10681

def tls_cert
  @tls_cert
end

#tls_insecure ⇒ Object

Skip TLS certificate verification for the upstream connection.



10683
10684
10685
# File 'lib/models/porcelain.rb', line 10683

def tls_insecure
  @tls_insecure
end

#url ⇒ Object

The URL to dial to initiate a connection from the egress node to this resource.



10685
10686
10687
# File 'lib/models/porcelain.rb', line 10685

def url
  @url
end

#username ⇒ Object

OAuth App Client ID



10687
10688
10689
# File 'lib/models/porcelain.rb', line 10687

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10729
10730
10731
10732
10733
10734
10735
# File 'lib/models/porcelain.rb', line 10729

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end