Class: SDM::MCPGatewayOAuthDCR

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_scopes: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayOAuthDCR

Returns a new instance of MCPGatewayOAuthDCR.



10774
10775
10776
10777
10778
10779
10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
10802
10803
10804
10805
10806
10807
10808
10809
10810
# File 'lib/models/porcelain.rb', line 10774

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  oauth_auth_endpoint: nil,
  oauth_register_endpoint: nil,
  oauth_scopes: nil,
  oauth_token_endpoint: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint
  @oauth_register_endpoint = oauth_register_endpoint == nil ? "" : oauth_register_endpoint
  @oauth_scopes = oauth_scopes == nil ? "" : oauth_scopes
  @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10740
10741
10742
# File 'lib/models/porcelain.rb', line 10740

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



10742
10743
10744
# File 'lib/models/porcelain.rb', line 10742

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



10744
10745
10746
# File 'lib/models/porcelain.rb', line 10744

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



10746
10747
10748
# File 'lib/models/porcelain.rb', line 10746

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



10748
10749
10750
# File 'lib/models/porcelain.rb', line 10748

def name
  @name
end

#oauth_auth_endpoint ⇒ Object

The OAuth 2.0 authorization endpoint URL.



10750
10751
10752
# File 'lib/models/porcelain.rb', line 10750

def oauth_auth_endpoint
  @oauth_auth_endpoint
end

#oauth_register_endpoint ⇒ Object

The OAuth 2.0 dynamic client registration endpoint URL.



10752
10753
10754
# File 'lib/models/porcelain.rb', line 10752

def oauth_register_endpoint
  @oauth_register_endpoint
end

#oauth_scopes ⇒ Object

Space-separated list of OAuth scopes to request.



10754
10755
10756
# File 'lib/models/porcelain.rb', line 10754

def oauth_scopes
  @oauth_scopes
end

#oauth_token_endpoint ⇒ Object

The OAuth 2.0 token endpoint URL.



10756
10757
10758
# File 'lib/models/porcelain.rb', line 10756

def oauth_token_endpoint
  @oauth_token_endpoint
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10758
10759
10760
# File 'lib/models/porcelain.rb', line 10758

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



10760
10761
10762
# File 'lib/models/porcelain.rb', line 10760

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



10762
10763
10764
# File 'lib/models/porcelain.rb', line 10762

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10764
10765
10766
# File 'lib/models/porcelain.rb', line 10764

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



10766
10767
10768
# File 'lib/models/porcelain.rb', line 10766

def tags
  @tags
end

#tls_cert ⇒ Object

Custom TLS certificate for upstream connection.



10768
10769
10770
# File 'lib/models/porcelain.rb', line 10768

def tls_cert
  @tls_cert
end

#tls_insecure ⇒ Object

Skip TLS certificate verification for the upstream connection.



10770
10771
10772
# File 'lib/models/porcelain.rb', line 10770

def tls_insecure
  @tls_insecure
end

#url ⇒ Object

The URL to dial to initiate a connection from the egress node to this resource.



10772
10773
10774
# File 'lib/models/porcelain.rb', line 10772

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10812
10813
10814
10815
10816
10817
10818
# File 'lib/models/porcelain.rb', line 10812

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end