Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



10962
10963
10964
10965
10966
10967
10968
10969
10970
10971
10972
10973
10974
10975
10976
10977
10978
10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
10992
10993
10994
10995
10996
10997
10998
10999
11000
11001
11002
11003
11004
11005
11006
# File 'lib/models/porcelain.rb', line 10962

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10920
10921
10922
# File 'lib/models/porcelain.rb', line 10920

def bind_interface
  @bind_interface
end

#certificate_authority ⇒ Object

The CA to authenticate TLS connections with.



10922
10923
10924
# File 'lib/models/porcelain.rb', line 10922

def certificate_authority
  @certificate_authority
end

#client_certificate ⇒ Object

The certificate to authenticate TLS connections with.



10924
10925
10926
# File 'lib/models/porcelain.rb', line 10924

def client_certificate
  @client_certificate
end

#client_key ⇒ Object

The key to authenticate TLS connections with.



10926
10927
10928
# File 'lib/models/porcelain.rb', line 10926

def client_key
  @client_key
end

#database ⇒ Object

The database for healthchecks. Does not affect client requests.



10928
10929
10930
# File 'lib/models/porcelain.rb', line 10928

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



10930
10931
10932
# File 'lib/models/porcelain.rb', line 10930

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



10932
10933
10934
# File 'lib/models/porcelain.rb', line 10932

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



10934
10935
10936
# File 'lib/models/porcelain.rb', line 10934

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



10936
10937
10938
# File 'lib/models/porcelain.rb', line 10936

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



10938
10939
10940
# File 'lib/models/porcelain.rb', line 10938

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



10940
10941
10942
# File 'lib/models/porcelain.rb', line 10940

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



10942
10943
10944
# File 'lib/models/porcelain.rb', line 10942

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10944
10945
10946
# File 'lib/models/porcelain.rb', line 10944

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



10946
10947
10948
# File 'lib/models/porcelain.rb', line 10946

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_auth ⇒ Object

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10948
10949
10950
# File 'lib/models/porcelain.rb', line 10948

def require_native_auth
  @require_native_auth
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



10950
10951
10952
# File 'lib/models/porcelain.rb', line 10950

def secret_store_id
  @secret_store_id
end

#server_name ⇒ Object

Server name for TLS verification (unverified by StrongDM if empty)



10952
10953
10954
# File 'lib/models/porcelain.rb', line 10952

def server_name
  @server_name
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10954
10955
10956
# File 'lib/models/porcelain.rb', line 10954

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



10956
10957
10958
# File 'lib/models/porcelain.rb', line 10956

def tags
  @tags
end

#use_azure_single_server_usernames ⇒ Object

If true, appends the hostname to the username when hitting a database.azure.com address



10958
10959
10960
# File 'lib/models/porcelain.rb', line 10958

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#username ⇒ Object

The username to authenticate with.



10960
10961
10962
# File 'lib/models/porcelain.rb', line 10960

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11008
11009
11010
11011
11012
11013
11014
# File 'lib/models/porcelain.rb', line 11008

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end