Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
10530
10531
10532
10533
# File 'lib/models/porcelain.rb', line 10491

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10451
10452
10453
# File 'lib/models/porcelain.rb', line 10451

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10453
10454
10455
# File 'lib/models/porcelain.rb', line 10453

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10455
10456
10457
# File 'lib/models/porcelain.rb', line 10455

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10457
10458
10459
# File 'lib/models/porcelain.rb', line 10457

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10459
10460
10461
# File 'lib/models/porcelain.rb', line 10459

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10461
10462
10463
# File 'lib/models/porcelain.rb', line 10461

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10463
10464
10465
# File 'lib/models/porcelain.rb', line 10463

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10465
10466
10467
# File 'lib/models/porcelain.rb', line 10465

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10467
10468
10469
# File 'lib/models/porcelain.rb', line 10467

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10469
10470
10471
# File 'lib/models/porcelain.rb', line 10469

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10471
10472
10473
# File 'lib/models/porcelain.rb', line 10471

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10473
10474
10475
# File 'lib/models/porcelain.rb', line 10473

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10475
10476
10477
# File 'lib/models/porcelain.rb', line 10475

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10477
10478
10479
# File 'lib/models/porcelain.rb', line 10477

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10479
10480
10481
# File 'lib/models/porcelain.rb', line 10479

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10481
10482
10483
# File 'lib/models/porcelain.rb', line 10481

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10483
10484
10485
# File 'lib/models/porcelain.rb', line 10483

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10485
10486
10487
# File 'lib/models/porcelain.rb', line 10485

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10487
10488
10489
# File 'lib/models/porcelain.rb', line 10487

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10489
10490
10491
# File 'lib/models/porcelain.rb', line 10489

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10535
10536
10537
10538
10539
10540
10541
# File 'lib/models/porcelain.rb', line 10535

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end