Class: SDM::ManagedSecretDeleteRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretDeleteRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretDeleteRequest specified the ID of a Managed Secret to be deleted.
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to delete.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretDeleteRequest
constructor
A new instance of ManagedSecretDeleteRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretDeleteRequest
Returns a new instance of ManagedSecretDeleteRequest.
8397 8398 8399 8400 8401 |
# File 'lib/models/porcelain.rb', line 8397 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to delete.
8395 8396 8397 |
# File 'lib/models/porcelain.rb', line 8395 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8403 8404 8405 8406 8407 8408 8409 |
# File 'lib/models/porcelain.rb', line 8403 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |