Class: SDM::ManagedSecretGetRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretGetRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretGetRequest specifies which Managed Secret to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretGetRequest
constructor
A new instance of ManagedSecretGetRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretGetRequest
Returns a new instance of ManagedSecretGetRequest.
11209 11210 11211 11212 11213 |
# File 'lib/models/porcelain.rb', line 11209 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
11207 11208 11209 |
# File 'lib/models/porcelain.rb', line 11207 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11215 11216 11217 11218 11219 11220 11221 |
# File 'lib/models/porcelain.rb', line 11215 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |