Class: SDM::ManagedSecretLog
- Inherits:
-
Object
- Object
- SDM::ManagedSecretLog
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretLog contains details about action performed against a managed secret
Instance Attribute Summary collapse
-
#account_id ⇒ Object
An ID of the account the action was performed by.
-
#action ⇒ Object
The action performed by the account against the managed secret.
-
#created_at ⇒ Object
Timestamp of when action was performed.
-
#debug ⇒ Object
Any debug logs associated with the action.
-
#id ⇒ Object
Unique identifier of the Managed Secret Log.
-
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
-
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
Instance Method Summary collapse
-
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
constructor
A new instance of ManagedSecretLog.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
Returns a new instance of ManagedSecretLog.
10798 10799 10800 10801 10802 10803 10804 10805 10806 10807 10808 10809 10810 10811 10812 10813 10814 |
# File 'lib/models/porcelain.rb', line 10798 def initialize( account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil ) @account_id = account_id == nil ? "" : account_id @action = action == nil ? "" : action @created_at = created_at == nil ? nil : created_at @debug = debug == nil ? "" : debug @id = id == nil ? "" : id @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id end |
Instance Attribute Details
#account_id ⇒ Object
An ID of the account the action was performed by.
10784 10785 10786 |
# File 'lib/models/porcelain.rb', line 10784 def account_id @account_id end |
#action ⇒ Object
The action performed by the account against the managed secret.
10786 10787 10788 |
# File 'lib/models/porcelain.rb', line 10786 def action @action end |
#created_at ⇒ Object
Timestamp of when action was performed.
10788 10789 10790 |
# File 'lib/models/porcelain.rb', line 10788 def created_at @created_at end |
#debug ⇒ Object
Any debug logs associated with the action.
10790 10791 10792 |
# File 'lib/models/porcelain.rb', line 10790 def debug @debug end |
#id ⇒ Object
Unique identifier of the Managed Secret Log.
10792 10793 10794 |
# File 'lib/models/porcelain.rb', line 10792 def id @id end |
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
10794 10795 10796 |
# File 'lib/models/porcelain.rb', line 10794 def managed_secret_id @managed_secret_id end |
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
10796 10797 10798 |
# File 'lib/models/porcelain.rb', line 10796 def secret_engine_id @secret_engine_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10816 10817 10818 10819 10820 10821 10822 |
# File 'lib/models/porcelain.rb', line 10816 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |