Class: SDM::ManagedSecretPasswordPolicy
- Inherits:
-
Object
- Object
- SDM::ManagedSecretPasswordPolicy
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_repeat ⇒ Object
If set to true allows for consecutive characters to repeat itself.
-
#exclude_characters ⇒ Object
Characters to exclude when generating password.
-
#exclude_upper_case ⇒ Object
If set to true do not include upper case letters when generating password.
-
#length ⇒ Object
Password length.
-
#num_digits ⇒ Object
Numbers of digits to use when generating password.
-
#num_symbols ⇒ Object
Number of symbols to use when generating password.
Instance Method Summary collapse
-
#initialize(allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil) ⇒ ManagedSecretPasswordPolicy
constructor
A new instance of ManagedSecretPasswordPolicy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil) ⇒ ManagedSecretPasswordPolicy
Returns a new instance of ManagedSecretPasswordPolicy.
11161 11162 11163 11164 11165 11166 11167 11168 11169 11170 11171 11172 11173 11174 11175 |
# File 'lib/models/porcelain.rb', line 11161 def initialize( allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil ) @allow_repeat = allow_repeat == nil ? false : allow_repeat @exclude_characters = exclude_characters == nil ? "" : exclude_characters @exclude_upper_case = exclude_upper_case == nil ? false : exclude_upper_case @length = length == nil ? 0 : length @num_digits = num_digits == nil ? 0 : num_digits @num_symbols = num_symbols == nil ? 0 : num_symbols end |
Instance Attribute Details
#allow_repeat ⇒ Object
If set to true allows for consecutive characters to repeat itself
11149 11150 11151 |
# File 'lib/models/porcelain.rb', line 11149 def allow_repeat @allow_repeat end |
#exclude_characters ⇒ Object
Characters to exclude when generating password
11151 11152 11153 |
# File 'lib/models/porcelain.rb', line 11151 def exclude_characters @exclude_characters end |
#exclude_upper_case ⇒ Object
If set to true do not include upper case letters when generating password
11153 11154 11155 |
# File 'lib/models/porcelain.rb', line 11153 def exclude_upper_case @exclude_upper_case end |
#length ⇒ Object
Password length
11155 11156 11157 |
# File 'lib/models/porcelain.rb', line 11155 def length @length end |
#num_digits ⇒ Object
Numbers of digits to use when generating password
11157 11158 11159 |
# File 'lib/models/porcelain.rb', line 11157 def num_digits @num_digits end |
#num_symbols ⇒ Object
Number of symbols to use when generating password
11159 11160 11161 |
# File 'lib/models/porcelain.rb', line 11159 def num_symbols @num_symbols end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11177 11178 11179 11180 11181 11182 11183 |
# File 'lib/models/porcelain.rb', line 11177 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |