Class: SDM::ManagedSecretRetrieveRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretRetrieveRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretRetrieveRequest specifies which Managed Secret to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretRetrieveRequest
constructor
A new instance of ManagedSecretRetrieveRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretRetrieveRequest
Returns a new instance of ManagedSecretRetrieveRequest.
10853 10854 10855 10856 10857 |
# File 'lib/models/porcelain.rb', line 10853 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
10851 10852 10853 |
# File 'lib/models/porcelain.rb', line 10851 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10859 10860 10861 10862 10863 10864 10865 |
# File 'lib/models/porcelain.rb', line 10859 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |