Class: SDM::ManagedSecretValidateRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretValidateRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretValidateRequest specifies which Managed Secret to validate
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
constructor
A new instance of ManagedSecretValidateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
Returns a new instance of ManagedSecretValidateRequest.
11371 11372 11373 11374 11375 |
# File 'lib/models/porcelain.rb', line 11371 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
11369 11370 11371 |
# File 'lib/models/porcelain.rb', line 11369 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11377 11378 11379 11380 11381 11382 11383 |
# File 'lib/models/porcelain.rb', line 11377 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |