Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria



11458
11459
11460
11461
11462
11463
11464
11465
11466
11467
11468
11469
11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
11494
# File 'lib/models/porcelain.rb', line 11458

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11424
11425
11426
# File 'lib/models/porcelain.rb', line 11424

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11426
11427
11428
# File 'lib/models/porcelain.rb', line 11426

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11428
11429
11430
# File 'lib/models/porcelain.rb', line 11428

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11430
11431
11432
# File 'lib/models/porcelain.rb', line 11430

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11432
11433
11434
# File 'lib/models/porcelain.rb', line 11432

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11434
11435
11436
# File 'lib/models/porcelain.rb', line 11434

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11436
11437
11438
# File 'lib/models/porcelain.rb', line 11436

def name
  @name
end

#passwordObject

The password to authenticate with.



11438
11439
11440
# File 'lib/models/porcelain.rb', line 11438

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11440
11441
11442
# File 'lib/models/porcelain.rb', line 11440

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11442
11443
11444
# File 'lib/models/porcelain.rb', line 11442

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11444
11445
11446
# File 'lib/models/porcelain.rb', line 11444

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11446
11447
11448
# File 'lib/models/porcelain.rb', line 11446

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11448
11449
11450
# File 'lib/models/porcelain.rb', line 11448

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11450
11451
11452
# File 'lib/models/porcelain.rb', line 11450

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11452
11453
11454
# File 'lib/models/porcelain.rb', line 11452

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11454
11455
11456
# File 'lib/models/porcelain.rb', line 11454

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11456
11457
11458
# File 'lib/models/porcelain.rb', line 11456

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11496
11497
11498
11499
11500
11501
11502
# File 'lib/models/porcelain.rb', line 11496

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end