Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



11839
11840
11841
11842
11843
11844
11845
11846
11847
11848
11849
11850
11851
11852
11853
11854
11855
11856
11857
11858
11859
11860
11861
11862
11863
11864
11865
# File 'lib/models/porcelain.rb', line 11839

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11815
11816
11817
# File 'lib/models/porcelain.rb', line 11815

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



11817
11818
11819
# File 'lib/models/porcelain.rb', line 11817

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



11819
11820
11821
# File 'lib/models/porcelain.rb', line 11819

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



11821
11822
11823
# File 'lib/models/porcelain.rb', line 11821

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



11823
11824
11825
# File 'lib/models/porcelain.rb', line 11823

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



11825
11826
11827
# File 'lib/models/porcelain.rb', line 11825

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



11827
11828
11829
# File 'lib/models/porcelain.rb', line 11827

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11829
11830
11831
# File 'lib/models/porcelain.rb', line 11829

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



11831
11832
11833
# File 'lib/models/porcelain.rb', line 11831

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



11833
11834
11835
# File 'lib/models/porcelain.rb', line 11833

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11835
11836
11837
# File 'lib/models/porcelain.rb', line 11835

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



11837
11838
11839
# File 'lib/models/porcelain.rb', line 11837

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11867
11868
11869
11870
11871
11872
11873
# File 'lib/models/porcelain.rb', line 11867

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end