Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



11864
11865
11866
11867
11868
11869
11870
11871
11872
11873
11874
11875
11876
11877
11878
11879
11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
11890
11891
11892
11893
11894
11895
11896
11897
11898
11899
11900
# File 'lib/models/porcelain.rb', line 11864

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11830
11831
11832
# File 'lib/models/porcelain.rb', line 11830

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11832
11833
11834
# File 'lib/models/porcelain.rb', line 11832

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



11834
11835
11836
# File 'lib/models/porcelain.rb', line 11834

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11836
11837
11838
# File 'lib/models/porcelain.rb', line 11836

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11838
11839
11840
# File 'lib/models/porcelain.rb', line 11838

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11840
11841
11842
# File 'lib/models/porcelain.rb', line 11840

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11842
11843
11844
# File 'lib/models/porcelain.rb', line 11842

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11844
11845
11846
# File 'lib/models/porcelain.rb', line 11844

def name
  @name
end

#passwordObject

The password to authenticate with.



11846
11847
11848
# File 'lib/models/porcelain.rb', line 11846

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11848
11849
11850
# File 'lib/models/porcelain.rb', line 11848

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11850
11851
11852
# File 'lib/models/porcelain.rb', line 11850

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11852
11853
11854
# File 'lib/models/porcelain.rb', line 11852

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11854
11855
11856
# File 'lib/models/porcelain.rb', line 11854

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11856
11857
11858
# File 'lib/models/porcelain.rb', line 11856

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11858
11859
11860
# File 'lib/models/porcelain.rb', line 11858

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11860
11861
11862
# File 'lib/models/porcelain.rb', line 11860

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11862
11863
11864
# File 'lib/models/porcelain.rb', line 11862

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11902
11903
11904
11905
11906
11907
11908
# File 'lib/models/porcelain.rb', line 11902

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end