Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
12355
12356
12357
12358
12359
12360
12361
# File 'lib/models/porcelain.rb', line 12327

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_database ⇒ Object

The authentication database to use.



12295
12296
12297
# File 'lib/models/porcelain.rb', line 12295

def auth_database
  @auth_database
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12297
12298
12299
# File 'lib/models/porcelain.rb', line 12297

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12299
12300
12301
# File 'lib/models/porcelain.rb', line 12299

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12301
12302
12303
# File 'lib/models/porcelain.rb', line 12301

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



12303
12304
12305
# File 'lib/models/porcelain.rb', line 12303

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



12305
12306
12307
# File 'lib/models/porcelain.rb', line 12305

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12307
12308
12309
# File 'lib/models/porcelain.rb', line 12307

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



12309
12310
12311
# File 'lib/models/porcelain.rb', line 12309

def password
  @password
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12311
12312
12313
# File 'lib/models/porcelain.rb', line 12311

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12313
12314
12315
# File 'lib/models/porcelain.rb', line 12313

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to use for IAM (MONGODB-AWS) authentication.



12315
12316
12317
# File 'lib/models/porcelain.rb', line 12315

def region
  @region
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12317
12318
12319
# File 'lib/models/porcelain.rb', line 12317

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12319
12320
12321
# File 'lib/models/porcelain.rb', line 12319

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12321
12322
12323
# File 'lib/models/porcelain.rb', line 12321

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



12323
12324
12325
# File 'lib/models/porcelain.rb', line 12323

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



12325
12326
12327
# File 'lib/models/porcelain.rb', line 12325

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12363
12364
12365
12366
12367
12368
12369
# File 'lib/models/porcelain.rb', line 12363

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end