Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



12037
12038
12039
12040
12041
12042
12043
12044
12045
12046
12047
12048
12049
12050
12051
12052
12053
12054
12055
12056
12057
12058
12059
12060
12061
12062
12063
12064
12065
12066
12067
12068
12069
12070
12071
12072
12073
# File 'lib/models/porcelain.rb', line 12037

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



12003
12004
12005
# File 'lib/models/porcelain.rb', line 12003

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12005
12006
12007
# File 'lib/models/porcelain.rb', line 12005

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12007
12008
12009
# File 'lib/models/porcelain.rb', line 12007

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12009
12010
12011
# File 'lib/models/porcelain.rb', line 12009

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12011
12012
12013
# File 'lib/models/porcelain.rb', line 12011

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12013
12014
12015
# File 'lib/models/porcelain.rb', line 12013

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12015
12016
12017
# File 'lib/models/porcelain.rb', line 12015

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12017
12018
12019
# File 'lib/models/porcelain.rb', line 12017

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12019
12020
12021
# File 'lib/models/porcelain.rb', line 12019

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12021
12022
12023
# File 'lib/models/porcelain.rb', line 12021

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



12023
12024
12025
# File 'lib/models/porcelain.rb', line 12023

def region
  @region
end

#role_arnObject

The role to assume after logging in.



12025
12026
12027
# File 'lib/models/porcelain.rb', line 12025

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



12027
12028
12029
# File 'lib/models/porcelain.rb', line 12027

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



12029
12030
12031
# File 'lib/models/porcelain.rb', line 12029

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12031
12032
12033
# File 'lib/models/porcelain.rb', line 12031

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12033
12034
12035
# File 'lib/models/porcelain.rb', line 12033

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12035
12036
12037
# File 'lib/models/porcelain.rb', line 12035

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12075
12076
12077
12078
12079
12080
12081
# File 'lib/models/porcelain.rb', line 12075

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end