Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
12701 12702 12703 12704 12705 12706 12707 12708 12709 12710 12711 |
# File 'lib/models/porcelain.rb', line 12701 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
12692 12693 12694 |
# File 'lib/models/porcelain.rb', line 12692 def @meta end |
#node ⇒ Object
The created Node.
12694 12695 12696 |
# File 'lib/models/porcelain.rb', line 12694 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
12696 12697 12698 |
# File 'lib/models/porcelain.rb', line 12696 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
12699 12700 12701 |
# File 'lib/models/porcelain.rb', line 12699 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12713 12714 12715 12716 12717 12718 12719 |
# File 'lib/models/porcelain.rb', line 12713 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |