Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



12467
12468
12469
12470
12471
12472
12473
12474
12475
12476
12477
# File 'lib/models/porcelain.rb', line 12467

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



12459
12460
12461
# File 'lib/models/porcelain.rb', line 12459

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



12461
12462
12463
# File 'lib/models/porcelain.rb', line 12461

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



12463
12464
12465
# File 'lib/models/porcelain.rb', line 12463

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



12465
12466
12467
# File 'lib/models/porcelain.rb', line 12465

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12479
12480
12481
12482
12483
12484
12485
# File 'lib/models/porcelain.rb', line 12479

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end