Class: SDM::NodeTCPProbeResponse
- Inherits:
-
Object
- Object
- SDM::NodeTCPProbeResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeTCPProbeResponse reports the result of a TCP probe.
Instance Attribute Summary collapse
-
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
-
#meta ⇒ Object
Reserved for future use.
-
#rate_limit ⇒ Object
Rate limit information.
-
#succeeded ⇒ Object
True if the node was able to connect to the target address.
Instance Method Summary collapse
-
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
constructor
A new instance of NodeTCPProbeResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
Returns a new instance of NodeTCPProbeResponse.
12548 12549 12550 12551 12552 12553 12554 12555 12556 12557 12558 |
# File 'lib/models/porcelain.rb', line 12548 def initialize( error: nil, meta: nil, rate_limit: nil, succeeded: nil ) @error = error == nil ? "" : error @meta = == nil ? nil : @rate_limit = rate_limit == nil ? nil : rate_limit @succeeded = succeeded == nil ? false : succeeded end |
Instance Attribute Details
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
12540 12541 12542 |
# File 'lib/models/porcelain.rb', line 12540 def error @error end |
#meta ⇒ Object
Reserved for future use.
12542 12543 12544 |
# File 'lib/models/porcelain.rb', line 12542 def @meta end |
#rate_limit ⇒ Object
Rate limit information.
12544 12545 12546 |
# File 'lib/models/porcelain.rb', line 12544 def rate_limit @rate_limit end |
#succeeded ⇒ Object
True if the node was able to connect to the target address.
12546 12547 12548 |
# File 'lib/models/porcelain.rb', line 12546 def succeeded @succeeded end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12560 12561 12562 12563 12564 12565 12566 |
# File 'lib/models/porcelain.rb', line 12560 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |