Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12611
12612
12613
12614
12615
12616
12617
12618
12619
12620
12621
12622
12623
12624
12625
12626
12627
12628
12629
12630
12631
12632
12633
12634
12635
12636
12637
12638
12639
12640
12641
# File 'lib/models/porcelain.rb', line 12611

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12583
12584
12585
# File 'lib/models/porcelain.rb', line 12583

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



12585
12586
12587
# File 'lib/models/porcelain.rb', line 12585

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



12587
12588
12589
# File 'lib/models/porcelain.rb', line 12587

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12589
12590
12591
# File 'lib/models/porcelain.rb', line 12589

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



12591
12592
12593
# File 'lib/models/porcelain.rb', line 12591

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12593
12594
12595
# File 'lib/models/porcelain.rb', line 12593

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12595
12596
12597
# File 'lib/models/porcelain.rb', line 12595

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12597
12598
12599
# File 'lib/models/porcelain.rb', line 12597

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



12599
12600
12601
# File 'lib/models/porcelain.rb', line 12599

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



12601
12602
12603
# File 'lib/models/porcelain.rb', line 12601

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12603
12604
12605
# File 'lib/models/porcelain.rb', line 12603

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12605
12606
12607
# File 'lib/models/porcelain.rb', line 12605

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12607
12608
12609
# File 'lib/models/porcelain.rb', line 12607

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12609
12610
12611
# File 'lib/models/porcelain.rb', line 12609

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12643
12644
12645
12646
12647
12648
12649
# File 'lib/models/porcelain.rb', line 12643

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end