Class: SDM::OracleNNE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE

Returns a new instance of OracleNNE.



13146
13147
13148
13149
13150
13151
13152
13153
13154
13155
13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
13167
13168
13169
13170
13171
13172
13173
13174
13175
13176
13177
13178
13179
13180
# File 'lib/models/porcelain.rb', line 13146

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13114
13115
13116
# File 'lib/models/porcelain.rb', line 13114

def bind_interface
  @bind_interface
end

#database ⇒ Object

Oracle service name to connect to



13116
13117
13118
# File 'lib/models/porcelain.rb', line 13116

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



13118
13119
13120
# File 'lib/models/porcelain.rb', line 13118

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



13120
13121
13122
# File 'lib/models/porcelain.rb', line 13120

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



13122
13123
13124
# File 'lib/models/porcelain.rb', line 13122

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



13124
13125
13126
# File 'lib/models/porcelain.rb', line 13124

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



13126
13127
13128
# File 'lib/models/porcelain.rb', line 13126

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



13128
13129
13130
# File 'lib/models/porcelain.rb', line 13128

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



13130
13131
13132
# File 'lib/models/porcelain.rb', line 13130

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13132
13133
13134
# File 'lib/models/porcelain.rb', line 13132

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



13134
13135
13136
# File 'lib/models/porcelain.rb', line 13134

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



13136
13137
13138
# File 'lib/models/porcelain.rb', line 13136

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13138
13139
13140
# File 'lib/models/porcelain.rb', line 13138

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



13140
13141
13142
# File 'lib/models/porcelain.rb', line 13140

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



13142
13143
13144
# File 'lib/models/porcelain.rb', line 13142

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



13144
13145
13146
# File 'lib/models/porcelain.rb', line 13144

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13182
13183
13184
13185
13186
13187
13188
# File 'lib/models/porcelain.rb', line 13182

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end