Class: SDM::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, discard_replays: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_config: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, public_key_pem: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization

Returns a new instance of Organization.



13263
13264
13265
13266
13267
13268
13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
13279
13280
13281
13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
13309
13310
13311
13312
13313
13314
13315
13316
13317
13318
13319
13320
13321
13322
13323
13324
13325
13326
13327
# File 'lib/models/porcelain.rb', line 13263

def initialize(
  auth_provider: nil,
  created_at: nil,
  device_trust_enabled: nil,
  device_trust_provider: nil,
  discard_replays: nil,
  enforce_single_session: nil,
  idle_timeout: nil,
  idle_timeout_enabled: nil,
  kind: nil,
  log_config: nil,
  log_local_encoder: nil,
  log_local_format: nil,
  log_local_storage: nil,
  log_remote_encoder: nil,
  log_socket_path: nil,
  log_tcp_address: nil,
  loopback_range: nil,
  mfa_enabled: nil,
  mfa_provider: nil,
  name: nil,
  public_key_pem: nil,
  require_secret_store: nil,
  saml_metadata_url: nil,
  scim_provider: nil,
  sensitive_label: nil,
  session_timeout: nil,
  session_timeout_enabled: nil,
  ssh_certificate_authority_public_key: nil,
  ssh_certificate_authority_updated_at: nil,
  updated_at: nil,
  websites_subdomain: nil
)
  @auth_provider = auth_provider == nil ? "" : auth_provider
  @created_at = created_at == nil ? nil : created_at
  @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled
  @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider
  @discard_replays = discard_replays == nil ? false : discard_replays
  @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session
  @idle_timeout = idle_timeout == nil ? nil : idle_timeout
  @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled
  @kind = kind == nil ? "" : kind
  @log_config = log_config == nil ? nil : log_config
  @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder
  @log_local_format = log_local_format == nil ? "" : log_local_format
  @log_local_storage = log_local_storage == nil ? "" : log_local_storage
  @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder
  @log_socket_path = log_socket_path == nil ? "" : log_socket_path
  @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address
  @loopback_range = loopback_range == nil ? "" : loopback_range
  @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled
  @mfa_provider = mfa_provider == nil ? "" : mfa_provider
  @name = name == nil ? "" : name
  @public_key_pem = public_key_pem == nil ? "" : public_key_pem
  @require_secret_store = require_secret_store == nil ? false : require_secret_store
  @saml_metadata_url =  == nil ? "" : 
  @scim_provider = scim_provider == nil ? "" : scim_provider
  @sensitive_label = sensitive_label == nil ? "" : sensitive_label
  @session_timeout = session_timeout == nil ? nil : session_timeout
  @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled
  @ssh_certificate_authority_public_key = ssh_certificate_authority_public_key == nil ? "" : ssh_certificate_authority_public_key
  @ssh_certificate_authority_updated_at = ssh_certificate_authority_updated_at == nil ? nil : ssh_certificate_authority_updated_at
  @updated_at = updated_at == nil ? nil : updated_at
  @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain
end

Instance Attribute Details

#auth_provider ⇒ Object

The Organization's authentication provider, one of the AuthProvider constants.



13193
13194
13195
# File 'lib/models/porcelain.rb', line 13193

def auth_provider
  @auth_provider
end

#created_at ⇒ Object

The time at which the Organization was created.



13195
13196
13197
# File 'lib/models/porcelain.rb', line 13195

def created_at
  @created_at
end

#device_trust_enabled ⇒ Object

Indicates if the Organization has device trust enabled.



13197
13198
13199
# File 'lib/models/porcelain.rb', line 13197

def device_trust_enabled
  @device_trust_enabled
end

#device_trust_provider ⇒ Object

The Organization's device trust provider, one of the DeviceTrustProvider constants.



13199
13200
13201
# File 'lib/models/porcelain.rb', line 13199

def device_trust_provider
  @device_trust_provider
end

#discard_replays ⇒ Object

Indicates if the Organization should drop replay data for SSH, RDP, and K8s logs. Deprecated: use categories specific log_config.categories.remote_discard_replays instead



13202
13203
13204
# File 'lib/models/porcelain.rb', line 13202

def discard_replays
  @discard_replays
end

#enforce_single_session ⇒ Object

Indicates if the Organization enforces a single session per user for the CLI and AdminUI.



13204
13205
13206
# File 'lib/models/porcelain.rb', line 13204

def enforce_single_session
  @enforce_single_session
end

#idle_timeout ⇒ Object

The Organization's idle timeout, if enabled.



13206
13207
13208
# File 'lib/models/porcelain.rb', line 13206

def idle_timeout
  @idle_timeout
end

#idle_timeout_enabled ⇒ Object

Indicates if the Organization has idle timeouts enabled.



13208
13209
13210
# File 'lib/models/porcelain.rb', line 13208

def idle_timeout_enabled
  @idle_timeout_enabled
end

#kind ⇒ Object

The Organization's type, one of the OrgKind constants.



13210
13211
13212
# File 'lib/models/porcelain.rb', line 13210

def kind
  @kind
end

#log_config ⇒ Object

The Organization's logging settings



13212
13213
13214
# File 'lib/models/porcelain.rb', line 13212

def log_config
  @log_config
end

#log_local_encoder ⇒ Object

The Organization's local log encryption encoder, one of the LogLocalEncoder constants. Deprecated: use log_config.local_encoder instead



13215
13216
13217
# File 'lib/models/porcelain.rb', line 13215

def log_local_encoder
  @log_local_encoder
end

#log_local_format ⇒ Object

The Organization's local log format, one of the LogLocalFormat constants. Deprecated: use log_config.local_format instead



13218
13219
13220
# File 'lib/models/porcelain.rb', line 13218

def log_local_format
  @log_local_format
end

#log_local_storage ⇒ Object

The Organization's local log storage, one of the LogLocalStorage constants. Deprecated: use log_config.local_storage instead



13221
13222
13223
# File 'lib/models/porcelain.rb', line 13221

def log_local_storage
  @log_local_storage
end

#log_remote_encoder ⇒ Object

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants. Deprecated: use categories specific log_config.categories.remote_encoder instead



13224
13225
13226
# File 'lib/models/porcelain.rb', line 13224

def log_remote_encoder
  @log_remote_encoder
end

#log_socket_path ⇒ Object

The Organization's socket path for Socket local log storage. Deprecated: use log_config.local_socket_path instead



13227
13228
13229
# File 'lib/models/porcelain.rb', line 13227

def log_socket_path
  @log_socket_path
end

#log_tcp_address ⇒ Object

The Organization's TCP address for TCP or Syslog local log storage. Deprecated: use log_config.local_tcp_address instead



13230
13231
13232
# File 'lib/models/porcelain.rb', line 13230

def log_tcp_address
  @log_tcp_address
end

#loopback_range ⇒ Object

The Organization's loopback range.



13232
13233
13234
# File 'lib/models/porcelain.rb', line 13232

def loopback_range
  @loopback_range
end

#mfa_enabled ⇒ Object

Indicates if the Organization has multi-factor authentication enabled.



13234
13235
13236
# File 'lib/models/porcelain.rb', line 13234

def mfa_enabled
  @mfa_enabled
end

#mfa_provider ⇒ Object

The Organization's multi-factor authentication provider, one of the MFAProvider constants.



13236
13237
13238
# File 'lib/models/porcelain.rb', line 13236

def mfa_provider
  @mfa_provider
end

#name ⇒ Object

The Organization's name.



13238
13239
13240
# File 'lib/models/porcelain.rb', line 13238

def name
  @name
end

#public_key_pem ⇒ Object

The Organization's public key PEM for encrypting remote logs. Deprecated: use log_config.public_key instead



13241
13242
13243
# File 'lib/models/porcelain.rb', line 13241

def public_key_pem
  @public_key_pem
end

#require_secret_store ⇒ Object

Indicates if the Organization requires secret stores.



13243
13244
13245
# File 'lib/models/porcelain.rb', line 13243

def require_secret_store
  @require_secret_store
end

#saml_metadata_url ⇒ Object

The Organization's URL for SAML metadata.



13245
13246
13247
# File 'lib/models/porcelain.rb', line 13245

def 
  @saml_metadata_url
end

#scim_provider ⇒ Object

The Organization's SCIM provider, one of the SCIMProvider constants.



13247
13248
13249
# File 'lib/models/porcelain.rb', line 13247

def scim_provider
  @scim_provider
end

#sensitive_label ⇒ Object

The Organization's label for sensitive resources.



13249
13250
13251
# File 'lib/models/porcelain.rb', line 13249

def sensitive_label
  @sensitive_label
end

#session_timeout ⇒ Object

The Organization's session timeout, if enabled.



13251
13252
13253
# File 'lib/models/porcelain.rb', line 13251

def session_timeout
  @session_timeout
end

#session_timeout_enabled ⇒ Object

Indicates if the Organization has session timeouts enabled.



13253
13254
13255
# File 'lib/models/porcelain.rb', line 13253

def session_timeout_enabled
  @session_timeout_enabled
end

#ssh_certificate_authority_public_key ⇒ Object

The Organization's SSH certificate authority public key.



13255
13256
13257
# File 'lib/models/porcelain.rb', line 13255

def ssh_certificate_authority_public_key
  @ssh_certificate_authority_public_key
end

#ssh_certificate_authority_updated_at ⇒ Object

The time at which the Organization's SSH certificate authority was last updated.



13257
13258
13259
# File 'lib/models/porcelain.rb', line 13257

def ssh_certificate_authority_updated_at
  @ssh_certificate_authority_updated_at
end

#updated_at ⇒ Object

The time at which the Organization was last updated.



13259
13260
13261
# File 'lib/models/porcelain.rb', line 13259

def updated_at
  @updated_at
end

#websites_subdomain ⇒ Object

The Organization's web site domain.



13261
13262
13263
# File 'lib/models/porcelain.rb', line 13261

def websites_subdomain
  @websites_subdomain
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13329
13330
13331
13332
13333
13334
13335
# File 'lib/models/porcelain.rb', line 13329

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end