Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



13376
13377
13378
13379
13380
13381
13382
13383
13384
# File 'lib/models/porcelain.rb', line 13376

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



13370
13371
13372
# File 'lib/models/porcelain.rb', line 13370

def activity_id
  @activity_id
end

#organization ⇒ Object

The complete Organization state at this time.



13372
13373
13374
# File 'lib/models/porcelain.rb', line 13372

def organization
  @organization
end

#timestamp ⇒ Object

The time at which the Organization state was recorded.



13374
13375
13376
# File 'lib/models/porcelain.rb', line 13374

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13386
13387
13388
13389
13390
13391
13392
# File 'lib/models/porcelain.rb', line 13386

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end