Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
13552 13553 13554 13555 13556 13557 13558 13559 13560 |
# File 'lib/models/porcelain.rb', line 13552 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
13546 13547 13548 |
# File 'lib/models/porcelain.rb', line 13546 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
13548 13549 13550 |
# File 'lib/models/porcelain.rb', line 13548 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
13550 13551 13552 |
# File 'lib/models/porcelain.rb', line 13550 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13562 13563 13564 13565 13566 13567 13568 |
# File 'lib/models/porcelain.rb', line 13562 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |