Class: SDM::PeeringGroupResource
- Inherits:
-
Object
- Object
- SDM::PeeringGroupResource
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupResource represents the attachment between a PeeringGroup and a Resource.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#resource_id ⇒ Object
Resource ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
constructor
A new instance of PeeringGroupResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
Returns a new instance of PeeringGroupResource.
13768 13769 13770 13771 13772 13773 13774 13775 13776 |
# File 'lib/models/porcelain.rb', line 13768 def initialize( group_id: nil, id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
13762 13763 13764 |
# File 'lib/models/porcelain.rb', line 13762 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
13764 13765 13766 |
# File 'lib/models/porcelain.rb', line 13764 def id @id end |
#resource_id ⇒ Object
Resource ID to be attached.
13766 13767 13768 |
# File 'lib/models/porcelain.rb', line 13766 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13778 13779 13780 13781 13782 13783 13784 |
# File 'lib/models/porcelain.rb', line 13778 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |