Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



13985
13986
13987
13988
13989
13990
13991
13992
13993
13994
13995
# File 'lib/models/porcelain.rb', line 13985

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



13977
13978
13979
# File 'lib/models/porcelain.rb', line 13977

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this Policy was deleted, the time it was deleted.



13979
13980
13981
# File 'lib/models/porcelain.rb', line 13979

def deleted_at
  @deleted_at
end

#policy ⇒ Object

The complete Policy state at this time.



13981
13982
13983
# File 'lib/models/porcelain.rb', line 13981

def policy
  @policy
end

#timestamp ⇒ Object

The time at which the Policy state was recorded.



13983
13984
13985
# File 'lib/models/porcelain.rb', line 13983

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13997
13998
13999
14000
14001
14002
14003
# File 'lib/models/porcelain.rb', line 13997

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end