Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



13636
13637
13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
13650
13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
13668
13669
13670
# File 'lib/models/porcelain.rb', line 13636

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13604
13605
13606
# File 'lib/models/porcelain.rb', line 13604

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13606
13607
13608
# File 'lib/models/porcelain.rb', line 13606

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13608
13609
13610
# File 'lib/models/porcelain.rb', line 13608

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13610
13611
13612
# File 'lib/models/porcelain.rb', line 13610

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13612
13613
13614
# File 'lib/models/porcelain.rb', line 13612

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13614
13615
13616
# File 'lib/models/porcelain.rb', line 13614

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13616
13617
13618
# File 'lib/models/porcelain.rb', line 13616

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13618
13619
13620
# File 'lib/models/porcelain.rb', line 13618

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



13620
13621
13622
# File 'lib/models/porcelain.rb', line 13620

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13622
13623
13624
# File 'lib/models/porcelain.rb', line 13622

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13624
13625
13626
# File 'lib/models/porcelain.rb', line 13624

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13626
13627
13628
# File 'lib/models/porcelain.rb', line 13626

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13628
13629
13630
# File 'lib/models/porcelain.rb', line 13628

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13630
13631
13632
# File 'lib/models/porcelain.rb', line 13630

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13632
13633
13634
# File 'lib/models/porcelain.rb', line 13632

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13634
13635
13636
# File 'lib/models/porcelain.rb', line 13634

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13672
13673
13674
13675
13676
13677
13678
# File 'lib/models/porcelain.rb', line 13672

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end