Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



14248
14249
14250
14251
14252
14253
14254
14255
14256
14257
14258
14259
14260
14261
14262
14263
14264
14265
14266
14267
14268
14269
14270
14271
14272
14273
14274
14275
14276
14277
14278
14279
14280
14281
14282
# File 'lib/models/porcelain.rb', line 14248

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14216
14217
14218
# File 'lib/models/porcelain.rb', line 14216

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14218
14219
14220
# File 'lib/models/porcelain.rb', line 14218

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



14220
14221
14222
# File 'lib/models/porcelain.rb', line 14220

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



14222
14223
14224
# File 'lib/models/porcelain.rb', line 14222

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



14224
14225
14226
# File 'lib/models/porcelain.rb', line 14224

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



14226
14227
14228
# File 'lib/models/porcelain.rb', line 14226

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



14228
14229
14230
# File 'lib/models/porcelain.rb', line 14228

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



14230
14231
14232
# File 'lib/models/porcelain.rb', line 14230

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



14232
14233
14234
# File 'lib/models/porcelain.rb', line 14232

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14234
14235
14236
# File 'lib/models/porcelain.rb', line 14234

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



14236
14237
14238
# File 'lib/models/porcelain.rb', line 14236

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



14238
14239
14240
# File 'lib/models/porcelain.rb', line 14238

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14240
14241
14242
# File 'lib/models/porcelain.rb', line 14240

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



14242
14243
14244
# File 'lib/models/porcelain.rb', line 14242

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



14244
14245
14246
# File 'lib/models/porcelain.rb', line 14244

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



14246
14247
14248
# File 'lib/models/porcelain.rb', line 14246

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14284
14285
14286
14287
14288
14289
14290
# File 'lib/models/porcelain.rb', line 14284

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end