Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



13923
13924
13925
13926
13927
13928
13929
13930
13931
13932
13933
# File 'lib/models/porcelain.rb', line 13923

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



13915
13916
13917
# File 'lib/models/porcelain.rb', line 13915

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



13917
13918
13919
# File 'lib/models/porcelain.rb', line 13917

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



13919
13920
13921
# File 'lib/models/porcelain.rb', line 13919

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



13921
13922
13923
# File 'lib/models/porcelain.rb', line 13921

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13935
13936
13937
13938
13939
13940
13941
# File 'lib/models/porcelain.rb', line 13935

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end