Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



14367
14368
14369
14370
14371
14372
14373
14374
14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
14403
14404
14405
14406
14407
# File 'lib/models/porcelain.rb', line 14367

def initialize(
  bind_interface: nil,
  dc_hostnames: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_fqdn: nil,
  sid: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @dc_hostnames = dc_hostnames == nil ? "" : dc_hostnames
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_fqdn = server_fqdn == nil ? "" : server_fqdn
  @sid = sid == nil ? "" : sid
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14329
14330
14331
# File 'lib/models/porcelain.rb', line 14329

def bind_interface
  @bind_interface
end

#dc_hostnamesObject

Comma-separated list of Active Directory Domain Controller hostnames. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), and for LDAPS SID resolution for strong certificate mapping in full enforcement mode when the identity alias does not specify a SID. Unused for Entra ID.



14331
14332
14333
# File 'lib/models/porcelain.rb', line 14331

def dc_hostnames
  @dc_hostnames
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14333
14334
14335
# File 'lib/models/porcelain.rb', line 14333

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14335
14336
14337
# File 'lib/models/porcelain.rb', line 14335

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14337
14338
14339
# File 'lib/models/porcelain.rb', line 14337

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14339
14340
14341
# File 'lib/models/porcelain.rb', line 14339

def id
  @id
end

#identity_alias_healthcheck_usernameObject

Username of the AD service account for health checks, and LDAPS SID resolution if necessary. Required for on-premises AD environments, unused for Entra ID.



14341
14342
14343
# File 'lib/models/porcelain.rb', line 14341

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



14343
14344
14345
# File 'lib/models/porcelain.rb', line 14343

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



14345
14346
14347
# File 'lib/models/porcelain.rb', line 14345

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



14347
14348
14349
# File 'lib/models/porcelain.rb', line 14347

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14349
14350
14351
# File 'lib/models/porcelain.rb', line 14349

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14351
14352
14353
# File 'lib/models/porcelain.rb', line 14351

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14353
14354
14355
# File 'lib/models/porcelain.rb', line 14353

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14355
14356
14357
# File 'lib/models/porcelain.rb', line 14355

def secret_store_id
  @secret_store_id
end

#server_fqdnObject

Fully-qualified DNS name of the target Windows server, including the AD domain. Must match the Service Principal Name (SPN) of the server in AD. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), unused for Entra ID.



14357
14358
14359
# File 'lib/models/porcelain.rb', line 14357

def server_fqdn
  @server_fqdn
end

#sidObject

Windows Security Identifier (SID) of the configured Username, or AD service account if using LDAPS SID resolution. Required in on-premises AD environments for strong certificate mapping in full enforcement mode, unused for Entra ID.



14359
14360
14361
# File 'lib/models/porcelain.rb', line 14359

def sid
  @sid
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14361
14362
14363
# File 'lib/models/porcelain.rb', line 14361

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14363
14364
14365
# File 'lib/models/porcelain.rb', line 14363

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14365
14366
14367
# File 'lib/models/porcelain.rb', line 14365

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14409
14410
14411
14412
14413
14414
14415
# File 'lib/models/porcelain.rb', line 14409

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end