Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



15087
15088
15089
15090
15091
15092
15093
15094
15095
15096
15097
15098
15099
15100
15101
15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
# File 'lib/models/porcelain.rb', line 15087

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15063
15064
15065
# File 'lib/models/porcelain.rb', line 15063

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



15065
15066
15067
# File 'lib/models/porcelain.rb', line 15065

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



15067
15068
15069
# File 'lib/models/porcelain.rb', line 15067

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



15069
15070
15071
# File 'lib/models/porcelain.rb', line 15069

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



15071
15072
15073
# File 'lib/models/porcelain.rb', line 15071

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



15073
15074
15075
# File 'lib/models/porcelain.rb', line 15073

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



15075
15076
15077
# File 'lib/models/porcelain.rb', line 15075

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15077
15078
15079
# File 'lib/models/porcelain.rb', line 15077

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



15079
15080
15081
# File 'lib/models/porcelain.rb', line 15079

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



15081
15082
15083
# File 'lib/models/porcelain.rb', line 15081

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15083
15084
15085
# File 'lib/models/porcelain.rb', line 15083

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



15085
15086
15087
# File 'lib/models/porcelain.rb', line 15085

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15115
15116
15117
15118
15119
15120
15121
# File 'lib/models/porcelain.rb', line 15115

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end