Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



14956
14957
14958
14959
14960
14961
14962
14963
14964
14965
14966
14967
14968
14969
14970
14971
14972
14973
14974
14975
14976
14977
14978
14979
14980
14981
14982
14983
14984
14985
14986
14987
14988
14989
14990
14991
14992
# File 'lib/models/porcelain.rb', line 14956

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14922
14923
14924
# File 'lib/models/porcelain.rb', line 14922

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



14924
14925
14926
# File 'lib/models/porcelain.rb', line 14924

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14926
14927
14928
# File 'lib/models/porcelain.rb', line 14926

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14928
14929
14930
# File 'lib/models/porcelain.rb', line 14928

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14930
14931
14932
# File 'lib/models/porcelain.rb', line 14930

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14932
14933
14934
# File 'lib/models/porcelain.rb', line 14932

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14934
14935
14936
# File 'lib/models/porcelain.rb', line 14934

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14936
14937
14938
# File 'lib/models/porcelain.rb', line 14936

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14938
14939
14940
# File 'lib/models/porcelain.rb', line 14938

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14940
14941
14942
# File 'lib/models/porcelain.rb', line 14940

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14942
14943
14944
# File 'lib/models/porcelain.rb', line 14942

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14944
14945
14946
# File 'lib/models/porcelain.rb', line 14944

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14946
14947
14948
# File 'lib/models/porcelain.rb', line 14946

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14948
14949
14950
# File 'lib/models/porcelain.rb', line 14948

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14950
14951
14952
# File 'lib/models/porcelain.rb', line 14950

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14952
14953
14954
# File 'lib/models/porcelain.rb', line 14952

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14954
14955
14956
# File 'lib/models/porcelain.rb', line 14954

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14994
14995
14996
14997
14998
14999
15000
# File 'lib/models/porcelain.rb', line 14994

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end