Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



15599
15600
15601
15602
15603
15604
15605
15606
15607
15608
15609
# File 'lib/models/porcelain.rb', line 15599

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_id ⇒ Object

The account for this remote identity.



15591
15592
15593
# File 'lib/models/porcelain.rb', line 15591

def 
  @account_id
end

#id ⇒ Object

Unique identifier of the RemoteIdentity.



15593
15594
15595
# File 'lib/models/porcelain.rb', line 15593

def id
  @id
end

#remote_identity_group_id ⇒ Object

The remote identity group.



15595
15596
15597
# File 'lib/models/porcelain.rb', line 15595

def remote_identity_group_id
  @remote_identity_group_id
end

#username ⇒ Object

The username to be used as the remote identity for this account.



15597
15598
15599
# File 'lib/models/porcelain.rb', line 15597

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15611
15612
15613
15614
15615
15616
15617
# File 'lib/models/porcelain.rb', line 15611

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end