Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
# File 'lib/models/porcelain.rb', line 15367

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



15359
15360
15361
# File 'lib/models/porcelain.rb', line 15359

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



15361
15362
15363
# File 'lib/models/porcelain.rb', line 15361

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



15363
15364
15365
# File 'lib/models/porcelain.rb', line 15363

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



15365
15366
15367
# File 'lib/models/porcelain.rb', line 15365

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15379
15380
15381
15382
15383
15384
15385
# File 'lib/models/porcelain.rb', line 15379

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end