Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



15860
15861
15862
15863
15864
15865
15866
15867
15868
# File 'lib/models/porcelain.rb', line 15860

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#data ⇒ Object

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



15853
15854
15855
# File 'lib/models/porcelain.rb', line 15853

def data
  @data
end

#events ⇒ Object

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



15856
15857
15858
# File 'lib/models/porcelain.rb', line 15856

def events
  @events
end

#symmetric_key ⇒ Object

If the data is encrypted, this contains the encrypted symmetric key



15858
15859
15860
# File 'lib/models/porcelain.rb', line 15858

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15870
15871
15872
15873
15874
15875
15876
# File 'lib/models/porcelain.rb', line 15870

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end