Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



15887
15888
15889
15890
15891
15892
15893
# File 'lib/models/porcelain.rb', line 15887

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#data ⇒ Object

The raw data of the ReplayChunkEvent.



15883
15884
15885
# File 'lib/models/porcelain.rb', line 15883

def data
  @data
end

#duration ⇒ Object

The time duration over which the data in this ReplayChunkEvent was transferred.



15885
15886
15887
# File 'lib/models/porcelain.rb', line 15885

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15895
15896
15897
15898
15899
15900
15901
# File 'lib/models/porcelain.rb', line 15895

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end