Class: SDM::RequestableAccountEntitlement
- Inherits:
-
Object
- Object
- SDM::RequestableAccountEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
RequestableAccountEntitlement represents an individual resource that an Account is permitted to request access to.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested.
Instance Method Summary collapse
-
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableAccountEntitlement
constructor
A new instance of RequestableAccountEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableAccountEntitlement
Returns a new instance of RequestableAccountEntitlement.
15482 15483 15484 15485 15486 15487 15488 15489 15490 15491 15492 |
# File 'lib/models/porcelain.rb', line 15482 def initialize( group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
15474 15475 15476 |
# File 'lib/models/porcelain.rb', line 15474 def group_id @group_id end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
15476 15477 15478 |
# File 'lib/models/porcelain.rb', line 15476 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
15478 15479 15480 |
# File 'lib/models/porcelain.rb', line 15478 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested.
15480 15481 15482 |
# File 'lib/models/porcelain.rb', line 15480 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15494 15495 15496 15497 15498 15499 15500 |
# File 'lib/models/porcelain.rb', line 15494 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |