Class: SDM::RequestableRoleEntitlement
- Inherits:
-
Object
- Object
- SDM::RequestableRoleEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
RequestableRoleEntitlement represents an individual resource that a Role permits its members to request access to.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested through this role.
Instance Method Summary collapse
-
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableRoleEntitlement
constructor
A new instance of RequestableRoleEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableRoleEntitlement
Returns a new instance of RequestableRoleEntitlement.
15590 15591 15592 15593 15594 15595 15596 15597 15598 15599 15600 |
# File 'lib/models/porcelain.rb', line 15590 def initialize( group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
15582 15583 15584 |
# File 'lib/models/porcelain.rb', line 15582 def group_id @group_id end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
15584 15585 15586 |
# File 'lib/models/porcelain.rb', line 15584 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
15586 15587 15588 |
# File 'lib/models/porcelain.rb', line 15586 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested through this role.
15588 15589 15590 |
# File 'lib/models/porcelain.rb', line 15588 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15602 15603 15604 15605 15606 15607 15608 |
# File 'lib/models/porcelain.rb', line 15602 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |