Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



16183
16184
16185
16186
16187
16188
16189
16190
16191
16192
16193
# File 'lib/models/porcelain.rb', line 16183

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



16175
16176
16177
# File 'lib/models/porcelain.rb', line 16175

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this Resource was deleted, the time it was deleted.



16177
16178
16179
# File 'lib/models/porcelain.rb', line 16177

def deleted_at
  @deleted_at
end

#resource ⇒ Object

The complete Resource state at this time.



16179
16180
16181
# File 'lib/models/porcelain.rb', line 16179

def resource
  @resource
end

#timestamp ⇒ Object

The time at which the Resource state was recorded.



16181
16182
16183
# File 'lib/models/porcelain.rb', line 16181

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16195
16196
16197
16198
16199
16200
16201
# File 'lib/models/porcelain.rb', line 16195

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end