Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



15815
15816
15817
15818
15819
15820
15821
15822
15823
15824
15825
15826
15827
# File 'lib/models/porcelain.rb', line 15815

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



15805
15806
15807
# File 'lib/models/porcelain.rb', line 15805

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



15807
15808
15809
# File 'lib/models/porcelain.rb', line 15807

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



15809
15810
15811
# File 'lib/models/porcelain.rb', line 15809

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



15811
15812
15813
# File 'lib/models/porcelain.rb', line 15811

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



15813
15814
15815
# File 'lib/models/porcelain.rb', line 15813

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15829
15830
15831
15832
15833
15834
15835
# File 'lib/models/porcelain.rb', line 15829

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end