Class: SDM::RoleGrant

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A RoleGrant connects a resource to a role, granting members of the role access to that resource.

Deprecated: use Role access rules instead.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, resource_id: nil, role_id: nil) ⇒ RoleGrant

Returns a new instance of RoleGrant.



5564
5565
5566
5567
5568
5569
5570
5571
5572
# File 'lib/models/porcelain.rb', line 5564

def initialize(
  id: nil,
  resource_id: nil,
  role_id: nil
)
  @id = id == nil ? "" : id
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#idObject

Unique identifier of the RoleGrant.



5558
5559
5560
# File 'lib/models/porcelain.rb', line 5558

def id
  @id
end

#resource_idObject

The id of the resource of this RoleGrant.



5560
5561
5562
# File 'lib/models/porcelain.rb', line 5560

def resource_id
  @resource_id
end

#role_idObject

The id of the attached role of this RoleGrant.



5562
5563
5564
# File 'lib/models/porcelain.rb', line 5562

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5574
5575
5576
5577
5578
5579
5580
# File 'lib/models/porcelain.rb', line 5574

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end