Class: SDM::RoleHistory
- Inherits:
-
Object
- Object
- SDM::RoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role.
-
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
-
#role ⇒ Object
The complete Role state at this time.
-
#timestamp ⇒ Object
The time at which the Role state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
constructor
A new instance of RoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
Returns a new instance of RoleHistory.
16366 16367 16368 16369 16370 16371 16372 16373 16374 16375 16376 |
# File 'lib/models/porcelain.rb', line 16366 def initialize( activity_id: nil, deleted_at: nil, role: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role = role == nil ? nil : role @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.
16358 16359 16360 |
# File 'lib/models/porcelain.rb', line 16358 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
16360 16361 16362 |
# File 'lib/models/porcelain.rb', line 16360 def deleted_at @deleted_at end |
#role ⇒ Object
The complete Role state at this time.
16362 16363 16364 |
# File 'lib/models/porcelain.rb', line 16362 def role @role end |
#timestamp ⇒ Object
The time at which the Role state was recorded.
16364 16365 16366 |
# File 'lib/models/porcelain.rb', line 16364 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16378 16379 16380 16381 16382 16383 16384 |
# File 'lib/models/porcelain.rb', line 16378 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |