Class: SDM::RoleResource
- Inherits:
-
Object
- Object
- SDM::RoleResource
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResource represents an individual access grant of a Role to a Resource.
Instance Attribute Summary collapse
-
#granted_at ⇒ Object
The most recent time at which access was granted.
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
-
#role_id ⇒ Object
The unique identifier of the Role to which access is granted.
Instance Method Summary collapse
-
#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource
constructor
A new instance of RoleResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource
Returns a new instance of RoleResource.
15851 15852 15853 15854 15855 15856 15857 15858 15859 |
# File 'lib/models/porcelain.rb', line 15851 def initialize( granted_at: nil, resource_id: nil, role_id: nil ) @granted_at = granted_at == nil ? nil : granted_at @resource_id = resource_id == nil ? "" : resource_id @role_id = role_id == nil ? "" : role_id end |
Instance Attribute Details
#granted_at ⇒ Object
The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.
15845 15846 15847 |
# File 'lib/models/porcelain.rb', line 15845 def granted_at @granted_at end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
15847 15848 15849 |
# File 'lib/models/porcelain.rb', line 15847 def resource_id @resource_id end |
#role_id ⇒ Object
The unique identifier of the Role to which access is granted.
15849 15850 15851 |
# File 'lib/models/porcelain.rb', line 15849 def role_id @role_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15861 15862 15863 15864 15865 15866 15867 |
# File 'lib/models/porcelain.rb', line 15861 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |