Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



16430
16431
16432
16433
16434
16435
16436
16437
16438
16439
16440
# File 'lib/models/porcelain.rb', line 16430

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



16422
16423
16424
# File 'lib/models/porcelain.rb', line 16422

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this RoleResource was deleted, the time it was deleted.



16424
16425
16426
# File 'lib/models/porcelain.rb', line 16424

def deleted_at
  @deleted_at
end

#role_resource ⇒ Object

The complete RoleResource state at this time.



16426
16427
16428
# File 'lib/models/porcelain.rb', line 16426

def role_resource
  @role_resource
end

#timestamp ⇒ Object

The time at which the RoleResource state was recorded.



16428
16429
16430
# File 'lib/models/porcelain.rb', line 16428

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16442
16443
16444
16445
16446
16447
16448
# File 'lib/models/porcelain.rb', line 16442

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end