Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



15932
15933
15934
15935
15936
15937
15938
15939
15940
15941
15942
15943
15944
15945
15946
15947
15948
15949
15950
15951
15952
15953
15954
15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
# File 'lib/models/porcelain.rb', line 15932

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



15894
15895
15896
# File 'lib/models/porcelain.rb', line 15894

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15896
15897
15898
# File 'lib/models/porcelain.rb', line 15896

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



15898
15899
15900
# File 'lib/models/porcelain.rb', line 15898

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



15900
15901
15902
# File 'lib/models/porcelain.rb', line 15900

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15902
15903
15904
# File 'lib/models/porcelain.rb', line 15902

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15904
15905
15906
# File 'lib/models/porcelain.rb', line 15904

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15906
15907
15908
# File 'lib/models/porcelain.rb', line 15906

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15908
15909
15910
# File 'lib/models/porcelain.rb', line 15908

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15910
15911
15912
# File 'lib/models/porcelain.rb', line 15910

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15912
15913
15914
# File 'lib/models/porcelain.rb', line 15912

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15914
15915
15916
# File 'lib/models/porcelain.rb', line 15914

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15916
15917
15918
# File 'lib/models/porcelain.rb', line 15916

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15918
15919
15920
# File 'lib/models/porcelain.rb', line 15918

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



15920
15921
15922
# File 'lib/models/porcelain.rb', line 15920

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



15922
15923
15924
# File 'lib/models/porcelain.rb', line 15922

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15924
15925
15926
# File 'lib/models/porcelain.rb', line 15924

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15926
15927
15928
# File 'lib/models/porcelain.rb', line 15926

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15928
15929
15930
# File 'lib/models/porcelain.rb', line 15928

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



15930
15931
15932
# File 'lib/models/porcelain.rb', line 15930

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15974
15975
15976
15977
15978
15979
15980
# File 'lib/models/porcelain.rb', line 15974

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end