Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



16159
16160
16161
16162
16163
16164
16165
16166
16167
16168
16169
16170
16171
16172
16173
16174
16175
16176
16177
16178
16179
16180
16181
16182
16183
16184
16185
16186
16187
16188
16189
16190
16191
16192
16193
16194
16195
16196
16197
16198
16199
16200
16201
16202
16203
# File 'lib/models/porcelain.rb', line 16159

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16117
16118
16119
# File 'lib/models/porcelain.rb', line 16117

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16119
16120
16121
# File 'lib/models/porcelain.rb', line 16119

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



16121
16122
16123
# File 'lib/models/porcelain.rb', line 16121

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16123
16124
16125
# File 'lib/models/porcelain.rb', line 16123

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16125
16126
16127
# File 'lib/models/porcelain.rb', line 16125

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16127
16128
16129
# File 'lib/models/porcelain.rb', line 16127

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16129
16130
16131
# File 'lib/models/porcelain.rb', line 16129

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



16131
16132
16133
# File 'lib/models/porcelain.rb', line 16131

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



16133
16134
16135
# File 'lib/models/porcelain.rb', line 16133

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



16135
16136
16137
# File 'lib/models/porcelain.rb', line 16135

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16137
16138
16139
# File 'lib/models/porcelain.rb', line 16137

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16139
16140
16141
# File 'lib/models/porcelain.rb', line 16139

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16141
16142
16143
# File 'lib/models/porcelain.rb', line 16141

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16143
16144
16145
# File 'lib/models/porcelain.rb', line 16143

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



16145
16146
16147
# File 'lib/models/porcelain.rb', line 16145

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



16147
16148
16149
# File 'lib/models/porcelain.rb', line 16147

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16149
16150
16151
# File 'lib/models/porcelain.rb', line 16149

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



16151
16152
16153
# File 'lib/models/porcelain.rb', line 16151

def server_spn
  @server_spn
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16153
16154
16155
# File 'lib/models/porcelain.rb', line 16153

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16155
16156
16157
# File 'lib/models/porcelain.rb', line 16155

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16157
16158
16159
# File 'lib/models/porcelain.rb', line 16157

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16205
16206
16207
16208
16209
16210
16211
# File 'lib/models/porcelain.rb', line 16205

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end