Class: SDM::SSHCustomerKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, private_key: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCustomerKey

Returns a new instance of SSHCustomerKey.



16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
17007
17008
17009
17010
17011
17012
17013
17014
17015
17016
17017
17018
17019
17020
17021
17022
17023
17024
17025
17026
17027
17028
17029
17030
17031
# File 'lib/models/porcelain.rb', line 16991

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  private_key: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchanges ⇒ Object

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16953
16954
16955
# File 'lib/models/porcelain.rb', line 16953

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16955
16956
16957
# File 'lib/models/porcelain.rb', line 16955

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



16957
16958
16959
# File 'lib/models/porcelain.rb', line 16957

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



16959
16960
16961
# File 'lib/models/porcelain.rb', line 16959

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



16961
16962
16963
# File 'lib/models/porcelain.rb', line 16961

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



16963
16964
16965
# File 'lib/models/porcelain.rb', line 16963

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16965
16966
16967
# File 'lib/models/porcelain.rb', line 16965

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



16967
16968
16969
# File 'lib/models/porcelain.rb', line 16967

def identity_set_id
  @identity_set_id
end

#lock_required ⇒ Object

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16969
16970
16971
# File 'lib/models/porcelain.rb', line 16969

def lock_required
  @lock_required
end

#name ⇒ Object

Unique human-readable name of the Resource.



16971
16972
16973
# File 'lib/models/porcelain.rb', line 16971

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



16973
16974
16975
# File 'lib/models/porcelain.rb', line 16973

def port
  @port
end

#port_forwarding ⇒ Object

Whether port forwarding is allowed through this server.



16975
16976
16977
# File 'lib/models/porcelain.rb', line 16975

def port_forwarding
  @port_forwarding
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16977
16978
16979
# File 'lib/models/porcelain.rb', line 16977

def port_override
  @port_override
end

#private_key ⇒ Object

The private key used to authenticate with the server.



16979
16980
16981
# File 'lib/models/porcelain.rb', line 16979

def private_key
  @private_key
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



16981
16982
16983
# File 'lib/models/porcelain.rb', line 16981

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



16983
16984
16985
# File 'lib/models/porcelain.rb', line 16983

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16985
16986
16987
# File 'lib/models/porcelain.rb', line 16985

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



16987
16988
16989
# File 'lib/models/porcelain.rb', line 16987

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



16989
16990
16991
# File 'lib/models/porcelain.rb', line 16989

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17033
17034
17035
17036
17037
17038
17039
# File 'lib/models/porcelain.rb', line 17033

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end