Class: SDM::SSHPassword

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHPassword

Returns a new instance of SSHPassword.



17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
17091
17092
17093
17094
17095
17096
17097
17098
17099
17100
17101
17102
17103
17104
17105
17106
17107
17108
17109
17110
17111
17112
17113
17114
# File 'lib/models/porcelain.rb', line 17078

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchanges ⇒ Object

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



17044
17045
17046
# File 'lib/models/porcelain.rb', line 17044

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17046
17047
17048
# File 'lib/models/porcelain.rb', line 17046

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



17048
17049
17050
# File 'lib/models/porcelain.rb', line 17048

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



17050
17051
17052
# File 'lib/models/porcelain.rb', line 17050

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



17052
17053
17054
# File 'lib/models/porcelain.rb', line 17052

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



17054
17055
17056
# File 'lib/models/porcelain.rb', line 17054

def id
  @id
end

#lock_required ⇒ Object

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



17056
17057
17058
# File 'lib/models/porcelain.rb', line 17056

def lock_required
  @lock_required
end

#name ⇒ Object

Unique human-readable name of the Resource.



17058
17059
17060
# File 'lib/models/porcelain.rb', line 17058

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



17060
17061
17062
# File 'lib/models/porcelain.rb', line 17060

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



17062
17063
17064
# File 'lib/models/porcelain.rb', line 17062

def port
  @port
end

#port_forwarding ⇒ Object

Whether port forwarding is allowed through this server.



17064
17065
17066
# File 'lib/models/porcelain.rb', line 17064

def port_forwarding
  @port_forwarding
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17066
17067
17068
# File 'lib/models/porcelain.rb', line 17066

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



17068
17069
17070
# File 'lib/models/porcelain.rb', line 17068

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



17070
17071
17072
# File 'lib/models/porcelain.rb', line 17070

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17072
17073
17074
# File 'lib/models/porcelain.rb', line 17072

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



17074
17075
17076
# File 'lib/models/porcelain.rb', line 17074

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



17076
17077
17078
# File 'lib/models/porcelain.rb', line 17076

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17116
17117
17118
17119
17120
17121
17122
# File 'lib/models/porcelain.rb', line 17116

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end