Class: SDM::SecretEngineDeleteRequest
- Inherits:
-
Object
- Object
- SDM::SecretEngineDeleteRequest
- Defined in:
- lib/models/porcelain.rb
Overview
SecretEngineDeleteRequest specified the ID of a Secret Engine to be deleted.
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
constructor
A new instance of SecretEngineDeleteRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ SecretEngineDeleteRequest
Returns a new instance of SecretEngineDeleteRequest.
17178 17179 17180 17181 17182 |
# File 'lib/models/porcelain.rb', line 17178 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Secret Engine to delete.
17176 17177 17178 |
# File 'lib/models/porcelain.rb', line 17176 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
17184 17185 17186 17187 17188 17189 17190 |
# File 'lib/models/porcelain.rb', line 17184 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |