Class: SDM::SecretEngineRotateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, password_policy: nil) ⇒ SecretEngineRotateRequest

Returns a new instance of SecretEngineRotateRequest.



17366
17367
17368
17369
17370
17371
17372
# File 'lib/models/porcelain.rb', line 17366

def initialize(
  id: nil,
  password_policy: nil
)
  @id = id == nil ? "" : id
  @password_policy = password_policy == nil ? nil : password_policy
end

Instance Attribute Details

#id ⇒ Object

The unique identifier of the Secret Engine to rotate credentials for.



17361
17362
17363
# File 'lib/models/porcelain.rb', line 17361

def id
  @id
end

#password_policy ⇒ Object

Optional password policy to use when generating a password If not provided it will use secret engine's password_policy



17364
17365
17366
# File 'lib/models/porcelain.rb', line 17364

def password_policy
  @password_policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17374
17375
17376
17377
17378
17379
17380
# File 'lib/models/porcelain.rb', line 17374

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end