Class: SDM::SecretStoreHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

SecretStoreHistory records the state of a SecretStore at a given point in time, where every change (create, update and delete) to a SecretStore produces an SecretStoreHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, secret_store: nil, timestamp: nil) ⇒ SecretStoreHistory

Returns a new instance of SecretStoreHistory.



17632
17633
17634
17635
17636
17637
17638
17639
17640
17641
17642
# File 'lib/models/porcelain.rb', line 17632

def initialize(
  activity_id: nil,
  deleted_at: nil,
  secret_store: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @secret_store = secret_store == nil ? nil : secret_store
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the SecretStore. May be empty for some system-initiated updates.



17624
17625
17626
# File 'lib/models/porcelain.rb', line 17624

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this SecretStore was deleted, the time it was deleted.



17626
17627
17628
# File 'lib/models/porcelain.rb', line 17626

def deleted_at
  @deleted_at
end

#secret_store ⇒ Object

The complete SecretStore state at this time.



17628
17629
17630
# File 'lib/models/porcelain.rb', line 17628

def secret_store
  @secret_store
end

#timestamp ⇒ Object

The time at which the SecretStore state was recorded.



17630
17631
17632
# File 'lib/models/porcelain.rb', line 17630

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17644
17645
17646
17647
17648
17649
17650
# File 'lib/models/porcelain.rb', line 17644

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end