Class: SDM::Service

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Service is a service account that can connect to resources they are granted directly, or granted via roles. Services are typically automated jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, name: nil, suspended: nil, tags: nil) ⇒ Service

Returns a new instance of Service.



17636
17637
17638
17639
17640
17641
17642
17643
17644
17645
17646
17647
17648
# File 'lib/models/porcelain.rb', line 17636

def initialize(
  created_at: nil,
  id: nil,
  name: nil,
  suspended: nil,
  tags: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @suspended = suspended == nil ? false : suspended
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#created_atObject

CreatedAt is the timestamp when the service was created



17626
17627
17628
# File 'lib/models/porcelain.rb', line 17626

def created_at
  @created_at
end

#idObject

Unique identifier of the Service.



17628
17629
17630
# File 'lib/models/porcelain.rb', line 17628

def id
  @id
end

#nameObject

Unique human-readable name of the Service.



17630
17631
17632
# File 'lib/models/porcelain.rb', line 17630

def name
  @name
end

#suspendedObject

The Service's suspended state.



17632
17633
17634
# File 'lib/models/porcelain.rb', line 17632

def suspended
  @suspended
end

#tagsObject

Tags is a map of key, value pairs.



17634
17635
17636
# File 'lib/models/porcelain.rb', line 17634

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17650
17651
17652
17653
17654
17655
17656
# File 'lib/models/porcelain.rb', line 17650

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end