Class: SDM::SnapshotPeeringGroupPeers
- Inherits:
-
Object
- Object
- SDM::SnapshotPeeringGroupPeers
- Extended by:
- Gem::Deprecate
- Defined in:
- lib/svc.rb
Overview
SnapshotPeeringGroupPeers exposes the read only methods of the PeeringGroupPeers service for historical queries.
Instance Method Summary collapse
-
#get(id, deadline: nil) ⇒ Object
Get reads the information of one peering group link.
-
#initialize(peering_group_peers) ⇒ SnapshotPeeringGroupPeers
constructor
A new instance of SnapshotPeeringGroupPeers.
-
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of peering group links.
Constructor Details
#initialize(peering_group_peers) ⇒ SnapshotPeeringGroupPeers
Returns a new instance of SnapshotPeeringGroupPeers.
2020 2021 2022 |
# File 'lib/svc.rb', line 2020 def initialize(peering_group_peers) @peering_group_peers = peering_group_peers end |
Instance Method Details
#get(id, deadline: nil) ⇒ Object
Get reads the information of one peering group link.
2025 2026 2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/svc.rb', line 2025 def get( id, deadline: nil ) return @peering_group_peers.get( id, deadline: deadline, ) end |
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of peering group links.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 |
# File 'lib/svc.rb', line 2036 def list( filter, *args, deadline: nil ) return @peering_group_peers.list( filter, *args, deadline: deadline, ) end |