Class: SDM::SnapshotPeeringGroupResources
- Inherits:
-
Object
- Object
- SDM::SnapshotPeeringGroupResources
- Extended by:
- Gem::Deprecate
- Defined in:
- lib/svc.rb
Overview
SnapshotPeeringGroupResources exposes the read only methods of the PeeringGroupResources service for historical queries.
Instance Method Summary collapse
-
#get(id, deadline: nil) ⇒ Object
Get reads the information of one peering group to resource attachment.
-
#initialize(peering_group_resources) ⇒ SnapshotPeeringGroupResources
constructor
A new instance of SnapshotPeeringGroupResources.
-
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of peering group resource attachments.
Constructor Details
#initialize(peering_group_resources) ⇒ SnapshotPeeringGroupResources
Returns a new instance of SnapshotPeeringGroupResources.
2203 2204 2205 |
# File 'lib/svc.rb', line 2203 def initialize(peering_group_resources) @peering_group_resources = peering_group_resources end |
Instance Method Details
#get(id, deadline: nil) ⇒ Object
Get reads the information of one peering group to resource attachment.
2208 2209 2210 2211 2212 2213 2214 2215 2216 |
# File 'lib/svc.rb', line 2208 def get( id, deadline: nil ) return @peering_group_resources.get( id, deadline: deadline, ) end |
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of peering group resource attachments.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 |
# File 'lib/svc.rb', line 2219 def list( filter, *args, deadline: nil ) return @peering_group_resources.list( filter, *args, deadline: deadline, ) end |