Class: SDM::Sybase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Sybase

Returns a new instance of Sybase.



18096
18097
18098
18099
18100
18101
18102
18103
18104
18105
18106
18107
18108
18109
18110
18111
18112
18113
18114
18115
18116
18117
18118
18119
18120
18121
18122
18123
18124
18125
18126
# File 'lib/models/porcelain.rb', line 18096

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18068
18069
18070
# File 'lib/models/porcelain.rb', line 18068

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



18070
18071
18072
# File 'lib/models/porcelain.rb', line 18070

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



18072
18073
18074
# File 'lib/models/porcelain.rb', line 18072

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



18074
18075
18076
# File 'lib/models/porcelain.rb', line 18074

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



18076
18077
18078
# File 'lib/models/porcelain.rb', line 18076

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



18078
18079
18080
# File 'lib/models/porcelain.rb', line 18078

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



18080
18081
18082
# File 'lib/models/porcelain.rb', line 18080

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



18082
18083
18084
# File 'lib/models/porcelain.rb', line 18082

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18084
18085
18086
# File 'lib/models/porcelain.rb', line 18084

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



18086
18087
18088
# File 'lib/models/porcelain.rb', line 18086

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



18088
18089
18090
# File 'lib/models/porcelain.rb', line 18088

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18090
18091
18092
# File 'lib/models/porcelain.rb', line 18090

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



18092
18093
18094
# File 'lib/models/porcelain.rb', line 18092

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



18094
18095
18096
# File 'lib/models/porcelain.rb', line 18094

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18128
18129
18130
18131
18132
18133
18134
# File 'lib/models/porcelain.rb', line 18128

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end