Class: SDM::SybaseIQ

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SybaseIQ

Returns a new instance of SybaseIQ.



17321
17322
17323
17324
17325
17326
17327
17328
17329
17330
17331
17332
17333
17334
17335
17336
17337
17338
17339
17340
17341
17342
17343
17344
17345
17346
17347
17348
17349
17350
17351
# File 'lib/models/porcelain.rb', line 17321

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



17293
17294
17295
# File 'lib/models/porcelain.rb', line 17293

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



17295
17296
17297
# File 'lib/models/porcelain.rb', line 17295

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



17297
17298
17299
# File 'lib/models/porcelain.rb', line 17297

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



17299
17300
17301
# File 'lib/models/porcelain.rb', line 17299

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



17301
17302
17303
# File 'lib/models/porcelain.rb', line 17301

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



17303
17304
17305
# File 'lib/models/porcelain.rb', line 17303

def name
  @name
end

#passwordObject

The password to authenticate with.



17305
17306
17307
# File 'lib/models/porcelain.rb', line 17305

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



17307
17308
17309
# File 'lib/models/porcelain.rb', line 17307

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



17309
17310
17311
# File 'lib/models/porcelain.rb', line 17309

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



17311
17312
17313
# File 'lib/models/porcelain.rb', line 17311

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



17313
17314
17315
# File 'lib/models/porcelain.rb', line 17313

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



17315
17316
17317
# File 'lib/models/porcelain.rb', line 17315

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



17317
17318
17319
# File 'lib/models/porcelain.rb', line 17317

def tags
  @tags
end

#usernameObject

The username to authenticate with.



17319
17320
17321
# File 'lib/models/porcelain.rb', line 17319

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



17353
17354
17355
17356
17357
17358
17359
# File 'lib/models/porcelain.rb', line 17353

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end