Class: SDM::Teradata

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Teradata

Returns a new instance of Teradata.



18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
18279
18280
18281
18282
18283
18284
18285
18286
18287
18288
18289
18290
# File 'lib/models/porcelain.rb', line 18260

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



18232
18233
18234
# File 'lib/models/porcelain.rb', line 18232

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



18234
18235
18236
# File 'lib/models/porcelain.rb', line 18234

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



18236
18237
18238
# File 'lib/models/porcelain.rb', line 18236

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



18238
18239
18240
# File 'lib/models/porcelain.rb', line 18238

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



18240
18241
18242
# File 'lib/models/porcelain.rb', line 18240

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



18242
18243
18244
# File 'lib/models/porcelain.rb', line 18242

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



18244
18245
18246
# File 'lib/models/porcelain.rb', line 18244

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



18246
18247
18248
# File 'lib/models/porcelain.rb', line 18246

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



18248
18249
18250
# File 'lib/models/porcelain.rb', line 18248

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



18250
18251
18252
# File 'lib/models/porcelain.rb', line 18250

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



18252
18253
18254
# File 'lib/models/porcelain.rb', line 18252

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



18254
18255
18256
# File 'lib/models/porcelain.rb', line 18254

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



18256
18257
18258
# File 'lib/models/porcelain.rb', line 18256

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



18258
18259
18260
# File 'lib/models/porcelain.rb', line 18258

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18292
18293
18294
18295
18296
18297
18298
# File 'lib/models/porcelain.rb', line 18292

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end