Class: SDM::VaultAWSIAMCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAWSIAMCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
constructor
A new instance of VaultAWSIAMCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAWSIAMCertSSHStore
Returns a new instance of VaultAWSIAMCertSSHStore.
18112 18113 18114 18115 18116 18117 18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 18128 18129 18130 |
# File 'lib/models/porcelain.rb', line 18112 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18096 18097 18098 |
# File 'lib/models/porcelain.rb', line 18096 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18098 18099 18100 |
# File 'lib/models/porcelain.rb', line 18098 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18100 18101 18102 |
# File 'lib/models/porcelain.rb', line 18100 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18102 18103 18104 |
# File 'lib/models/porcelain.rb', line 18102 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18104 18105 18106 |
# File 'lib/models/porcelain.rb', line 18104 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18106 18107 18108 |
# File 'lib/models/porcelain.rb', line 18106 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18108 18109 18110 |
# File 'lib/models/porcelain.rb', line 18108 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18110 18111 18112 |
# File 'lib/models/porcelain.rb', line 18110 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18132 18133 18134 18135 18136 18137 18138 |
# File 'lib/models/porcelain.rb', line 18132 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |