Class: SDM::VaultAWSIAMCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAWSIAMCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSIAMCertX509Store
constructor
A new instance of VaultAWSIAMCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAWSIAMCertX509Store
Returns a new instance of VaultAWSIAMCertX509Store.
18530 18531 18532 18533 18534 18535 18536 18537 18538 18539 18540 18541 18542 18543 18544 18545 18546 18547 18548 |
# File 'lib/models/porcelain.rb', line 18530 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18514 18515 18516 |
# File 'lib/models/porcelain.rb', line 18514 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18516 18517 18518 |
# File 'lib/models/porcelain.rb', line 18516 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18518 18519 18520 |
# File 'lib/models/porcelain.rb', line 18518 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18520 18521 18522 |
# File 'lib/models/porcelain.rb', line 18520 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18522 18523 18524 |
# File 'lib/models/porcelain.rb', line 18522 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18524 18525 18526 |
# File 'lib/models/porcelain.rb', line 18524 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18526 18527 18528 |
# File 'lib/models/porcelain.rb', line 18526 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18528 18529 18530 |
# File 'lib/models/porcelain.rb', line 18528 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18550 18551 18552 18553 18554 18555 18556 |
# File 'lib/models/porcelain.rb', line 18550 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |