Class: SDM::VaultAppRoleCertSSHStore
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
constructor
A new instance of VaultAppRoleCertSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil) ⇒ VaultAppRoleCertSSHStore
Returns a new instance of VaultAppRoleCertSSHStore.
18358 18359 18360 18361 18362 18363 18364 18365 18366 18367 18368 18369 18370 18371 18372 18373 18374 18375 18376 |
# File 'lib/models/porcelain.rb', line 18358 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, server_address: nil, signing_role: nil, ssh_mount_point: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @ssh_mount_point = ssh_mount_point == nil ? "" : ssh_mount_point = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18342 18343 18344 |
# File 'lib/models/porcelain.rb', line 18342 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18344 18345 18346 |
# File 'lib/models/porcelain.rb', line 18344 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18346 18347 18348 |
# File 'lib/models/porcelain.rb', line 18346 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18348 18349 18350 |
# File 'lib/models/porcelain.rb', line 18348 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18350 18351 18352 |
# File 'lib/models/porcelain.rb', line 18350 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18352 18353 18354 |
# File 'lib/models/porcelain.rb', line 18352 def signing_role @signing_role end |
#ssh_mount_point ⇒ Object
The mount point of the SSH engine configured with the desired CA
18354 18355 18356 |
# File 'lib/models/porcelain.rb', line 18354 def ssh_mount_point @ssh_mount_point end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18356 18357 18358 |
# File 'lib/models/porcelain.rb', line 18356 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18378 18379 18380 18381 18382 18383 18384 |
# File 'lib/models/porcelain.rb', line 18378 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |