Class: SDM::VaultAppRoleCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultAppRoleCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
constructor
A new instance of VaultAppRoleCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultAppRoleCertX509Store
Returns a new instance of VaultAppRoleCertX509Store.
18405 18406 18407 18408 18409 18410 18411 18412 18413 18414 18415 18416 18417 18418 18419 18420 18421 18422 18423 |
# File 'lib/models/porcelain.rb', line 18405 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18389 18390 18391 |
# File 'lib/models/porcelain.rb', line 18389 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA in minutes. Recommended value is 5.
18391 18392 18393 |
# File 'lib/models/porcelain.rb', line 18391 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18393 18394 18395 |
# File 'lib/models/porcelain.rb', line 18393 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18395 18396 18397 |
# File 'lib/models/porcelain.rb', line 18395 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18397 18398 18399 |
# File 'lib/models/porcelain.rb', line 18397 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18399 18400 18401 |
# File 'lib/models/porcelain.rb', line 18399 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18401 18402 18403 |
# File 'lib/models/porcelain.rb', line 18401 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18403 18404 18405 |
# File 'lib/models/porcelain.rb', line 18403 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18425 18426 18427 18428 18429 18430 18431 |
# File 'lib/models/porcelain.rb', line 18425 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |