Class: SDM::VaultTLSCertX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTLSCertX509Store



18556
18557
18558
18559
18560
18561
18562
18563
18564
18565
18566
18567
18568
18569
18570
18571
18572
18573
18574
18575
18576
18577
18578
18579
18580
# File 'lib/models/porcelain.rb', line 18556

def initialize(
  ca_cert_path: nil,
  client_cert_path: nil,
  client_key_path: nil,
  id: nil,
  issuedcertttlminutes: nil,
  name: nil,
  namespace: nil,
  pki_mount_point: nil,
  server_address: nil,
  signing_role: nil,
  tags: nil
)
  @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path
  @client_cert_path = client_cert_path == nil ? "" : client_cert_path
  @client_key_path = client_key_path == nil ? "" : client_key_path
  @id = id == nil ? "" : id
  @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes
  @name = name == nil ? "" : name
  @namespace = namespace == nil ? "" : namespace
  @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point
  @server_address = server_address == nil ? "" : server_address
  @signing_role = signing_role == nil ? "" : signing_role
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_cert_pathObject

A path to a CA file accessible by a Node



18534
18535
18536
# File 'lib/models/porcelain.rb', line 18534

def ca_cert_path
  @ca_cert_path
end

#client_cert_pathObject

A path to a client certificate file accessible by a Node



18536
18537
18538
# File 'lib/models/porcelain.rb', line 18536

def client_cert_path
  @client_cert_path
end

#client_key_pathObject

A path to a client key file accessible by a Node



18538
18539
18540
# File 'lib/models/porcelain.rb', line 18538

def client_key_path
  @client_key_path
end

#idObject

Unique identifier of the SecretStore.



18540
18541
18542
# File 'lib/models/porcelain.rb', line 18540

def id
  @id
end

#issuedcertttlminutesObject

The lifetime of certificates issued by this CA represented in minutes.



18542
18543
18544
# File 'lib/models/porcelain.rb', line 18542

def issuedcertttlminutes
  @issuedcertttlminutes
end

#nameObject

Unique human-readable name of the SecretStore.



18544
18545
18546
# File 'lib/models/porcelain.rb', line 18544

def name
  @name
end

#namespaceObject

The namespace to make requests within



18546
18547
18548
# File 'lib/models/porcelain.rb', line 18546

def namespace
  @namespace
end

#pki_mount_pointObject

The mount point of the PKI engine configured with the desired CA



18548
18549
18550
# File 'lib/models/porcelain.rb', line 18548

def pki_mount_point
  @pki_mount_point
end

#server_addressObject

The URL of the Vault to target



18550
18551
18552
# File 'lib/models/porcelain.rb', line 18550

def server_address
  @server_address
end

#signing_roleObject

The signing role to be used for signing certificates



18552
18553
18554
# File 'lib/models/porcelain.rb', line 18552

def signing_role
  @signing_role
end

#tagsObject

Tags is a map of key, value pairs.



18554
18555
18556
# File 'lib/models/porcelain.rb', line 18554

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



18582
18583
18584
18585
18586
18587
18588
# File 'lib/models/porcelain.rb', line 18582

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end