Class: SDM::VaultTLSStore
- Inherits:
-
Object
- Object
- SDM::VaultTLSStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node.
-
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node.
-
#client_key_path ⇒ Object
A path to a client key file accessible by a Node.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
constructor
A new instance of VaultTLSStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil) ⇒ VaultTLSStore
Returns a new instance of VaultTLSStore.
18605 18606 18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 18620 18621 18622 18623 |
# File 'lib/models/porcelain.rb', line 18605 def initialize( ca_cert_path: nil, client_cert_path: nil, client_key_path: nil, id: nil, name: nil, namespace: nil, server_address: nil, tags: nil ) @ca_cert_path = ca_cert_path == nil ? "" : ca_cert_path @client_cert_path = client_cert_path == nil ? "" : client_cert_path @client_key_path = client_key_path == nil ? "" : client_key_path @id = id == nil ? "" : id @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_cert_path ⇒ Object
A path to a CA file accessible by a Node
18589 18590 18591 |
# File 'lib/models/porcelain.rb', line 18589 def ca_cert_path @ca_cert_path end |
#client_cert_path ⇒ Object
A path to a client certificate file accessible by a Node
18591 18592 18593 |
# File 'lib/models/porcelain.rb', line 18591 def client_cert_path @client_cert_path end |
#client_key_path ⇒ Object
A path to a client key file accessible by a Node
18593 18594 18595 |
# File 'lib/models/porcelain.rb', line 18593 def client_key_path @client_key_path end |
#id ⇒ Object
Unique identifier of the SecretStore.
18595 18596 18597 |
# File 'lib/models/porcelain.rb', line 18595 def id @id end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18597 18598 18599 |
# File 'lib/models/porcelain.rb', line 18597 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18599 18600 18601 |
# File 'lib/models/porcelain.rb', line 18599 def namespace @namespace end |
#server_address ⇒ Object
The URL of the Vault to target
18601 18602 18603 |
# File 'lib/models/porcelain.rb', line 18601 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18603 18604 18605 |
# File 'lib/models/porcelain.rb', line 18603 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18625 18626 18627 18628 18629 18630 18631 |
# File 'lib/models/porcelain.rb', line 18625 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |