Class: SDM::VaultTokenCertX509Store
- Inherits:
-
Object
- Object
- SDM::VaultTokenCertX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#namespace ⇒ Object
The namespace to make requests within.
-
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA.
-
#server_address ⇒ Object
The URL of the Vault to target.
-
#signing_role ⇒ Object
The signing role to be used for signing certificates.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
constructor
A new instance of VaultTokenCertX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil) ⇒ VaultTokenCertX509Store
Returns a new instance of VaultTokenCertX509Store.
18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 18593 18594 18595 18596 18597 18598 18599 18600 |
# File 'lib/models/porcelain.rb', line 18582 def initialize( id: nil, issuedcertttlminutes: nil, name: nil, namespace: nil, pki_mount_point: nil, server_address: nil, signing_role: nil, tags: nil ) @id = id == nil ? "" : id @issuedcertttlminutes = issuedcertttlminutes == nil ? 0 : issuedcertttlminutes @name = name == nil ? "" : name @namespace = namespace == nil ? "" : namespace @pki_mount_point = pki_mount_point == nil ? "" : pki_mount_point @server_address = server_address == nil ? "" : server_address @signing_role = signing_role == nil ? "" : signing_role = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the SecretStore.
18566 18567 18568 |
# File 'lib/models/porcelain.rb', line 18566 def id @id end |
#issuedcertttlminutes ⇒ Object
The lifetime of certificates issued by this CA represented in minutes.
18568 18569 18570 |
# File 'lib/models/porcelain.rb', line 18568 def issuedcertttlminutes @issuedcertttlminutes end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
18570 18571 18572 |
# File 'lib/models/porcelain.rb', line 18570 def name @name end |
#namespace ⇒ Object
The namespace to make requests within
18572 18573 18574 |
# File 'lib/models/porcelain.rb', line 18572 def namespace @namespace end |
#pki_mount_point ⇒ Object
The mount point of the PKI engine configured with the desired CA
18574 18575 18576 |
# File 'lib/models/porcelain.rb', line 18574 def pki_mount_point @pki_mount_point end |
#server_address ⇒ Object
The URL of the Vault to target
18576 18577 18578 |
# File 'lib/models/porcelain.rb', line 18576 def server_address @server_address end |
#signing_role ⇒ Object
The signing role to be used for signing certificates
18578 18579 18580 |
# File 'lib/models/porcelain.rb', line 18578 def signing_role @signing_role end |
#tags ⇒ Object
Tags is a map of key, value pairs.
18580 18581 18582 |
# File 'lib/models/porcelain.rb', line 18580 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
18602 18603 18604 18605 18606 18607 18608 |
# File 'lib/models/porcelain.rb', line 18602 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |