Class: SDM::Vertica

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Vertica

Returns a new instance of Vertica.



19241
19242
19243
19244
19245
19246
19247
19248
19249
19250
19251
19252
19253
19254
19255
19256
19257
19258
19259
19260
19261
19262
19263
19264
19265
19266
19267
19268
19269
19270
19271
19272
19273
# File 'lib/models/porcelain.rb', line 19241

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



19211
19212
19213
# File 'lib/models/porcelain.rb', line 19211

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



19213
19214
19215
# File 'lib/models/porcelain.rb', line 19213

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



19215
19216
19217
# File 'lib/models/porcelain.rb', line 19215

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



19217
19218
19219
# File 'lib/models/porcelain.rb', line 19217

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



19219
19220
19221
# File 'lib/models/porcelain.rb', line 19219

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



19221
19222
19223
# File 'lib/models/porcelain.rb', line 19221

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



19223
19224
19225
# File 'lib/models/porcelain.rb', line 19223

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



19225
19226
19227
# File 'lib/models/porcelain.rb', line 19225

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



19227
19228
19229
# File 'lib/models/porcelain.rb', line 19227

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



19229
19230
19231
# File 'lib/models/porcelain.rb', line 19229

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



19231
19232
19233
# File 'lib/models/porcelain.rb', line 19231

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



19233
19234
19235
# File 'lib/models/porcelain.rb', line 19233

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



19235
19236
19237
# File 'lib/models/porcelain.rb', line 19235

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



19237
19238
19239
# File 'lib/models/porcelain.rb', line 19237

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



19239
19240
19241
# File 'lib/models/porcelain.rb', line 19239

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19275
19276
19277
19278
19279
19280
19281
# File 'lib/models/porcelain.rb', line 19275

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end