Class: SDM::WorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowApprover is an account or a role with the ability to approve requests bound to a workflow. WorkflowApprover is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowApprover

Returns a new instance of WorkflowApprover.



19359
19360
19361
19362
19363
19364
19365
19366
19367
19368
19369
# File 'lib/models/porcelain.rb', line 19359

def initialize(
  account_id: nil,
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The approver account id.



19351
19352
19353
# File 'lib/models/porcelain.rb', line 19351

def 
  @account_id
end

#idObject

Unique identifier of the WorkflowApprover.



19353
19354
19355
# File 'lib/models/porcelain.rb', line 19353

def id
  @id
end

#role_idObject

The approver role id



19355
19356
19357
# File 'lib/models/porcelain.rb', line 19355

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



19357
19358
19359
# File 'lib/models/porcelain.rb', line 19357

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19371
19372
19373
19374
19375
19376
19377
# File 'lib/models/porcelain.rb', line 19371

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end