Class: SDM::WorkflowRole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of to request access to a resource via the workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, role_id: nil, workflow_id: nil) ⇒ WorkflowRole

Returns a new instance of WorkflowRole.



19263
19264
19265
19266
19267
19268
19269
19270
19271
# File 'lib/models/porcelain.rb', line 19263

def initialize(
  id: nil,
  role_id: nil,
  workflow_id: nil
)
  @id = id == nil ? "" : id
  @role_id = role_id == nil ? "" : role_id
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#idObject

Unique identifier of the WorkflowRole.



19257
19258
19259
# File 'lib/models/porcelain.rb', line 19257

def id
  @id
end

#role_idObject

The role id.



19259
19260
19261
# File 'lib/models/porcelain.rb', line 19259

def role_id
  @role_id
end

#workflow_idObject

The workflow id.



19261
19262
19263
# File 'lib/models/porcelain.rb', line 19261

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



19273
19274
19275
19276
19277
19278
19279
# File 'lib/models/porcelain.rb', line 19273

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end