Class: SDM::AKS
- Inherits:
-
Object
- Object
- SDM::AKS
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil) ⇒ AKS
constructor
A new instance of AKS.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil) ⇒ AKS
Returns a new instance of AKS.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/models/porcelain.rb', line 44 def initialize( certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil ) if != nil @certificate_authority = end if client_certificate != nil @client_certificate = client_certificate end if client_key != nil @client_key = client_key end if egress_filter != nil @egress_filter = egress_filter end if healthcheck_namespace != nil @healthcheck_namespace = healthcheck_namespace end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if port != nil @port = port end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end end |
Instance Attribute Details
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
20 21 22 |
# File 'lib/models/porcelain.rb', line 20 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
22 23 24 |
# File 'lib/models/porcelain.rb', line 22 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
24 25 26 |
# File 'lib/models/porcelain.rb', line 24 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
26 27 28 |
# File 'lib/models/porcelain.rb', line 26 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to `default`.
28 29 30 |
# File 'lib/models/porcelain.rb', line 28 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
30 31 32 |
# File 'lib/models/porcelain.rb', line 30 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
32 33 34 |
# File 'lib/models/porcelain.rb', line 32 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
34 35 36 |
# File 'lib/models/porcelain.rb', line 34 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
36 37 38 |
# File 'lib/models/porcelain.rb', line 36 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
38 39 40 |
# File 'lib/models/porcelain.rb', line 38 def port @port end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
40 41 42 |
# File 'lib/models/porcelain.rb', line 40 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
42 43 44 |
# File 'lib/models/porcelain.rb', line 42 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
96 97 98 99 100 101 102 |
# File 'lib/models/porcelain.rb', line 96 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |