Class: SDM::AKSBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AKSBasicAuth

Returns a new instance of AKSBasicAuth.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/models/porcelain.rb', line 146

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



118
119
120
# File 'lib/models/porcelain.rb', line 118

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



120
121
122
# File 'lib/models/porcelain.rb', line 120

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



122
123
124
# File 'lib/models/porcelain.rb', line 122

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



124
125
126
# File 'lib/models/porcelain.rb', line 124

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



126
127
128
# File 'lib/models/porcelain.rb', line 126

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



128
129
130
# File 'lib/models/porcelain.rb', line 128

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



130
131
132
# File 'lib/models/porcelain.rb', line 130

def name
  @name
end

#passwordObject

The password to authenticate with.



132
133
134
# File 'lib/models/porcelain.rb', line 132

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



134
135
136
# File 'lib/models/porcelain.rb', line 134

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



136
137
138
# File 'lib/models/porcelain.rb', line 136

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



138
139
140
# File 'lib/models/porcelain.rb', line 138

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



140
141
142
# File 'lib/models/porcelain.rb', line 140

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



142
143
144
# File 'lib/models/porcelain.rb', line 142

def tags
  @tags
end

#usernameObject

The username to authenticate with.



144
145
146
# File 'lib/models/porcelain.rb', line 144

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



178
179
180
181
182
183
184
# File 'lib/models/porcelain.rb', line 178

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end