Class: SDM::AKSBasicAuth
- Inherits:
-
Object
- Object
- SDM::AKSBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AKSBasicAuth
constructor
A new instance of AKSBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AKSBasicAuth
Returns a new instance of AKSBasicAuth.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/models/porcelain.rb', line 146 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
118 119 120 |
# File 'lib/models/porcelain.rb', line 118 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
120 121 122 |
# File 'lib/models/porcelain.rb', line 120 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
122 123 124 |
# File 'lib/models/porcelain.rb', line 122 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
124 125 126 |
# File 'lib/models/porcelain.rb', line 124 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
126 127 128 |
# File 'lib/models/porcelain.rb', line 126 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
128 129 130 |
# File 'lib/models/porcelain.rb', line 128 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
130 131 132 |
# File 'lib/models/porcelain.rb', line 130 def name @name end |
#password ⇒ Object
The password to authenticate with.
132 133 134 |
# File 'lib/models/porcelain.rb', line 132 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
134 135 136 |
# File 'lib/models/porcelain.rb', line 134 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
136 137 138 |
# File 'lib/models/porcelain.rb', line 136 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
138 139 140 |
# File 'lib/models/porcelain.rb', line 138 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
140 141 142 |
# File 'lib/models/porcelain.rb', line 140 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
142 143 144 |
# File 'lib/models/porcelain.rb', line 142 def @tags end |
#username ⇒ Object
The username to authenticate with.
144 145 146 |
# File 'lib/models/porcelain.rb', line 144 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
178 179 180 181 182 183 184 |
# File 'lib/models/porcelain.rb', line 178 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |