Class: SDM::AKSServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ AKSServiceAccount

Returns a new instance of AKSServiceAccount.



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/models/porcelain.rb', line 227

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



190
191
192
# File 'lib/models/porcelain.rb', line 190

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



192
193
194
# File 'lib/models/porcelain.rb', line 192

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



194
195
196
# File 'lib/models/porcelain.rb', line 194

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



197
198
199
# File 'lib/models/porcelain.rb', line 197

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



199
200
201
# File 'lib/models/porcelain.rb', line 199

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



201
202
203
# File 'lib/models/porcelain.rb', line 201

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



203
204
205
# File 'lib/models/porcelain.rb', line 203

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



205
206
207
# File 'lib/models/porcelain.rb', line 205

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



207
208
209
# File 'lib/models/porcelain.rb', line 207

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



209
210
211
# File 'lib/models/porcelain.rb', line 209

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



211
212
213
# File 'lib/models/porcelain.rb', line 211

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



213
214
215
# File 'lib/models/porcelain.rb', line 213

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



215
216
217
# File 'lib/models/porcelain.rb', line 215

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



217
218
219
# File 'lib/models/porcelain.rb', line 217

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



219
220
221
# File 'lib/models/porcelain.rb', line 219

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



221
222
223
# File 'lib/models/porcelain.rb', line 221

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



223
224
225
# File 'lib/models/porcelain.rb', line 223

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



225
226
227
# File 'lib/models/porcelain.rb', line 225

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



267
268
269
270
271
272
273
# File 'lib/models/porcelain.rb', line 267

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end