Class: SDM::AKSServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ AKSServiceAccountUserImpersonation

Returns a new instance of AKSServiceAccountUserImpersonation.



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/models/porcelain.rb', line 304

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



278
279
280
# File 'lib/models/porcelain.rb', line 278

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



280
281
282
# File 'lib/models/porcelain.rb', line 280

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



282
283
284
# File 'lib/models/porcelain.rb', line 282

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



284
285
286
# File 'lib/models/porcelain.rb', line 284

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



286
287
288
# File 'lib/models/porcelain.rb', line 286

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



288
289
290
# File 'lib/models/porcelain.rb', line 288

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



290
291
292
# File 'lib/models/porcelain.rb', line 290

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



292
293
294
# File 'lib/models/porcelain.rb', line 292

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



294
295
296
# File 'lib/models/porcelain.rb', line 294

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



296
297
298
# File 'lib/models/porcelain.rb', line 296

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



298
299
300
# File 'lib/models/porcelain.rb', line 298

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



300
301
302
# File 'lib/models/porcelain.rb', line 300

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



302
303
304
# File 'lib/models/porcelain.rb', line 302

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



334
335
336
337
338
339
340
# File 'lib/models/porcelain.rb', line 334

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end