Class: SDM::AKSServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::AKSServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
The API token to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ AKSServiceAccountUserImpersonation
constructor
A new instance of AKSServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ AKSServiceAccountUserImpersonation
Returns a new instance of AKSServiceAccountUserImpersonation.
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/models/porcelain.rb', line 304 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
278 279 280 |
# File 'lib/models/porcelain.rb', line 278 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
280 281 282 |
# File 'lib/models/porcelain.rb', line 280 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
282 283 284 |
# File 'lib/models/porcelain.rb', line 282 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
284 285 286 |
# File 'lib/models/porcelain.rb', line 284 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
286 287 288 |
# File 'lib/models/porcelain.rb', line 286 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
288 289 290 |
# File 'lib/models/porcelain.rb', line 288 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
290 291 292 |
# File 'lib/models/porcelain.rb', line 290 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
292 293 294 |
# File 'lib/models/porcelain.rb', line 292 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
294 295 296 |
# File 'lib/models/porcelain.rb', line 294 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
296 297 298 |
# File 'lib/models/porcelain.rb', line 296 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
298 299 300 |
# File 'lib/models/porcelain.rb', line 298 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
300 301 302 |
# File 'lib/models/porcelain.rb', line 300 def @tags end |
#token ⇒ Object
The API token to authenticate with.
302 303 304 |
# File 'lib/models/porcelain.rb', line 302 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
334 335 336 337 338 339 340 |
# File 'lib/models/porcelain.rb', line 334 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |