Class: SDM::AKSUserImpersonation
- Inherits:
-
Object
- Object
- SDM::AKSUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AKSUserImpersonation
constructor
A new instance of AKSUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AKSUserImpersonation
Returns a new instance of AKSUserImpersonation.
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/models/porcelain.rb', line 375 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
345 346 347 |
# File 'lib/models/porcelain.rb', line 345 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
347 348 349 |
# File 'lib/models/porcelain.rb', line 347 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
349 350 351 |
# File 'lib/models/porcelain.rb', line 349 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
351 352 353 |
# File 'lib/models/porcelain.rb', line 351 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
353 354 355 |
# File 'lib/models/porcelain.rb', line 353 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
355 356 357 |
# File 'lib/models/porcelain.rb', line 355 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
357 358 359 |
# File 'lib/models/porcelain.rb', line 357 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
359 360 361 |
# File 'lib/models/porcelain.rb', line 359 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
361 362 363 |
# File 'lib/models/porcelain.rb', line 361 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
363 364 365 |
# File 'lib/models/porcelain.rb', line 363 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
365 366 367 |
# File 'lib/models/porcelain.rb', line 365 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
367 368 369 |
# File 'lib/models/porcelain.rb', line 367 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
369 370 371 |
# File 'lib/models/porcelain.rb', line 369 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
371 372 373 |
# File 'lib/models/porcelain.rb', line 371 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
373 374 375 |
# File 'lib/models/porcelain.rb', line 373 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
409 410 411 412 413 414 415 |
# File 'lib/models/porcelain.rb', line 409 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |