Class: SDM::AMQP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AMQP

Returns a new instance of AMQP.



723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
# File 'lib/models/porcelain.rb', line 723

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



693
694
695
# File 'lib/models/porcelain.rb', line 693

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



695
696
697
# File 'lib/models/porcelain.rb', line 695

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



697
698
699
# File 'lib/models/porcelain.rb', line 697

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



699
700
701
# File 'lib/models/porcelain.rb', line 699

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



701
702
703
# File 'lib/models/porcelain.rb', line 701

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



703
704
705
# File 'lib/models/porcelain.rb', line 703

def name
  @name
end

#passwordObject

The password to authenticate with.



705
706
707
# File 'lib/models/porcelain.rb', line 705

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



707
708
709
# File 'lib/models/porcelain.rb', line 707

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



709
710
711
# File 'lib/models/porcelain.rb', line 709

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



711
712
713
# File 'lib/models/porcelain.rb', line 711

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



713
714
715
# File 'lib/models/porcelain.rb', line 713

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



715
716
717
# File 'lib/models/porcelain.rb', line 715

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



717
718
719
# File 'lib/models/porcelain.rb', line 717

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



719
720
721
# File 'lib/models/porcelain.rb', line 719

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



721
722
723
# File 'lib/models/porcelain.rb', line 721

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



757
758
759
760
761
762
763
# File 'lib/models/porcelain.rb', line 757

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end