Class: SDM::AMQP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AMQP is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AMQP

Returns a new instance of AMQP.



720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
# File 'lib/models/porcelain.rb', line 720

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



690
691
692
# File 'lib/models/porcelain.rb', line 690

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



692
693
694
# File 'lib/models/porcelain.rb', line 692

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



694
695
696
# File 'lib/models/porcelain.rb', line 694

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



696
697
698
# File 'lib/models/porcelain.rb', line 696

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



698
699
700
# File 'lib/models/porcelain.rb', line 698

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



700
701
702
# File 'lib/models/porcelain.rb', line 700

def name
  @name
end

#passwordObject

The password to authenticate with.



702
703
704
# File 'lib/models/porcelain.rb', line 702

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



704
705
706
# File 'lib/models/porcelain.rb', line 704

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



706
707
708
# File 'lib/models/porcelain.rb', line 706

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



708
709
710
# File 'lib/models/porcelain.rb', line 708

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



710
711
712
# File 'lib/models/porcelain.rb', line 710

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



712
713
714
# File 'lib/models/porcelain.rb', line 712

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



714
715
716
# File 'lib/models/porcelain.rb', line 714

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



716
717
718
# File 'lib/models/porcelain.rb', line 716

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



718
719
720
# File 'lib/models/porcelain.rb', line 718

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



754
755
756
757
758
759
760
# File 'lib/models/porcelain.rb', line 754

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end