Class: SDM::AWS

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthcheck_region: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AWS

Returns a new instance of AWS.



793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/models/porcelain.rb', line 793

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_region: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_region = healthcheck_region == nil ? "" : healthcheck_region
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



763
764
765
# File 'lib/models/porcelain.rb', line 763

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



765
766
767
# File 'lib/models/porcelain.rb', line 765

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



767
768
769
# File 'lib/models/porcelain.rb', line 767

def egress_filter
  @egress_filter
end

#healthcheck_regionObject

The AWS region healthcheck requests should attempt to connect to.



769
770
771
# File 'lib/models/porcelain.rb', line 769

def healthcheck_region
  @healthcheck_region
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



771
772
773
# File 'lib/models/porcelain.rb', line 771

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



773
774
775
# File 'lib/models/porcelain.rb', line 773

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



775
776
777
# File 'lib/models/porcelain.rb', line 775

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



777
778
779
# File 'lib/models/porcelain.rb', line 777

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



779
780
781
# File 'lib/models/porcelain.rb', line 779

def proxy_cluster_id
  @proxy_cluster_id
end

#role_arnObject

The role to assume after logging in.



781
782
783
# File 'lib/models/porcelain.rb', line 781

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



783
784
785
# File 'lib/models/porcelain.rb', line 783

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



785
786
787
# File 'lib/models/porcelain.rb', line 785

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



787
788
789
# File 'lib/models/porcelain.rb', line 787

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



789
790
791
# File 'lib/models/porcelain.rb', line 789

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



791
792
793
# File 'lib/models/porcelain.rb', line 791

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



827
828
829
830
831
832
833
# File 'lib/models/porcelain.rb', line 827

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end