Class: SDM::AWS
- Inherits:
-
Object
- Object
- SDM::AWS
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_region ⇒ Object
The AWS region healthcheck requests should attempt to connect to.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthcheck_region: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AWS
constructor
A new instance of AWS.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthcheck_region: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AWS
Returns a new instance of AWS.
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/models/porcelain.rb', line 793 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthcheck_region: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_region = healthcheck_region == nil ? "" : healthcheck_region @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
763 764 765 |
# File 'lib/models/porcelain.rb', line 763 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
765 766 767 |
# File 'lib/models/porcelain.rb', line 765 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
767 768 769 |
# File 'lib/models/porcelain.rb', line 767 def egress_filter @egress_filter end |
#healthcheck_region ⇒ Object
The AWS region healthcheck requests should attempt to connect to.
769 770 771 |
# File 'lib/models/porcelain.rb', line 769 def healthcheck_region @healthcheck_region end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
771 772 773 |
# File 'lib/models/porcelain.rb', line 771 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
773 774 775 |
# File 'lib/models/porcelain.rb', line 773 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
775 776 777 |
# File 'lib/models/porcelain.rb', line 775 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
777 778 779 |
# File 'lib/models/porcelain.rb', line 777 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
779 780 781 |
# File 'lib/models/porcelain.rb', line 779 def proxy_cluster_id @proxy_cluster_id end |
#role_arn ⇒ Object
The role to assume after logging in.
781 782 783 |
# File 'lib/models/porcelain.rb', line 781 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
783 784 785 |
# File 'lib/models/porcelain.rb', line 783 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
785 786 787 |
# File 'lib/models/porcelain.rb', line 785 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
787 788 789 |
# File 'lib/models/porcelain.rb', line 787 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
789 790 791 |
# File 'lib/models/porcelain.rb', line 789 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
791 792 793 |
# File 'lib/models/porcelain.rb', line 791 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
827 828 829 830 831 832 833 |
# File 'lib/models/porcelain.rb', line 827 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |