Class: SDM::AWS
- Inherits:
-
Object
- Object
- SDM::AWS
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_region ⇒ Object
The AWS region healthcheck requests should attempt to connect to.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthcheck_region: nil, healthy: nil, id: nil, name: nil, port_override: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AWS
constructor
A new instance of AWS.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthcheck_region: nil, healthy: nil, id: nil, name: nil, port_override: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AWS
Returns a new instance of AWS.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/models/porcelain.rb', line 448 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthcheck_region: nil, healthy: nil, id: nil, name: nil, port_override: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_region = healthcheck_region == nil ? "" : healthcheck_region @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
420 421 422 |
# File 'lib/models/porcelain.rb', line 420 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
422 423 424 |
# File 'lib/models/porcelain.rb', line 422 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
424 425 426 |
# File 'lib/models/porcelain.rb', line 424 def egress_filter @egress_filter end |
#healthcheck_region ⇒ Object
The AWS region healthcheck requests should attempt to connect to.
426 427 428 |
# File 'lib/models/porcelain.rb', line 426 def healthcheck_region @healthcheck_region end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
428 429 430 |
# File 'lib/models/porcelain.rb', line 428 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
430 431 432 |
# File 'lib/models/porcelain.rb', line 430 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
432 433 434 |
# File 'lib/models/porcelain.rb', line 432 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
434 435 436 |
# File 'lib/models/porcelain.rb', line 434 def port_override @port_override end |
#role_arn ⇒ Object
The role to assume after logging in.
436 437 438 |
# File 'lib/models/porcelain.rb', line 436 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
438 439 440 |
# File 'lib/models/porcelain.rb', line 438 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
440 441 442 |
# File 'lib/models/porcelain.rb', line 440 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
442 443 444 |
# File 'lib/models/porcelain.rb', line 442 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
444 445 446 |
# File 'lib/models/porcelain.rb', line 444 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
446 447 448 |
# File 'lib/models/porcelain.rb', line 446 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
480 481 482 483 484 485 486 |
# File 'lib/models/porcelain.rb', line 480 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |