Class: SDM::AWSConsole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, enable_env_variables: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil) ⇒ AWSConsole

Returns a new instance of AWSConsole.



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
# File 'lib/models/porcelain.rb', line 570

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  enable_env_variables: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  session_expiry: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @enable_env_variables = enable_env_variables == nil ? false : enable_env_variables
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @session_expiry = session_expiry == nil ? 0 : session_expiry
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



538
539
540
# File 'lib/models/porcelain.rb', line 538

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



540
541
542
# File 'lib/models/porcelain.rb', line 540

def egress_filter
  @egress_filter
end

#enable_env_variablesObject

If true, prefer environment variables to authenticate connection even if EC2 roles are configured.



542
543
544
# File 'lib/models/porcelain.rb', line 542

def enable_env_variables
  @enable_env_variables
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



544
545
546
# File 'lib/models/porcelain.rb', line 544

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



546
547
548
# File 'lib/models/porcelain.rb', line 546

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



548
549
550
# File 'lib/models/porcelain.rb', line 548

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



550
551
552
# File 'lib/models/porcelain.rb', line 550

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



552
553
554
# File 'lib/models/porcelain.rb', line 552

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



554
555
556
# File 'lib/models/porcelain.rb', line 554

def port_override
  @port_override
end

#regionObject

The AWS region to connect to.



556
557
558
# File 'lib/models/porcelain.rb', line 556

def region
  @region
end

#role_arnObject

The role to assume after logging in.



558
559
560
# File 'lib/models/porcelain.rb', line 558

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



560
561
562
# File 'lib/models/porcelain.rb', line 560

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



562
563
564
# File 'lib/models/porcelain.rb', line 562

def secret_store_id
  @secret_store_id
end

#session_expiryObject

The length of time in seconds AWS console sessions will live before needing to reauthenticate.



564
565
566
# File 'lib/models/porcelain.rb', line 564

def session_expiry
  @session_expiry
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



566
567
568
# File 'lib/models/porcelain.rb', line 566

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



568
569
570
# File 'lib/models/porcelain.rb', line 568

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



606
607
608
609
610
611
612
# File 'lib/models/porcelain.rb', line 606

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end