Class: SDM::AWSConsole
- Inherits:
-
Object
- Object
- SDM::AWSConsole
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#enable_env_variables ⇒ Object
If true, prefer environment variables to authenticate connection even if EC2 roles are configured.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#session_expiry ⇒ Object
The length of time in seconds AWS console sessions will live before needing to reauthenticate.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_https ⇒ Object
This option enforces HTTPS on the client, not resource connection.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, enable_env_variables: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ AWSConsole
constructor
A new instance of AWSConsole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, enable_env_variables: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, use_https: nil) ⇒ AWSConsole
Returns a new instance of AWSConsole.
979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/models/porcelain.rb', line 979 def initialize( bind_interface: nil, egress_filter: nil, enable_env_variables: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, use_https: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @enable_env_variables = enable_env_variables == nil ? false : enable_env_variables @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @session_expiry = session_expiry == nil ? 0 : session_expiry @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_https = use_https == nil ? false : use_https end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
943 944 945 |
# File 'lib/models/porcelain.rb', line 943 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
945 946 947 |
# File 'lib/models/porcelain.rb', line 945 def egress_filter @egress_filter end |
#enable_env_variables ⇒ Object
If true, prefer environment variables to authenticate connection even if EC2 roles are configured.
947 948 949 |
# File 'lib/models/porcelain.rb', line 947 def enable_env_variables @enable_env_variables end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
949 950 951 |
# File 'lib/models/porcelain.rb', line 949 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
951 952 953 |
# File 'lib/models/porcelain.rb', line 951 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
953 954 955 |
# File 'lib/models/porcelain.rb', line 953 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
955 956 957 |
# File 'lib/models/porcelain.rb', line 955 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
957 958 959 |
# File 'lib/models/porcelain.rb', line 957 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
959 960 961 |
# File 'lib/models/porcelain.rb', line 959 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
961 962 963 |
# File 'lib/models/porcelain.rb', line 961 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
963 964 965 |
# File 'lib/models/porcelain.rb', line 963 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
965 966 967 |
# File 'lib/models/porcelain.rb', line 965 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
967 968 969 |
# File 'lib/models/porcelain.rb', line 967 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
969 970 971 |
# File 'lib/models/porcelain.rb', line 969 def secret_store_id @secret_store_id end |
#session_expiry ⇒ Object
The length of time in seconds AWS console sessions will live before needing to reauthenticate.
971 972 973 |
# File 'lib/models/porcelain.rb', line 971 def session_expiry @session_expiry end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
973 974 975 |
# File 'lib/models/porcelain.rb', line 973 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
975 976 977 |
# File 'lib/models/porcelain.rb', line 975 def @tags end |
#use_https ⇒ Object
This option enforces HTTPS on the client, not resource connection.
977 978 979 |
# File 'lib/models/porcelain.rb', line 977 def use_https @use_https end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/models/porcelain.rb', line 1019 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |