Class: SDM::AWSConsoleStaticKeyPair
- Inherits:
-
Object
- Object
- SDM::AWSConsoleStaticKeyPair
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to authenticate with.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to authenticate with.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#session_expiry ⇒ Object
The length of time in seconds AWS console sessions will live before needing to reauthenticate.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil) ⇒ AWSConsoleStaticKeyPair
constructor
A new instance of AWSConsoleStaticKeyPair.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil) ⇒ AWSConsoleStaticKeyPair
Returns a new instance of AWSConsoleStaticKeyPair.
1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 |
# File 'lib/models/porcelain.rb', line 1059 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @session_expiry = session_expiry == nil ? 0 : session_expiry @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to authenticate with.
1023 1024 1025 |
# File 'lib/models/porcelain.rb', line 1023 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
1025 1026 1027 |
# File 'lib/models/porcelain.rb', line 1025 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1027 1028 1029 |
# File 'lib/models/porcelain.rb', line 1027 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1029 1030 1031 |
# File 'lib/models/porcelain.rb', line 1029 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1031 1032 1033 |
# File 'lib/models/porcelain.rb', line 1031 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
1033 1034 1035 |
# File 'lib/models/porcelain.rb', line 1033 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
1035 1036 1037 |
# File 'lib/models/porcelain.rb', line 1035 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1037 1038 1039 |
# File 'lib/models/porcelain.rb', line 1037 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
1039 1040 1041 |
# File 'lib/models/porcelain.rb', line 1039 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
1041 1042 1043 |
# File 'lib/models/porcelain.rb', line 1041 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
1043 1044 1045 |
# File 'lib/models/porcelain.rb', line 1043 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
1045 1046 1047 |
# File 'lib/models/porcelain.rb', line 1045 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
1047 1048 1049 |
# File 'lib/models/porcelain.rb', line 1047 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to authenticate with.
1049 1050 1051 |
# File 'lib/models/porcelain.rb', line 1049 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1051 1052 1053 |
# File 'lib/models/porcelain.rb', line 1051 def secret_store_id @secret_store_id end |
#session_expiry ⇒ Object
The length of time in seconds AWS console sessions will live before needing to reauthenticate.
1053 1054 1055 |
# File 'lib/models/porcelain.rb', line 1053 def session_expiry @session_expiry end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1055 1056 1057 |
# File 'lib/models/porcelain.rb', line 1055 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1057 1058 1059 |
# File 'lib/models/porcelain.rb', line 1057 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/models/porcelain.rb', line 1099 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |