Class: SDM::AWSInstanceProfile
- Inherits:
-
Object
- Object
- SDM::AWSInstanceProfile
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#enable_env_variables ⇒ Object
If true, prefer environment variables to authenticate connection even if EC2 roles are configured.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, enable_env_variables: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AWSInstanceProfile
constructor
A new instance of AWSInstanceProfile.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, enable_env_variables: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AWSInstanceProfile
Returns a new instance of AWSInstanceProfile.
1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/models/porcelain.rb', line 1149 def initialize( bind_interface: nil, egress_filter: nil, enable_env_variables: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @enable_env_variables = enable_env_variables == nil ? false : enable_env_variables @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
1121 1122 1123 |
# File 'lib/models/porcelain.rb', line 1121 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1123 1124 1125 |
# File 'lib/models/porcelain.rb', line 1123 def egress_filter @egress_filter end |
#enable_env_variables ⇒ Object
If true, prefer environment variables to authenticate connection even if EC2 roles are configured.
1125 1126 1127 |
# File 'lib/models/porcelain.rb', line 1125 def enable_env_variables @enable_env_variables end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1127 1128 1129 |
# File 'lib/models/porcelain.rb', line 1127 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1129 1130 1131 |
# File 'lib/models/porcelain.rb', line 1129 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1131 1132 1133 |
# File 'lib/models/porcelain.rb', line 1131 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
1133 1134 1135 |
# File 'lib/models/porcelain.rb', line 1133 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
1135 1136 1137 |
# File 'lib/models/porcelain.rb', line 1135 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
1137 1138 1139 |
# File 'lib/models/porcelain.rb', line 1137 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
1139 1140 1141 |
# File 'lib/models/porcelain.rb', line 1139 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
1141 1142 1143 |
# File 'lib/models/porcelain.rb', line 1141 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1143 1144 1145 |
# File 'lib/models/porcelain.rb', line 1143 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
1145 1146 1147 |
# File 'lib/models/porcelain.rb', line 1145 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1147 1148 1149 |
# File 'lib/models/porcelain.rb', line 1147 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1181 1182 1183 1184 1185 1186 1187 |
# File 'lib/models/porcelain.rb', line 1181 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |