Class: SDM::AccessRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccessRequests are requests for access to a resource that may match a Workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, grant_id: nil, id: nil, reason: nil, resource_id: nil, start_from: nil, status: nil, status_at: nil, valid_until: nil, workflow_id: nil) ⇒ AccessRequest

Returns a new instance of AccessRequest.



753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
# File 'lib/models/porcelain.rb', line 753

def initialize(
  account_id: nil,
  grant_id: nil,
  id: nil,
  reason: nil,
  resource_id: nil,
  start_from: nil,
  status: nil,
  status_at: nil,
  valid_until: nil,
  workflow_id: nil
)
  @account_id =  == nil ? "" : 
  @grant_id = grant_id == nil ? "" : grant_id
  @id = id == nil ? "" : id
  @reason = reason == nil ? "" : reason
  @resource_id = resource_id == nil ? "" : resource_id
  @start_from = start_from == nil ? nil : start_from
  @status = status == nil ? "" : status
  @status_at = status_at == nil ? nil : status_at
  @valid_until = valid_until == nil ? nil : valid_until
  @workflow_id = workflow_id == nil ? "" : workflow_id
end

Instance Attribute Details

#account_idObject

The account that initiated the request.



732
733
734
# File 'lib/models/porcelain.rb', line 732

def 
  @account_id
end

#grant_idObject

The account grant created, if it exists.



734
735
736
# File 'lib/models/porcelain.rb', line 734

def grant_id
  @grant_id
end

#idObject

The access request id.



736
737
738
# File 'lib/models/porcelain.rb', line 736

def id
  @id
end

#reasonObject

The reason the access was requested.



738
739
740
# File 'lib/models/porcelain.rb', line 738

def reason
  @reason
end

#resource_idObject

The resource id.



740
741
742
# File 'lib/models/porcelain.rb', line 740

def resource_id
  @resource_id
end

#start_fromObject

The timestamp when the requested access will be granted. If this field is not specified it will default to the current time.



743
744
745
# File 'lib/models/porcelain.rb', line 743

def start_from
  @start_from
end

#statusObject

The status of the access request.



745
746
747
# File 'lib/models/porcelain.rb', line 745

def status
  @status
end

#status_atObject

The timestamp when the status changed.



747
748
749
# File 'lib/models/porcelain.rb', line 747

def status_at
  @status_at
end

#valid_untilObject

The timestamp when the requested access will expire.



749
750
751
# File 'lib/models/porcelain.rb', line 749

def valid_until
  @valid_until
end

#workflow_idObject

The workflow the request bound to.



751
752
753
# File 'lib/models/porcelain.rb', line 751

def workflow_id
  @workflow_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



777
778
779
780
781
782
783
# File 'lib/models/porcelain.rb', line 777

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end