Class: SDM::AccessRequestConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccessRequestConfig holds the information required to request access to a resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(duration: nil, reason: nil, resource_id: nil, start_from: nil) ⇒ AccessRequestConfig

Returns a new instance of AccessRequestConfig.



797
798
799
800
801
802
803
804
805
806
807
# File 'lib/models/porcelain.rb', line 797

def initialize(
  duration: nil,
  reason: nil,
  resource_id: nil,
  start_from: nil
)
  @duration = duration == nil ? "" : duration
  @reason = reason == nil ? "" : reason
  @resource_id = resource_id == nil ? "" : resource_id
  @start_from = start_from == nil ? nil : start_from
end

Instance Attribute Details

#durationObject

The time access should end, defaults to the next occurance of 5 pm



789
790
791
# File 'lib/models/porcelain.rb', line 789

def duration
  @duration
end

#reasonObject

The reason for access



791
792
793
# File 'lib/models/porcelain.rb', line 791

def reason
  @reason
end

#resource_idObject

The resource for which access is being requested



793
794
795
# File 'lib/models/porcelain.rb', line 793

def resource_id
  @resource_id
end

#start_fromObject

The time access should start, defaults to now



795
796
797
# File 'lib/models/porcelain.rb', line 795

def start_from
  @start_from
end

Instance Method Details

#to_json(options = {}) ⇒ Object



809
810
811
812
813
814
815
# File 'lib/models/porcelain.rb', line 809

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end