Class: SDM::AccessRequestHistory
- Inherits:
-
Object
- Object
- SDM::AccessRequestHistory
- Defined in:
- lib/models/porcelain.rb
Overview
AccessRequestHistory records the state of a AccessRequest at a given point in time, where every change (create, update and delete) to a AccessRequest produces an AccessRequestHistory record.
Instance Attribute Summary collapse
-
#access_request ⇒ Object
The complete AccessRequest state at this time.
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the AccessRequest.
-
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the AccessRequest state was recorded.
Instance Method Summary collapse
-
#initialize(access_request: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccessRequestHistory
constructor
A new instance of AccessRequestHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_request: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccessRequestHistory
Returns a new instance of AccessRequestHistory.
1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 |
# File 'lib/models/porcelain.rb', line 1417 def initialize( access_request: nil, activity_id: nil, deleted_at: nil, timestamp: nil ) @access_request = access_request == nil ? nil : access_request @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at = == nil ? nil : end |
Instance Attribute Details
#access_request ⇒ Object
The complete AccessRequest state at this time.
1408 1409 1410 |
# File 'lib/models/porcelain.rb', line 1408 def access_request @access_request end |
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the AccessRequest. May be empty for some system-initiated updates.
1411 1412 1413 |
# File 'lib/models/porcelain.rb', line 1411 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Workflow was deleted, the time it was deleted.
1413 1414 1415 |
# File 'lib/models/porcelain.rb', line 1413 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the AccessRequest state was recorded.
1415 1416 1417 |
# File 'lib/models/porcelain.rb', line 1415 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1429 1430 1431 1432 1433 1434 1435 |
# File 'lib/models/porcelain.rb', line 1429 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |