Class: SDM::AccountAttachmentHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountAttachmentHistory records the state of an AccountAttachment at a given point in time, where every change (create or delete) to an AccountAttachment produces an AccountAttachmentHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_attachment: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountAttachmentHistory

Returns a new instance of AccountAttachmentHistory.



1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
# File 'lib/models/porcelain.rb', line 1589

def initialize(
  account_attachment: nil,
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil
)
  @account_attachment =  == nil ? nil : 
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_attachmentObject

The complete AccountAttachment state at this time.



1580
1581
1582
# File 'lib/models/porcelain.rb', line 1580

def 
  @account_attachment
end

#activity_idObject

The unique identifier of the Activity that produced this change to the AccountAttachment. May be empty for some system-initiated updates.



1583
1584
1585
# File 'lib/models/porcelain.rb', line 1583

def activity_id
  @activity_id
end

#deleted_atObject

If this AccountAttachment was deleted, the time it was deleted.



1585
1586
1587
# File 'lib/models/porcelain.rb', line 1585

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the AccountAttachment state was recorded.



1587
1588
1589
# File 'lib/models/porcelain.rb', line 1587

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1601
1602
1603
1604
1605
1606
1607
# File 'lib/models/porcelain.rb', line 1601

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end