Class: SDM::AccountCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountCreateResponse reports how the Accounts were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account: nil, meta: nil, rate_limit: nil, token: nil) ⇒ AccountCreateResponse

Returns a new instance of AccountCreateResponse.



683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
# File 'lib/models/porcelain.rb', line 683

def initialize(
  account: nil,
  meta: nil,
  rate_limit: nil,
  token: nil
)
  if  != nil
    @account = 
  end
  if meta != nil
    @meta = meta
  end
  if rate_limit != nil
    @rate_limit = rate_limit
  end
  if token != nil
    @token = token
  end
end

Instance Attribute Details

#accountObject

The created Account.



674
675
676
# File 'lib/models/porcelain.rb', line 674

def 
  @account
end

#metaObject

Reserved for future use.



676
677
678
# File 'lib/models/porcelain.rb', line 676

def meta
  @meta
end

#rate_limitObject

Rate limit information.



678
679
680
# File 'lib/models/porcelain.rb', line 678

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Account. The Account will use this token to authenticate with the strongDM API.



681
682
683
# File 'lib/models/porcelain.rb', line 681

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



703
704
705
706
707
708
709
# File 'lib/models/porcelain.rb', line 703

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end