Class: SDM::AccountCreateResponse
- Inherits:
-
Object
- Object
- SDM::AccountCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
AccountCreateResponse reports how the Accounts were created in the system.
Instance Attribute Summary collapse
-
#account ⇒ Object
The created Account.
-
#meta ⇒ Object
Reserved for future use.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Account.
Instance Method Summary collapse
-
#initialize(account: nil, meta: nil, rate_limit: nil, token: nil) ⇒ AccountCreateResponse
constructor
A new instance of AccountCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account: nil, meta: nil, rate_limit: nil, token: nil) ⇒ AccountCreateResponse
Returns a new instance of AccountCreateResponse.
683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 |
# File 'lib/models/porcelain.rb', line 683 def initialize( account: nil, meta: nil, rate_limit: nil, token: nil ) if account != nil @account = account end if != nil @meta = end if rate_limit != nil @rate_limit = rate_limit end if token != nil @token = token end end |
Instance Attribute Details
#account ⇒ Object
The created Account.
674 675 676 |
# File 'lib/models/porcelain.rb', line 674 def account @account end |
#meta ⇒ Object
Reserved for future use.
676 677 678 |
# File 'lib/models/porcelain.rb', line 676 def @meta end |
#rate_limit ⇒ Object
Rate limit information.
678 679 680 |
# File 'lib/models/porcelain.rb', line 678 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Account. The Account will use this token to authenticate with the strongDM API.
681 682 683 |
# File 'lib/models/porcelain.rb', line 681 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
703 704 705 706 707 708 709 |
# File 'lib/models/porcelain.rb', line 703 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |