Class: SDM::AccountGrantHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountGrantHistory records the state of an AccountGrant at a given point in time, where every change (create or delete) to an AccountGrant produces an AccountGrantHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_grant: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountGrantHistory

Returns a new instance of AccountGrantHistory.



1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
# File 'lib/models/porcelain.rb', line 1837

def initialize(
  account_grant: nil,
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil
)
  @account_grant =  == nil ? nil : 
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_grantObject

The complete AccountGrant state at this time.



1828
1829
1830
# File 'lib/models/porcelain.rb', line 1828

def 
  @account_grant
end

#activity_idObject

The unique identifier of the Activity that produced this change to the AccountGrant. May be empty for some system-initiated updates.



1831
1832
1833
# File 'lib/models/porcelain.rb', line 1831

def activity_id
  @activity_id
end

#deleted_atObject

If this AccountGrant was deleted, the time it was deleted.



1833
1834
1835
# File 'lib/models/porcelain.rb', line 1833

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the AccountGrant state was recorded.



1835
1836
1837
# File 'lib/models/porcelain.rb', line 1835

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1849
1850
1851
1852
1853
1854
1855
# File 'lib/models/porcelain.rb', line 1849

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end