Class: SDM::AccountHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountHistory records the state of an Account at a given point in time, where every change (create, update and delete) to an Account produces an AccountHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountHistory

Returns a new instance of AccountHistory.



1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
# File 'lib/models/porcelain.rb', line 1368

def initialize(
  account: nil,
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil
)
  @account =  == nil ? nil : 
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#accountObject

The complete Account state at this time.



1359
1360
1361
# File 'lib/models/porcelain.rb', line 1359

def 
  @account
end

#activity_idObject

The unique identifier of the Activity that produced this change to the Account. May be empty for some system-initiated updates.



1362
1363
1364
# File 'lib/models/porcelain.rb', line 1362

def activity_id
  @activity_id
end

#deleted_atObject

If this Account was deleted, the time it was deleted.



1364
1365
1366
# File 'lib/models/porcelain.rb', line 1364

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Account state was recorded.



1366
1367
1368
# File 'lib/models/porcelain.rb', line 1366

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1380
1381
1382
1383
1384
1385
1386
# File 'lib/models/porcelain.rb', line 1380

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end