Class: SDM::AccountHistory
- Inherits:
-
Object
- Object
- SDM::AccountHistory
- Defined in:
- lib/models/porcelain.rb
Overview
AccountHistory records the state of an Account at a given point in time, where every change (create, update and delete) to an Account produces an AccountHistory record.
Instance Attribute Summary collapse
-
#account ⇒ Object
The complete Account state at this time.
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Account.
-
#deleted_at ⇒ Object
If this Account was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the Account state was recorded.
Instance Method Summary collapse
-
#initialize(account: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountHistory
constructor
A new instance of AccountHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountHistory
Returns a new instance of AccountHistory.
1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/models/porcelain.rb', line 1213 def initialize( account: nil, activity_id: nil, deleted_at: nil, timestamp: nil ) @account = account == nil ? nil : account @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : end |
Instance Attribute Details
#account ⇒ Object
The complete Account state at this time.
1204 1205 1206 |
# File 'lib/models/porcelain.rb', line 1204 def account @account end |
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Account. May be empty for some system-initiated updates.
1207 1208 1209 |
# File 'lib/models/porcelain.rb', line 1207 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Account was deleted, the time it was deleted.
1209 1210 1211 |
# File 'lib/models/porcelain.rb', line 1209 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the Account state was recorded.
1211 1212 1213 |
# File 'lib/models/porcelain.rb', line 1211 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1225 1226 1227 1228 1229 1230 1231 |
# File 'lib/models/porcelain.rb', line 1225 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |