Class: SDM::AccountHistory
- Inherits:
-
Object
- Object
- SDM::AccountHistory
- Defined in:
- lib/models/porcelain.rb
Overview
AccountHistory records the state of an Account at a given point in time, where every change (create, update and delete) to an Account produces an AccountHistory record.
Instance Attribute Summary collapse
-
#account ⇒ Object
The complete Account state at this time.
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Account.
-
#deleted_at ⇒ Object
If this Account was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the Account state was recorded.
Instance Method Summary collapse
-
#initialize(account: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountHistory
constructor
A new instance of AccountHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountHistory
Returns a new instance of AccountHistory.
1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 |
# File 'lib/models/porcelain.rb', line 1019 def initialize( account: nil, activity_id: nil, deleted_at: nil, timestamp: nil ) @account = account == nil ? nil : account @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : end |
Instance Attribute Details
#account ⇒ Object
The complete Account state at this time.
1010 1011 1012 |
# File 'lib/models/porcelain.rb', line 1010 def account @account end |
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Account. May be empty for some system-initiated updates.
1013 1014 1015 |
# File 'lib/models/porcelain.rb', line 1013 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Account was deleted, the time it was deleted.
1015 1016 1017 |
# File 'lib/models/porcelain.rb', line 1015 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the Account state was recorded.
1017 1018 1019 |
# File 'lib/models/porcelain.rb', line 1017 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/models/porcelain.rb', line 1031 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |