Class: SDM::AccountHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountHistory records the state of an Account at a given point in time, where every change (create, update and delete) to an Account produces an AccountHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountHistory

Returns a new instance of AccountHistory.



2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/models/porcelain.rb', line 2114

def initialize(
  account: nil,
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil
)
  @account =  == nil ? nil : 
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#accountObject

The complete Account state at this time.



2105
2106
2107
# File 'lib/models/porcelain.rb', line 2105

def 
  @account
end

#activity_idObject

The unique identifier of the Activity that produced this change to the Account. May be empty for some system-initiated updates.



2108
2109
2110
# File 'lib/models/porcelain.rb', line 2108

def activity_id
  @activity_id
end

#deleted_atObject

If this Account was deleted, the time it was deleted.



2110
2111
2112
# File 'lib/models/porcelain.rb', line 2110

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the Account state was recorded.



2112
2113
2114
# File 'lib/models/porcelain.rb', line 2112

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2126
2127
2128
2129
2130
2131
2132
# File 'lib/models/porcelain.rb', line 2126

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end