Class: SDM::AccountPermission

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountPermission represents an individual API action available to an account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, granted_at: nil, permission: nil, scope: nil, scoped_id: nil) ⇒ AccountPermission

Returns a new instance of AccountPermission.



2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
# File 'lib/models/porcelain.rb', line 2171

def initialize(
  account_id: nil,
  granted_at: nil,
  permission: nil,
  scope: nil,
  scoped_id: nil
)
  @account_id =  == nil ? "" : 
  @granted_at = granted_at == nil ? nil : granted_at
  @permission = permission == nil ? "" : permission
  @scope = scope == nil ? "" : scope
  @scoped_id = scoped_id == nil ? "" : scoped_id
end

Instance Attribute Details

#account_idObject

The unique identifier of the Account this permission belongs to.



2155
2156
2157
# File 'lib/models/porcelain.rb', line 2155

def 
  @account_id
end

#granted_atObject

The most recent time at which the permission was granted. If a permission was granted, revoked, and granted again, this will reflect the later time.



2158
2159
2160
# File 'lib/models/porcelain.rb', line 2158

def granted_at
  @granted_at
end

#permissionObject

The value of this permission, split into vertical and action, one of the Permission constants.



2160
2161
2162
# File 'lib/models/porcelain.rb', line 2160

def permission
  @permission
end

#scopeObject

The scope of this permission. A global scope means this action can be taken on any entity; otherwise the action can only be taken on or in the scope of the scoped id.



2164
2165
2166
# File 'lib/models/porcelain.rb', line 2164

def scope
  @scope
end

#scoped_idObject

The ID to which or in whose context this operation is permitted. e.g. The ID of a role that a team leader has the abillity to remove and add accounts to, or the ID of a resource that a user has the permission to connect to. If Scope is global, scoped id is not populated.



2169
2170
2171
# File 'lib/models/porcelain.rb', line 2169

def scoped_id
  @scoped_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2185
2186
2187
2188
2189
2190
2191
# File 'lib/models/porcelain.rb', line 2185

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end