Class: SDM::AccountPermission

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountPermission represents an individual API action available to an account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, granted_at: nil, permission: nil, scope: nil, scoped_id: nil) ⇒ AccountPermission

Returns a new instance of AccountPermission.



1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
# File 'lib/models/porcelain.rb', line 1060

def initialize(
  account_id: nil,
  granted_at: nil,
  permission: nil,
  scope: nil,
  scoped_id: nil
)
  @account_id =  == nil ? "" : 
  @granted_at = granted_at == nil ? nil : granted_at
  @permission = permission == nil ? "" : permission
  @scope = scope == nil ? "" : scope
  @scoped_id = scoped_id == nil ? "" : scoped_id
end

Instance Attribute Details

#account_idObject

The unique identifier of the Account this permission belongs to.



1043
1044
1045
# File 'lib/models/porcelain.rb', line 1043

def 
  @account_id
end

#granted_atObject

The most recent time at which the permission was granted. If a permission was granted, revoked, and granted again, this will reflect the later time.



1046
1047
1048
# File 'lib/models/porcelain.rb', line 1046

def granted_at
  @granted_at
end

#permissionObject

The value of this permission, split into vertical and action e.g. 'secretstore:List', 'role:update'



1049
1050
1051
# File 'lib/models/porcelain.rb', line 1049

def permission
  @permission
end

#scopeObject

The scope of this permission. A global scope means this action can be taken on any entity; otherwise the action can only be taken on or in the scope of the scoped id.



1053
1054
1055
# File 'lib/models/porcelain.rb', line 1053

def scope
  @scope
end

#scoped_idObject

The ID to which or in whose context this operation is permitted. e.g. The ID of a role that a team leader has the abillity to remove and add accounts to, or the ID of a resource that a user has the permission to connect to. If Scope is global, scoped id is not populated.



1058
1059
1060
# File 'lib/models/porcelain.rb', line 1058

def scoped_id
  @scoped_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1074
1075
1076
1077
1078
1079
1080
# File 'lib/models/porcelain.rb', line 1074

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end