Class: SDM::AccountResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountResource represents an individual access grant of a Account to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_grant_id: nil, account_id: nil, created_at: nil, expires_at: nil, granted_at: nil, resource_id: nil, role_id: nil) ⇒ AccountResource

Returns a new instance of AccountResource.



1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
# File 'lib/models/porcelain.rb', line 1452

def initialize(
  account_grant_id: nil,
  account_id: nil,
  created_at: nil,
  expires_at: nil,
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @account_grant_id =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @created_at = created_at == nil ? nil : created_at
  @expires_at = expires_at == nil ? nil : expires_at
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#account_grant_idObject

The unique identifier of the AccountGrant through which the Account was granted access to the Resource. If empty, access was not granted through an AccountGrant.



1435
1436
1437
# File 'lib/models/porcelain.rb', line 1435

def 
  @account_grant_id
end

#account_idObject

The unique identifier of the Account to which access is granted.



1437
1438
1439
# File 'lib/models/porcelain.rb', line 1437

def 
  @account_id
end

#created_atObject

The time this grant was created, distinct from 'granted at' in the case where access is scheduled for the future. If access was granted, revoked, and granted again, this will reflect the later creation time.



1440
1441
1442
# File 'lib/models/porcelain.rb', line 1440

def created_at
  @created_at
end

#expires_atObject

The time at which access will expire. If empty, this access has no expiration.



1442
1443
1444
# File 'lib/models/porcelain.rb', line 1442

def expires_at
  @expires_at
end

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



1445
1446
1447
# File 'lib/models/porcelain.rb', line 1445

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



1447
1448
1449
# File 'lib/models/porcelain.rb', line 1447

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role through which the Account was granted access to the Resource. If empty, access was not granted through an AccountAttachment to a Role.



1450
1451
1452
# File 'lib/models/porcelain.rb', line 1450

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1470
1471
1472
1473
1474
1475
1476
# File 'lib/models/porcelain.rb', line 1470

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end