Class: SDM::AccountResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountResource represents an individual access grant of a Account to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_grant_id: nil, account_id: nil, created_at: nil, expires_at: nil, granted_at: nil, resource_id: nil, role_id: nil) ⇒ AccountResource

Returns a new instance of AccountResource.



1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
# File 'lib/models/porcelain.rb', line 1298

def initialize(
  account_grant_id: nil,
  account_id: nil,
  created_at: nil,
  expires_at: nil,
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @account_grant_id =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @created_at = created_at == nil ? nil : created_at
  @expires_at = expires_at == nil ? nil : expires_at
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#account_grant_idObject

The unique identifier of the AccountGrant through which the Account was granted access to the Resource. If empty, access was not granted through an AccountGrant.



1281
1282
1283
# File 'lib/models/porcelain.rb', line 1281

def 
  @account_grant_id
end

#account_idObject

The unique identifier of the Account to which access is granted.



1283
1284
1285
# File 'lib/models/porcelain.rb', line 1283

def 
  @account_id
end

#created_atObject

The time this grant was created, distinct from 'granted at' in the case where access is scheduled for the future. If access was granted, revoked, and granted again, this will reflect the later creation time.



1286
1287
1288
# File 'lib/models/porcelain.rb', line 1286

def created_at
  @created_at
end

#expires_atObject

The time at which access will expire. If empty, this access has no expiration.



1288
1289
1290
# File 'lib/models/porcelain.rb', line 1288

def expires_at
  @expires_at
end

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



1291
1292
1293
# File 'lib/models/porcelain.rb', line 1291

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



1293
1294
1295
# File 'lib/models/porcelain.rb', line 1293

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role through which the Account was granted access to the Resource. If empty, access was not granted through an AccountAttachment to a Role.



1296
1297
1298
# File 'lib/models/porcelain.rb', line 1296

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1316
1317
1318
1319
1320
1321
1322
# File 'lib/models/porcelain.rb', line 1316

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end