Class: SDM::AccountResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AccountResourceHistory records the state of a AccountResource at a given point in time, where every change (create or delete) to a AccountResource produces an AccountResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_resource: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountResourceHistory

Returns a new instance of AccountResourceHistory.



1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
# File 'lib/models/porcelain.rb', line 1339

def initialize(
  account_resource: nil,
  activity_id: nil,
  deleted_at: nil,
  timestamp: nil
)
  @account_resource =  == nil ? nil : 
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_resourceObject

The complete AccountResource state at this time.



1330
1331
1332
# File 'lib/models/porcelain.rb', line 1330

def 
  @account_resource
end

#activity_idObject

The unique identifier of the Activity that produced this change to the AccountResource. May be empty for some system-initiated updates.



1333
1334
1335
# File 'lib/models/porcelain.rb', line 1333

def activity_id
  @activity_id
end

#deleted_atObject

If this AccountResource was deleted, the time it was deleted.



1335
1336
1337
# File 'lib/models/porcelain.rb', line 1335

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the AccountResource state was recorded.



1337
1338
1339
# File 'lib/models/porcelain.rb', line 1337

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1351
1352
1353
1354
1355
1356
1357
# File 'lib/models/porcelain.rb', line 1351

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end