Class: SDM::AccountResourceHistory
- Inherits:
-
Object
- Object
- SDM::AccountResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
AccountResourceHistory records the state of a AccountResource at a given point in time, where every change (create or delete) to a AccountResource produces an AccountResourceHistory record.
Instance Attribute Summary collapse
-
#account_resource ⇒ Object
The complete AccountResource state at this time.
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the AccountResource.
-
#deleted_at ⇒ Object
If this AccountResource was deleted, the time it was deleted.
-
#timestamp ⇒ Object
The time at which the AccountResource state was recorded.
Instance Method Summary collapse
-
#initialize(account_resource: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountResourceHistory
constructor
A new instance of AccountResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_resource: nil, activity_id: nil, deleted_at: nil, timestamp: nil) ⇒ AccountResourceHistory
Returns a new instance of AccountResourceHistory.
2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 |
# File 'lib/models/porcelain.rb', line 2239 def initialize( account_resource: nil, activity_id: nil, deleted_at: nil, timestamp: nil ) @account_resource = account_resource == nil ? nil : account_resource @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @timestamp = == nil ? nil : end |
Instance Attribute Details
#account_resource ⇒ Object
The complete AccountResource state at this time.
2230 2231 2232 |
# File 'lib/models/porcelain.rb', line 2230 def account_resource @account_resource end |
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the AccountResource. May be empty for some system-initiated updates.
2233 2234 2235 |
# File 'lib/models/porcelain.rb', line 2233 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this AccountResource was deleted, the time it was deleted.
2235 2236 2237 |
# File 'lib/models/porcelain.rb', line 2235 def deleted_at @deleted_at end |
#timestamp ⇒ Object
The time at which the AccountResource state was recorded.
2237 2238 2239 |
# File 'lib/models/porcelain.rb', line 2237 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2251 2252 2253 2254 2255 2256 2257 |
# File 'lib/models/porcelain.rb', line 2251 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |