Class: SDM::Activity
- Inherits:
-
Object
- Object
- SDM::Activity
- Defined in:
- lib/models/porcelain.rb
Overview
An Activity is a record of an action taken against a strongDM deployment, e.g. a user creation, resource deletion, sso configuration change, etc.
Instance Attribute Summary collapse
-
#actor ⇒ Object
The account who executed this activity.
-
#completed_at ⇒ Object
The time this activity took effect.
-
#description ⇒ Object
A humanized description of the activity.
-
#entities ⇒ Object
The entities involved in this activity.
-
#id ⇒ Object
Unique identifier of the Activity.
-
#ip_address ⇒ Object
The IP from which this action was taken.
-
#user_agent ⇒ Object
The User Agent present when this request was executed.
-
#verb ⇒ Object
The kind of activity which has taken place, one of the ActivityVerb constants.
Instance Method Summary collapse
-
#initialize(actor: nil, completed_at: nil, description: nil, entities: nil, id: nil, ip_address: nil, user_agent: nil, verb: nil) ⇒ Activity
constructor
A new instance of Activity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(actor: nil, completed_at: nil, description: nil, entities: nil, id: nil, ip_address: nil, user_agent: nil, verb: nil) ⇒ Activity
Returns a new instance of Activity.
2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 |
# File 'lib/models/porcelain.rb', line 2448 def initialize( actor: nil, completed_at: nil, description: nil, entities: nil, id: nil, ip_address: nil, user_agent: nil, verb: nil ) @actor = actor == nil ? nil : actor @completed_at = completed_at == nil ? nil : completed_at @description = description == nil ? "" : description @entities = entities == nil ? [] : entities @id = id == nil ? "" : id @ip_address = ip_address == nil ? "" : ip_address @user_agent = user_agent == nil ? "" : user_agent @verb = verb == nil ? "" : verb end |
Instance Attribute Details
#actor ⇒ Object
The account who executed this activity. If the actor later has a name or email change, that change is not reflected here. Actor is a snapshot of the executing account at the time an activity took place.
2429 2430 2431 |
# File 'lib/models/porcelain.rb', line 2429 def actor @actor end |
#completed_at ⇒ Object
The time this activity took effect.
2431 2432 2433 |
# File 'lib/models/porcelain.rb', line 2431 def completed_at @completed_at end |
#description ⇒ Object
A humanized description of the activity.
2433 2434 2435 |
# File 'lib/models/porcelain.rb', line 2433 def description @description end |
#entities ⇒ Object
The entities involved in this activity. These entities can be any first class entity in the strongDM system, eg. a user, a role, a node, an account grant. Not every activity affects explicit entities.
2437 2438 2439 |
# File 'lib/models/porcelain.rb', line 2437 def entities @entities end |
#id ⇒ Object
Unique identifier of the Activity.
2439 2440 2441 |
# File 'lib/models/porcelain.rb', line 2439 def id @id end |
#ip_address ⇒ Object
The IP from which this action was taken.
2441 2442 2443 |
# File 'lib/models/porcelain.rb', line 2441 def ip_address @ip_address end |
#user_agent ⇒ Object
The User Agent present when this request was executed. Generally a client type and version like strongdm-cli/55.66.77
2444 2445 2446 |
# File 'lib/models/porcelain.rb', line 2444 def user_agent @user_agent end |
#verb ⇒ Object
The kind of activity which has taken place, one of the ActivityVerb constants.
2446 2447 2448 |
# File 'lib/models/porcelain.rb', line 2446 def verb @verb end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/models/porcelain.rb', line 2468 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |