Class: SDM::Activity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

An Activity is a record of an action taken against a strongDM deployment, e.g. a user creation, resource deletion, sso configuration change, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(actor: nil, completed_at: nil, description: nil, entities: nil, id: nil, ip_address: nil, verb: nil) ⇒ Activity

Returns a new instance of Activity.



1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
# File 'lib/models/porcelain.rb', line 1177

def initialize(
  actor: nil,
  completed_at: nil,
  description: nil,
  entities: nil,
  id: nil,
  ip_address: nil,
  verb: nil
)
  @actor = actor == nil ? nil : actor
  @completed_at = completed_at == nil ? nil : completed_at
  @description = description == nil ? "" : description
  @entities = entities == nil ? [] : entities
  @id = id == nil ? "" : id
  @ip_address = ip_address == nil ? "" : ip_address
  @verb = verb == nil ? "" : verb
end

Instance Attribute Details

#actorObject

The account who executed this activity. If the actor later has a name or email change, that change is not reflected here. Actor is a snapshot of the executing account at the time an activity took place.



1161
1162
1163
# File 'lib/models/porcelain.rb', line 1161

def actor
  @actor
end

#completed_atObject

The time this activity took effect.



1163
1164
1165
# File 'lib/models/porcelain.rb', line 1163

def completed_at
  @completed_at
end

#descriptionObject

A humanized description of the activity.



1165
1166
1167
# File 'lib/models/porcelain.rb', line 1165

def description
  @description
end

#entitiesObject

The entities involved in this activity. These entities can be any first class entity in the strongDM system, eg. a user, a role, a node, an account grant. Not every activity affects explicit entities.



1169
1170
1171
# File 'lib/models/porcelain.rb', line 1169

def entities
  @entities
end

#idObject

Unique identifier of the Activity.



1171
1172
1173
# File 'lib/models/porcelain.rb', line 1171

def id
  @id
end

#ip_addressObject

The IP from which this action was taken.



1173
1174
1175
# File 'lib/models/porcelain.rb', line 1173

def ip_address
  @ip_address
end

#verbObject

The kind of activity which has taken place.



1175
1176
1177
# File 'lib/models/porcelain.rb', line 1175

def verb
  @verb
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1195
1196
1197
1198
1199
1200
1201
# File 'lib/models/porcelain.rb', line 1195

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end