Class: SDM::ActivityActor

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_external_id: nil, email: nil, first_name: nil, id: nil, last_name: nil) ⇒ ActivityActor

Returns a new instance of ActivityActor.



1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
# File 'lib/models/porcelain.rb', line 1291

def initialize(
  activity_external_id: nil,
  email: nil,
  first_name: nil,
  id: nil,
  last_name: nil
)
  @activity_external_id = activity_external_id == nil ? "" : activity_external_id
  @email = email == nil ? "" : email
  @first_name = first_name == nil ? "" : first_name
  @id = id == nil ? "" : id
  @last_name = last_name == nil ? "" : last_name
end

Instance Attribute Details

#activity_external_idObject

The external ID of the actor at the time this activity occurred.



1281
1282
1283
# File 'lib/models/porcelain.rb', line 1281

def activity_external_id
  @activity_external_id
end

#emailObject

The email of the actor at the time this activity occurred.



1283
1284
1285
# File 'lib/models/porcelain.rb', line 1283

def email
  @email
end

#first_nameObject

The first name of the actor at the time this activity occurred.



1285
1286
1287
# File 'lib/models/porcelain.rb', line 1285

def first_name
  @first_name
end

#idObject

Unique identifier of the actor. Immutable.



1287
1288
1289
# File 'lib/models/porcelain.rb', line 1287

def id
  @id
end

#last_nameObject

The last name of the actor at the time this activity occurred.



1289
1290
1291
# File 'lib/models/porcelain.rb', line 1289

def last_name
  @last_name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1305
1306
1307
1308
1309
1310
1311
# File 'lib/models/porcelain.rb', line 1305

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end