Class: SDM::ActivityActor

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_external_id: nil, email: nil, first_name: nil, id: nil, last_name: nil) ⇒ ActivityActor

Returns a new instance of ActivityActor.



1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
# File 'lib/models/porcelain.rb', line 1216

def initialize(
  activity_external_id: nil,
  email: nil,
  first_name: nil,
  id: nil,
  last_name: nil
)
  @activity_external_id = activity_external_id == nil ? "" : activity_external_id
  @email = email == nil ? "" : email
  @first_name = first_name == nil ? "" : first_name
  @id = id == nil ? "" : id
  @last_name = last_name == nil ? "" : last_name
end

Instance Attribute Details

#activity_external_idObject

The external ID of the actor at the time this activity occurred.



1206
1207
1208
# File 'lib/models/porcelain.rb', line 1206

def activity_external_id
  @activity_external_id
end

#emailObject

The email of the actor at the time this activity occurred.



1208
1209
1210
# File 'lib/models/porcelain.rb', line 1208

def email
  @email
end

#first_nameObject

The first name of the actor at the time this activity occurred.



1210
1211
1212
# File 'lib/models/porcelain.rb', line 1210

def first_name
  @first_name
end

#idObject

Unique identifier of the actor. Immutable.



1212
1213
1214
# File 'lib/models/porcelain.rb', line 1212

def id
  @id
end

#last_nameObject

The last name of the actor at the time this activity occurred.



1214
1215
1216
# File 'lib/models/porcelain.rb', line 1214

def last_name
  @last_name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1230
1231
1232
1233
1234
1235
1236
# File 'lib/models/porcelain.rb', line 1230

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end