Class: SDM::ActivityEntity
- Inherits:
-
Object
- Object
- SDM::ActivityEntity
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the affected entity, if it has one (for example, if it is an account).
-
#external_id ⇒ Object
The external ID of the affected entity, if it has one (for example, if it is an account).
-
#id ⇒ Object
The unique identifier of the entity this activity affected.
-
#name ⇒ Object
A display name representing the affected entity.
-
#type ⇒ Object
The type of entity affected, one of the Activity Entities constants.
Instance Method Summary collapse
-
#initialize(email: nil, external_id: nil, id: nil, name: nil, type: nil) ⇒ ActivityEntity
constructor
A new instance of ActivityEntity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(email: nil, external_id: nil, id: nil, name: nil, type: nil) ⇒ ActivityEntity
Returns a new instance of ActivityEntity.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 |
# File 'lib/models/porcelain.rb', line 1251 def initialize( email: nil, external_id: nil, id: nil, name: nil, type: nil ) @email = email == nil ? "" : email @external_id = external_id == nil ? "" : external_id @id = id == nil ? "" : id @name = name == nil ? "" : name @type = type == nil ? "" : type end |
Instance Attribute Details
#email ⇒ Object
The email of the affected entity, if it has one (for example, if it is an account).
1241 1242 1243 |
# File 'lib/models/porcelain.rb', line 1241 def email @email end |
#external_id ⇒ Object
The external ID of the affected entity, if it has one (for example, if it is an account).
1243 1244 1245 |
# File 'lib/models/porcelain.rb', line 1243 def external_id @external_id end |
#id ⇒ Object
The unique identifier of the entity this activity affected.
1245 1246 1247 |
# File 'lib/models/porcelain.rb', line 1245 def id @id end |
#name ⇒ Object
A display name representing the affected entity.
1247 1248 1249 |
# File 'lib/models/porcelain.rb', line 1247 def name @name end |
#type ⇒ Object
The type of entity affected, one of the Activity Entities constants.
1249 1250 1251 |
# File 'lib/models/porcelain.rb', line 1249 def type @type end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/models/porcelain.rb', line 1265 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |