Class: SDM::Aerospike

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_services_alternate: nil, username: nil) ⇒ Aerospike

Returns a new instance of Aerospike.



1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
# File 'lib/models/porcelain.rb', line 1985

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_services_alternate: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_services_alternate = use_services_alternate == nil ? false : use_services_alternate
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1955
1956
1957
# File 'lib/models/porcelain.rb', line 1955

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1957
1958
1959
# File 'lib/models/porcelain.rb', line 1957

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1959
1960
1961
# File 'lib/models/porcelain.rb', line 1959

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



1961
1962
1963
# File 'lib/models/porcelain.rb', line 1961

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1963
1964
1965
# File 'lib/models/porcelain.rb', line 1963

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1965
1966
1967
# File 'lib/models/porcelain.rb', line 1965

def name
  @name
end

#passwordObject

The password to authenticate with.



1967
1968
1969
# File 'lib/models/porcelain.rb', line 1967

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



1969
1970
1971
# File 'lib/models/porcelain.rb', line 1969

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



1971
1972
1973
# File 'lib/models/porcelain.rb', line 1971

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



1973
1974
1975
# File 'lib/models/porcelain.rb', line 1973

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1975
1976
1977
# File 'lib/models/porcelain.rb', line 1975

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1977
1978
1979
# File 'lib/models/porcelain.rb', line 1977

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1979
1980
1981
# File 'lib/models/porcelain.rb', line 1979

def tags
  @tags
end

#use_services_alternateObject

If true, uses UseServicesAlternates directive for Aerospike connection



1981
1982
1983
# File 'lib/models/porcelain.rb', line 1981

def use_services_alternate
  @use_services_alternate
end

#usernameObject

The username to authenticate with.



1983
1984
1985
# File 'lib/models/porcelain.rb', line 1983

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2019
2020
2021
2022
2023
2024
2025
# File 'lib/models/porcelain.rb', line 2019

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end