Class: SDM::Aerospike
- Inherits:
-
Object
- Object
- SDM::Aerospike
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_services_alternate ⇒ Object
If true, uses UseServicesAlternates directive for Aerospike connection.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_services_alternate: nil, username: nil) ⇒ Aerospike
constructor
A new instance of Aerospike.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_services_alternate: nil, username: nil) ⇒ Aerospike
Returns a new instance of Aerospike.
1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 |
# File 'lib/models/porcelain.rb', line 1985 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_services_alternate: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_services_alternate = use_services_alternate == nil ? false : use_services_alternate @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
1955 1956 1957 |
# File 'lib/models/porcelain.rb', line 1955 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1957 1958 1959 |
# File 'lib/models/porcelain.rb', line 1957 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1959 1960 1961 |
# File 'lib/models/porcelain.rb', line 1959 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
1961 1962 1963 |
# File 'lib/models/porcelain.rb', line 1961 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1963 1964 1965 |
# File 'lib/models/porcelain.rb', line 1963 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1965 1966 1967 |
# File 'lib/models/porcelain.rb', line 1965 def name @name end |
#password ⇒ Object
The password to authenticate with.
1967 1968 1969 |
# File 'lib/models/porcelain.rb', line 1967 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
1969 1970 1971 |
# File 'lib/models/porcelain.rb', line 1969 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
1971 1972 1973 |
# File 'lib/models/porcelain.rb', line 1971 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
1973 1974 1975 |
# File 'lib/models/porcelain.rb', line 1973 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1975 1976 1977 |
# File 'lib/models/porcelain.rb', line 1975 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1977 1978 1979 |
# File 'lib/models/porcelain.rb', line 1977 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1979 1980 1981 |
# File 'lib/models/porcelain.rb', line 1979 def @tags end |
#use_services_alternate ⇒ Object
If true, uses UseServicesAlternates directive for Aerospike connection
1981 1982 1983 |
# File 'lib/models/porcelain.rb', line 1981 def use_services_alternate @use_services_alternate end |
#username ⇒ Object
The username to authenticate with.
1983 1984 1985 |
# File 'lib/models/porcelain.rb', line 1983 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2019 2020 2021 2022 2023 2024 2025 |
# File 'lib/models/porcelain.rb', line 2019 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |