Class: SDM::AmazonEKS

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKS

Returns a new instance of AmazonEKS.



1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
# File 'lib/models/porcelain.rb', line 1900

def initialize(
  access_key: nil,
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



1850
1851
1852
# File 'lib/models/porcelain.rb', line 1850

def access_key
  @access_key
end

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



1853
1854
1855
# File 'lib/models/porcelain.rb', line 1853

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1855
1856
1857
# File 'lib/models/porcelain.rb', line 1855

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



1857
1858
1859
# File 'lib/models/porcelain.rb', line 1857

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



1859
1860
1861
# File 'lib/models/porcelain.rb', line 1859

def cluster_name
  @cluster_name
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



1861
1862
1863
# File 'lib/models/porcelain.rb', line 1861

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



1864
1865
1866
# File 'lib/models/porcelain.rb', line 1864

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1866
1867
1868
# File 'lib/models/porcelain.rb', line 1866

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



1868
1869
1870
# File 'lib/models/porcelain.rb', line 1868

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1870
1871
1872
# File 'lib/models/porcelain.rb', line 1870

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1872
1873
1874
# File 'lib/models/porcelain.rb', line 1872

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1874
1875
1876
# File 'lib/models/porcelain.rb', line 1874

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



1876
1877
1878
# File 'lib/models/porcelain.rb', line 1876

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



1878
1879
1880
# File 'lib/models/porcelain.rb', line 1878

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



1880
1881
1882
# File 'lib/models/porcelain.rb', line 1880

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



1882
1883
1884
# File 'lib/models/porcelain.rb', line 1882

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



1884
1885
1886
# File 'lib/models/porcelain.rb', line 1884

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



1886
1887
1888
# File 'lib/models/porcelain.rb', line 1886

def region
  @region
end

#role_arnObject

The role to assume after logging in.



1888
1889
1890
# File 'lib/models/porcelain.rb', line 1888

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



1890
1891
1892
# File 'lib/models/porcelain.rb', line 1890

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



1892
1893
1894
# File 'lib/models/porcelain.rb', line 1892

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1894
1895
1896
# File 'lib/models/porcelain.rb', line 1894

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1896
1897
1898
# File 'lib/models/porcelain.rb', line 1896

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1898
1899
1900
# File 'lib/models/porcelain.rb', line 1898

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1952
1953
1954
1955
1956
1957
1958
# File 'lib/models/porcelain.rb', line 1952

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end