Class: SDM::AmazonEKS

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKS

Returns a new instance of AmazonEKS.



1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
# File 'lib/models/porcelain.rb', line 1777

def initialize(
  access_key: nil,
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



1729
1730
1731
# File 'lib/models/porcelain.rb', line 1729

def access_key
  @access_key
end

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



1732
1733
1734
# File 'lib/models/porcelain.rb', line 1732

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1734
1735
1736
# File 'lib/models/porcelain.rb', line 1734

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



1736
1737
1738
# File 'lib/models/porcelain.rb', line 1736

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



1738
1739
1740
# File 'lib/models/porcelain.rb', line 1738

def cluster_name
  @cluster_name
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



1740
1741
1742
# File 'lib/models/porcelain.rb', line 1740

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



1743
1744
1745
# File 'lib/models/porcelain.rb', line 1743

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1745
1746
1747
# File 'lib/models/porcelain.rb', line 1745

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



1747
1748
1749
# File 'lib/models/porcelain.rb', line 1747

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1749
1750
1751
# File 'lib/models/porcelain.rb', line 1749

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1751
1752
1753
# File 'lib/models/porcelain.rb', line 1751

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1753
1754
1755
# File 'lib/models/porcelain.rb', line 1753

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



1755
1756
1757
# File 'lib/models/porcelain.rb', line 1755

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



1757
1758
1759
# File 'lib/models/porcelain.rb', line 1757

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



1759
1760
1761
# File 'lib/models/porcelain.rb', line 1759

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



1761
1762
1763
# File 'lib/models/porcelain.rb', line 1761

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



1763
1764
1765
# File 'lib/models/porcelain.rb', line 1763

def region
  @region
end

#role_arnObject

The role to assume after logging in.



1765
1766
1767
# File 'lib/models/porcelain.rb', line 1765

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



1767
1768
1769
# File 'lib/models/porcelain.rb', line 1767

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



1769
1770
1771
# File 'lib/models/porcelain.rb', line 1769

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1771
1772
1773
# File 'lib/models/porcelain.rb', line 1771

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1773
1774
1775
# File 'lib/models/porcelain.rb', line 1773

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1775
1776
1777
# File 'lib/models/porcelain.rb', line 1775

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1827
1828
1829
1830
1831
1832
1833
# File 'lib/models/porcelain.rb', line 1827

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end