Class: SDM::AmazonEKS

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKS

Returns a new instance of AmazonEKS.



1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
# File 'lib/models/porcelain.rb', line 1339

def initialize(
  access_key: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  region: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @region = region == nil ? "" : region
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



1303
1304
1305
# File 'lib/models/porcelain.rb', line 1303

def access_key
  @access_key
end

#bind_interfaceObject

Bind interface



1305
1306
1307
# File 'lib/models/porcelain.rb', line 1305

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



1307
1308
1309
# File 'lib/models/porcelain.rb', line 1307

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

Returns the value of attribute cluster_name.



1309
1310
1311
# File 'lib/models/porcelain.rb', line 1309

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1311
1312
1313
# File 'lib/models/porcelain.rb', line 1311

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



1313
1314
1315
# File 'lib/models/porcelain.rb', line 1313

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1315
1316
1317
# File 'lib/models/porcelain.rb', line 1315

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1317
1318
1319
# File 'lib/models/porcelain.rb', line 1317

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1319
1320
1321
# File 'lib/models/porcelain.rb', line 1319

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1321
1322
1323
# File 'lib/models/porcelain.rb', line 1321

def name
  @name
end

#regionObject

Returns the value of attribute region.



1323
1324
1325
# File 'lib/models/porcelain.rb', line 1323

def region
  @region
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



1325
1326
1327
# File 'lib/models/porcelain.rb', line 1325

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



1327
1328
1329
# File 'lib/models/porcelain.rb', line 1327

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#role_arnObject

Returns the value of attribute role_arn.



1329
1330
1331
# File 'lib/models/porcelain.rb', line 1329

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



1331
1332
1333
# File 'lib/models/porcelain.rb', line 1331

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



1333
1334
1335
# File 'lib/models/porcelain.rb', line 1333

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1335
1336
1337
# File 'lib/models/porcelain.rb', line 1335

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1337
1338
1339
# File 'lib/models/porcelain.rb', line 1337

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1379
1380
1381
1382
1383
1384
1385
# File 'lib/models/porcelain.rb', line 1379

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end