Class: SDM::AmazonEKS

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKS

Returns a new instance of AmazonEKS.



840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
# File 'lib/models/porcelain.rb', line 840

def initialize(
  access_key: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  region: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @region = region == nil ? "" : region
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



804
805
806
# File 'lib/models/porcelain.rb', line 804

def access_key
  @access_key
end

#bind_interfaceObject

Bind interface



806
807
808
# File 'lib/models/porcelain.rb', line 806

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



808
809
810
# File 'lib/models/porcelain.rb', line 808

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

Returns the value of attribute cluster_name.



810
811
812
# File 'lib/models/porcelain.rb', line 810

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



812
813
814
# File 'lib/models/porcelain.rb', line 812

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



814
815
816
# File 'lib/models/porcelain.rb', line 814

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



816
817
818
# File 'lib/models/porcelain.rb', line 816

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



818
819
820
# File 'lib/models/porcelain.rb', line 818

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



820
821
822
# File 'lib/models/porcelain.rb', line 820

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



822
823
824
# File 'lib/models/porcelain.rb', line 822

def name
  @name
end

#regionObject

Returns the value of attribute region.



824
825
826
# File 'lib/models/porcelain.rb', line 824

def region
  @region
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



826
827
828
# File 'lib/models/porcelain.rb', line 826

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



828
829
830
# File 'lib/models/porcelain.rb', line 828

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#role_arnObject

Returns the value of attribute role_arn.



830
831
832
# File 'lib/models/porcelain.rb', line 830

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



832
833
834
# File 'lib/models/porcelain.rb', line 832

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



834
835
836
# File 'lib/models/porcelain.rb', line 834

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



836
837
838
# File 'lib/models/porcelain.rb', line 836

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



838
839
840
# File 'lib/models/porcelain.rb', line 838

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



880
881
882
883
884
885
886
# File 'lib/models/porcelain.rb', line 880

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end