Class: SDM::AmazonEKSInstanceProfile

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfile

Returns a new instance of AmazonEKSInstanceProfile.



2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
2859
2860
2861
# File 'lib/models/porcelain.rb', line 2815

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



2770
2771
2772
# File 'lib/models/porcelain.rb', line 2770

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



2772
2773
2774
# File 'lib/models/porcelain.rb', line 2772

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



2774
2775
2776
# File 'lib/models/porcelain.rb', line 2774

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



2776
2777
2778
# File 'lib/models/porcelain.rb', line 2776

def cluster_name
  @cluster_name
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



2778
2779
2780
# File 'lib/models/porcelain.rb', line 2778

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



2781
2782
2783
# File 'lib/models/porcelain.rb', line 2781

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2783
2784
2785
# File 'lib/models/porcelain.rb', line 2783

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



2785
2786
2787
# File 'lib/models/porcelain.rb', line 2785

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



2787
2788
2789
# File 'lib/models/porcelain.rb', line 2787

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2789
2790
2791
# File 'lib/models/porcelain.rb', line 2789

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2791
2792
2793
# File 'lib/models/porcelain.rb', line 2791

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



2793
2794
2795
# File 'lib/models/porcelain.rb', line 2793

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



2795
2796
2797
# File 'lib/models/porcelain.rb', line 2795

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



2797
2798
2799
# File 'lib/models/porcelain.rb', line 2797

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



2799
2800
2801
# File 'lib/models/porcelain.rb', line 2799

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



2801
2802
2803
# File 'lib/models/porcelain.rb', line 2801

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



2803
2804
2805
# File 'lib/models/porcelain.rb', line 2803

def region
  @region
end

#role_arnObject

The role to assume after logging in.



2805
2806
2807
# File 'lib/models/porcelain.rb', line 2805

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2807
2808
2809
# File 'lib/models/porcelain.rb', line 2807

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2809
2810
2811
# File 'lib/models/porcelain.rb', line 2809

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



2811
2812
2813
# File 'lib/models/porcelain.rb', line 2811

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2813
2814
2815
# File 'lib/models/porcelain.rb', line 2813

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2863
2864
2865
2866
2867
2868
2869
# File 'lib/models/porcelain.rb', line 2863

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end