Class: SDM::AmazonEKSInstanceProfile

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfile

Returns a new instance of AmazonEKSInstanceProfile.



1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
# File 'lib/models/porcelain.rb', line 1674

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1638
1639
1640
# File 'lib/models/porcelain.rb', line 1638

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



1640
1641
1642
# File 'lib/models/porcelain.rb', line 1640

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



1642
1643
1644
# File 'lib/models/porcelain.rb', line 1642

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1644
1645
1646
# File 'lib/models/porcelain.rb', line 1644

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



1646
1647
1648
# File 'lib/models/porcelain.rb', line 1646

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1648
1649
1650
# File 'lib/models/porcelain.rb', line 1648

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1650
1651
1652
# File 'lib/models/porcelain.rb', line 1650

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1652
1653
1654
# File 'lib/models/porcelain.rb', line 1652

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1654
1655
1656
# File 'lib/models/porcelain.rb', line 1654

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



1656
1657
1658
# File 'lib/models/porcelain.rb', line 1656

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



1658
1659
1660
# File 'lib/models/porcelain.rb', line 1658

def region
  @region
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



1660
1661
1662
# File 'lib/models/porcelain.rb', line 1660

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



1662
1663
1664
# File 'lib/models/porcelain.rb', line 1662

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#role_arnObject

The role to assume after logging in.



1664
1665
1666
# File 'lib/models/porcelain.rb', line 1664

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



1666
1667
1668
# File 'lib/models/porcelain.rb', line 1666

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1668
1669
1670
# File 'lib/models/porcelain.rb', line 1668

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1670
1671
1672
# File 'lib/models/porcelain.rb', line 1670

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1672
1673
1674
# File 'lib/models/porcelain.rb', line 1672

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1714
1715
1716
1717
1718
1719
1720
# File 'lib/models/porcelain.rb', line 1714

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end