Class: SDM::AmazonEKSInstanceProfile
- Inherits:
-
Object
- Object
- SDM::AmazonEKSInstanceProfile
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#cluster_name ⇒ Object
The name of the cluster to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#remote_identity_group_id ⇒ Object
The ID of the remote identity group to use for remote identity connections.
-
#remote_identity_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own remote identity username.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfile
constructor
A new instance of AmazonEKSInstanceProfile.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfile
Returns a new instance of AmazonEKSInstanceProfile.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 |
# File 'lib/models/porcelain.rb', line 1510 def initialize( bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @cluster_name = cluster_name == nil ? "" : cluster_name @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
1474 1475 1476 |
# File 'lib/models/porcelain.rb', line 1474 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
1476 1477 1478 |
# File 'lib/models/porcelain.rb', line 1476 def @certificate_authority end |
#cluster_name ⇒ Object
The name of the cluster to connect to.
1478 1479 1480 |
# File 'lib/models/porcelain.rb', line 1478 def cluster_name @cluster_name end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1480 1481 1482 |
# File 'lib/models/porcelain.rb', line 1480 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
1482 1483 1484 |
# File 'lib/models/porcelain.rb', line 1482 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
1484 1485 1486 |
# File 'lib/models/porcelain.rb', line 1484 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1486 1487 1488 |
# File 'lib/models/porcelain.rb', line 1486 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1488 1489 1490 |
# File 'lib/models/porcelain.rb', line 1488 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1490 1491 1492 |
# File 'lib/models/porcelain.rb', line 1490 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
1492 1493 1494 |
# File 'lib/models/porcelain.rb', line 1492 def port_override @port_override end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
1494 1495 1496 |
# File 'lib/models/porcelain.rb', line 1494 def region @region end |
#remote_identity_group_id ⇒ Object
The ID of the remote identity group to use for remote identity connections.
1496 1497 1498 |
# File 'lib/models/porcelain.rb', line 1496 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own remote identity username.
1498 1499 1500 |
# File 'lib/models/porcelain.rb', line 1498 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#role_arn ⇒ Object
The role to assume after logging in.
1500 1501 1502 |
# File 'lib/models/porcelain.rb', line 1500 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
1502 1503 1504 |
# File 'lib/models/porcelain.rb', line 1502 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1504 1505 1506 |
# File 'lib/models/porcelain.rb', line 1504 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1506 1507 1508 |
# File 'lib/models/porcelain.rb', line 1506 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1508 1509 1510 |
# File 'lib/models/porcelain.rb', line 1508 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1550 1551 1552 1553 1554 1555 1556 |
# File 'lib/models/porcelain.rb', line 1550 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |