Class: SDM::AmazonEKSInstanceProfile
- Inherits:
-
Object
- Object
- SDM::AmazonEKSInstanceProfile
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#region ⇒ Object
Returns the value of attribute region.
-
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
-
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKSInstanceProfile
constructor
A new instance of AmazonEKSInstanceProfile.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKSInstanceProfile
Returns a new instance of AmazonEKSInstanceProfile.
1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/models/porcelain.rb', line 1422 def initialize( bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @cluster_name = cluster_name == nil ? "" : cluster_name @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @region = region == nil ? "" : region @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1390 1391 1392 |
# File 'lib/models/porcelain.rb', line 1390 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
1392 1393 1394 |
# File 'lib/models/porcelain.rb', line 1392 def @certificate_authority end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
1394 1395 1396 |
# File 'lib/models/porcelain.rb', line 1394 def cluster_name @cluster_name end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1396 1397 1398 |
# File 'lib/models/porcelain.rb', line 1396 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
1398 1399 1400 |
# File 'lib/models/porcelain.rb', line 1398 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
1400 1401 1402 |
# File 'lib/models/porcelain.rb', line 1400 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1402 1403 1404 |
# File 'lib/models/porcelain.rb', line 1402 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1404 1405 1406 |
# File 'lib/models/porcelain.rb', line 1404 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1406 1407 1408 |
# File 'lib/models/porcelain.rb', line 1406 def name @name end |
#region ⇒ Object
Returns the value of attribute region.
1408 1409 1410 |
# File 'lib/models/porcelain.rb', line 1408 def region @region end |
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
1410 1411 1412 |
# File 'lib/models/porcelain.rb', line 1410 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
1412 1413 1414 |
# File 'lib/models/porcelain.rb', line 1412 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1414 1415 1416 |
# File 'lib/models/porcelain.rb', line 1414 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1416 1417 1418 |
# File 'lib/models/porcelain.rb', line 1416 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1418 1419 1420 |
# File 'lib/models/porcelain.rb', line 1418 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1420 1421 1422 |
# File 'lib/models/porcelain.rb', line 1420 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1458 1459 1460 1461 1462 1463 1464 |
# File 'lib/models/porcelain.rb', line 1458 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |