Class: SDM::AmazonEKSInstanceProfile

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKSInstanceProfile

Returns a new instance of AmazonEKSInstanceProfile.



1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
# File 'lib/models/porcelain.rb', line 1084

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  region: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @region = region == nil ? "" : region
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



1052
1053
1054
# File 'lib/models/porcelain.rb', line 1052

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



1054
1055
1056
# File 'lib/models/porcelain.rb', line 1054

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

Returns the value of attribute cluster_name.



1056
1057
1058
# File 'lib/models/porcelain.rb', line 1056

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1058
1059
1060
# File 'lib/models/porcelain.rb', line 1058

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



1060
1061
1062
# File 'lib/models/porcelain.rb', line 1060

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1062
1063
1064
# File 'lib/models/porcelain.rb', line 1062

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1064
1065
1066
# File 'lib/models/porcelain.rb', line 1064

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1066
1067
1068
# File 'lib/models/porcelain.rb', line 1066

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1068
1069
1070
# File 'lib/models/porcelain.rb', line 1068

def name
  @name
end

#regionObject

Returns the value of attribute region.



1070
1071
1072
# File 'lib/models/porcelain.rb', line 1070

def region
  @region
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



1072
1073
1074
# File 'lib/models/porcelain.rb', line 1072

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



1074
1075
1076
# File 'lib/models/porcelain.rb', line 1074

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#role_arnObject

Returns the value of attribute role_arn.



1076
1077
1078
# File 'lib/models/porcelain.rb', line 1076

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



1078
1079
1080
# File 'lib/models/porcelain.rb', line 1078

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1080
1081
1082
# File 'lib/models/porcelain.rb', line 1080

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1082
1083
1084
# File 'lib/models/porcelain.rb', line 1082

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1120
1121
1122
1123
1124
1125
1126
# File 'lib/models/porcelain.rb', line 1120

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end