Class: SDM::AmazonEKSInstanceProfileUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AmazonEKSInstanceProfileUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfileUserImpersonation

Returns a new instance of AmazonEKSInstanceProfileUserImpersonation.



2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
# File 'lib/models/porcelain.rb', line 2905

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



2871
2872
2873
# File 'lib/models/porcelain.rb', line 2871

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



2873
2874
2875
# File 'lib/models/porcelain.rb', line 2873

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



2875
2876
2877
# File 'lib/models/porcelain.rb', line 2875

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2877
2878
2879
# File 'lib/models/porcelain.rb', line 2877

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



2879
2880
2881
# File 'lib/models/porcelain.rb', line 2879

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



2881
2882
2883
# File 'lib/models/porcelain.rb', line 2881

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2883
2884
2885
# File 'lib/models/porcelain.rb', line 2883

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2885
2886
2887
# File 'lib/models/porcelain.rb', line 2885

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2887
2888
2889
# File 'lib/models/porcelain.rb', line 2887

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



2889
2890
2891
# File 'lib/models/porcelain.rb', line 2889

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



2891
2892
2893
# File 'lib/models/porcelain.rb', line 2891

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



2893
2894
2895
# File 'lib/models/porcelain.rb', line 2893

def region
  @region
end

#role_arnObject

The role to assume after logging in.



2895
2896
2897
# File 'lib/models/porcelain.rb', line 2895

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2897
2898
2899
# File 'lib/models/porcelain.rb', line 2897

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2899
2900
2901
# File 'lib/models/porcelain.rb', line 2899

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



2901
2902
2903
# File 'lib/models/porcelain.rb', line 2901

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2903
2904
2905
# File 'lib/models/porcelain.rb', line 2903

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2943
2944
2945
2946
2947
2948
2949
# File 'lib/models/porcelain.rb', line 2943

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end