Class: SDM::AmazonEKSInstanceProfileUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfileUserImpersonation

Returns a new instance of AmazonEKSInstanceProfileUserImpersonation.



1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
# File 'lib/models/porcelain.rb', line 1971

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1939
1940
1941
# File 'lib/models/porcelain.rb', line 1939

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



1941
1942
1943
# File 'lib/models/porcelain.rb', line 1941

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



1943
1944
1945
# File 'lib/models/porcelain.rb', line 1943

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1945
1946
1947
# File 'lib/models/porcelain.rb', line 1945

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



1947
1948
1949
# File 'lib/models/porcelain.rb', line 1947

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1949
1950
1951
# File 'lib/models/porcelain.rb', line 1949

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1951
1952
1953
# File 'lib/models/porcelain.rb', line 1951

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1953
1954
1955
# File 'lib/models/porcelain.rb', line 1953

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1955
1956
1957
# File 'lib/models/porcelain.rb', line 1955

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



1957
1958
1959
# File 'lib/models/porcelain.rb', line 1957

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



1959
1960
1961
# File 'lib/models/porcelain.rb', line 1959

def region
  @region
end

#role_arnObject

The role to assume after logging in.



1961
1962
1963
# File 'lib/models/porcelain.rb', line 1961

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



1963
1964
1965
# File 'lib/models/porcelain.rb', line 1963

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1965
1966
1967
# File 'lib/models/porcelain.rb', line 1965

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1967
1968
1969
# File 'lib/models/porcelain.rb', line 1967

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1969
1970
1971
# File 'lib/models/porcelain.rb', line 1969

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2007
2008
2009
2010
2011
2012
2013
# File 'lib/models/porcelain.rb', line 2007

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end