Class: SDM::AmazonEKSInstanceProfileUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfileUserImpersonation

Returns a new instance of AmazonEKSInstanceProfileUserImpersonation.



1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
# File 'lib/models/porcelain.rb', line 1761

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1725
1726
1727
# File 'lib/models/porcelain.rb', line 1725

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



1727
1728
1729
# File 'lib/models/porcelain.rb', line 1727

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



1729
1730
1731
# File 'lib/models/porcelain.rb', line 1729

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1731
1732
1733
# File 'lib/models/porcelain.rb', line 1731

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



1733
1734
1735
# File 'lib/models/porcelain.rb', line 1733

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1735
1736
1737
# File 'lib/models/porcelain.rb', line 1735

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1737
1738
1739
# File 'lib/models/porcelain.rb', line 1737

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1739
1740
1741
# File 'lib/models/porcelain.rb', line 1739

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1741
1742
1743
# File 'lib/models/porcelain.rb', line 1741

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



1743
1744
1745
# File 'lib/models/porcelain.rb', line 1743

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



1745
1746
1747
# File 'lib/models/porcelain.rb', line 1745

def region
  @region
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



1747
1748
1749
# File 'lib/models/porcelain.rb', line 1747

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



1749
1750
1751
# File 'lib/models/porcelain.rb', line 1749

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#role_arnObject

The role to assume after logging in.



1751
1752
1753
# File 'lib/models/porcelain.rb', line 1751

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



1753
1754
1755
# File 'lib/models/porcelain.rb', line 1753

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1755
1756
1757
# File 'lib/models/porcelain.rb', line 1755

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1757
1758
1759
# File 'lib/models/porcelain.rb', line 1757

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1759
1760
1761
# File 'lib/models/porcelain.rb', line 1759

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1801
1802
1803
1804
1805
1806
1807
# File 'lib/models/porcelain.rb', line 1801

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end