Class: SDM::AmazonEKSInstanceProfileUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfileUserImpersonation

Returns a new instance of AmazonEKSInstanceProfileUserImpersonation.



1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
# File 'lib/models/porcelain.rb', line 1597

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1561
1562
1563
# File 'lib/models/porcelain.rb', line 1561

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



1563
1564
1565
# File 'lib/models/porcelain.rb', line 1563

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



1565
1566
1567
# File 'lib/models/porcelain.rb', line 1565

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1567
1568
1569
# File 'lib/models/porcelain.rb', line 1567

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



1569
1570
1571
# File 'lib/models/porcelain.rb', line 1569

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1571
1572
1573
# File 'lib/models/porcelain.rb', line 1571

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1573
1574
1575
# File 'lib/models/porcelain.rb', line 1573

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1575
1576
1577
# File 'lib/models/porcelain.rb', line 1575

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1577
1578
1579
# File 'lib/models/porcelain.rb', line 1577

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



1579
1580
1581
# File 'lib/models/porcelain.rb', line 1579

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



1581
1582
1583
# File 'lib/models/porcelain.rb', line 1581

def region
  @region
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



1583
1584
1585
# File 'lib/models/porcelain.rb', line 1583

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



1585
1586
1587
# File 'lib/models/porcelain.rb', line 1585

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#role_arnObject

The role to assume after logging in.



1587
1588
1589
# File 'lib/models/porcelain.rb', line 1587

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



1589
1590
1591
# File 'lib/models/porcelain.rb', line 1589

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1591
1592
1593
# File 'lib/models/porcelain.rb', line 1591

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1593
1594
1595
# File 'lib/models/porcelain.rb', line 1593

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1595
1596
1597
# File 'lib/models/porcelain.rb', line 1595

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1637
1638
1639
1640
1641
1642
1643
# File 'lib/models/porcelain.rb', line 1637

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end