Class: SDM::AmazonEKSInstanceProfileUserImpersonation
- Inherits:
-
Object
- Object
- SDM::AmazonEKSInstanceProfileUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
-
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfileUserImpersonation
constructor
A new instance of AmazonEKSInstanceProfileUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfileUserImpersonation
Returns a new instance of AmazonEKSInstanceProfileUserImpersonation.
1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'lib/models/porcelain.rb', line 1589 def initialize( bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @cluster_name = cluster_name == nil ? "" : cluster_name @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1553 1554 1555 |
# File 'lib/models/porcelain.rb', line 1553 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
1555 1556 1557 |
# File 'lib/models/porcelain.rb', line 1555 def @certificate_authority end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
1557 1558 1559 |
# File 'lib/models/porcelain.rb', line 1557 def cluster_name @cluster_name end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1559 1560 1561 |
# File 'lib/models/porcelain.rb', line 1559 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
1561 1562 1563 |
# File 'lib/models/porcelain.rb', line 1561 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
1563 1564 1565 |
# File 'lib/models/porcelain.rb', line 1563 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1565 1566 1567 |
# File 'lib/models/porcelain.rb', line 1565 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1567 1568 1569 |
# File 'lib/models/porcelain.rb', line 1567 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1569 1570 1571 |
# File 'lib/models/porcelain.rb', line 1569 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1571 1572 1573 |
# File 'lib/models/porcelain.rb', line 1571 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
1573 1574 1575 |
# File 'lib/models/porcelain.rb', line 1573 def region @region end |
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
1575 1576 1577 |
# File 'lib/models/porcelain.rb', line 1575 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
1577 1578 1579 |
# File 'lib/models/porcelain.rb', line 1577 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1579 1580 1581 |
# File 'lib/models/porcelain.rb', line 1579 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1581 1582 1583 |
# File 'lib/models/porcelain.rb', line 1581 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1583 1584 1585 |
# File 'lib/models/porcelain.rb', line 1583 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1585 1586 1587 |
# File 'lib/models/porcelain.rb', line 1585 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1587 1588 1589 |
# File 'lib/models/porcelain.rb', line 1587 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1629 1630 1631 1632 1633 1634 1635 |
# File 'lib/models/porcelain.rb', line 1629 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |