Class: SDM::AmazonEKSInstanceProfileUserImpersonation
- Inherits:
-
Object
- Object
- SDM::AmazonEKSInstanceProfileUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Overview
AmazonEKSInstanceProfileUserImpersonation is deprecated, see docs for more info.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#cluster_name ⇒ Object
The name of the cluster to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfileUserImpersonation
constructor
A new instance of AmazonEKSInstanceProfileUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSInstanceProfileUserImpersonation
Returns a new instance of AmazonEKSInstanceProfileUserImpersonation.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 |
# File 'lib/models/porcelain.rb', line 2914 def initialize( bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface = == nil ? "" : @cluster_name = cluster_name == nil ? "" : cluster_name @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
2880 2881 2882 |
# File 'lib/models/porcelain.rb', line 2880 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
2882 2883 2884 |
# File 'lib/models/porcelain.rb', line 2882 def end |
#cluster_name ⇒ Object
The name of the cluster to connect to.
2884 2885 2886 |
# File 'lib/models/porcelain.rb', line 2884 def cluster_name @cluster_name end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2886 2887 2888 |
# File 'lib/models/porcelain.rb', line 2886 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
2888 2889 2890 |
# File 'lib/models/porcelain.rb', line 2888 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
2890 2891 2892 |
# File 'lib/models/porcelain.rb', line 2890 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2892 2893 2894 |
# File 'lib/models/porcelain.rb', line 2892 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2894 2895 2896 |
# File 'lib/models/porcelain.rb', line 2894 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2896 2897 2898 |
# File 'lib/models/porcelain.rb', line 2896 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
2898 2899 2900 |
# File 'lib/models/porcelain.rb', line 2898 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
2900 2901 2902 |
# File 'lib/models/porcelain.rb', line 2900 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
2902 2903 2904 |
# File 'lib/models/porcelain.rb', line 2902 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
2904 2905 2906 |
# File 'lib/models/porcelain.rb', line 2904 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
2906 2907 2908 |
# File 'lib/models/porcelain.rb', line 2906 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2908 2909 2910 |
# File 'lib/models/porcelain.rb', line 2908 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
2910 2911 2912 |
# File 'lib/models/porcelain.rb', line 2910 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2912 2913 2914 |
# File 'lib/models/porcelain.rb', line 2912 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2952 2953 2954 2955 2956 2957 2958 |
# File 'lib/models/porcelain.rb', line 2952 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |