Class: SDM::AmazonEKSUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AmazonEKSUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSUserImpersonation

Returns a new instance of AmazonEKSUserImpersonation.



2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
# File 'lib/models/porcelain.rb', line 2997

def initialize(
  access_key: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



2959
2960
2961
# File 'lib/models/porcelain.rb', line 2959

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



2961
2962
2963
# File 'lib/models/porcelain.rb', line 2961

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



2963
2964
2965
# File 'lib/models/porcelain.rb', line 2963

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



2965
2966
2967
# File 'lib/models/porcelain.rb', line 2965

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2967
2968
2969
# File 'lib/models/porcelain.rb', line 2967

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



2969
2970
2971
# File 'lib/models/porcelain.rb', line 2969

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



2971
2972
2973
# File 'lib/models/porcelain.rb', line 2971

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2973
2974
2975
# File 'lib/models/porcelain.rb', line 2973

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2975
2976
2977
# File 'lib/models/porcelain.rb', line 2975

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2977
2978
2979
# File 'lib/models/porcelain.rb', line 2977

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



2979
2980
2981
# File 'lib/models/porcelain.rb', line 2979

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



2981
2982
2983
# File 'lib/models/porcelain.rb', line 2981

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



2983
2984
2985
# File 'lib/models/porcelain.rb', line 2983

def region
  @region
end

#role_arnObject

The role to assume after logging in.



2985
2986
2987
# File 'lib/models/porcelain.rb', line 2985

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2987
2988
2989
# File 'lib/models/porcelain.rb', line 2987

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



2989
2990
2991
# File 'lib/models/porcelain.rb', line 2989

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2991
2992
2993
# File 'lib/models/porcelain.rb', line 2991

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



2993
2994
2995
# File 'lib/models/porcelain.rb', line 2993

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2995
2996
2997
# File 'lib/models/porcelain.rb', line 2995

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3039
3040
3041
3042
3043
3044
3045
# File 'lib/models/porcelain.rb', line 3039

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end