Class: SDM::AmazonEKSUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSUserImpersonation

Returns a new instance of AmazonEKSUserImpersonation.



2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
# File 'lib/models/porcelain.rb', line 2054

def initialize(
  access_key: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



2018
2019
2020
# File 'lib/models/porcelain.rb', line 2018

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2020
2021
2022
# File 'lib/models/porcelain.rb', line 2020

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



2022
2023
2024
# File 'lib/models/porcelain.rb', line 2022

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

The name of the cluster to connect to.



2024
2025
2026
# File 'lib/models/porcelain.rb', line 2024

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2026
2027
2028
# File 'lib/models/porcelain.rb', line 2026

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



2028
2029
2030
# File 'lib/models/porcelain.rb', line 2028

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



2030
2031
2032
# File 'lib/models/porcelain.rb', line 2030

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2032
2033
2034
# File 'lib/models/porcelain.rb', line 2032

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2034
2035
2036
# File 'lib/models/porcelain.rb', line 2034

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2036
2037
2038
# File 'lib/models/porcelain.rb', line 2036

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



2038
2039
2040
# File 'lib/models/porcelain.rb', line 2038

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



2040
2041
2042
# File 'lib/models/porcelain.rb', line 2040

def region
  @region
end

#role_arnObject

The role to assume after logging in.



2042
2043
2044
# File 'lib/models/porcelain.rb', line 2042

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2044
2045
2046
# File 'lib/models/porcelain.rb', line 2044

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



2046
2047
2048
# File 'lib/models/porcelain.rb', line 2046

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2048
2049
2050
# File 'lib/models/porcelain.rb', line 2048

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2050
2051
2052
# File 'lib/models/porcelain.rb', line 2050

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2052
2053
2054
# File 'lib/models/porcelain.rb', line 2052

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2094
2095
2096
2097
2098
2099
2100
# File 'lib/models/porcelain.rb', line 2094

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end