Class: SDM::AmazonEKSUserImpersonation
- Inherits:
-
Object
- Object
- SDM::AmazonEKSUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#cluster_name ⇒ Object
The name of the cluster to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSUserImpersonation
constructor
A new instance of AmazonEKSUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSUserImpersonation
Returns a new instance of AmazonEKSUserImpersonation.
1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 |
# File 'lib/models/porcelain.rb', line 1848 def initialize( access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @cluster_name = cluster_name == nil ? "" : cluster_name @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
1812 1813 1814 |
# File 'lib/models/porcelain.rb', line 1812 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
1814 1815 1816 |
# File 'lib/models/porcelain.rb', line 1814 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
1816 1817 1818 |
# File 'lib/models/porcelain.rb', line 1816 def @certificate_authority end |
#cluster_name ⇒ Object
The name of the cluster to connect to.
1818 1819 1820 |
# File 'lib/models/porcelain.rb', line 1818 def cluster_name @cluster_name end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1820 1821 1822 |
# File 'lib/models/porcelain.rb', line 1820 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
1822 1823 1824 |
# File 'lib/models/porcelain.rb', line 1822 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
1824 1825 1826 |
# File 'lib/models/porcelain.rb', line 1824 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1826 1827 1828 |
# File 'lib/models/porcelain.rb', line 1826 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1828 1829 1830 |
# File 'lib/models/porcelain.rb', line 1828 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1830 1831 1832 |
# File 'lib/models/porcelain.rb', line 1830 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
1832 1833 1834 |
# File 'lib/models/porcelain.rb', line 1832 def port_override @port_override end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
1834 1835 1836 |
# File 'lib/models/porcelain.rb', line 1834 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
1836 1837 1838 |
# File 'lib/models/porcelain.rb', line 1836 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
1838 1839 1840 |
# File 'lib/models/porcelain.rb', line 1838 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
1840 1841 1842 |
# File 'lib/models/porcelain.rb', line 1840 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1842 1843 1844 |
# File 'lib/models/porcelain.rb', line 1842 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1844 1845 1846 |
# File 'lib/models/porcelain.rb', line 1844 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1846 1847 1848 |
# File 'lib/models/porcelain.rb', line 1846 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1888 1889 1890 1891 1892 1893 1894 |
# File 'lib/models/porcelain.rb', line 1888 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |