Class: SDM::AmazonEKSUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSUserImpersonation

Returns a new instance of AmazonEKSUserImpersonation.



1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
# File 'lib/models/porcelain.rb', line 1675

def initialize(
  access_key: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



1639
1640
1641
# File 'lib/models/porcelain.rb', line 1639

def access_key
  @access_key
end

#bind_interfaceObject

Bind interface



1641
1642
1643
# File 'lib/models/porcelain.rb', line 1641

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



1643
1644
1645
# File 'lib/models/porcelain.rb', line 1643

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

Returns the value of attribute cluster_name.



1645
1646
1647
# File 'lib/models/porcelain.rb', line 1645

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1647
1648
1649
# File 'lib/models/porcelain.rb', line 1647

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



1649
1650
1651
# File 'lib/models/porcelain.rb', line 1649

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1651
1652
1653
# File 'lib/models/porcelain.rb', line 1651

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1653
1654
1655
# File 'lib/models/porcelain.rb', line 1653

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1655
1656
1657
# File 'lib/models/porcelain.rb', line 1655

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1657
1658
1659
# File 'lib/models/porcelain.rb', line 1657

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



1659
1660
1661
# File 'lib/models/porcelain.rb', line 1659

def port_override
  @port_override
end

#regionObject

Returns the value of attribute region.



1661
1662
1663
# File 'lib/models/porcelain.rb', line 1661

def region
  @region
end

#role_arnObject

Returns the value of attribute role_arn.



1663
1664
1665
# File 'lib/models/porcelain.rb', line 1663

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



1665
1666
1667
# File 'lib/models/porcelain.rb', line 1665

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



1667
1668
1669
# File 'lib/models/porcelain.rb', line 1667

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1669
1670
1671
# File 'lib/models/porcelain.rb', line 1669

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1671
1672
1673
# File 'lib/models/porcelain.rb', line 1671

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1673
1674
1675
# File 'lib/models/porcelain.rb', line 1673

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1715
1716
1717
1718
1719
1720
1721
# File 'lib/models/porcelain.rb', line 1715

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end