Class: SDM::AmazonEKSUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonEKSUserImpersonation

Returns a new instance of AmazonEKSUserImpersonation.



1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
# File 'lib/models/porcelain.rb', line 1648

def initialize(
  access_key: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



1614
1615
1616
# File 'lib/models/porcelain.rb', line 1614

def access_key
  @access_key
end

#bind_interfaceObject

Bind interface



1616
1617
1618
# File 'lib/models/porcelain.rb', line 1616

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



1618
1619
1620
# File 'lib/models/porcelain.rb', line 1618

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

Returns the value of attribute cluster_name.



1620
1621
1622
# File 'lib/models/porcelain.rb', line 1620

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1622
1623
1624
# File 'lib/models/porcelain.rb', line 1622

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



1624
1625
1626
# File 'lib/models/porcelain.rb', line 1624

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1626
1627
1628
# File 'lib/models/porcelain.rb', line 1626

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1628
1629
1630
# File 'lib/models/porcelain.rb', line 1628

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1630
1631
1632
# File 'lib/models/porcelain.rb', line 1630

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1632
1633
1634
# File 'lib/models/porcelain.rb', line 1632

def name
  @name
end

#regionObject

Returns the value of attribute region.



1634
1635
1636
# File 'lib/models/porcelain.rb', line 1634

def region
  @region
end

#role_arnObject

Returns the value of attribute role_arn.



1636
1637
1638
# File 'lib/models/porcelain.rb', line 1636

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



1638
1639
1640
# File 'lib/models/porcelain.rb', line 1638

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



1640
1641
1642
# File 'lib/models/porcelain.rb', line 1640

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1642
1643
1644
# File 'lib/models/porcelain.rb', line 1642

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1644
1645
1646
# File 'lib/models/porcelain.rb', line 1644

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1646
1647
1648
# File 'lib/models/porcelain.rb', line 1646

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1686
1687
1688
1689
1690
1691
1692
# File 'lib/models/porcelain.rb', line 1686

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end