Class: SDM::AmazonEKSUserImpersonation
- Inherits:
-
Object
- Object
- SDM::AmazonEKSUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKSUserImpersonation
constructor
A new instance of AmazonEKSUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKSUserImpersonation
Returns a new instance of AmazonEKSUserImpersonation.
1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 |
# File 'lib/models/porcelain.rb', line 1500 def initialize( access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @cluster_name = cluster_name == nil ? "" : cluster_name @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
1468 1469 1470 |
# File 'lib/models/porcelain.rb', line 1468 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
1470 1471 1472 |
# File 'lib/models/porcelain.rb', line 1470 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
1472 1473 1474 |
# File 'lib/models/porcelain.rb', line 1472 def @certificate_authority end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
1474 1475 1476 |
# File 'lib/models/porcelain.rb', line 1474 def cluster_name @cluster_name end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1476 1477 1478 |
# File 'lib/models/porcelain.rb', line 1476 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
1478 1479 1480 |
# File 'lib/models/porcelain.rb', line 1478 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
1480 1481 1482 |
# File 'lib/models/porcelain.rb', line 1480 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1482 1483 1484 |
# File 'lib/models/porcelain.rb', line 1482 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1484 1485 1486 |
# File 'lib/models/porcelain.rb', line 1484 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1486 1487 1488 |
# File 'lib/models/porcelain.rb', line 1486 def name @name end |
#region ⇒ Object
Returns the value of attribute region.
1488 1489 1490 |
# File 'lib/models/porcelain.rb', line 1488 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1490 1491 1492 |
# File 'lib/models/porcelain.rb', line 1490 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1492 1493 1494 |
# File 'lib/models/porcelain.rb', line 1492 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
1494 1495 1496 |
# File 'lib/models/porcelain.rb', line 1494 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1496 1497 1498 |
# File 'lib/models/porcelain.rb', line 1496 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1498 1499 1500 |
# File 'lib/models/porcelain.rb', line 1498 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1536 1537 1538 1539 1540 1541 1542 |
# File 'lib/models/porcelain.rb', line 1536 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |