Class: SDM::AmazonEKSUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKSUserImpersonation

Returns a new instance of AmazonEKSUserImpersonation.



1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/models/porcelain.rb', line 1162

def initialize(
  access_key: nil,
  bind_interface: nil,
  certificate_authority: nil,
  cluster_name: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @cluster_name = cluster_name == nil ? "" : cluster_name
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



1130
1131
1132
# File 'lib/models/porcelain.rb', line 1130

def access_key
  @access_key
end

#bind_interfaceObject

Bind interface



1132
1133
1134
# File 'lib/models/porcelain.rb', line 1132

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



1134
1135
1136
# File 'lib/models/porcelain.rb', line 1134

def certificate_authority
  @certificate_authority
end

#cluster_nameObject

Returns the value of attribute cluster_name.



1136
1137
1138
# File 'lib/models/porcelain.rb', line 1136

def cluster_name
  @cluster_name
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1138
1139
1140
# File 'lib/models/porcelain.rb', line 1138

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



1140
1141
1142
# File 'lib/models/porcelain.rb', line 1140

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



1142
1143
1144
# File 'lib/models/porcelain.rb', line 1142

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1144
1145
1146
# File 'lib/models/porcelain.rb', line 1144

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1146
1147
1148
# File 'lib/models/porcelain.rb', line 1146

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1148
1149
1150
# File 'lib/models/porcelain.rb', line 1148

def name
  @name
end

#regionObject

Returns the value of attribute region.



1150
1151
1152
# File 'lib/models/porcelain.rb', line 1150

def region
  @region
end

#role_arnObject

Returns the value of attribute role_arn.



1152
1153
1154
# File 'lib/models/porcelain.rb', line 1152

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



1154
1155
1156
# File 'lib/models/porcelain.rb', line 1154

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



1156
1157
1158
# File 'lib/models/porcelain.rb', line 1156

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1158
1159
1160
# File 'lib/models/porcelain.rb', line 1158

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1160
1161
1162
# File 'lib/models/porcelain.rb', line 1160

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1198
1199
1200
1201
1202
1203
1204
# File 'lib/models/porcelain.rb', line 1198

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end