Class: SDM::AmazonEKSUserImpersonation
- Inherits:
-
Object
- Object
- SDM::AmazonEKSUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKSUserImpersonation
constructor
A new instance of AmazonEKSUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonEKSUserImpersonation
Returns a new instance of AmazonEKSUserImpersonation.
922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/models/porcelain.rb', line 922 def initialize( access_key: nil, bind_interface: nil, certificate_authority: nil, cluster_name: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @cluster_name = cluster_name == nil ? "" : cluster_name @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
890 891 892 |
# File 'lib/models/porcelain.rb', line 890 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
892 893 894 |
# File 'lib/models/porcelain.rb', line 892 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
894 895 896 |
# File 'lib/models/porcelain.rb', line 894 def @certificate_authority end |
#cluster_name ⇒ Object
Returns the value of attribute cluster_name.
896 897 898 |
# File 'lib/models/porcelain.rb', line 896 def cluster_name @cluster_name end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
898 899 900 |
# File 'lib/models/porcelain.rb', line 898 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
900 901 902 |
# File 'lib/models/porcelain.rb', line 900 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
902 903 904 |
# File 'lib/models/porcelain.rb', line 902 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
904 905 906 |
# File 'lib/models/porcelain.rb', line 904 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
906 907 908 |
# File 'lib/models/porcelain.rb', line 906 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
908 909 910 |
# File 'lib/models/porcelain.rb', line 908 def name @name end |
#region ⇒ Object
Returns the value of attribute region.
910 911 912 |
# File 'lib/models/porcelain.rb', line 910 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
912 913 914 |
# File 'lib/models/porcelain.rb', line 912 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
914 915 916 |
# File 'lib/models/porcelain.rb', line 914 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
916 917 918 |
# File 'lib/models/porcelain.rb', line 916 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
918 919 920 |
# File 'lib/models/porcelain.rb', line 918 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
920 921 922 |
# File 'lib/models/porcelain.rb', line 920 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
958 959 960 961 962 963 964 |
# File 'lib/models/porcelain.rb', line 958 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |