Class: SDM::AmazonES

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonES

Returns a new instance of AmazonES.



2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
# File 'lib/models/porcelain.rb', line 2135

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



2105
2106
2107
# File 'lib/models/porcelain.rb', line 2105

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2107
2108
2109
# File 'lib/models/porcelain.rb', line 2107

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2109
2110
2111
# File 'lib/models/porcelain.rb', line 2109

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. search-?.region.es.amazonaws.com"



2111
2112
2113
# File 'lib/models/porcelain.rb', line 2111

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2113
2114
2115
# File 'lib/models/porcelain.rb', line 2113

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2115
2116
2117
# File 'lib/models/porcelain.rb', line 2115

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2117
2118
2119
# File 'lib/models/porcelain.rb', line 2117

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



2119
2120
2121
# File 'lib/models/porcelain.rb', line 2119

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



2121
2122
2123
# File 'lib/models/porcelain.rb', line 2121

def region
  @region
end

#role_arnObject

The role to assume after logging in.



2123
2124
2125
# File 'lib/models/porcelain.rb', line 2123

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2125
2126
2127
# File 'lib/models/porcelain.rb', line 2125

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



2127
2128
2129
# File 'lib/models/porcelain.rb', line 2127

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2129
2130
2131
# File 'lib/models/porcelain.rb', line 2129

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2131
2132
2133
# File 'lib/models/porcelain.rb', line 2131

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2133
2134
2135
# File 'lib/models/porcelain.rb', line 2133

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2169
2170
2171
2172
2173
2174
2175
# File 'lib/models/porcelain.rb', line 2169

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end