Class: SDM::AmazonES
- Inherits:
-
Object
- Object
- SDM::AmazonES
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonES
constructor
A new instance of AmazonES.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonES
Returns a new instance of AmazonES.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 |
# File 'lib/models/porcelain.rb', line 2135 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
2105 2106 2107 |
# File 'lib/models/porcelain.rb', line 2105 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2107 2108 2109 |
# File 'lib/models/porcelain.rb', line 2107 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2109 2110 2111 |
# File 'lib/models/porcelain.rb', line 2109 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. search-?.region.es.amazonaws.com"
2111 2112 2113 |
# File 'lib/models/porcelain.rb', line 2111 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2113 2114 2115 |
# File 'lib/models/porcelain.rb', line 2113 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2115 2116 2117 |
# File 'lib/models/porcelain.rb', line 2115 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2117 2118 2119 |
# File 'lib/models/porcelain.rb', line 2117 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2119 2120 2121 |
# File 'lib/models/porcelain.rb', line 2119 def port_override @port_override end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
2121 2122 2123 |
# File 'lib/models/porcelain.rb', line 2121 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
2123 2124 2125 |
# File 'lib/models/porcelain.rb', line 2123 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
2125 2126 2127 |
# File 'lib/models/porcelain.rb', line 2125 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
2127 2128 2129 |
# File 'lib/models/porcelain.rb', line 2127 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2129 2130 2131 |
# File 'lib/models/porcelain.rb', line 2129 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2131 2132 2133 |
# File 'lib/models/porcelain.rb', line 2131 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2133 2134 2135 |
# File 'lib/models/porcelain.rb', line 2133 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2169 2170 2171 2172 2173 2174 2175 |
# File 'lib/models/porcelain.rb', line 2169 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |