Class: SDM::AmazonES

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AmazonES

Returns a new instance of AmazonES.



1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
# File 'lib/models/porcelain.rb', line 1765

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



1735
1736
1737
# File 'lib/models/porcelain.rb', line 1735

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1737
1738
1739
# File 'lib/models/porcelain.rb', line 1737

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1739
1740
1741
# File 'lib/models/porcelain.rb', line 1739

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. search-?.region.es.amazonaws.com"



1741
1742
1743
# File 'lib/models/porcelain.rb', line 1741

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1743
1744
1745
# File 'lib/models/porcelain.rb', line 1743

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1745
1746
1747
# File 'lib/models/porcelain.rb', line 1745

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1747
1748
1749
# File 'lib/models/porcelain.rb', line 1747

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



1749
1750
1751
# File 'lib/models/porcelain.rb', line 1749

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



1751
1752
1753
# File 'lib/models/porcelain.rb', line 1751

def region
  @region
end

#role_arnObject

The role to assume after logging in.



1753
1754
1755
# File 'lib/models/porcelain.rb', line 1753

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



1755
1756
1757
# File 'lib/models/porcelain.rb', line 1755

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



1757
1758
1759
# File 'lib/models/porcelain.rb', line 1757

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1759
1760
1761
# File 'lib/models/porcelain.rb', line 1759

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1761
1762
1763
# File 'lib/models/porcelain.rb', line 1761

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1763
1764
1765
# File 'lib/models/porcelain.rb', line 1763

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1799
1800
1801
1802
1803
1804
1805
# File 'lib/models/porcelain.rb', line 1799

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end