Class: SDM::AmazonES
- Inherits:
-
Object
- Object
- SDM::AmazonES
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonES
constructor
A new instance of AmazonES.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonES
Returns a new instance of AmazonES.
1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 |
# File 'lib/models/porcelain.rb', line 1574 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
1546 1547 1548 |
# File 'lib/models/porcelain.rb', line 1546 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
1548 1549 1550 |
# File 'lib/models/porcelain.rb', line 1548 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1550 1551 1552 |
# File 'lib/models/porcelain.rb', line 1550 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
1552 1553 1554 |
# File 'lib/models/porcelain.rb', line 1552 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1554 1555 1556 |
# File 'lib/models/porcelain.rb', line 1554 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1556 1557 1558 |
# File 'lib/models/porcelain.rb', line 1556 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1558 1559 1560 |
# File 'lib/models/porcelain.rb', line 1558 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1560 1561 1562 |
# File 'lib/models/porcelain.rb', line 1560 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
1562 1563 1564 |
# File 'lib/models/porcelain.rb', line 1562 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1564 1565 1566 |
# File 'lib/models/porcelain.rb', line 1564 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1566 1567 1568 |
# File 'lib/models/porcelain.rb', line 1566 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
1568 1569 1570 |
# File 'lib/models/porcelain.rb', line 1568 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1570 1571 1572 |
# File 'lib/models/porcelain.rb', line 1570 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1572 1573 1574 |
# File 'lib/models/porcelain.rb', line 1572 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/models/porcelain.rb', line 1606 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |