Class: SDM::AmazonES
- Inherits:
-
Object
- Object
- SDM::AmazonES
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonES
constructor
A new instance of AmazonES.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonES
Returns a new instance of AmazonES.
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/models/porcelain.rb', line 1236 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
1208 1209 1210 |
# File 'lib/models/porcelain.rb', line 1208 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
1210 1211 1212 |
# File 'lib/models/porcelain.rb', line 1210 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1212 1213 1214 |
# File 'lib/models/porcelain.rb', line 1212 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
1214 1215 1216 |
# File 'lib/models/porcelain.rb', line 1214 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1216 1217 1218 |
# File 'lib/models/porcelain.rb', line 1216 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1218 1219 1220 |
# File 'lib/models/porcelain.rb', line 1218 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1220 1221 1222 |
# File 'lib/models/porcelain.rb', line 1220 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1222 1223 1224 |
# File 'lib/models/porcelain.rb', line 1222 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
1224 1225 1226 |
# File 'lib/models/porcelain.rb', line 1224 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1226 1227 1228 |
# File 'lib/models/porcelain.rb', line 1226 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1228 1229 1230 |
# File 'lib/models/porcelain.rb', line 1228 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
1230 1231 1232 |
# File 'lib/models/porcelain.rb', line 1230 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1232 1233 1234 |
# File 'lib/models/porcelain.rb', line 1232 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1234 1235 1236 |
# File 'lib/models/porcelain.rb', line 1234 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1268 1269 1270 1271 1272 1273 1274 |
# File 'lib/models/porcelain.rb', line 1268 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |