Class: SDM::AmazonES
- Inherits:
-
Object
- Object
- SDM::AmazonES
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonES
constructor
A new instance of AmazonES.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ AmazonES
Returns a new instance of AmazonES.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/models/porcelain.rb', line 996 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
968 969 970 |
# File 'lib/models/porcelain.rb', line 968 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
970 971 972 |
# File 'lib/models/porcelain.rb', line 970 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
972 973 974 |
# File 'lib/models/porcelain.rb', line 972 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
974 975 976 |
# File 'lib/models/porcelain.rb', line 974 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
976 977 978 |
# File 'lib/models/porcelain.rb', line 976 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
978 979 980 |
# File 'lib/models/porcelain.rb', line 978 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
980 981 982 |
# File 'lib/models/porcelain.rb', line 980 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
982 983 984 |
# File 'lib/models/porcelain.rb', line 982 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
984 985 986 |
# File 'lib/models/porcelain.rb', line 984 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
986 987 988 |
# File 'lib/models/porcelain.rb', line 986 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
988 989 990 |
# File 'lib/models/porcelain.rb', line 988 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
990 991 992 |
# File 'lib/models/porcelain.rb', line 990 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
992 993 994 |
# File 'lib/models/porcelain.rb', line 992 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
994 995 996 |
# File 'lib/models/porcelain.rb', line 994 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1028 1029 1030 1031 1032 1033 1034 |
# File 'lib/models/porcelain.rb', line 1028 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |