Class: SDM::AmazonESIAM
- Inherits:
-
Object
- Object
- SDM::AmazonESIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tlsrequired ⇒ Object
Use TLS to connect to the OpenSearch server.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tlsrequired: nil) ⇒ AmazonESIAM
constructor
A new instance of AmazonESIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tlsrequired: nil) ⇒ AmazonESIAM
Returns a new instance of AmazonESIAM.
2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 |
# File 'lib/models/porcelain.rb', line 2351 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tlsrequired: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tlsrequired = tlsrequired == nil ? false : tlsrequired end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2321 2322 2323 |
# File 'lib/models/porcelain.rb', line 2321 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2323 2324 2325 |
# File 'lib/models/porcelain.rb', line 2323 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. search-?.region.es.amazonaws.com"
2325 2326 2327 |
# File 'lib/models/porcelain.rb', line 2325 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2327 2328 2329 |
# File 'lib/models/porcelain.rb', line 2327 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2329 2330 2331 |
# File 'lib/models/porcelain.rb', line 2329 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2331 2332 2333 |
# File 'lib/models/porcelain.rb', line 2331 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2333 2334 2335 |
# File 'lib/models/porcelain.rb', line 2333 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
2335 2336 2337 |
# File 'lib/models/porcelain.rb', line 2335 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
2337 2338 2339 |
# File 'lib/models/porcelain.rb', line 2337 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
2339 2340 2341 |
# File 'lib/models/porcelain.rb', line 2339 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
2341 2342 2343 |
# File 'lib/models/porcelain.rb', line 2341 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2343 2344 2345 |
# File 'lib/models/porcelain.rb', line 2343 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2345 2346 2347 |
# File 'lib/models/porcelain.rb', line 2345 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2347 2348 2349 |
# File 'lib/models/porcelain.rb', line 2347 def @tags end |
#tlsrequired ⇒ Object
Use TLS to connect to the OpenSearch server
2349 2350 2351 |
# File 'lib/models/porcelain.rb', line 2349 def tlsrequired @tlsrequired end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2385 2386 2387 2388 2389 2390 2391 |
# File 'lib/models/porcelain.rb', line 2385 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |