Class: SDM::AmazonESIAM
- Inherits:
-
Object
- Object
- SDM::AmazonESIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tlsrequired ⇒ Object
Use TLS to connect to the OpenSearch server.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tlsrequired: nil) ⇒ AmazonESIAM
constructor
A new instance of AmazonESIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tlsrequired: nil) ⇒ AmazonESIAM
Returns a new instance of AmazonESIAM.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 3204 3205 3206 3207 3208 |
# File 'lib/models/porcelain.rb', line 3176 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tlsrequired: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tlsrequired = tlsrequired == nil ? false : tlsrequired end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
3146 3147 3148 |
# File 'lib/models/porcelain.rb', line 3146 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3148 3149 3150 |
# File 'lib/models/porcelain.rb', line 3148 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. search-?.region.es.amazonaws.com"
3150 3151 3152 |
# File 'lib/models/porcelain.rb', line 3150 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3152 3153 3154 |
# File 'lib/models/porcelain.rb', line 3152 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3154 3155 3156 |
# File 'lib/models/porcelain.rb', line 3154 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3156 3157 3158 |
# File 'lib/models/porcelain.rb', line 3156 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
3158 3159 3160 |
# File 'lib/models/porcelain.rb', line 3158 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3160 3161 3162 |
# File 'lib/models/porcelain.rb', line 3160 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
3162 3163 3164 |
# File 'lib/models/porcelain.rb', line 3162 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
3164 3165 3166 |
# File 'lib/models/porcelain.rb', line 3164 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
3166 3167 3168 |
# File 'lib/models/porcelain.rb', line 3166 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3168 3169 3170 |
# File 'lib/models/porcelain.rb', line 3168 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
3170 3171 3172 |
# File 'lib/models/porcelain.rb', line 3170 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3172 3173 3174 |
# File 'lib/models/porcelain.rb', line 3172 def @tags end |
#tlsrequired ⇒ Object
Use TLS to connect to the OpenSearch server
3174 3175 3176 |
# File 'lib/models/porcelain.rb', line 3174 def tlsrequired @tlsrequired end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3210 3211 3212 3213 3214 3215 3216 |
# File 'lib/models/porcelain.rb', line 3210 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |