Class: SDM::AmazonMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091

Returns a new instance of AmazonMQAMQP091.



3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
3265
3266
3267
3268
# File 'lib/models/porcelain.rb', line 3236

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



3206
3207
3208
# File 'lib/models/porcelain.rb', line 3206

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3208
3209
3210
# File 'lib/models/porcelain.rb', line 3208

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3210
3211
3212
# File 'lib/models/porcelain.rb', line 3210

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3212
3213
3214
# File 'lib/models/porcelain.rb', line 3212

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3214
3215
3216
# File 'lib/models/porcelain.rb', line 3214

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3216
3217
3218
# File 'lib/models/porcelain.rb', line 3216

def name
  @name
end

#passwordObject

The password to authenticate with.



3218
3219
3220
# File 'lib/models/porcelain.rb', line 3218

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3220
3221
3222
# File 'lib/models/porcelain.rb', line 3220

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



3222
3223
3224
# File 'lib/models/porcelain.rb', line 3222

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3224
3225
3226
# File 'lib/models/porcelain.rb', line 3224

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3226
3227
3228
# File 'lib/models/porcelain.rb', line 3226

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



3228
3229
3230
# File 'lib/models/porcelain.rb', line 3228

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3230
3231
3232
# File 'lib/models/porcelain.rb', line 3230

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



3232
3233
3234
# File 'lib/models/porcelain.rb', line 3232

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



3234
3235
3236
# File 'lib/models/porcelain.rb', line 3234

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3270
3271
3272
3273
3274
3275
3276
# File 'lib/models/porcelain.rb', line 3270

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end