Class: SDM::AmazonMQAMQP091
- Inherits:
-
Object
- Object
- SDM::AmazonMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
constructor
A new instance of AmazonMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
Returns a new instance of AmazonMQAMQP091.
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 |
# File 'lib/models/porcelain.rb', line 3234 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
3204 3205 3206 |
# File 'lib/models/porcelain.rb', line 3204 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3206 3207 3208 |
# File 'lib/models/porcelain.rb', line 3206 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3208 3209 3210 |
# File 'lib/models/porcelain.rb', line 3208 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3210 3211 3212 |
# File 'lib/models/porcelain.rb', line 3210 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3212 3213 3214 |
# File 'lib/models/porcelain.rb', line 3212 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3214 3215 3216 |
# File 'lib/models/porcelain.rb', line 3214 def name @name end |
#password ⇒ Object
The password to authenticate with.
3216 3217 3218 |
# File 'lib/models/porcelain.rb', line 3216 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3218 3219 3220 |
# File 'lib/models/porcelain.rb', line 3218 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
3220 3221 3222 |
# File 'lib/models/porcelain.rb', line 3220 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3222 3223 3224 |
# File 'lib/models/porcelain.rb', line 3222 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3224 3225 3226 |
# File 'lib/models/porcelain.rb', line 3224 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
3226 3227 3228 |
# File 'lib/models/porcelain.rb', line 3226 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3228 3229 3230 |
# File 'lib/models/porcelain.rb', line 3228 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
3230 3231 3232 |
# File 'lib/models/porcelain.rb', line 3230 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
3232 3233 3234 |
# File 'lib/models/porcelain.rb', line 3232 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/models/porcelain.rb', line 3268 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |