Class: SDM::AmazonMQAMQP091
- Inherits:
-
Object
- Object
- SDM::AmazonMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
constructor
A new instance of AmazonMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
Returns a new instance of AmazonMQAMQP091.
2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 |
# File 'lib/models/porcelain.rb', line 2423 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2393 2394 2395 |
# File 'lib/models/porcelain.rb', line 2393 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2395 2396 2397 |
# File 'lib/models/porcelain.rb', line 2395 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2397 2398 2399 |
# File 'lib/models/porcelain.rb', line 2397 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
2399 2400 2401 |
# File 'lib/models/porcelain.rb', line 2399 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2401 2402 2403 |
# File 'lib/models/porcelain.rb', line 2401 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2403 2404 2405 |
# File 'lib/models/porcelain.rb', line 2403 def name @name end |
#password ⇒ Object
The password to authenticate with.
2405 2406 2407 |
# File 'lib/models/porcelain.rb', line 2405 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
2407 2408 2409 |
# File 'lib/models/porcelain.rb', line 2407 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2409 2410 2411 |
# File 'lib/models/porcelain.rb', line 2409 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
2411 2412 2413 |
# File 'lib/models/porcelain.rb', line 2411 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2413 2414 2415 |
# File 'lib/models/porcelain.rb', line 2413 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2415 2416 2417 |
# File 'lib/models/porcelain.rb', line 2415 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2417 2418 2419 |
# File 'lib/models/porcelain.rb', line 2417 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
2419 2420 2421 |
# File 'lib/models/porcelain.rb', line 2419 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
2421 2422 2423 |
# File 'lib/models/porcelain.rb', line 2421 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/models/porcelain.rb', line 2457 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |