Class: SDM::AmazonMQAMQP091
- Inherits:
-
Object
- Object
- SDM::AmazonMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
constructor
A new instance of AmazonMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
Returns a new instance of AmazonMQAMQP091.
2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 |
# File 'lib/models/porcelain.rb', line 2208 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2180 2181 2182 |
# File 'lib/models/porcelain.rb', line 2180 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2182 2183 2184 |
# File 'lib/models/porcelain.rb', line 2182 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2184 2185 2186 |
# File 'lib/models/porcelain.rb', line 2184 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
2186 2187 2188 |
# File 'lib/models/porcelain.rb', line 2186 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2188 2189 2190 |
# File 'lib/models/porcelain.rb', line 2188 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2190 2191 2192 |
# File 'lib/models/porcelain.rb', line 2190 def name @name end |
#password ⇒ Object
The password to authenticate with.
2192 2193 2194 |
# File 'lib/models/porcelain.rb', line 2192 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
2194 2195 2196 |
# File 'lib/models/porcelain.rb', line 2194 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2196 2197 2198 |
# File 'lib/models/porcelain.rb', line 2196 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2198 2199 2200 |
# File 'lib/models/porcelain.rb', line 2198 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2200 2201 2202 |
# File 'lib/models/porcelain.rb', line 2200 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2202 2203 2204 |
# File 'lib/models/porcelain.rb', line 2202 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
2204 2205 2206 |
# File 'lib/models/porcelain.rb', line 2204 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
2206 2207 2208 |
# File 'lib/models/porcelain.rb', line 2206 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/models/porcelain.rb', line 2240 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |