Class: SDM::AmazonMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091

Returns a new instance of AmazonMQAMQP091.



2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
2032
# File 'lib/models/porcelain.rb', line 2002

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1974
1975
1976
# File 'lib/models/porcelain.rb', line 1974

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1976
1977
1978
# File 'lib/models/porcelain.rb', line 1976

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1978
1979
1980
# File 'lib/models/porcelain.rb', line 1978

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



1980
1981
1982
# File 'lib/models/porcelain.rb', line 1980

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1982
1983
1984
# File 'lib/models/porcelain.rb', line 1982

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1984
1985
1986
# File 'lib/models/porcelain.rb', line 1984

def name
  @name
end

#passwordObject

The password to authenticate with.



1986
1987
1988
# File 'lib/models/porcelain.rb', line 1986

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



1988
1989
1990
# File 'lib/models/porcelain.rb', line 1988

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



1990
1991
1992
# File 'lib/models/porcelain.rb', line 1990

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1992
1993
1994
# File 'lib/models/porcelain.rb', line 1992

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1994
1995
1996
# File 'lib/models/porcelain.rb', line 1994

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1996
1997
1998
# File 'lib/models/porcelain.rb', line 1996

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



1998
1999
2000
# File 'lib/models/porcelain.rb', line 1998

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



2000
2001
2002
# File 'lib/models/porcelain.rb', line 2000

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2034
2035
2036
2037
2038
2039
2040
# File 'lib/models/porcelain.rb', line 2034

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end