Class: SDM::AmazonMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091

Returns a new instance of AmazonMQAMQP091.



1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
# File 'lib/models/porcelain.rb', line 1838

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



1810
1811
1812
# File 'lib/models/porcelain.rb', line 1810

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1812
1813
1814
# File 'lib/models/porcelain.rb', line 1812

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1814
1815
1816
# File 'lib/models/porcelain.rb', line 1814

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



1816
1817
1818
# File 'lib/models/porcelain.rb', line 1816

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1818
1819
1820
# File 'lib/models/porcelain.rb', line 1818

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1820
1821
1822
# File 'lib/models/porcelain.rb', line 1820

def name
  @name
end

#passwordObject

The password to authenticate with.



1822
1823
1824
# File 'lib/models/porcelain.rb', line 1822

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



1824
1825
1826
# File 'lib/models/porcelain.rb', line 1824

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



1826
1827
1828
# File 'lib/models/porcelain.rb', line 1826

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1828
1829
1830
# File 'lib/models/porcelain.rb', line 1828

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



1830
1831
1832
# File 'lib/models/porcelain.rb', line 1830

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



1832
1833
1834
# File 'lib/models/porcelain.rb', line 1832

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



1834
1835
1836
# File 'lib/models/porcelain.rb', line 1834

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



1836
1837
1838
# File 'lib/models/porcelain.rb', line 1836

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1870
1871
1872
1873
1874
1875
1876
# File 'lib/models/porcelain.rb', line 1870

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end