Class: SDM::AmazonMQAMQP091
- Inherits:
-
Object
- Object
- SDM::AmazonMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
constructor
A new instance of AmazonMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
Returns a new instance of AmazonMQAMQP091.
1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/models/porcelain.rb', line 1643 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1617 1618 1619 |
# File 'lib/models/porcelain.rb', line 1617 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1619 1620 1621 |
# File 'lib/models/porcelain.rb', line 1619 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1621 1622 1623 |
# File 'lib/models/porcelain.rb', line 1621 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
1623 1624 1625 |
# File 'lib/models/porcelain.rb', line 1623 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1625 1626 1627 |
# File 'lib/models/porcelain.rb', line 1625 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1627 1628 1629 |
# File 'lib/models/porcelain.rb', line 1627 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
1629 1630 1631 |
# File 'lib/models/porcelain.rb', line 1629 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
1631 1632 1633 |
# File 'lib/models/porcelain.rb', line 1631 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1633 1634 1635 |
# File 'lib/models/porcelain.rb', line 1633 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1635 1636 1637 |
# File 'lib/models/porcelain.rb', line 1635 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1637 1638 1639 |
# File 'lib/models/porcelain.rb', line 1637 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
1639 1640 1641 |
# File 'lib/models/porcelain.rb', line 1639 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
1641 1642 1643 |
# File 'lib/models/porcelain.rb', line 1641 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1673 1674 1675 1676 1677 1678 1679 |
# File 'lib/models/porcelain.rb', line 1673 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |