Class: SDM::AmazonMQAMQP091
- Inherits:
-
Object
- Object
- SDM::AmazonMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
constructor
A new instance of AmazonMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ AmazonMQAMQP091
Returns a new instance of AmazonMQAMQP091.
1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 |
# File 'lib/models/porcelain.rb', line 1305 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1279 1280 1281 |
# File 'lib/models/porcelain.rb', line 1279 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1281 1282 1283 |
# File 'lib/models/porcelain.rb', line 1281 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1283 1284 1285 |
# File 'lib/models/porcelain.rb', line 1283 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
1285 1286 1287 |
# File 'lib/models/porcelain.rb', line 1285 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1287 1288 1289 |
# File 'lib/models/porcelain.rb', line 1287 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1289 1290 1291 |
# File 'lib/models/porcelain.rb', line 1289 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
1291 1292 1293 |
# File 'lib/models/porcelain.rb', line 1291 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
1293 1294 1295 |
# File 'lib/models/porcelain.rb', line 1293 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1295 1296 1297 |
# File 'lib/models/porcelain.rb', line 1295 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1297 1298 1299 |
# File 'lib/models/porcelain.rb', line 1297 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1299 1300 1301 |
# File 'lib/models/porcelain.rb', line 1299 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
1301 1302 1303 |
# File 'lib/models/porcelain.rb', line 1301 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
1303 1304 1305 |
# File 'lib/models/porcelain.rb', line 1303 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1335 1336 1337 1338 1339 1340 1341 |
# File 'lib/models/porcelain.rb', line 1335 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |