Class: SDM::ApprovalWorkflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized approvers and be approved or denied.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(approval_mode: nil, approval_workflow_steps: nil, description: nil, id: nil, name: nil) ⇒ ApprovalWorkflow

Returns a new instance of ApprovalWorkflow.



2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
# File 'lib/models/porcelain.rb', line 2645

def initialize(
  approval_mode: nil,
  approval_workflow_steps: nil,
  description: nil,
  id: nil,
  name: nil
)
  @approval_mode = approval_mode == nil ? "" : approval_mode
  @approval_workflow_steps = approval_workflow_steps == nil ? [] : approval_workflow_steps
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
end

Instance Attribute Details

#approval_modeObject

Approval mode of the ApprovalWorkflow



2635
2636
2637
# File 'lib/models/porcelain.rb', line 2635

def approval_mode
  @approval_mode
end

#approval_workflow_stepsObject

The approval steps of this approval workflow



2637
2638
2639
# File 'lib/models/porcelain.rb', line 2637

def approval_workflow_steps
  @approval_workflow_steps
end

#descriptionObject

Optional description of the ApprovalWorkflow.



2639
2640
2641
# File 'lib/models/porcelain.rb', line 2639

def description
  @description
end

#idObject

Unique identifier of the ApprovalWorkflow.



2641
2642
2643
# File 'lib/models/porcelain.rb', line 2641

def id
  @id
end

#nameObject

Unique human-readable name of the ApprovalWorkflow.



2643
2644
2645
# File 'lib/models/porcelain.rb', line 2643

def name
  @name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2659
2660
2661
2662
2663
2664
2665
# File 'lib/models/porcelain.rb', line 2659

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end