Class: SDM::ApprovalWorkflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized approvers and be approved or denied.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(approval_mode: nil, description: nil, id: nil, name: nil) ⇒ ApprovalWorkflow

Returns a new instance of ApprovalWorkflow.



2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
# File 'lib/models/porcelain.rb', line 2586

def initialize(
  approval_mode: nil,
  description: nil,
  id: nil,
  name: nil
)
  @approval_mode = approval_mode == nil ? "" : approval_mode
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
end

Instance Attribute Details

#approval_modeObject

Approval mode of the ApprovalWorkflow



2578
2579
2580
# File 'lib/models/porcelain.rb', line 2578

def approval_mode
  @approval_mode
end

#descriptionObject

Optional description of the ApprovalWorkflow.



2580
2581
2582
# File 'lib/models/porcelain.rb', line 2580

def description
  @description
end

#idObject

Unique identifier of the ApprovalWorkflow.



2582
2583
2584
# File 'lib/models/porcelain.rb', line 2582

def id
  @id
end

#nameObject

Unique human-readable name of the ApprovalWorkflow.



2584
2585
2586
# File 'lib/models/porcelain.rb', line 2584

def name
  @name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2598
2599
2600
2601
2602
2603
2604
# File 'lib/models/porcelain.rb', line 2598

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end