Class: SDM::ApprovalWorkflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized approvers and be approved or denied.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(approval_mode: nil, description: nil, id: nil, name: nil) ⇒ ApprovalWorkflow

Returns a new instance of ApprovalWorkflow.



2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
# File 'lib/models/porcelain.rb', line 2481

def initialize(
  approval_mode: nil,
  description: nil,
  id: nil,
  name: nil
)
  @approval_mode = approval_mode == nil ? "" : approval_mode
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
end

Instance Attribute Details

#approval_modeObject

Approval mode of the ApprovalWorkflow



2473
2474
2475
# File 'lib/models/porcelain.rb', line 2473

def approval_mode
  @approval_mode
end

#descriptionObject

Optional description of the ApprovalWorkflow.



2475
2476
2477
# File 'lib/models/porcelain.rb', line 2475

def description
  @description
end

#idObject

Unique identifier of the ApprovalWorkflow.



2477
2478
2479
# File 'lib/models/porcelain.rb', line 2477

def id
  @id
end

#nameObject

Unique human-readable name of the ApprovalWorkflow.



2479
2480
2481
# File 'lib/models/porcelain.rb', line 2479

def name
  @name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2493
2494
2495
2496
2497
2498
2499
# File 'lib/models/porcelain.rb', line 2493

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end