Class: SDM::ApprovalWorkflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized approvers and be approved or denied.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(approval_mode: nil, description: nil, id: nil, name: nil) ⇒ ApprovalWorkflow

Returns a new instance of ApprovalWorkflow.



2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
# File 'lib/models/porcelain.rb', line 2261

def initialize(
  approval_mode: nil,
  description: nil,
  id: nil,
  name: nil
)
  @approval_mode = approval_mode == nil ? "" : approval_mode
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
end

Instance Attribute Details

#approval_modeObject

Approval mode of the ApprovalWorkflow



2253
2254
2255
# File 'lib/models/porcelain.rb', line 2253

def approval_mode
  @approval_mode
end

#descriptionObject

Optional description of the ApprovalWorkflow.



2255
2256
2257
# File 'lib/models/porcelain.rb', line 2255

def description
  @description
end

#idObject

Unique identifier of the ApprovalWorkflow.



2257
2258
2259
# File 'lib/models/porcelain.rb', line 2257

def id
  @id
end

#nameObject

Unique human-readable name of the ApprovalWorkflow.



2259
2260
2261
# File 'lib/models/porcelain.rb', line 2259

def name
  @name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2273
2274
2275
2276
2277
2278
2279
# File 'lib/models/porcelain.rb', line 2273

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end