Class: SDM::ApprovalWorkflow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized approvers and be approved or denied.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(approval_mode: nil, approval_workflow_steps: nil, description: nil, id: nil, name: nil) ⇒ ApprovalWorkflow

Returns a new instance of ApprovalWorkflow.



3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
# File 'lib/models/porcelain.rb', line 3354

def initialize(
  approval_mode: nil,
  approval_workflow_steps: nil,
  description: nil,
  id: nil,
  name: nil
)
  @approval_mode = approval_mode == nil ? "" : approval_mode
  @approval_workflow_steps = approval_workflow_steps == nil ? [] : approval_workflow_steps
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
end

Instance Attribute Details

#approval_modeObject

Approval mode of the ApprovalWorkflow



3344
3345
3346
# File 'lib/models/porcelain.rb', line 3344

def approval_mode
  @approval_mode
end

#approval_workflow_stepsObject

The approval steps of this approval workflow



3346
3347
3348
# File 'lib/models/porcelain.rb', line 3346

def approval_workflow_steps
  @approval_workflow_steps
end

#descriptionObject

Optional description of the ApprovalWorkflow.



3348
3349
3350
# File 'lib/models/porcelain.rb', line 3348

def description
  @description
end

#idObject

Unique identifier of the ApprovalWorkflow.



3350
3351
3352
# File 'lib/models/porcelain.rb', line 3350

def id
  @id
end

#nameObject

Unique human-readable name of the ApprovalWorkflow.



3352
3353
3354
# File 'lib/models/porcelain.rb', line 3352

def name
  @name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3368
3369
3370
3371
3372
3373
3374
# File 'lib/models/porcelain.rb', line 3368

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end