Class: SDM::ApprovalWorkflowApprover
- Inherits:
-
Object
- Object
- SDM::ApprovalWorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
ApprovalWorkflowApprover links an approval workflow approver to an ApprovalWorkflowStep
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#approval_flow_id ⇒ Object
The approval flow id specified the approval workflow that this approver belongs to.
-
#approval_step_id ⇒ Object
The approval step id specified the approval flow step that this approver belongs to.
-
#id ⇒ Object
Unique identifier of the ApprovalWorkflowApprover.
-
#reference ⇒ Object
A reference to an approver.
-
#role_id ⇒ Object
The approver role id.
Instance Method Summary collapse
-
#initialize(account_id: nil, approval_flow_id: nil, approval_step_id: nil, id: nil, reference: nil, role_id: nil) ⇒ ApprovalWorkflowApprover
constructor
A new instance of ApprovalWorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, approval_flow_id: nil, approval_step_id: nil, id: nil, reference: nil, role_id: nil) ⇒ ApprovalWorkflowApprover
Returns a new instance of ApprovalWorkflowApprover.
2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 |
# File 'lib/models/porcelain.rb', line 2685 def initialize( account_id: nil, approval_flow_id: nil, approval_step_id: nil, id: nil, reference: nil, role_id: nil ) @account_id = account_id == nil ? "" : account_id @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id @approval_step_id = approval_step_id == nil ? "" : approval_step_id @id = id == nil ? "" : id @reference = reference == nil ? "" : reference @role_id = role_id == nil ? "" : role_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
2671 2672 2673 |
# File 'lib/models/porcelain.rb', line 2671 def account_id @account_id end |
#approval_flow_id ⇒ Object
The approval flow id specified the approval workflow that this approver belongs to
2673 2674 2675 |
# File 'lib/models/porcelain.rb', line 2673 def approval_flow_id @approval_flow_id end |
#approval_step_id ⇒ Object
The approval step id specified the approval flow step that this approver belongs to
2675 2676 2677 |
# File 'lib/models/porcelain.rb', line 2675 def approval_step_id @approval_step_id end |
#id ⇒ Object
Unique identifier of the ApprovalWorkflowApprover.
2677 2678 2679 |
# File 'lib/models/porcelain.rb', line 2677 def id @id end |
#reference ⇒ Object
A reference to an approver. Will be one of ApproverReference constants. This field is only populated when reading historical Approval Workflow Approvers data through the Approval Workflows History API. For the deprecated Approval Workflow Approvers API no value is returned for this field and it is non-settable.
2681 2682 2683 |
# File 'lib/models/porcelain.rb', line 2681 def reference @reference end |
#role_id ⇒ Object
The approver role id
2683 2684 2685 |
# File 'lib/models/porcelain.rb', line 2683 def role_id @role_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2701 2702 2703 2704 2705 2706 2707 |
# File 'lib/models/porcelain.rb', line 2701 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |