Class: SDM::ApprovalWorkflowApprover
- Inherits:
-
Object
- Object
- SDM::ApprovalWorkflowApprover
- Defined in:
- lib/models/porcelain.rb
Overview
ApprovalWorkflowApprover links an approval workflow approver to an ApprovalWorkflowStep ApprovalWorkflowApprover is deprecated, see docs for more info.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The approver account id.
-
#approval_flow_id ⇒ Object
The approval flow id specified the approval workflow that this approver belongs to.
-
#approval_step_id ⇒ Object
The approval step id specified the approval flow step that this approver belongs to.
-
#id ⇒ Object
Unique identifier of the ApprovalWorkflowApprover.
-
#reference ⇒ Object
A reference to an approver.
-
#role_id ⇒ Object
The approver role id.
Instance Method Summary collapse
-
#initialize(account_id: nil, approval_flow_id: nil, approval_step_id: nil, id: nil, reference: nil, role_id: nil) ⇒ ApprovalWorkflowApprover
constructor
A new instance of ApprovalWorkflowApprover.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, approval_flow_id: nil, approval_step_id: nil, id: nil, reference: nil, role_id: nil) ⇒ ApprovalWorkflowApprover
3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/models/porcelain.rb', line 3402 def initialize( account_id: nil, approval_flow_id: nil, approval_step_id: nil, id: nil, reference: nil, role_id: nil ) @account_id = account_id == nil ? "" : account_id @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id @approval_step_id = approval_step_id == nil ? "" : approval_step_id @id = id == nil ? "" : id @reference = reference == nil ? "" : reference @role_id = role_id == nil ? "" : role_id end |
Instance Attribute Details
#account_id ⇒ Object
The approver account id.
3388 3389 3390 |
# File 'lib/models/porcelain.rb', line 3388 def account_id @account_id end |
#approval_flow_id ⇒ Object
The approval flow id specified the approval workflow that this approver belongs to
3390 3391 3392 |
# File 'lib/models/porcelain.rb', line 3390 def approval_flow_id @approval_flow_id end |
#approval_step_id ⇒ Object
The approval step id specified the approval flow step that this approver belongs to
3392 3393 3394 |
# File 'lib/models/porcelain.rb', line 3392 def approval_step_id @approval_step_id end |
#id ⇒ Object
Unique identifier of the ApprovalWorkflowApprover.
3394 3395 3396 |
# File 'lib/models/porcelain.rb', line 3394 def id @id end |
#reference ⇒ Object
A reference to an approver. Will be one of ApproverReference constants. This field is only populated when reading historical Approval Workflow Approvers data through the Approval Workflows History API. For the deprecated Approval Workflow Approvers API no value is returned for this field and it is non-settable.
3398 3399 3400 |
# File 'lib/models/porcelain.rb', line 3398 def reference @reference end |
#role_id ⇒ Object
The approver role id
3400 3401 3402 |
# File 'lib/models/porcelain.rb', line 3400 def role_id @role_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3418 3419 3420 3421 3422 3423 3424 |
# File 'lib/models/porcelain.rb', line 3418 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |