Class: SDM::ApprovalWorkflowApprover

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowApprover links an approval workflow approver to an ApprovalWorkflowStep ApprovalWorkflowApprover is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, approval_flow_id: nil, approval_step_id: nil, id: nil, reference: nil, role_id: nil) ⇒ ApprovalWorkflowApprover

Returns a new instance of ApprovalWorkflowApprover.



3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
# File 'lib/models/porcelain.rb', line 3395

def initialize(
  account_id: nil,
  approval_flow_id: nil,
  approval_step_id: nil,
  id: nil,
  reference: nil,
  role_id: nil
)
  @account_id =  == nil ? "" : 
  @approval_flow_id = approval_flow_id == nil ? "" : approval_flow_id
  @approval_step_id = approval_step_id == nil ? "" : approval_step_id
  @id = id == nil ? "" : id
  @reference = reference == nil ? "" : reference
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#account_idObject

The approver account id.



3381
3382
3383
# File 'lib/models/porcelain.rb', line 3381

def 
  @account_id
end

#approval_flow_idObject

The approval flow id specified the approval workflow that this approver belongs to



3383
3384
3385
# File 'lib/models/porcelain.rb', line 3383

def approval_flow_id
  @approval_flow_id
end

#approval_step_idObject

The approval step id specified the approval flow step that this approver belongs to



3385
3386
3387
# File 'lib/models/porcelain.rb', line 3385

def approval_step_id
  @approval_step_id
end

#idObject

Unique identifier of the ApprovalWorkflowApprover.



3387
3388
3389
# File 'lib/models/porcelain.rb', line 3387

def id
  @id
end

#referenceObject

A reference to an approver. Will be one of ApproverReference constants. This field is only populated when reading historical Approval Workflow Approvers data through the Approval Workflows History API. For the deprecated Approval Workflow Approvers API no value is returned for this field and it is non-settable.



3391
3392
3393
# File 'lib/models/porcelain.rb', line 3391

def reference
  @reference
end

#role_idObject

The approver role id



3393
3394
3395
# File 'lib/models/porcelain.rb', line 3393

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3411
3412
3413
3414
3415
3416
3417
# File 'lib/models/porcelain.rb', line 3411

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end