Class: SDM::ApprovalWorkflowApproverHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowApproverHistory records the state of an ApprovalWorkflowApprover at a given point in time, where every change (create or delete) to an ApprovalWorkflowApprover produces an ApprovalWorkflowApproverHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, approval_workflow_approver: nil, deleted_at: nil, timestamp: nil) ⇒ ApprovalWorkflowApproverHistory

Returns a new instance of ApprovalWorkflowApproverHistory.



2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
# File 'lib/models/porcelain.rb', line 2733

def initialize(
  activity_id: nil,
  approval_workflow_approver: nil,
  deleted_at: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @approval_workflow_approver = approval_workflow_approver == nil ? nil : approval_workflow_approver
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the ApprovalWorkflowApprover. May be empty for some system-initiated updates.



2725
2726
2727
# File 'lib/models/porcelain.rb', line 2725

def activity_id
  @activity_id
end

#approval_workflow_approverObject

The complete ApprovalWorkflowApprover state at this time.



2727
2728
2729
# File 'lib/models/porcelain.rb', line 2727

def approval_workflow_approver
  @approval_workflow_approver
end

#deleted_atObject

If this ApprovalWorkflowApprover was deleted, the time it was deleted.



2729
2730
2731
# File 'lib/models/porcelain.rb', line 2729

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the ApprovalWorkflowApprover state was recorded.



2731
2732
2733
# File 'lib/models/porcelain.rb', line 2731

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2745
2746
2747
2748
2749
2750
2751
# File 'lib/models/porcelain.rb', line 2745

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end