Class: SDM::ApprovalWorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowHistory records the state of an ApprovalWorkflow at a given point in time, where every change (create, update and delete) to an ApprovalWorkflow produces an ApprovalWorkflowHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, approval_workflow: nil, deleted_at: nil, timestamp: nil) ⇒ ApprovalWorkflowHistory

Returns a new instance of ApprovalWorkflowHistory.



2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
# File 'lib/models/porcelain.rb', line 2757

def initialize(
  activity_id: nil,
  approval_workflow: nil,
  deleted_at: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @approval_workflow = approval_workflow == nil ? nil : approval_workflow
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the ApprovalWorkflow. May be empty for some system-initiated updates.



2749
2750
2751
# File 'lib/models/porcelain.rb', line 2749

def activity_id
  @activity_id
end

#approval_workflowObject

The complete ApprovalWorkflow state at this time.



2751
2752
2753
# File 'lib/models/porcelain.rb', line 2751

def approval_workflow
  @approval_workflow
end

#deleted_atObject

If this ApprovalWorkflow was deleted, the time it was deleted.



2753
2754
2755
# File 'lib/models/porcelain.rb', line 2753

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the ApprovalWorkflow state was recorded.



2755
2756
2757
# File 'lib/models/porcelain.rb', line 2755

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2769
2770
2771
2772
2773
2774
2775
# File 'lib/models/porcelain.rb', line 2769

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end