Class: SDM::ApprovalWorkflowHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowHistory records the state of an ApprovalWorkflow at a given point in time, where every change (create, update and delete) to an ApprovalWorkflow produces an ApprovalWorkflowHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, approval_workflow: nil, deleted_at: nil, timestamp: nil) ⇒ ApprovalWorkflowHistory

Returns a new instance of ApprovalWorkflowHistory.



2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
# File 'lib/models/porcelain.rb', line 2521

def initialize(
  activity_id: nil,
  approval_workflow: nil,
  deleted_at: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @approval_workflow = approval_workflow == nil ? nil : approval_workflow
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the ApprovalWorkflow. May be empty for some system-initiated updates.



2513
2514
2515
# File 'lib/models/porcelain.rb', line 2513

def activity_id
  @activity_id
end

#approval_workflowObject

The complete ApprovalWorkflow state at this time.



2515
2516
2517
# File 'lib/models/porcelain.rb', line 2515

def approval_workflow
  @approval_workflow
end

#deleted_atObject

If this ApprovalWorkflow was deleted, the time it was deleted.



2517
2518
2519
# File 'lib/models/porcelain.rb', line 2517

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the ApprovalWorkflow state was recorded.



2519
2520
2521
# File 'lib/models/porcelain.rb', line 2519

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2533
2534
2535
2536
2537
2538
2539
# File 'lib/models/porcelain.rb', line 2533

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end