Class: SDM::ApprovalWorkflowStepHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowStepHistory records the state of an ApprovalWorkflowStep at a given point in time, where every change (create or delete) to an ApprovalWorkflowStep produces an ApprovalWorkflowStepHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, approval_workflow_step: nil, deleted_at: nil, timestamp: nil) ⇒ ApprovalWorkflowStepHistory

Returns a new instance of ApprovalWorkflowStepHistory.



3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
3110
# File 'lib/models/porcelain.rb', line 3100

def initialize(
  activity_id: nil,
  approval_workflow_step: nil,
  deleted_at: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @approval_workflow_step = approval_workflow_step == nil ? nil : approval_workflow_step
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the ApprovalWorkflowStep. May be empty for some system-initiated updates.



3092
3093
3094
# File 'lib/models/porcelain.rb', line 3092

def activity_id
  @activity_id
end

#approval_workflow_stepObject

The complete ApprovalWorkflowStep state at this time.



3094
3095
3096
# File 'lib/models/porcelain.rb', line 3094

def approval_workflow_step
  @approval_workflow_step
end

#deleted_atObject

If this ApprovalWorkflowStep was deleted, the time it was deleted.



3096
3097
3098
# File 'lib/models/porcelain.rb', line 3096

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the ApprovalWorkflowStep state was recorded.



3098
3099
3100
# File 'lib/models/porcelain.rb', line 3098

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3112
3113
3114
3115
3116
3117
3118
# File 'lib/models/porcelain.rb', line 3112

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end