Class: SDM::ApprovalWorkflowStepHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ApprovalWorkflowStepHistory records the state of an ApprovalWorkflowStep at a given point in time, where every change (create or delete) to an ApprovalWorkflowStep produces an ApprovalWorkflowStepHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, approval_workflow_step: nil, deleted_at: nil, timestamp: nil) ⇒ ApprovalWorkflowStepHistory

Returns a new instance of ApprovalWorkflowStepHistory.



3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
# File 'lib/models/porcelain.rb', line 3021

def initialize(
  activity_id: nil,
  approval_workflow_step: nil,
  deleted_at: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @approval_workflow_step = approval_workflow_step == nil ? nil : approval_workflow_step
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the ApprovalWorkflowStep. May be empty for some system-initiated updates.



3013
3014
3015
# File 'lib/models/porcelain.rb', line 3013

def activity_id
  @activity_id
end

#approval_workflow_stepObject

The complete ApprovalWorkflowStep state at this time.



3015
3016
3017
# File 'lib/models/porcelain.rb', line 3015

def approval_workflow_step
  @approval_workflow_step
end

#deleted_atObject

If this ApprovalWorkflowStep was deleted, the time it was deleted.



3017
3018
3019
# File 'lib/models/porcelain.rb', line 3017

def deleted_at
  @deleted_at
end

#timestampObject

The time at which the ApprovalWorkflowStep state was recorded.



3019
3020
3021
# File 'lib/models/porcelain.rb', line 3019

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3033
3034
3035
3036
3037
3038
3039
# File 'lib/models/porcelain.rb', line 3033

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end