Class: SDM::Athena

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena

Returns a new instance of Athena.



3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
# File 'lib/models/porcelain.rb', line 3276

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



3244
3245
3246
# File 'lib/models/porcelain.rb', line 3244

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3246
3247
3248
# File 'lib/models/porcelain.rb', line 3246

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3248
3249
3250
# File 'lib/models/porcelain.rb', line 3248

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3250
3251
3252
# File 'lib/models/porcelain.rb', line 3250

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3252
3253
3254
# File 'lib/models/porcelain.rb', line 3252

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3254
3255
3256
# File 'lib/models/porcelain.rb', line 3254

def name
  @name
end

#outputObject

The AWS S3 output location.



3256
3257
3258
# File 'lib/models/porcelain.rb', line 3256

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource.



3258
3259
3260
# File 'lib/models/porcelain.rb', line 3258

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3260
3261
3262
# File 'lib/models/porcelain.rb', line 3260

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



3262
3263
3264
# File 'lib/models/porcelain.rb', line 3262

def region
  @region
end

#role_arnObject

The role to assume after logging in.



3264
3265
3266
# File 'lib/models/porcelain.rb', line 3264

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



3266
3267
3268
# File 'lib/models/porcelain.rb', line 3266

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



3268
3269
3270
# File 'lib/models/porcelain.rb', line 3268

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3270
3271
3272
# File 'lib/models/porcelain.rb', line 3270

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3272
3273
3274
# File 'lib/models/porcelain.rb', line 3272

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3274
3275
3276
# File 'lib/models/porcelain.rb', line 3274

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3312
3313
3314
3315
3316
3317
3318
# File 'lib/models/porcelain.rb', line 3312

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end