Class: SDM::Athena

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena

Returns a new instance of Athena.



3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
3148
3149
3150
3151
3152
3153
3154
3155
3156
# File 'lib/models/porcelain.rb', line 3122

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



3090
3091
3092
# File 'lib/models/porcelain.rb', line 3090

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3092
3093
3094
# File 'lib/models/porcelain.rb', line 3092

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3094
3095
3096
# File 'lib/models/porcelain.rb', line 3094

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3096
3097
3098
# File 'lib/models/porcelain.rb', line 3096

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3098
3099
3100
# File 'lib/models/porcelain.rb', line 3098

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3100
3101
3102
# File 'lib/models/porcelain.rb', line 3100

def name
  @name
end

#outputObject

The AWS S3 output location.



3102
3103
3104
# File 'lib/models/porcelain.rb', line 3102

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource.



3104
3105
3106
# File 'lib/models/porcelain.rb', line 3104

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3106
3107
3108
# File 'lib/models/porcelain.rb', line 3106

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



3108
3109
3110
# File 'lib/models/porcelain.rb', line 3108

def region
  @region
end

#role_arnObject

The role to assume after logging in.



3110
3111
3112
# File 'lib/models/porcelain.rb', line 3110

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



3112
3113
3114
# File 'lib/models/porcelain.rb', line 3112

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



3114
3115
3116
# File 'lib/models/porcelain.rb', line 3114

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3116
3117
3118
# File 'lib/models/porcelain.rb', line 3116

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3118
3119
3120
# File 'lib/models/porcelain.rb', line 3118

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3120
3121
3122
# File 'lib/models/porcelain.rb', line 3120

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3158
3159
3160
3161
3162
3163
3164
# File 'lib/models/porcelain.rb', line 3158

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end