Class: SDM::Athena

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena

Returns a new instance of Athena.



3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
# File 'lib/models/porcelain.rb', line 3017

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



2985
2986
2987
# File 'lib/models/porcelain.rb', line 2985

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2987
2988
2989
# File 'lib/models/porcelain.rb', line 2987

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2989
2990
2991
# File 'lib/models/porcelain.rb', line 2989

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2991
2992
2993
# File 'lib/models/porcelain.rb', line 2991

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2993
2994
2995
# File 'lib/models/porcelain.rb', line 2993

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2995
2996
2997
# File 'lib/models/porcelain.rb', line 2995

def name
  @name
end

#outputObject

The AWS S3 output location.



2997
2998
2999
# File 'lib/models/porcelain.rb', line 2997

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource.



2999
3000
3001
# File 'lib/models/porcelain.rb', line 2999

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3001
3002
3003
# File 'lib/models/porcelain.rb', line 3001

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



3003
3004
3005
# File 'lib/models/porcelain.rb', line 3003

def region
  @region
end

#role_arnObject

The role to assume after logging in.



3005
3006
3007
# File 'lib/models/porcelain.rb', line 3005

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



3007
3008
3009
# File 'lib/models/porcelain.rb', line 3007

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



3009
3010
3011
# File 'lib/models/porcelain.rb', line 3009

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3011
3012
3013
# File 'lib/models/porcelain.rb', line 3011

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3013
3014
3015
# File 'lib/models/porcelain.rb', line 3013

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3015
3016
3017
# File 'lib/models/porcelain.rb', line 3015

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3053
3054
3055
3056
3057
3058
3059
# File 'lib/models/porcelain.rb', line 3053

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end