Class: SDM::Athena

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena

Returns a new instance of Athena.



2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
# File 'lib/models/porcelain.rb', line 2795

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



2765
2766
2767
# File 'lib/models/porcelain.rb', line 2765

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2767
2768
2769
# File 'lib/models/porcelain.rb', line 2767

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2769
2770
2771
# File 'lib/models/porcelain.rb', line 2769

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2771
2772
2773
# File 'lib/models/porcelain.rb', line 2771

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2773
2774
2775
# File 'lib/models/porcelain.rb', line 2773

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2775
2776
2777
# File 'lib/models/porcelain.rb', line 2775

def name
  @name
end

#outputObject

The AWS S3 output location.



2777
2778
2779
# File 'lib/models/porcelain.rb', line 2777

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource.



2779
2780
2781
# File 'lib/models/porcelain.rb', line 2779

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



2781
2782
2783
# File 'lib/models/porcelain.rb', line 2781

def region
  @region
end

#role_arnObject

The role to assume after logging in.



2783
2784
2785
# File 'lib/models/porcelain.rb', line 2783

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2785
2786
2787
# File 'lib/models/porcelain.rb', line 2785

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



2787
2788
2789
# File 'lib/models/porcelain.rb', line 2787

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2789
2790
2791
# File 'lib/models/porcelain.rb', line 2789

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2791
2792
2793
# File 'lib/models/porcelain.rb', line 2791

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2793
2794
2795
# File 'lib/models/porcelain.rb', line 2793

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2829
2830
2831
2832
2833
2834
2835
# File 'lib/models/porcelain.rb', line 2829

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end