Class: SDM::Athena
- Inherits:
-
Object
- Object
- SDM::Athena
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
The AWS S3 output location.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena
constructor
A new instance of Athena.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena
Returns a new instance of Athena.
2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 |
# File 'lib/models/porcelain.rb', line 2795 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
2765 2766 2767 |
# File 'lib/models/porcelain.rb', line 2765 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2767 2768 2769 |
# File 'lib/models/porcelain.rb', line 2767 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2769 2770 2771 |
# File 'lib/models/porcelain.rb', line 2769 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2771 2772 2773 |
# File 'lib/models/porcelain.rb', line 2771 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2773 2774 2775 |
# File 'lib/models/porcelain.rb', line 2773 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2775 2776 2777 |
# File 'lib/models/porcelain.rb', line 2775 def name @name end |
#output ⇒ Object
The AWS S3 output location.
2777 2778 2779 |
# File 'lib/models/porcelain.rb', line 2777 def output @output end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2779 2780 2781 |
# File 'lib/models/porcelain.rb', line 2779 def port_override @port_override end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
2781 2782 2783 |
# File 'lib/models/porcelain.rb', line 2781 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
2783 2784 2785 |
# File 'lib/models/porcelain.rb', line 2783 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
2785 2786 2787 |
# File 'lib/models/porcelain.rb', line 2785 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
2787 2788 2789 |
# File 'lib/models/porcelain.rb', line 2787 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2789 2790 2791 |
# File 'lib/models/porcelain.rb', line 2789 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2791 2792 2793 |
# File 'lib/models/porcelain.rb', line 2791 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2793 2794 2795 |
# File 'lib/models/porcelain.rb', line 2793 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2829 2830 2831 2832 2833 2834 2835 |
# File 'lib/models/porcelain.rb', line 2829 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |