Class: SDM::Athena

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena

Returns a new instance of Athena.



2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
# File 'lib/models/porcelain.rb', line 2075

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



2045
2046
2047
# File 'lib/models/porcelain.rb', line 2045

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2047
2048
2049
# File 'lib/models/porcelain.rb', line 2047

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2049
2050
2051
# File 'lib/models/porcelain.rb', line 2049

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2051
2052
2053
# File 'lib/models/porcelain.rb', line 2051

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2053
2054
2055
# File 'lib/models/porcelain.rb', line 2053

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2055
2056
2057
# File 'lib/models/porcelain.rb', line 2055

def name
  @name
end

#outputObject

The AWS S3 output location.



2057
2058
2059
# File 'lib/models/porcelain.rb', line 2057

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource.



2059
2060
2061
# File 'lib/models/porcelain.rb', line 2059

def port_override
  @port_override
end

#regionObject

The AWS region to connect to e.g. us-east-1.



2061
2062
2063
# File 'lib/models/porcelain.rb', line 2061

def region
  @region
end

#role_arnObject

The role to assume after logging in.



2063
2064
2065
# File 'lib/models/porcelain.rb', line 2063

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



2065
2066
2067
# File 'lib/models/porcelain.rb', line 2065

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



2067
2068
2069
# File 'lib/models/porcelain.rb', line 2067

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2069
2070
2071
# File 'lib/models/porcelain.rb', line 2069

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2071
2072
2073
# File 'lib/models/porcelain.rb', line 2071

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2073
2074
2075
# File 'lib/models/porcelain.rb', line 2073

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2109
2110
2111
2112
2113
2114
2115
# File 'lib/models/porcelain.rb', line 2109

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end