Class: SDM::Athena
- Inherits:
-
Object
- Object
- SDM::Athena
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
The AWS S3 output location.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena
constructor
A new instance of Athena.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena
Returns a new instance of Athena.
1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/models/porcelain.rb', line 1911 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
1881 1882 1883 |
# File 'lib/models/porcelain.rb', line 1881 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
1883 1884 1885 |
# File 'lib/models/porcelain.rb', line 1883 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1885 1886 1887 |
# File 'lib/models/porcelain.rb', line 1885 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1887 1888 1889 |
# File 'lib/models/porcelain.rb', line 1887 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1889 1890 1891 |
# File 'lib/models/porcelain.rb', line 1889 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1891 1892 1893 |
# File 'lib/models/porcelain.rb', line 1891 def name @name end |
#output ⇒ Object
The AWS S3 output location.
1893 1894 1895 |
# File 'lib/models/porcelain.rb', line 1893 def output @output end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
1895 1896 1897 |
# File 'lib/models/porcelain.rb', line 1895 def port_override @port_override end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
1897 1898 1899 |
# File 'lib/models/porcelain.rb', line 1897 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
1899 1900 1901 |
# File 'lib/models/porcelain.rb', line 1899 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
1901 1902 1903 |
# File 'lib/models/porcelain.rb', line 1901 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
1903 1904 1905 |
# File 'lib/models/porcelain.rb', line 1903 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1905 1906 1907 |
# File 'lib/models/porcelain.rb', line 1905 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1907 1908 1909 |
# File 'lib/models/porcelain.rb', line 1907 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1909 1910 1911 |
# File 'lib/models/porcelain.rb', line 1909 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1945 1946 1947 1948 1949 1950 1951 |
# File 'lib/models/porcelain.rb', line 1945 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |