Class: SDM::Athena
- Inherits:
-
Object
- Object
- SDM::Athena
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
Returns the value of attribute output.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena
constructor
A new instance of Athena.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena
Returns a new instance of Athena.
1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 |
# File 'lib/models/porcelain.rb', line 1900 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
1870 1871 1872 |
# File 'lib/models/porcelain.rb', line 1870 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
1872 1873 1874 |
# File 'lib/models/porcelain.rb', line 1872 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1874 1875 1876 |
# File 'lib/models/porcelain.rb', line 1874 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1876 1877 1878 |
# File 'lib/models/porcelain.rb', line 1876 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1878 1879 1880 |
# File 'lib/models/porcelain.rb', line 1878 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1880 1881 1882 |
# File 'lib/models/porcelain.rb', line 1880 def name @name end |
#output ⇒ Object
Returns the value of attribute output.
1882 1883 1884 |
# File 'lib/models/porcelain.rb', line 1882 def output @output end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1884 1885 1886 |
# File 'lib/models/porcelain.rb', line 1884 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
1886 1887 1888 |
# File 'lib/models/porcelain.rb', line 1886 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1888 1889 1890 |
# File 'lib/models/porcelain.rb', line 1888 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1890 1891 1892 |
# File 'lib/models/porcelain.rb', line 1890 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
1892 1893 1894 |
# File 'lib/models/porcelain.rb', line 1892 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1894 1895 1896 |
# File 'lib/models/porcelain.rb', line 1894 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1896 1897 1898 |
# File 'lib/models/porcelain.rb', line 1896 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1898 1899 1900 |
# File 'lib/models/porcelain.rb', line 1898 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1934 1935 1936 1937 1938 1939 1940 |
# File 'lib/models/porcelain.rb', line 1934 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |