Class: SDM::Athena
- Inherits:
-
Object
- Object
- SDM::Athena
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
Returns the value of attribute output.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena
constructor
A new instance of Athena.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena
Returns a new instance of Athena.
1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 |
# File 'lib/models/porcelain.rb', line 1753 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
1723 1724 1725 |
# File 'lib/models/porcelain.rb', line 1723 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
1725 1726 1727 |
# File 'lib/models/porcelain.rb', line 1725 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1727 1728 1729 |
# File 'lib/models/porcelain.rb', line 1727 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1729 1730 1731 |
# File 'lib/models/porcelain.rb', line 1729 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1731 1732 1733 |
# File 'lib/models/porcelain.rb', line 1731 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1733 1734 1735 |
# File 'lib/models/porcelain.rb', line 1733 def name @name end |
#output ⇒ Object
Returns the value of attribute output.
1735 1736 1737 |
# File 'lib/models/porcelain.rb', line 1735 def output @output end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1737 1738 1739 |
# File 'lib/models/porcelain.rb', line 1737 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
1739 1740 1741 |
# File 'lib/models/porcelain.rb', line 1739 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1741 1742 1743 |
# File 'lib/models/porcelain.rb', line 1741 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1743 1744 1745 |
# File 'lib/models/porcelain.rb', line 1743 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
1745 1746 1747 |
# File 'lib/models/porcelain.rb', line 1745 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1747 1748 1749 |
# File 'lib/models/porcelain.rb', line 1747 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1749 1750 1751 |
# File 'lib/models/porcelain.rb', line 1749 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1751 1752 1753 |
# File 'lib/models/porcelain.rb', line 1751 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1787 1788 1789 1790 1791 1792 1793 |
# File 'lib/models/porcelain.rb', line 1787 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |