Class: SDM::Athena
- Inherits:
-
Object
- Object
- SDM::Athena
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
Returns the value of attribute output.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ Athena
constructor
A new instance of Athena.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ Athena
Returns a new instance of Athena.
1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'lib/models/porcelain.rb', line 1711 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
1683 1684 1685 |
# File 'lib/models/porcelain.rb', line 1683 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
1685 1686 1687 |
# File 'lib/models/porcelain.rb', line 1685 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1687 1688 1689 |
# File 'lib/models/porcelain.rb', line 1687 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1689 1690 1691 |
# File 'lib/models/porcelain.rb', line 1689 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1691 1692 1693 |
# File 'lib/models/porcelain.rb', line 1691 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1693 1694 1695 |
# File 'lib/models/porcelain.rb', line 1693 def name @name end |
#output ⇒ Object
Returns the value of attribute output.
1695 1696 1697 |
# File 'lib/models/porcelain.rb', line 1695 def output @output end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1697 1698 1699 |
# File 'lib/models/porcelain.rb', line 1697 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
1699 1700 1701 |
# File 'lib/models/porcelain.rb', line 1699 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1701 1702 1703 |
# File 'lib/models/porcelain.rb', line 1701 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1703 1704 1705 |
# File 'lib/models/porcelain.rb', line 1703 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
1705 1706 1707 |
# File 'lib/models/porcelain.rb', line 1705 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1707 1708 1709 |
# File 'lib/models/porcelain.rb', line 1707 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1709 1710 1711 |
# File 'lib/models/porcelain.rb', line 1709 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1743 1744 1745 1746 1747 1748 1749 |
# File 'lib/models/porcelain.rb', line 1743 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |