Class: SDM::Athena
- Inherits:
-
Object
- Object
- SDM::Athena
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
Returns the value of attribute output.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ Athena
constructor
A new instance of Athena.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ Athena
Returns a new instance of Athena.
1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 |
# File 'lib/models/porcelain.rb', line 1373 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
1345 1346 1347 |
# File 'lib/models/porcelain.rb', line 1345 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
1347 1348 1349 |
# File 'lib/models/porcelain.rb', line 1347 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1349 1350 1351 |
# File 'lib/models/porcelain.rb', line 1349 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1351 1352 1353 |
# File 'lib/models/porcelain.rb', line 1351 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1353 1354 1355 |
# File 'lib/models/porcelain.rb', line 1353 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1355 1356 1357 |
# File 'lib/models/porcelain.rb', line 1355 def name @name end |
#output ⇒ Object
Returns the value of attribute output.
1357 1358 1359 |
# File 'lib/models/porcelain.rb', line 1357 def output @output end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1359 1360 1361 |
# File 'lib/models/porcelain.rb', line 1359 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
1361 1362 1363 |
# File 'lib/models/porcelain.rb', line 1361 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
1363 1364 1365 |
# File 'lib/models/porcelain.rb', line 1363 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
1365 1366 1367 |
# File 'lib/models/porcelain.rb', line 1365 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
1367 1368 1369 |
# File 'lib/models/porcelain.rb', line 1367 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1369 1370 1371 |
# File 'lib/models/porcelain.rb', line 1369 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1371 1372 1373 |
# File 'lib/models/porcelain.rb', line 1371 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/models/porcelain.rb', line 1405 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |