Class: SDM::Athena

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Athena

Returns a new instance of Athena.



3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
3957
3958
3959
3960
3961
# File 'lib/models/porcelain.rb', line 3927

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



3895
3896
3897
# File 'lib/models/porcelain.rb', line 3895

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



3897
3898
3899
# File 'lib/models/porcelain.rb', line 3897

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3899
3900
3901
# File 'lib/models/porcelain.rb', line 3899

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3901
3902
3903
# File 'lib/models/porcelain.rb', line 3901

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3903
3904
3905
# File 'lib/models/porcelain.rb', line 3903

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3905
3906
3907
# File 'lib/models/porcelain.rb', line 3905

def name
  @name
end

#outputObject

The AWS S3 output location.



3907
3908
3909
# File 'lib/models/porcelain.rb', line 3907

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



3909
3910
3911
# File 'lib/models/porcelain.rb', line 3909

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3911
3912
3913
# File 'lib/models/porcelain.rb', line 3911

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



3913
3914
3915
# File 'lib/models/porcelain.rb', line 3913

def region
  @region
end

#role_arnObject

The role to assume after logging in.



3915
3916
3917
# File 'lib/models/porcelain.rb', line 3915

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



3917
3918
3919
# File 'lib/models/porcelain.rb', line 3917

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



3919
3920
3921
# File 'lib/models/porcelain.rb', line 3919

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3921
3922
3923
# File 'lib/models/porcelain.rb', line 3921

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



3923
3924
3925
# File 'lib/models/porcelain.rb', line 3923

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3925
3926
3927
# File 'lib/models/porcelain.rb', line 3925

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3963
3964
3965
3966
3967
3968
3969
# File 'lib/models/porcelain.rb', line 3963

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end