Class: SDM::AthenaIAM
- Inherits:
-
Object
- Object
- SDM::AthenaIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
The AWS S3 output location.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM
constructor
A new instance of AthenaIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM
Returns a new instance of AthenaIAM.
3351 3352 3353 3354 3355 3356 3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 3375 3376 3377 3378 3379 3380 3381 |
# File 'lib/models/porcelain.rb', line 3351 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3323 3324 3325 |
# File 'lib/models/porcelain.rb', line 3323 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3325 3326 3327 |
# File 'lib/models/porcelain.rb', line 3325 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3327 3328 3329 |
# File 'lib/models/porcelain.rb', line 3327 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3329 3330 3331 |
# File 'lib/models/porcelain.rb', line 3329 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3331 3332 3333 |
# File 'lib/models/porcelain.rb', line 3331 def name @name end |
#output ⇒ Object
The AWS S3 output location.
3333 3334 3335 |
# File 'lib/models/porcelain.rb', line 3333 def output @output end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3335 3336 3337 |
# File 'lib/models/porcelain.rb', line 3335 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3337 3338 3339 |
# File 'lib/models/porcelain.rb', line 3337 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
3339 3340 3341 |
# File 'lib/models/porcelain.rb', line 3339 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
3341 3342 3343 |
# File 'lib/models/porcelain.rb', line 3341 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
3343 3344 3345 |
# File 'lib/models/porcelain.rb', line 3343 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3345 3346 3347 |
# File 'lib/models/porcelain.rb', line 3345 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3347 3348 3349 |
# File 'lib/models/porcelain.rb', line 3347 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3349 3350 3351 |
# File 'lib/models/porcelain.rb', line 3349 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3383 3384 3385 3386 3387 3388 3389 |
# File 'lib/models/porcelain.rb', line 3383 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |