Class: SDM::AthenaIAM
- Inherits:
-
Object
- Object
- SDM::AthenaIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
The AWS S3 output location.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM
constructor
A new instance of AthenaIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM
Returns a new instance of AthenaIAM.
3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 |
# File 'lib/models/porcelain.rb', line 3265 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3237 3238 3239 |
# File 'lib/models/porcelain.rb', line 3237 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3239 3240 3241 |
# File 'lib/models/porcelain.rb', line 3239 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3241 3242 3243 |
# File 'lib/models/porcelain.rb', line 3241 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3243 3244 3245 |
# File 'lib/models/porcelain.rb', line 3243 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3245 3246 3247 |
# File 'lib/models/porcelain.rb', line 3245 def name @name end |
#output ⇒ Object
The AWS S3 output location.
3247 3248 3249 |
# File 'lib/models/porcelain.rb', line 3247 def output @output end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3249 3250 3251 |
# File 'lib/models/porcelain.rb', line 3249 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3251 3252 3253 |
# File 'lib/models/porcelain.rb', line 3251 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
3253 3254 3255 |
# File 'lib/models/porcelain.rb', line 3253 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
3255 3256 3257 |
# File 'lib/models/porcelain.rb', line 3255 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
3257 3258 3259 |
# File 'lib/models/porcelain.rb', line 3257 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3259 3260 3261 |
# File 'lib/models/porcelain.rb', line 3259 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3261 3262 3263 |
# File 'lib/models/porcelain.rb', line 3261 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3263 3264 3265 |
# File 'lib/models/porcelain.rb', line 3263 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3297 3298 3299 3300 3301 3302 3303 |
# File 'lib/models/porcelain.rb', line 3297 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |