Class: SDM::AthenaIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM

Returns a new instance of AthenaIAM.



3197
3198
3199
3200
3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
3219
3220
3221
3222
3223
3224
3225
3226
3227
# File 'lib/models/porcelain.rb', line 3197

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3169
3170
3171
# File 'lib/models/porcelain.rb', line 3169

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3171
3172
3173
# File 'lib/models/porcelain.rb', line 3171

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3173
3174
3175
# File 'lib/models/porcelain.rb', line 3173

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3175
3176
3177
# File 'lib/models/porcelain.rb', line 3175

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3177
3178
3179
# File 'lib/models/porcelain.rb', line 3177

def name
  @name
end

#outputObject

The AWS S3 output location.



3179
3180
3181
# File 'lib/models/porcelain.rb', line 3179

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource.



3181
3182
3183
# File 'lib/models/porcelain.rb', line 3181

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3183
3184
3185
# File 'lib/models/porcelain.rb', line 3183

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



3185
3186
3187
# File 'lib/models/porcelain.rb', line 3185

def region
  @region
end

#role_arnObject

The role to assume after logging in.



3187
3188
3189
# File 'lib/models/porcelain.rb', line 3187

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



3189
3190
3191
# File 'lib/models/porcelain.rb', line 3189

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3191
3192
3193
# File 'lib/models/porcelain.rb', line 3191

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3193
3194
3195
# File 'lib/models/porcelain.rb', line 3193

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3195
3196
3197
# File 'lib/models/porcelain.rb', line 3195

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3229
3230
3231
3232
3233
3234
3235
# File 'lib/models/porcelain.rb', line 3229

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end