Class: SDM::AthenaIAM
- Inherits:
-
Object
- Object
- SDM::AthenaIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#output ⇒ Object
The AWS S3 output location.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM
constructor
A new instance of AthenaIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM
Returns a new instance of AthenaIAM.
3197 3198 3199 3200 3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 |
# File 'lib/models/porcelain.rb', line 3197 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @output = output == nil ? "" : output @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3169 3170 3171 |
# File 'lib/models/porcelain.rb', line 3169 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3171 3172 3173 |
# File 'lib/models/porcelain.rb', line 3171 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3173 3174 3175 |
# File 'lib/models/porcelain.rb', line 3173 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3175 3176 3177 |
# File 'lib/models/porcelain.rb', line 3175 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3177 3178 3179 |
# File 'lib/models/porcelain.rb', line 3177 def name @name end |
#output ⇒ Object
The AWS S3 output location.
3179 3180 3181 |
# File 'lib/models/porcelain.rb', line 3179 def output @output end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3181 3182 3183 |
# File 'lib/models/porcelain.rb', line 3181 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3183 3184 3185 |
# File 'lib/models/porcelain.rb', line 3183 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to e.g. us-east-1.
3185 3186 3187 |
# File 'lib/models/porcelain.rb', line 3185 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
3187 3188 3189 |
# File 'lib/models/porcelain.rb', line 3187 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
3189 3190 3191 |
# File 'lib/models/porcelain.rb', line 3189 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3191 3192 3193 |
# File 'lib/models/porcelain.rb', line 3191 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3193 3194 3195 |
# File 'lib/models/porcelain.rb', line 3193 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3195 3196 3197 |
# File 'lib/models/porcelain.rb', line 3195 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3229 3230 3231 3232 3233 3234 3235 |
# File 'lib/models/porcelain.rb', line 3229 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |