Class: SDM::AthenaIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AthenaIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM

Returns a new instance of AthenaIAM.



3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
# File 'lib/models/porcelain.rb', line 3094

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3066
3067
3068
# File 'lib/models/porcelain.rb', line 3066

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3068
3069
3070
# File 'lib/models/porcelain.rb', line 3068

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3070
3071
3072
# File 'lib/models/porcelain.rb', line 3070

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3072
3073
3074
# File 'lib/models/porcelain.rb', line 3072

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3074
3075
3076
# File 'lib/models/porcelain.rb', line 3074

def name
  @name
end

#outputObject

The AWS S3 output location.



3076
3077
3078
# File 'lib/models/porcelain.rb', line 3076

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource.



3078
3079
3080
# File 'lib/models/porcelain.rb', line 3078

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3080
3081
3082
# File 'lib/models/porcelain.rb', line 3080

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



3082
3083
3084
# File 'lib/models/porcelain.rb', line 3082

def region
  @region
end

#role_arnObject

The role to assume after logging in.



3084
3085
3086
# File 'lib/models/porcelain.rb', line 3084

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



3086
3087
3088
# File 'lib/models/porcelain.rb', line 3086

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3088
3089
3090
# File 'lib/models/porcelain.rb', line 3088

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3090
3091
3092
# File 'lib/models/porcelain.rb', line 3090

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3092
3093
3094
# File 'lib/models/porcelain.rb', line 3092

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3126
3127
3128
3129
3130
3131
3132
# File 'lib/models/porcelain.rb', line 3126

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end