Class: SDM::AthenaIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, output: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ AthenaIAM

Returns a new instance of AthenaIAM.



3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
# File 'lib/models/porcelain.rb', line 3987

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  output: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @output = output == nil ? "" : output
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



3959
3960
3961
# File 'lib/models/porcelain.rb', line 3959

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3961
3962
3963
# File 'lib/models/porcelain.rb', line 3961

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3963
3964
3965
# File 'lib/models/porcelain.rb', line 3963

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3965
3966
3967
# File 'lib/models/porcelain.rb', line 3965

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3967
3968
3969
# File 'lib/models/porcelain.rb', line 3967

def name
  @name
end

#outputObject

The AWS S3 output location.



3969
3970
3971
# File 'lib/models/porcelain.rb', line 3969

def output
  @output
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



3971
3972
3973
# File 'lib/models/porcelain.rb', line 3971

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3973
3974
3975
# File 'lib/models/porcelain.rb', line 3973

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to e.g. us-east-1.



3975
3976
3977
# File 'lib/models/porcelain.rb', line 3975

def region
  @region
end

#role_arnObject

The role to assume after logging in.



3977
3978
3979
# File 'lib/models/porcelain.rb', line 3977

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



3979
3980
3981
# File 'lib/models/porcelain.rb', line 3979

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3981
3982
3983
# File 'lib/models/porcelain.rb', line 3981

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



3983
3984
3985
# File 'lib/models/porcelain.rb', line 3983

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3985
3986
3987
# File 'lib/models/porcelain.rb', line 3985

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4019
4020
4021
4022
4023
4024
4025
# File 'lib/models/porcelain.rb', line 4019

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end