Class: SDM::AuroraMysql
- Inherits:
-
Object
- Object
- SDM::AuroraMysql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AuroraMysql
constructor
A new instance of AuroraMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AuroraMysql
Returns a new instance of AuroraMysql.
4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 |
# File 'lib/models/porcelain.rb', line 4079 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
4045 4046 4047 |
# File 'lib/models/porcelain.rb', line 4045 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests
4047 4048 4049 |
# File 'lib/models/porcelain.rb', line 4047 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4049 4050 4051 |
# File 'lib/models/porcelain.rb', line 4049 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4051 4052 4053 |
# File 'lib/models/porcelain.rb', line 4051 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4053 4054 4055 |
# File 'lib/models/porcelain.rb', line 4053 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4055 4056 4057 |
# File 'lib/models/porcelain.rb', line 4055 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4057 4058 4059 |
# File 'lib/models/porcelain.rb', line 4057 def name @name end |
#password ⇒ Object
The password to authenticate with.
4059 4060 4061 |
# File 'lib/models/porcelain.rb', line 4059 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4061 4062 4063 |
# File 'lib/models/porcelain.rb', line 4061 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
4063 4064 4065 |
# File 'lib/models/porcelain.rb', line 4063 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4065 4066 4067 |
# File 'lib/models/porcelain.rb', line 4065 def proxy_cluster_id @proxy_cluster_id end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
4067 4068 4069 |
# File 'lib/models/porcelain.rb', line 4067 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4069 4070 4071 |
# File 'lib/models/porcelain.rb', line 4069 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
4071 4072 4073 |
# File 'lib/models/porcelain.rb', line 4071 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4073 4074 4075 |
# File 'lib/models/porcelain.rb', line 4073 def @tags end |
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address
4075 4076 4077 |
# File 'lib/models/porcelain.rb', line 4075 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
The username to authenticate with.
4077 4078 4079 |
# File 'lib/models/porcelain.rb', line 4077 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4117 4118 4119 4120 4121 4122 4123 |
# File 'lib/models/porcelain.rb', line 4117 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |