Class: SDM::AuroraMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AuroraMysql

Returns a new instance of AuroraMysql.



3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
3374
3375
3376
3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
# File 'lib/models/porcelain.rb', line 3353

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3319
3320
3321
# File 'lib/models/porcelain.rb', line 3319

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests



3321
3322
3323
# File 'lib/models/porcelain.rb', line 3321

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3323
3324
3325
# File 'lib/models/porcelain.rb', line 3323

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3325
3326
3327
# File 'lib/models/porcelain.rb', line 3325

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3327
3328
3329
# File 'lib/models/porcelain.rb', line 3327

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3329
3330
3331
# File 'lib/models/porcelain.rb', line 3329

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3331
3332
3333
# File 'lib/models/porcelain.rb', line 3331

def name
  @name
end

#passwordObject

The password to authenticate with.



3333
3334
3335
# File 'lib/models/porcelain.rb', line 3333

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3335
3336
3337
# File 'lib/models/porcelain.rb', line 3335

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3337
3338
3339
# File 'lib/models/porcelain.rb', line 3337

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3339
3340
3341
# File 'lib/models/porcelain.rb', line 3339

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



3341
3342
3343
# File 'lib/models/porcelain.rb', line 3341

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3343
3344
3345
# File 'lib/models/porcelain.rb', line 3343

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3345
3346
3347
# File 'lib/models/porcelain.rb', line 3345

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3347
3348
3349
# File 'lib/models/porcelain.rb', line 3347

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



3349
3350
3351
# File 'lib/models/porcelain.rb', line 3349

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



3351
3352
3353
# File 'lib/models/porcelain.rb', line 3351

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3391
3392
3393
3394
3395
3396
3397
# File 'lib/models/porcelain.rb', line 3391

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end