Class: SDM::AuroraMysql
- Inherits:
-
Object
- Object
- SDM::AuroraMysql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AuroraMysql
constructor
A new instance of AuroraMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AuroraMysql
Returns a new instance of AuroraMysql.
3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 |
# File 'lib/models/porcelain.rb', line 3274 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3240 3241 3242 |
# File 'lib/models/porcelain.rb', line 3240 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests
3242 3243 3244 |
# File 'lib/models/porcelain.rb', line 3242 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3244 3245 3246 |
# File 'lib/models/porcelain.rb', line 3244 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3246 3247 3248 |
# File 'lib/models/porcelain.rb', line 3246 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3248 3249 3250 |
# File 'lib/models/porcelain.rb', line 3248 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3250 3251 3252 |
# File 'lib/models/porcelain.rb', line 3250 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3252 3253 3254 |
# File 'lib/models/porcelain.rb', line 3252 def name @name end |
#password ⇒ Object
The password to authenticate with.
3254 3255 3256 |
# File 'lib/models/porcelain.rb', line 3254 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3256 3257 3258 |
# File 'lib/models/porcelain.rb', line 3256 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3258 3259 3260 |
# File 'lib/models/porcelain.rb', line 3258 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3260 3261 3262 |
# File 'lib/models/porcelain.rb', line 3260 def proxy_cluster_id @proxy_cluster_id end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
3262 3263 3264 |
# File 'lib/models/porcelain.rb', line 3262 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3264 3265 3266 |
# File 'lib/models/porcelain.rb', line 3264 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3266 3267 3268 |
# File 'lib/models/porcelain.rb', line 3266 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3268 3269 3270 |
# File 'lib/models/porcelain.rb', line 3268 def @tags end |
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address
3270 3271 3272 |
# File 'lib/models/porcelain.rb', line 3270 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
The username to authenticate with.
3272 3273 3274 |
# File 'lib/models/porcelain.rb', line 3272 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3312 3313 3314 3315 3316 3317 3318 |
# File 'lib/models/porcelain.rb', line 3312 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |