Class: SDM::AuroraMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AuroraMysql

Returns a new instance of AuroraMysql.



3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
# File 'lib/models/porcelain.rb', line 3091

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3057
3058
3059
# File 'lib/models/porcelain.rb', line 3057

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests



3059
3060
3061
# File 'lib/models/porcelain.rb', line 3059

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3061
3062
3063
# File 'lib/models/porcelain.rb', line 3061

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3063
3064
3065
# File 'lib/models/porcelain.rb', line 3063

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3065
3066
3067
# File 'lib/models/porcelain.rb', line 3065

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3067
3068
3069
# File 'lib/models/porcelain.rb', line 3067

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3069
3070
3071
# File 'lib/models/porcelain.rb', line 3069

def name
  @name
end

#passwordObject

The password to authenticate with.



3071
3072
3073
# File 'lib/models/porcelain.rb', line 3071

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3073
3074
3075
# File 'lib/models/porcelain.rb', line 3073

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3075
3076
3077
# File 'lib/models/porcelain.rb', line 3075

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3077
3078
3079
# File 'lib/models/porcelain.rb', line 3077

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



3079
3080
3081
# File 'lib/models/porcelain.rb', line 3079

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3081
3082
3083
# File 'lib/models/porcelain.rb', line 3081

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3083
3084
3085
# File 'lib/models/porcelain.rb', line 3083

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3085
3086
3087
# File 'lib/models/porcelain.rb', line 3085

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



3087
3088
3089
# File 'lib/models/porcelain.rb', line 3087

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



3089
3090
3091
# File 'lib/models/porcelain.rb', line 3089

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3129
3130
3131
3132
3133
3134
3135
# File 'lib/models/porcelain.rb', line 3129

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end