Class: SDM::AuroraMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AuroraMysql

Returns a new instance of AuroraMysql.



2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
# File 'lib/models/porcelain.rb', line 2872

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2840
2841
2842
# File 'lib/models/porcelain.rb', line 2840

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests



2842
2843
2844
# File 'lib/models/porcelain.rb', line 2842

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2844
2845
2846
# File 'lib/models/porcelain.rb', line 2844

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2846
2847
2848
# File 'lib/models/porcelain.rb', line 2846

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2848
2849
2850
# File 'lib/models/porcelain.rb', line 2848

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2850
2851
2852
# File 'lib/models/porcelain.rb', line 2850

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2852
2853
2854
# File 'lib/models/porcelain.rb', line 2852

def name
  @name
end

#passwordObject

The password to authenticate with.



2854
2855
2856
# File 'lib/models/porcelain.rb', line 2854

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2856
2857
2858
# File 'lib/models/porcelain.rb', line 2856

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2858
2859
2860
# File 'lib/models/porcelain.rb', line 2858

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



2860
2861
2862
# File 'lib/models/porcelain.rb', line 2860

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2862
2863
2864
# File 'lib/models/porcelain.rb', line 2862

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2864
2865
2866
# File 'lib/models/porcelain.rb', line 2864

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2866
2867
2868
# File 'lib/models/porcelain.rb', line 2866

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



2868
2869
2870
# File 'lib/models/porcelain.rb', line 2868

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



2870
2871
2872
# File 'lib/models/porcelain.rb', line 2870

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2908
2909
2910
2911
2912
2913
2914
# File 'lib/models/porcelain.rb', line 2908

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end