Class: SDM::AuroraMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AuroraMysql

Returns a new instance of AuroraMysql.



2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
# File 'lib/models/porcelain.rb', line 2152

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2120
2121
2122
# File 'lib/models/porcelain.rb', line 2120

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2122
2123
2124
# File 'lib/models/porcelain.rb', line 2122

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2124
2125
2126
# File 'lib/models/porcelain.rb', line 2124

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2126
2127
2128
# File 'lib/models/porcelain.rb', line 2126

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2128
2129
2130
# File 'lib/models/porcelain.rb', line 2128

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2130
2131
2132
# File 'lib/models/porcelain.rb', line 2130

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2132
2133
2134
# File 'lib/models/porcelain.rb', line 2132

def name
  @name
end

#passwordObject

The password to authenticate with.



2134
2135
2136
# File 'lib/models/porcelain.rb', line 2134

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2136
2137
2138
# File 'lib/models/porcelain.rb', line 2136

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2138
2139
2140
# File 'lib/models/porcelain.rb', line 2138

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



2140
2141
2142
# File 'lib/models/porcelain.rb', line 2140

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2142
2143
2144
# File 'lib/models/porcelain.rb', line 2142

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2144
2145
2146
# File 'lib/models/porcelain.rb', line 2144

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2146
2147
2148
# File 'lib/models/porcelain.rb', line 2146

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



2148
2149
2150
# File 'lib/models/porcelain.rb', line 2148

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



2150
2151
2152
# File 'lib/models/porcelain.rb', line 2150

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2188
2189
2190
2191
2192
2193
2194
# File 'lib/models/porcelain.rb', line 2188

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end