Class: SDM::AuroraMysql
- Inherits:
-
Object
- Object
- SDM::AuroraMysql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraMysql
constructor
A new instance of AuroraMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraMysql
Returns a new instance of AuroraMysql.
1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/models/porcelain.rb', line 1973 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1945 1946 1947 |
# File 'lib/models/porcelain.rb', line 1945 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
1947 1948 1949 |
# File 'lib/models/porcelain.rb', line 1947 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1949 1950 1951 |
# File 'lib/models/porcelain.rb', line 1949 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1951 1952 1953 |
# File 'lib/models/porcelain.rb', line 1951 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
1953 1954 1955 |
# File 'lib/models/porcelain.rb', line 1953 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1955 1956 1957 |
# File 'lib/models/porcelain.rb', line 1955 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1957 1958 1959 |
# File 'lib/models/porcelain.rb', line 1957 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
1959 1960 1961 |
# File 'lib/models/porcelain.rb', line 1959 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
1961 1962 1963 |
# File 'lib/models/porcelain.rb', line 1961 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1963 1964 1965 |
# File 'lib/models/porcelain.rb', line 1963 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1965 1966 1967 |
# File 'lib/models/porcelain.rb', line 1965 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
1967 1968 1969 |
# File 'lib/models/porcelain.rb', line 1967 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1969 1970 1971 |
# File 'lib/models/porcelain.rb', line 1969 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
1971 1972 1973 |
# File 'lib/models/porcelain.rb', line 1971 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2005 2006 2007 2008 2009 2010 2011 |
# File 'lib/models/porcelain.rb', line 2005 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |