Class: SDM::AuroraMysql
- Inherits:
-
Object
- Object
- SDM::AuroraMysql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AuroraMysql
constructor
A new instance of AuroraMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AuroraMysql
Returns a new instance of AuroraMysql.
1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 |
# File 'lib/models/porcelain.rb', line 1442 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1416 1417 1418 |
# File 'lib/models/porcelain.rb', line 1416 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
1418 1419 1420 |
# File 'lib/models/porcelain.rb', line 1418 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1420 1421 1422 |
# File 'lib/models/porcelain.rb', line 1420 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1422 1423 1424 |
# File 'lib/models/porcelain.rb', line 1422 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
1424 1425 1426 |
# File 'lib/models/porcelain.rb', line 1424 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1426 1427 1428 |
# File 'lib/models/porcelain.rb', line 1426 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1428 1429 1430 |
# File 'lib/models/porcelain.rb', line 1428 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
1430 1431 1432 |
# File 'lib/models/porcelain.rb', line 1430 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
1432 1433 1434 |
# File 'lib/models/porcelain.rb', line 1432 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1434 1435 1436 |
# File 'lib/models/porcelain.rb', line 1434 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1436 1437 1438 |
# File 'lib/models/porcelain.rb', line 1436 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1438 1439 1440 |
# File 'lib/models/porcelain.rb', line 1438 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
1440 1441 1442 |
# File 'lib/models/porcelain.rb', line 1440 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1472 1473 1474 1475 1476 1477 1478 |
# File 'lib/models/porcelain.rb', line 1472 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |