Class: SDM::AuroraMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AuroraMysql

Returns a new instance of AuroraMysql.



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
# File 'lib/models/porcelain.rb', line 1200

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



1174
1175
1176
# File 'lib/models/porcelain.rb', line 1174

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



1176
1177
1178
# File 'lib/models/porcelain.rb', line 1176

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1178
1179
1180
# File 'lib/models/porcelain.rb', line 1178

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1180
1181
1182
# File 'lib/models/porcelain.rb', line 1180

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



1182
1183
1184
# File 'lib/models/porcelain.rb', line 1182

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1184
1185
1186
# File 'lib/models/porcelain.rb', line 1184

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1186
1187
1188
# File 'lib/models/porcelain.rb', line 1186

def name
  @name
end

#passwordObject

Returns the value of attribute password.



1188
1189
1190
# File 'lib/models/porcelain.rb', line 1188

def password
  @password
end

#portObject

Returns the value of attribute port.



1190
1191
1192
# File 'lib/models/porcelain.rb', line 1190

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



1192
1193
1194
# File 'lib/models/porcelain.rb', line 1192

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1194
1195
1196
# File 'lib/models/porcelain.rb', line 1194

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1196
1197
1198
# File 'lib/models/porcelain.rb', line 1196

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



1198
1199
1200
# File 'lib/models/porcelain.rb', line 1198

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1230
1231
1232
1233
1234
1235
1236
# File 'lib/models/porcelain.rb', line 1230

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end