Class: SDM::AuroraMysqlIAM
- Inherits:
-
Object
- Object
- SDM::AuroraMysqlIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraMysqlIAM
constructor
A new instance of AuroraMysqlIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraMysqlIAM
Returns a new instance of AuroraMysqlIAM.
4145 4146 4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 4168 4169 4170 4171 4172 4173 4174 4175 4176 4177 4178 4179 |
# File 'lib/models/porcelain.rb', line 4145 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
4113 4114 4115 |
# File 'lib/models/porcelain.rb', line 4113 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests
4115 4116 4117 |
# File 'lib/models/porcelain.rb', line 4115 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4117 4118 4119 |
# File 'lib/models/porcelain.rb', line 4117 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4119 4120 4121 |
# File 'lib/models/porcelain.rb', line 4119 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4121 4122 4123 |
# File 'lib/models/porcelain.rb', line 4121 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4123 4124 4125 |
# File 'lib/models/porcelain.rb', line 4123 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4125 4126 4127 |
# File 'lib/models/porcelain.rb', line 4125 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4127 4128 4129 |
# File 'lib/models/porcelain.rb', line 4127 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
4129 4130 4131 |
# File 'lib/models/porcelain.rb', line 4129 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4131 4132 4133 |
# File 'lib/models/porcelain.rb', line 4131 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
4133 4134 4135 |
# File 'lib/models/porcelain.rb', line 4133 def region @region end |
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
4135 4136 4137 |
# File 'lib/models/porcelain.rb', line 4135 def role_assumption_arn @role_assumption_arn end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4137 4138 4139 |
# File 'lib/models/porcelain.rb', line 4137 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
4139 4140 4141 |
# File 'lib/models/porcelain.rb', line 4139 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4141 4142 4143 |
# File 'lib/models/porcelain.rb', line 4141 def @tags end |
#username ⇒ Object
The username to authenticate with.
4143 4144 4145 |
# File 'lib/models/porcelain.rb', line 4143 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4181 4182 4183 4184 4185 4186 4187 |
# File 'lib/models/porcelain.rb', line 4181 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |