Class: SDM::AuroraMysqlIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraMysqlIAM

Returns a new instance of AuroraMysqlIAM.



4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
# File 'lib/models/porcelain.rb', line 4139

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4107
4108
4109
# File 'lib/models/porcelain.rb', line 4107

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests



4109
4110
4111
# File 'lib/models/porcelain.rb', line 4109

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4111
4112
4113
# File 'lib/models/porcelain.rb', line 4111

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4113
4114
4115
# File 'lib/models/porcelain.rb', line 4113

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4115
4116
4117
# File 'lib/models/porcelain.rb', line 4115

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4117
4118
4119
# File 'lib/models/porcelain.rb', line 4117

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4119
4120
4121
# File 'lib/models/porcelain.rb', line 4119

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4121
4122
4123
# File 'lib/models/porcelain.rb', line 4121

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4123
4124
4125
# File 'lib/models/porcelain.rb', line 4123

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4125
4126
4127
# File 'lib/models/porcelain.rb', line 4125

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



4127
4128
4129
# File 'lib/models/porcelain.rb', line 4127

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



4129
4130
4131
# File 'lib/models/porcelain.rb', line 4129

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4131
4132
4133
# File 'lib/models/porcelain.rb', line 4131

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4133
4134
4135
# File 'lib/models/porcelain.rb', line 4133

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4135
4136
4137
# File 'lib/models/porcelain.rb', line 4135

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4137
4138
4139
# File 'lib/models/porcelain.rb', line 4137

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4175
4176
4177
4178
4179
4180
4181
# File 'lib/models/porcelain.rb', line 4175

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end