Class: SDM::AuroraMysqlIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraMysqlIAM

Returns a new instance of AuroraMysqlIAM.



3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
# File 'lib/models/porcelain.rb', line 3252

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3220
3221
3222
# File 'lib/models/porcelain.rb', line 3220

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests



3222
3223
3224
# File 'lib/models/porcelain.rb', line 3222

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3224
3225
3226
# File 'lib/models/porcelain.rb', line 3224

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3226
3227
3228
# File 'lib/models/porcelain.rb', line 3226

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3228
3229
3230
# File 'lib/models/porcelain.rb', line 3228

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3230
3231
3232
# File 'lib/models/porcelain.rb', line 3230

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3232
3233
3234
# File 'lib/models/porcelain.rb', line 3232

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3234
3235
3236
# File 'lib/models/porcelain.rb', line 3234

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3236
3237
3238
# File 'lib/models/porcelain.rb', line 3236

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3238
3239
3240
# File 'lib/models/porcelain.rb', line 3238

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



3240
3241
3242
# File 'lib/models/porcelain.rb', line 3240

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



3242
3243
3244
# File 'lib/models/porcelain.rb', line 3242

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3244
3245
3246
# File 'lib/models/porcelain.rb', line 3244

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3246
3247
3248
# File 'lib/models/porcelain.rb', line 3246

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3248
3249
3250
# File 'lib/models/porcelain.rb', line 3248

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3250
3251
3252
# File 'lib/models/porcelain.rb', line 3250

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3288
3289
3290
3291
3292
3293
3294
# File 'lib/models/porcelain.rb', line 3288

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end