Class: SDM::AuroraPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres

Returns a new instance of AuroraPostgres.



3588
3589
3590
3591
3592
3593
3594
3595
3596
3597
3598
3599
3600
3601
3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
# File 'lib/models/porcelain.rb', line 3588

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3556
3557
3558
# File 'lib/models/porcelain.rb', line 3556

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3558
3559
3560
# File 'lib/models/porcelain.rb', line 3558

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3560
3561
3562
# File 'lib/models/porcelain.rb', line 3560

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3562
3563
3564
# File 'lib/models/porcelain.rb', line 3562

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3564
3565
3566
# File 'lib/models/porcelain.rb', line 3564

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3566
3567
3568
# File 'lib/models/porcelain.rb', line 3566

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3568
3569
3570
# File 'lib/models/porcelain.rb', line 3568

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



3570
3571
3572
# File 'lib/models/porcelain.rb', line 3570

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



3572
3573
3574
# File 'lib/models/porcelain.rb', line 3572

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3574
3575
3576
# File 'lib/models/porcelain.rb', line 3574

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3576
3577
3578
# File 'lib/models/porcelain.rb', line 3576

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3578
3579
3580
# File 'lib/models/porcelain.rb', line 3578

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3580
3581
3582
# File 'lib/models/porcelain.rb', line 3580

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3582
3583
3584
# File 'lib/models/porcelain.rb', line 3582

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3584
3585
3586
# File 'lib/models/porcelain.rb', line 3584

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3586
3587
3588
# File 'lib/models/porcelain.rb', line 3586

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3624
3625
3626
3627
3628
3629
3630
# File 'lib/models/porcelain.rb', line 3624

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end