Class: SDM::AuroraPostgres
- Inherits:
-
Object
- Object
- SDM::AuroraPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres
constructor
A new instance of AuroraPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres
Returns a new instance of AuroraPostgres.
3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 3542 3543 3544 3545 3546 3547 |
# File 'lib/models/porcelain.rb', line 3513 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3481 3482 3483 |
# File 'lib/models/porcelain.rb', line 3481 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
3483 3484 3485 |
# File 'lib/models/porcelain.rb', line 3483 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3485 3486 3487 |
# File 'lib/models/porcelain.rb', line 3485 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3487 3488 3489 |
# File 'lib/models/porcelain.rb', line 3487 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3489 3490 3491 |
# File 'lib/models/porcelain.rb', line 3489 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3491 3492 3493 |
# File 'lib/models/porcelain.rb', line 3491 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3493 3494 3495 |
# File 'lib/models/porcelain.rb', line 3493 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
3495 3496 3497 |
# File 'lib/models/porcelain.rb', line 3495 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
3497 3498 3499 |
# File 'lib/models/porcelain.rb', line 3497 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3499 3500 3501 |
# File 'lib/models/porcelain.rb', line 3499 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3501 3502 3503 |
# File 'lib/models/porcelain.rb', line 3501 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3503 3504 3505 |
# File 'lib/models/porcelain.rb', line 3503 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3505 3506 3507 |
# File 'lib/models/porcelain.rb', line 3505 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3507 3508 3509 |
# File 'lib/models/porcelain.rb', line 3507 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3509 3510 3511 |
# File 'lib/models/porcelain.rb', line 3509 def @tags end |
#username ⇒ Object
The username to authenticate with.
3511 3512 3513 |
# File 'lib/models/porcelain.rb', line 3511 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3549 3550 3551 3552 3553 3554 3555 |
# File 'lib/models/porcelain.rb', line 3549 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |