Class: SDM::AuroraPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres

Returns a new instance of AuroraPostgres.



3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/models/porcelain.rb', line 3434

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3402
3403
3404
# File 'lib/models/porcelain.rb', line 3402

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3404
3405
3406
# File 'lib/models/porcelain.rb', line 3404

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3406
3407
3408
# File 'lib/models/porcelain.rb', line 3406

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3408
3409
3410
# File 'lib/models/porcelain.rb', line 3408

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3410
3411
3412
# File 'lib/models/porcelain.rb', line 3410

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3412
3413
3414
# File 'lib/models/porcelain.rb', line 3412

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3414
3415
3416
# File 'lib/models/porcelain.rb', line 3414

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



3416
3417
3418
# File 'lib/models/porcelain.rb', line 3416

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



3418
3419
3420
# File 'lib/models/porcelain.rb', line 3418

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3420
3421
3422
# File 'lib/models/porcelain.rb', line 3420

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3422
3423
3424
# File 'lib/models/porcelain.rb', line 3422

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3424
3425
3426
# File 'lib/models/porcelain.rb', line 3424

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3426
3427
3428
# File 'lib/models/porcelain.rb', line 3426

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3428
3429
3430
# File 'lib/models/porcelain.rb', line 3428

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3430
3431
3432
# File 'lib/models/porcelain.rb', line 3430

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3432
3433
3434
# File 'lib/models/porcelain.rb', line 3432

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3470
3471
3472
3473
3474
3475
3476
# File 'lib/models/porcelain.rb', line 3470

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end