Class: SDM::AuroraPostgres
- Inherits:
-
Object
- Object
- SDM::AuroraPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres
constructor
A new instance of AuroraPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres
Returns a new instance of AuroraPostgres.
3434 3435 3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 |
# File 'lib/models/porcelain.rb', line 3434 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3402 3403 3404 |
# File 'lib/models/porcelain.rb', line 3402 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
3404 3405 3406 |
# File 'lib/models/porcelain.rb', line 3404 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3406 3407 3408 |
# File 'lib/models/porcelain.rb', line 3406 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3408 3409 3410 |
# File 'lib/models/porcelain.rb', line 3408 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3410 3411 3412 |
# File 'lib/models/porcelain.rb', line 3410 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3412 3413 3414 |
# File 'lib/models/porcelain.rb', line 3412 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3414 3415 3416 |
# File 'lib/models/porcelain.rb', line 3414 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
3416 3417 3418 |
# File 'lib/models/porcelain.rb', line 3416 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
3418 3419 3420 |
# File 'lib/models/porcelain.rb', line 3418 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3420 3421 3422 |
# File 'lib/models/porcelain.rb', line 3420 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3422 3423 3424 |
# File 'lib/models/porcelain.rb', line 3422 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3424 3425 3426 |
# File 'lib/models/porcelain.rb', line 3424 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3426 3427 3428 |
# File 'lib/models/porcelain.rb', line 3426 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3428 3429 3430 |
# File 'lib/models/porcelain.rb', line 3428 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3430 3431 3432 |
# File 'lib/models/porcelain.rb', line 3430 def @tags end |
#username ⇒ Object
The username to authenticate with.
3432 3433 3434 |
# File 'lib/models/porcelain.rb', line 3432 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/models/porcelain.rb', line 3470 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |