Class: SDM::AuroraPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres

Returns a new instance of AuroraPostgres.



2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
# File 'lib/models/porcelain.rb', line 2949

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2919
2920
2921
# File 'lib/models/porcelain.rb', line 2919

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2921
2922
2923
# File 'lib/models/porcelain.rb', line 2921

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2923
2924
2925
# File 'lib/models/porcelain.rb', line 2923

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2925
2926
2927
# File 'lib/models/porcelain.rb', line 2925

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2927
2928
2929
# File 'lib/models/porcelain.rb', line 2927

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2929
2930
2931
# File 'lib/models/porcelain.rb', line 2929

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2931
2932
2933
# File 'lib/models/porcelain.rb', line 2931

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



2933
2934
2935
# File 'lib/models/porcelain.rb', line 2933

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



2935
2936
2937
# File 'lib/models/porcelain.rb', line 2935

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2937
2938
2939
# File 'lib/models/porcelain.rb', line 2937

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2939
2940
2941
# File 'lib/models/porcelain.rb', line 2939

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2941
2942
2943
# File 'lib/models/porcelain.rb', line 2941

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2943
2944
2945
# File 'lib/models/porcelain.rb', line 2943

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2945
2946
2947
# File 'lib/models/porcelain.rb', line 2945

def tags
  @tags
end

#usernameObject

The username to authenticate with.



2947
2948
2949
# File 'lib/models/porcelain.rb', line 2947

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2983
2984
2985
2986
2987
2988
2989
# File 'lib/models/porcelain.rb', line 2983

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end