Class: SDM::AuroraPostgres
- Inherits:
-
Object
- Object
- SDM::AuroraPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres
constructor
A new instance of AuroraPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres
Returns a new instance of AuroraPostgres.
2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 |
# File 'lib/models/porcelain.rb', line 2229 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2199 2200 2201 |
# File 'lib/models/porcelain.rb', line 2199 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
2201 2202 2203 |
# File 'lib/models/porcelain.rb', line 2201 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2203 2204 2205 |
# File 'lib/models/porcelain.rb', line 2203 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2205 2206 2207 |
# File 'lib/models/porcelain.rb', line 2205 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
2207 2208 2209 |
# File 'lib/models/porcelain.rb', line 2207 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2209 2210 2211 |
# File 'lib/models/porcelain.rb', line 2209 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2211 2212 2213 |
# File 'lib/models/porcelain.rb', line 2211 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
2213 2214 2215 |
# File 'lib/models/porcelain.rb', line 2213 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
2215 2216 2217 |
# File 'lib/models/porcelain.rb', line 2215 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
2217 2218 2219 |
# File 'lib/models/porcelain.rb', line 2217 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2219 2220 2221 |
# File 'lib/models/porcelain.rb', line 2219 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2221 2222 2223 |
# File 'lib/models/porcelain.rb', line 2221 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2223 2224 2225 |
# File 'lib/models/porcelain.rb', line 2223 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2225 2226 2227 |
# File 'lib/models/porcelain.rb', line 2225 def @tags end |
#username ⇒ Object
The username to authenticate with.
2227 2228 2229 |
# File 'lib/models/porcelain.rb', line 2227 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2263 2264 2265 2266 2267 2268 2269 |
# File 'lib/models/porcelain.rb', line 2263 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |