Class: SDM::AuroraPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres

Returns a new instance of AuroraPostgres.



2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
# File 'lib/models/porcelain.rb', line 2065

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2035
2036
2037
# File 'lib/models/porcelain.rb', line 2035

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2037
2038
2039
# File 'lib/models/porcelain.rb', line 2037

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2039
2040
2041
# File 'lib/models/porcelain.rb', line 2039

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2041
2042
2043
# File 'lib/models/porcelain.rb', line 2041

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2043
2044
2045
# File 'lib/models/porcelain.rb', line 2043

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2045
2046
2047
# File 'lib/models/porcelain.rb', line 2045

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2047
2048
2049
# File 'lib/models/porcelain.rb', line 2047

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



2049
2050
2051
# File 'lib/models/porcelain.rb', line 2049

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



2051
2052
2053
# File 'lib/models/porcelain.rb', line 2051

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2053
2054
2055
# File 'lib/models/porcelain.rb', line 2053

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2055
2056
2057
# File 'lib/models/porcelain.rb', line 2055

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2057
2058
2059
# File 'lib/models/porcelain.rb', line 2057

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2059
2060
2061
# File 'lib/models/porcelain.rb', line 2059

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2061
2062
2063
# File 'lib/models/porcelain.rb', line 2061

def tags
  @tags
end

#usernameObject

The username to authenticate with.



2063
2064
2065
# File 'lib/models/porcelain.rb', line 2063

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2099
2100
2101
2102
2103
2104
2105
# File 'lib/models/porcelain.rb', line 2099

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end