Class: SDM::AuroraPostgres
- Inherits:
-
Object
- Object
- SDM::AuroraPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres
constructor
A new instance of AuroraPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres
Returns a new instance of AuroraPostgres.
2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 |
# File 'lib/models/porcelain.rb', line 2054 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2024 2025 2026 |
# File 'lib/models/porcelain.rb', line 2024 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
2026 2027 2028 |
# File 'lib/models/porcelain.rb', line 2026 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2028 2029 2030 |
# File 'lib/models/porcelain.rb', line 2028 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2030 2031 2032 |
# File 'lib/models/porcelain.rb', line 2030 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2032 2033 2034 |
# File 'lib/models/porcelain.rb', line 2032 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2034 2035 2036 |
# File 'lib/models/porcelain.rb', line 2034 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2036 2037 2038 |
# File 'lib/models/porcelain.rb', line 2036 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
2038 2039 2040 |
# File 'lib/models/porcelain.rb', line 2038 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
2040 2041 2042 |
# File 'lib/models/porcelain.rb', line 2040 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2042 2043 2044 |
# File 'lib/models/porcelain.rb', line 2042 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2044 2045 2046 |
# File 'lib/models/porcelain.rb', line 2044 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2046 2047 2048 |
# File 'lib/models/porcelain.rb', line 2046 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2048 2049 2050 |
# File 'lib/models/porcelain.rb', line 2048 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2050 2051 2052 |
# File 'lib/models/porcelain.rb', line 2050 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2052 2053 2054 |
# File 'lib/models/porcelain.rb', line 2052 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/models/porcelain.rb', line 2088 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |