Class: SDM::AuroraPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgres

Returns a new instance of AuroraPostgres.



2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/models/porcelain.rb', line 2046

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2016
2017
2018
# File 'lib/models/porcelain.rb', line 2016

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2018
2019
2020
# File 'lib/models/porcelain.rb', line 2018

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2020
2021
2022
# File 'lib/models/porcelain.rb', line 2020

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2022
2023
2024
# File 'lib/models/porcelain.rb', line 2022

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2024
2025
2026
# File 'lib/models/porcelain.rb', line 2024

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2026
2027
2028
# File 'lib/models/porcelain.rb', line 2026

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2028
2029
2030
# File 'lib/models/porcelain.rb', line 2028

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



2030
2031
2032
# File 'lib/models/porcelain.rb', line 2030

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



2032
2033
2034
# File 'lib/models/porcelain.rb', line 2032

def password
  @password
end

#portObject

Returns the value of attribute port.



2034
2035
2036
# File 'lib/models/porcelain.rb', line 2034

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2036
2037
2038
# File 'lib/models/porcelain.rb', line 2036

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2038
2039
2040
# File 'lib/models/porcelain.rb', line 2038

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2040
2041
2042
# File 'lib/models/porcelain.rb', line 2040

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2042
2043
2044
# File 'lib/models/porcelain.rb', line 2042

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2044
2045
2046
# File 'lib/models/porcelain.rb', line 2044

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2080
2081
2082
2083
2084
2085
2086
# File 'lib/models/porcelain.rb', line 2080

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end