Class: SDM::AuroraPostgres
- Inherits:
-
Object
- Object
- SDM::AuroraPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AuroraPostgres
constructor
A new instance of AuroraPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AuroraPostgres
Returns a new instance of AuroraPostgres.
1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/models/porcelain.rb', line 1849 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1821 1822 1823 |
# File 'lib/models/porcelain.rb', line 1821 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
1823 1824 1825 |
# File 'lib/models/porcelain.rb', line 1823 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1825 1826 1827 |
# File 'lib/models/porcelain.rb', line 1825 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1827 1828 1829 |
# File 'lib/models/porcelain.rb', line 1827 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
1829 1830 1831 |
# File 'lib/models/porcelain.rb', line 1829 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1831 1832 1833 |
# File 'lib/models/porcelain.rb', line 1831 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1833 1834 1835 |
# File 'lib/models/porcelain.rb', line 1833 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
1835 1836 1837 |
# File 'lib/models/porcelain.rb', line 1835 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
1837 1838 1839 |
# File 'lib/models/porcelain.rb', line 1837 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
1839 1840 1841 |
# File 'lib/models/porcelain.rb', line 1839 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1841 1842 1843 |
# File 'lib/models/porcelain.rb', line 1841 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1843 1844 1845 |
# File 'lib/models/porcelain.rb', line 1843 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1845 1846 1847 |
# File 'lib/models/porcelain.rb', line 1845 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
1847 1848 1849 |
# File 'lib/models/porcelain.rb', line 1847 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/models/porcelain.rb', line 1881 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |