Class: SDM::AuroraPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AuroraPostgres

Returns a new instance of AuroraPostgres.



1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
# File 'lib/models/porcelain.rb', line 1511

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



1483
1484
1485
# File 'lib/models/porcelain.rb', line 1483

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



1485
1486
1487
# File 'lib/models/porcelain.rb', line 1485

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1487
1488
1489
# File 'lib/models/porcelain.rb', line 1487

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1489
1490
1491
# File 'lib/models/porcelain.rb', line 1489

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



1491
1492
1493
# File 'lib/models/porcelain.rb', line 1491

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1493
1494
1495
# File 'lib/models/porcelain.rb', line 1493

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1495
1496
1497
# File 'lib/models/porcelain.rb', line 1495

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



1497
1498
1499
# File 'lib/models/porcelain.rb', line 1497

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



1499
1500
1501
# File 'lib/models/porcelain.rb', line 1499

def password
  @password
end

#portObject

Returns the value of attribute port.



1501
1502
1503
# File 'lib/models/porcelain.rb', line 1501

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



1503
1504
1505
# File 'lib/models/porcelain.rb', line 1503

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1505
1506
1507
# File 'lib/models/porcelain.rb', line 1505

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1507
1508
1509
# File 'lib/models/porcelain.rb', line 1507

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



1509
1510
1511
# File 'lib/models/porcelain.rb', line 1509

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1543
1544
1545
1546
1547
1548
1549
# File 'lib/models/porcelain.rb', line 1543

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end