Class: SDM::AuroraPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgresIAM

Returns a new instance of AuroraPostgresIAM.



3412
3413
3414
3415
3416
3417
3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
3445
3446
3447
3448
# File 'lib/models/porcelain.rb', line 3412

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3378
3379
3380
# File 'lib/models/porcelain.rb', line 3378

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3380
3381
3382
# File 'lib/models/porcelain.rb', line 3380

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3382
3383
3384
# File 'lib/models/porcelain.rb', line 3382

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3384
3385
3386
# File 'lib/models/porcelain.rb', line 3384

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3386
3387
3388
# File 'lib/models/porcelain.rb', line 3386

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3388
3389
3390
# File 'lib/models/porcelain.rb', line 3388

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3390
3391
3392
# File 'lib/models/porcelain.rb', line 3390

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



3392
3393
3394
# File 'lib/models/porcelain.rb', line 3392

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3394
3395
3396
# File 'lib/models/porcelain.rb', line 3394

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3396
3397
3398
# File 'lib/models/porcelain.rb', line 3396

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3398
3399
3400
# File 'lib/models/porcelain.rb', line 3398

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



3400
3401
3402
# File 'lib/models/porcelain.rb', line 3400

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



3402
3403
3404
# File 'lib/models/porcelain.rb', line 3402

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3404
3405
3406
# File 'lib/models/porcelain.rb', line 3404

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3406
3407
3408
# File 'lib/models/porcelain.rb', line 3406

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3408
3409
3410
# File 'lib/models/porcelain.rb', line 3408

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3410
3411
3412
# File 'lib/models/porcelain.rb', line 3410

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3450
3451
3452
3453
3454
3455
3456
# File 'lib/models/porcelain.rb', line 3450

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end