Class: SDM::AuroraPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgresIAM

Returns a new instance of AuroraPostgresIAM.



3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
3367
3368
# File 'lib/models/porcelain.rb', line 3332

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3298
3299
3300
# File 'lib/models/porcelain.rb', line 3298

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3300
3301
3302
# File 'lib/models/porcelain.rb', line 3300

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3302
3303
3304
# File 'lib/models/porcelain.rb', line 3302

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3304
3305
3306
# File 'lib/models/porcelain.rb', line 3304

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3306
3307
3308
# File 'lib/models/porcelain.rb', line 3306

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3308
3309
3310
# File 'lib/models/porcelain.rb', line 3308

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3310
3311
3312
# File 'lib/models/porcelain.rb', line 3310

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



3312
3313
3314
# File 'lib/models/porcelain.rb', line 3312

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3314
3315
3316
# File 'lib/models/porcelain.rb', line 3314

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3316
3317
3318
# File 'lib/models/porcelain.rb', line 3316

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3318
3319
3320
# File 'lib/models/porcelain.rb', line 3318

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



3320
3321
3322
# File 'lib/models/porcelain.rb', line 3320

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



3322
3323
3324
# File 'lib/models/porcelain.rb', line 3322

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3324
3325
3326
# File 'lib/models/porcelain.rb', line 3324

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3326
3327
3328
# File 'lib/models/porcelain.rb', line 3326

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3328
3329
3330
# File 'lib/models/porcelain.rb', line 3328

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3330
3331
3332
# File 'lib/models/porcelain.rb', line 3330

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3370
3371
3372
3373
3374
3375
3376
# File 'lib/models/porcelain.rb', line 3370

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end