Class: SDM::AuroraPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AuroraPostgresIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AuroraPostgresIAM

Returns a new instance of AuroraPostgresIAM.



2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
# File 'lib/models/porcelain.rb', line 2379

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2347
2348
2349
# File 'lib/models/porcelain.rb', line 2347

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2349
2350
2351
# File 'lib/models/porcelain.rb', line 2349

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2351
2352
2353
# File 'lib/models/porcelain.rb', line 2351

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2353
2354
2355
# File 'lib/models/porcelain.rb', line 2353

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2355
2356
2357
# File 'lib/models/porcelain.rb', line 2355

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2357
2358
2359
# File 'lib/models/porcelain.rb', line 2357

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2359
2360
2361
# File 'lib/models/porcelain.rb', line 2359

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



2361
2362
2363
# File 'lib/models/porcelain.rb', line 2361

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2363
2364
2365
# File 'lib/models/porcelain.rb', line 2363

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2365
2366
2367
# File 'lib/models/porcelain.rb', line 2365

def port_override
  @port_override
end

#regionObject

The AWS region to connect to.



2367
2368
2369
# File 'lib/models/porcelain.rb', line 2367

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



2369
2370
2371
# File 'lib/models/porcelain.rb', line 2369

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2371
2372
2373
# File 'lib/models/porcelain.rb', line 2371

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2373
2374
2375
# File 'lib/models/porcelain.rb', line 2373

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2375
2376
2377
# File 'lib/models/porcelain.rb', line 2375

def tags
  @tags
end

#usernameObject

The username to authenticate with.



2377
2378
2379
# File 'lib/models/porcelain.rb', line 2377

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2415
2416
2417
2418
2419
2420
2421
# File 'lib/models/porcelain.rb', line 2415

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end