Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



3590
3591
3592
3593
3594
3595
3596
3597
3598
3599
3600
3601
3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
# File 'lib/models/porcelain.rb', line 3590

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



3564
3565
3566
# File 'lib/models/porcelain.rb', line 3564

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3566
3567
3568
# File 'lib/models/porcelain.rb', line 3566

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3568
3569
3570
# File 'lib/models/porcelain.rb', line 3568

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3570
3571
3572
# File 'lib/models/porcelain.rb', line 3570

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3572
3573
3574
# File 'lib/models/porcelain.rb', line 3572

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3574
3575
3576
# File 'lib/models/porcelain.rb', line 3574

def name
  @name
end

#passwordObject

The password to authenticate with.



3576
3577
3578
# File 'lib/models/porcelain.rb', line 3576

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



3578
3579
3580
# File 'lib/models/porcelain.rb', line 3578

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3580
3581
3582
# File 'lib/models/porcelain.rb', line 3580

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3582
3583
3584
# File 'lib/models/porcelain.rb', line 3582

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3584
3585
3586
# File 'lib/models/porcelain.rb', line 3584

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3586
3587
3588
# File 'lib/models/porcelain.rb', line 3586

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



3588
3589
3590
# File 'lib/models/porcelain.rb', line 3588

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3620
3621
3622
3623
3624
3625
3626
# File 'lib/models/porcelain.rb', line 3620

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end