Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



3407
3408
3409
3410
3411
3412
3413
3414
3415
3416
3417
3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
# File 'lib/models/porcelain.rb', line 3407

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



3381
3382
3383
# File 'lib/models/porcelain.rb', line 3381

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3383
3384
3385
# File 'lib/models/porcelain.rb', line 3383

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3385
3386
3387
# File 'lib/models/porcelain.rb', line 3385

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3387
3388
3389
# File 'lib/models/porcelain.rb', line 3387

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3389
3390
3391
# File 'lib/models/porcelain.rb', line 3389

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3391
3392
3393
# File 'lib/models/porcelain.rb', line 3391

def name
  @name
end

#passwordObject

The password to authenticate with.



3393
3394
3395
# File 'lib/models/porcelain.rb', line 3393

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



3395
3396
3397
# File 'lib/models/porcelain.rb', line 3395

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3397
3398
3399
# File 'lib/models/porcelain.rb', line 3397

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3399
3400
3401
# File 'lib/models/porcelain.rb', line 3399

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3401
3402
3403
# File 'lib/models/porcelain.rb', line 3401

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3403
3404
3405
# File 'lib/models/porcelain.rb', line 3403

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



3405
3406
3407
# File 'lib/models/porcelain.rb', line 3405

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3437
3438
3439
3440
3441
3442
3443
# File 'lib/models/porcelain.rb', line 3437

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end