Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/models/porcelain.rb', line 3336

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



3310
3311
3312
# File 'lib/models/porcelain.rb', line 3310

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3312
3313
3314
# File 'lib/models/porcelain.rb', line 3312

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3314
3315
3316
# File 'lib/models/porcelain.rb', line 3314

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3316
3317
3318
# File 'lib/models/porcelain.rb', line 3316

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3318
3319
3320
# File 'lib/models/porcelain.rb', line 3318

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3320
3321
3322
# File 'lib/models/porcelain.rb', line 3320

def name
  @name
end

#passwordObject

The password to authenticate with.



3322
3323
3324
# File 'lib/models/porcelain.rb', line 3322

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



3324
3325
3326
# File 'lib/models/porcelain.rb', line 3324

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3326
3327
3328
# File 'lib/models/porcelain.rb', line 3326

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3328
3329
3330
# File 'lib/models/porcelain.rb', line 3328

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3330
3331
3332
# File 'lib/models/porcelain.rb', line 3330

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3332
3333
3334
# File 'lib/models/porcelain.rb', line 3332

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



3334
3335
3336
# File 'lib/models/porcelain.rb', line 3334

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3366
3367
3368
3369
3370
3371
3372
# File 'lib/models/porcelain.rb', line 3366

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end