Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



3176
3177
3178
3179
3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
# File 'lib/models/porcelain.rb', line 3176

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



3150
3151
3152
# File 'lib/models/porcelain.rb', line 3150

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3152
3153
3154
# File 'lib/models/porcelain.rb', line 3152

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3154
3155
3156
# File 'lib/models/porcelain.rb', line 3154

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3156
3157
3158
# File 'lib/models/porcelain.rb', line 3156

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3158
3159
3160
# File 'lib/models/porcelain.rb', line 3158

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3160
3161
3162
# File 'lib/models/porcelain.rb', line 3160

def name
  @name
end

#passwordObject

The password to authenticate with.



3162
3163
3164
# File 'lib/models/porcelain.rb', line 3162

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



3164
3165
3166
# File 'lib/models/porcelain.rb', line 3164

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3166
3167
3168
# File 'lib/models/porcelain.rb', line 3166

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3168
3169
3170
# File 'lib/models/porcelain.rb', line 3168

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3170
3171
3172
# File 'lib/models/porcelain.rb', line 3170

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3172
3173
3174
# File 'lib/models/porcelain.rb', line 3172

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



3174
3175
3176
# File 'lib/models/porcelain.rb', line 3174

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3206
3207
3208
3209
3210
3211
3212
# File 'lib/models/porcelain.rb', line 3206

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end