Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
# File 'lib/models/porcelain.rb', line 3097

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



3073
3074
3075
# File 'lib/models/porcelain.rb', line 3073

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3075
3076
3077
# File 'lib/models/porcelain.rb', line 3075

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3077
3078
3079
# File 'lib/models/porcelain.rb', line 3077

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3079
3080
3081
# File 'lib/models/porcelain.rb', line 3079

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3081
3082
3083
# File 'lib/models/porcelain.rb', line 3081

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3083
3084
3085
# File 'lib/models/porcelain.rb', line 3083

def name
  @name
end

#passwordObject

The password to authenticate with.



3085
3086
3087
# File 'lib/models/porcelain.rb', line 3085

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



3087
3088
3089
# File 'lib/models/porcelain.rb', line 3087

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3089
3090
3091
# File 'lib/models/porcelain.rb', line 3089

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3091
3092
3093
# File 'lib/models/porcelain.rb', line 3091

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3093
3094
3095
# File 'lib/models/porcelain.rb', line 3093

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



3095
3096
3097
# File 'lib/models/porcelain.rb', line 3095

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3125
3126
3127
3128
3129
3130
3131
# File 'lib/models/porcelain.rb', line 3125

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end