Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
# File 'lib/models/porcelain.rb', line 2450

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



2426
2427
2428
# File 'lib/models/porcelain.rb', line 2426

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2428
2429
2430
# File 'lib/models/porcelain.rb', line 2428

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2430
2431
2432
# File 'lib/models/porcelain.rb', line 2430

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2432
2433
2434
# File 'lib/models/porcelain.rb', line 2432

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2434
2435
2436
# File 'lib/models/porcelain.rb', line 2434

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2436
2437
2438
# File 'lib/models/porcelain.rb', line 2436

def name
  @name
end

#passwordObject

The password to authenticate with.



2438
2439
2440
# File 'lib/models/porcelain.rb', line 2438

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



2440
2441
2442
# File 'lib/models/porcelain.rb', line 2440

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2442
2443
2444
# File 'lib/models/porcelain.rb', line 2442

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2444
2445
2446
# File 'lib/models/porcelain.rb', line 2444

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2446
2447
2448
# File 'lib/models/porcelain.rb', line 2446

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



2448
2449
2450
# File 'lib/models/porcelain.rb', line 2448

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2478
2479
2480
2481
2482
2483
2484
# File 'lib/models/porcelain.rb', line 2478

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end