Class: SDM::Azure
- Inherits:
-
Object
- Object
- SDM::Azure
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
The application ID to authenticate with.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
The tenant ID to authenticate to.
Instance Method Summary collapse
-
#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure
constructor
A new instance of Azure.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure
Returns a new instance of Azure.
2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 |
# File 'lib/models/porcelain.rb', line 2298 def initialize( app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @app_id = app_id == nil ? "" : app_id @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#app_id ⇒ Object
The application ID to authenticate with.
2274 2275 2276 |
# File 'lib/models/porcelain.rb', line 2274 def app_id @app_id end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2276 2277 2278 |
# File 'lib/models/porcelain.rb', line 2276 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2278 2279 2280 |
# File 'lib/models/porcelain.rb', line 2278 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2280 2281 2282 |
# File 'lib/models/porcelain.rb', line 2280 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2282 2283 2284 |
# File 'lib/models/porcelain.rb', line 2282 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2284 2285 2286 |
# File 'lib/models/porcelain.rb', line 2284 def name @name end |
#password ⇒ Object
The password to authenticate with.
2286 2287 2288 |
# File 'lib/models/porcelain.rb', line 2286 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2288 2289 2290 |
# File 'lib/models/porcelain.rb', line 2288 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2290 2291 2292 |
# File 'lib/models/porcelain.rb', line 2290 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2292 2293 2294 |
# File 'lib/models/porcelain.rb', line 2292 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2294 2295 2296 |
# File 'lib/models/porcelain.rb', line 2294 def @tags end |
#tenant_id ⇒ Object
The tenant ID to authenticate to.
2296 2297 2298 |
# File 'lib/models/porcelain.rb', line 2296 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/models/porcelain.rb', line 2326 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |