Class: SDM::Azure
- Inherits:
-
Object
- Object
- SDM::Azure
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
Returns the value of attribute app_id.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Instance Method Summary collapse
-
#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure
constructor
A new instance of Azure.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ Azure
Returns a new instance of Azure.
2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 |
# File 'lib/models/porcelain.rb', line 2122 def initialize( app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @app_id = app_id == nil ? "" : app_id @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#app_id ⇒ Object
Returns the value of attribute app_id.
2098 2099 2100 |
# File 'lib/models/porcelain.rb', line 2098 def app_id @app_id end |
#bind_interface ⇒ Object
Bind interface
2100 2101 2102 |
# File 'lib/models/porcelain.rb', line 2100 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2102 2103 2104 |
# File 'lib/models/porcelain.rb', line 2102 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2104 2105 2106 |
# File 'lib/models/porcelain.rb', line 2104 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2106 2107 2108 |
# File 'lib/models/porcelain.rb', line 2106 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2108 2109 2110 |
# File 'lib/models/porcelain.rb', line 2108 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2110 2111 2112 |
# File 'lib/models/porcelain.rb', line 2110 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2112 2113 2114 |
# File 'lib/models/porcelain.rb', line 2112 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2114 2115 2116 |
# File 'lib/models/porcelain.rb', line 2114 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2116 2117 2118 |
# File 'lib/models/porcelain.rb', line 2116 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2118 2119 2120 |
# File 'lib/models/porcelain.rb', line 2118 def @tags end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
2120 2121 2122 |
# File 'lib/models/porcelain.rb', line 2120 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2150 2151 2152 2153 2154 2155 2156 |
# File 'lib/models/porcelain.rb', line 2150 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |