Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, secret_store_id: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/models/porcelain.rb', line 2081

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  secret_store_id: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

Returns the value of attribute app_id.



2061
2062
2063
# File 'lib/models/porcelain.rb', line 2061

def app_id
  @app_id
end

#bind_interfaceObject

Bind interface



2063
2064
2065
# File 'lib/models/porcelain.rb', line 2063

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2065
2066
2067
# File 'lib/models/porcelain.rb', line 2065

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2067
2068
2069
# File 'lib/models/porcelain.rb', line 2067

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2069
2070
2071
# File 'lib/models/porcelain.rb', line 2069

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2071
2072
2073
# File 'lib/models/porcelain.rb', line 2071

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2073
2074
2075
# File 'lib/models/porcelain.rb', line 2073

def password
  @password
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2075
2076
2077
# File 'lib/models/porcelain.rb', line 2075

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2077
2078
2079
# File 'lib/models/porcelain.rb', line 2077

def tags
  @tags
end

#tenant_idObject

Returns the value of attribute tenant_id.



2079
2080
2081
# File 'lib/models/porcelain.rb', line 2079

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2105
2106
2107
2108
2109
2110
2111
# File 'lib/models/porcelain.rb', line 2105

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end