Class: SDM::Azure
- Inherits:
-
Object
- Object
- SDM::Azure
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
Returns the value of attribute app_id.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Instance Method Summary collapse
-
#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, secret_store_id: nil, tags: nil, tenant_id: nil) ⇒ Azure
constructor
A new instance of Azure.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, secret_store_id: nil, tags: nil, tenant_id: nil) ⇒ Azure
Returns a new instance of Azure.
1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 |
# File 'lib/models/porcelain.rb', line 1911 def initialize( app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, secret_store_id: nil, tags: nil, tenant_id: nil ) @app_id = app_id == nil ? "" : app_id @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#app_id ⇒ Object
Returns the value of attribute app_id.
1891 1892 1893 |
# File 'lib/models/porcelain.rb', line 1891 def app_id @app_id end |
#bind_interface ⇒ Object
Bind interface
1893 1894 1895 |
# File 'lib/models/porcelain.rb', line 1893 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1895 1896 1897 |
# File 'lib/models/porcelain.rb', line 1895 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1897 1898 1899 |
# File 'lib/models/porcelain.rb', line 1897 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1899 1900 1901 |
# File 'lib/models/porcelain.rb', line 1899 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1901 1902 1903 |
# File 'lib/models/porcelain.rb', line 1901 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
1903 1904 1905 |
# File 'lib/models/porcelain.rb', line 1903 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1905 1906 1907 |
# File 'lib/models/porcelain.rb', line 1905 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1907 1908 1909 |
# File 'lib/models/porcelain.rb', line 1907 def @tags end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
1909 1910 1911 |
# File 'lib/models/porcelain.rb', line 1909 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1935 1936 1937 1938 1939 1940 1941 |
# File 'lib/models/porcelain.rb', line 1935 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |