Class: SDM::Azure

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, secret_store_id: nil, tags: nil, tenant_id: nil) ⇒ Azure

Returns a new instance of Azure.



1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
# File 'lib/models/porcelain.rb', line 1573

def initialize(
  app_id: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  secret_store_id: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

Returns the value of attribute app_id.



1553
1554
1555
# File 'lib/models/porcelain.rb', line 1553

def app_id
  @app_id
end

#bind_interfaceObject

Bind interface



1555
1556
1557
# File 'lib/models/porcelain.rb', line 1555

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1557
1558
1559
# File 'lib/models/porcelain.rb', line 1557

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1559
1560
1561
# File 'lib/models/porcelain.rb', line 1559

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1561
1562
1563
# File 'lib/models/porcelain.rb', line 1561

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1563
1564
1565
# File 'lib/models/porcelain.rb', line 1563

def name
  @name
end

#passwordObject

Returns the value of attribute password.



1565
1566
1567
# File 'lib/models/porcelain.rb', line 1565

def password
  @password
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1567
1568
1569
# File 'lib/models/porcelain.rb', line 1567

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1569
1570
1571
# File 'lib/models/porcelain.rb', line 1569

def tags
  @tags
end

#tenant_idObject

Returns the value of attribute tenant_id.



1571
1572
1573
# File 'lib/models/porcelain.rb', line 1571

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1597
1598
1599
1600
1601
1602
1603
# File 'lib/models/porcelain.rb', line 1597

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end