Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



4447
4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
4466
4467
4468
4469
4470
4471
4472
4473
4474
4475
# File 'lib/models/porcelain.rb', line 4447

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



4421
4422
4423
# File 'lib/models/porcelain.rb', line 4421

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4423
4424
4425
# File 'lib/models/porcelain.rb', line 4423

def bind_interface
  @bind_interface
end

#client_certificateObject

The service Principal certificate file, both private and public key included.



4425
4426
4427
# File 'lib/models/porcelain.rb', line 4425

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4427
4428
4429
# File 'lib/models/porcelain.rb', line 4427

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4429
4430
4431
# File 'lib/models/porcelain.rb', line 4429

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4431
4432
4433
# File 'lib/models/porcelain.rb', line 4431

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4433
4434
4435
# File 'lib/models/porcelain.rb', line 4433

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4435
4436
4437
# File 'lib/models/porcelain.rb', line 4435

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4437
4438
4439
# File 'lib/models/porcelain.rb', line 4437

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4439
4440
4441
# File 'lib/models/porcelain.rb', line 4439

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4441
4442
4443
# File 'lib/models/porcelain.rb', line 4441

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4443
4444
4445
# File 'lib/models/porcelain.rb', line 4443

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



4445
4446
4447
# File 'lib/models/porcelain.rb', line 4445

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4477
4478
4479
4480
4481
4482
4483
# File 'lib/models/porcelain.rb', line 4477

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end