Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
# File 'lib/models/porcelain.rb', line 3736

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



3710
3711
3712
# File 'lib/models/porcelain.rb', line 3710

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3712
3713
3714
# File 'lib/models/porcelain.rb', line 3712

def bind_interface
  @bind_interface
end

#client_certificateObject

The service Principal certificate file, both private and public key included.



3714
3715
3716
# File 'lib/models/porcelain.rb', line 3714

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3716
3717
3718
# File 'lib/models/porcelain.rb', line 3716

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3718
3719
3720
# File 'lib/models/porcelain.rb', line 3718

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3720
3721
3722
# File 'lib/models/porcelain.rb', line 3720

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3722
3723
3724
# File 'lib/models/porcelain.rb', line 3722

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



3724
3725
3726
# File 'lib/models/porcelain.rb', line 3724

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3726
3727
3728
# File 'lib/models/porcelain.rb', line 3726

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3728
3729
3730
# File 'lib/models/porcelain.rb', line 3728

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3730
3731
3732
# File 'lib/models/porcelain.rb', line 3730

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3732
3733
3734
# File 'lib/models/porcelain.rb', line 3732

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



3734
3735
3736
# File 'lib/models/porcelain.rb', line 3734

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3766
3767
3768
3769
3770
3771
3772
# File 'lib/models/porcelain.rb', line 3766

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end