Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



3657
3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
3669
3670
3671
3672
3673
3674
3675
3676
3677
3678
3679
3680
3681
3682
3683
3684
3685
# File 'lib/models/porcelain.rb', line 3657

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



3631
3632
3633
# File 'lib/models/porcelain.rb', line 3631

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3633
3634
3635
# File 'lib/models/porcelain.rb', line 3633

def bind_interface
  @bind_interface
end

#client_certificateObject

The service Principal certificate file, both private and public key included.



3635
3636
3637
# File 'lib/models/porcelain.rb', line 3635

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3637
3638
3639
# File 'lib/models/porcelain.rb', line 3637

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3639
3640
3641
# File 'lib/models/porcelain.rb', line 3639

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3641
3642
3643
# File 'lib/models/porcelain.rb', line 3641

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3643
3644
3645
# File 'lib/models/porcelain.rb', line 3643

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



3645
3646
3647
# File 'lib/models/porcelain.rb', line 3645

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3647
3648
3649
# File 'lib/models/porcelain.rb', line 3647

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3649
3650
3651
# File 'lib/models/porcelain.rb', line 3649

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3651
3652
3653
# File 'lib/models/porcelain.rb', line 3651

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3653
3654
3655
# File 'lib/models/porcelain.rb', line 3653

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



3655
3656
3657
# File 'lib/models/porcelain.rb', line 3655

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3687
3688
3689
3690
3691
3692
3693
# File 'lib/models/porcelain.rb', line 3687

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end