Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/models/porcelain.rb', line 3552

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



3526
3527
3528
# File 'lib/models/porcelain.rb', line 3526

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3528
3529
3530
# File 'lib/models/porcelain.rb', line 3528

def bind_interface
  @bind_interface
end

#client_certificateObject

The service Principal certificate file, both private and public key included.



3530
3531
3532
# File 'lib/models/porcelain.rb', line 3530

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3532
3533
3534
# File 'lib/models/porcelain.rb', line 3532

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3534
3535
3536
# File 'lib/models/porcelain.rb', line 3534

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3536
3537
3538
# File 'lib/models/porcelain.rb', line 3536

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3538
3539
3540
# File 'lib/models/porcelain.rb', line 3538

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



3540
3541
3542
# File 'lib/models/porcelain.rb', line 3540

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3542
3543
3544
# File 'lib/models/porcelain.rb', line 3542

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3544
3545
3546
# File 'lib/models/porcelain.rb', line 3544

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3546
3547
3548
# File 'lib/models/porcelain.rb', line 3546

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3548
3549
3550
# File 'lib/models/porcelain.rb', line 3548

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



3550
3551
3552
# File 'lib/models/porcelain.rb', line 3550

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3582
3583
3584
3585
3586
3587
3588
# File 'lib/models/porcelain.rb', line 3582

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end