Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'lib/models/porcelain.rb', line 2513

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



2489
2490
2491
# File 'lib/models/porcelain.rb', line 2489

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2491
2492
2493
# File 'lib/models/porcelain.rb', line 2491

def bind_interface
  @bind_interface
end

#client_certificateObject

The service Principal certificate file, both private and public key included.



2493
2494
2495
# File 'lib/models/porcelain.rb', line 2493

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2495
2496
2497
# File 'lib/models/porcelain.rb', line 2495

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2497
2498
2499
# File 'lib/models/porcelain.rb', line 2497

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2499
2500
2501
# File 'lib/models/porcelain.rb', line 2499

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2501
2502
2503
# File 'lib/models/porcelain.rb', line 2501

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



2503
2504
2505
# File 'lib/models/porcelain.rb', line 2503

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2505
2506
2507
# File 'lib/models/porcelain.rb', line 2505

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2507
2508
2509
# File 'lib/models/porcelain.rb', line 2507

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2509
2510
2511
# File 'lib/models/porcelain.rb', line 2509

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



2511
2512
2513
# File 'lib/models/porcelain.rb', line 2511

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2541
2542
2543
2544
2545
2546
2547
# File 'lib/models/porcelain.rb', line 2541

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end