Class: SDM::AzureCertificate
- Inherits:
-
Object
- Object
- SDM::AzureCertificate
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
The application ID to authenticate with.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#client_certificate ⇒ Object
The service Principal certificate file, both private and public key included.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
The tenant ID to authenticate to.
Instance Method Summary collapse
-
#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate
constructor
A new instance of AzureCertificate.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate
Returns a new instance of AzureCertificate.
2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'lib/models/porcelain.rb', line 2361 def initialize( app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @app_id = app_id == nil ? "" : app_id @bind_interface = bind_interface == nil ? "" : bind_interface @client_certificate = client_certificate == nil ? "" : client_certificate @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#app_id ⇒ Object
The application ID to authenticate with.
2337 2338 2339 |
# File 'lib/models/porcelain.rb', line 2337 def app_id @app_id end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2339 2340 2341 |
# File 'lib/models/porcelain.rb', line 2339 def bind_interface @bind_interface end |
#client_certificate ⇒ Object
The service Principal certificate file, both private and public key included.
2341 2342 2343 |
# File 'lib/models/porcelain.rb', line 2341 def client_certificate @client_certificate end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2343 2344 2345 |
# File 'lib/models/porcelain.rb', line 2343 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2345 2346 2347 |
# File 'lib/models/porcelain.rb', line 2345 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2347 2348 2349 |
# File 'lib/models/porcelain.rb', line 2347 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2349 2350 2351 |
# File 'lib/models/porcelain.rb', line 2349 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2351 2352 2353 |
# File 'lib/models/porcelain.rb', line 2351 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2353 2354 2355 |
# File 'lib/models/porcelain.rb', line 2353 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2355 2356 2357 |
# File 'lib/models/porcelain.rb', line 2355 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2357 2358 2359 |
# File 'lib/models/porcelain.rb', line 2357 def @tags end |
#tenant_id ⇒ Object
The tenant ID to authenticate to.
2359 2360 2361 |
# File 'lib/models/porcelain.rb', line 2359 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2389 2390 2391 2392 2393 2394 2395 |
# File 'lib/models/porcelain.rb', line 2389 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |