Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/models/porcelain.rb', line 2197

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

The application ID to authenticate with.



2173
2174
2175
# File 'lib/models/porcelain.rb', line 2173

def app_id
  @app_id
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2175
2176
2177
# File 'lib/models/porcelain.rb', line 2175

def bind_interface
  @bind_interface
end

#client_certificateObject

The service Principal certificate file, both private and public key included.



2177
2178
2179
# File 'lib/models/porcelain.rb', line 2177

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2179
2180
2181
# File 'lib/models/porcelain.rb', line 2179

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2181
2182
2183
# File 'lib/models/porcelain.rb', line 2181

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2183
2184
2185
# File 'lib/models/porcelain.rb', line 2183

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2185
2186
2187
# File 'lib/models/porcelain.rb', line 2185

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



2187
2188
2189
# File 'lib/models/porcelain.rb', line 2187

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2189
2190
2191
# File 'lib/models/porcelain.rb', line 2189

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2191
2192
2193
# File 'lib/models/porcelain.rb', line 2191

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2193
2194
2195
# File 'lib/models/porcelain.rb', line 2193

def tags
  @tags
end

#tenant_idObject

The tenant ID to authenticate to.



2195
2196
2197
# File 'lib/models/porcelain.rb', line 2195

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2225
2226
2227
2228
2229
2230
2231
# File 'lib/models/porcelain.rb', line 2225

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end