Class: SDM::AzureCertificate
- Inherits:
-
Object
- Object
- SDM::AzureCertificate
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
Returns the value of attribute app_id.
-
#bind_interface ⇒ Object
Bind interface.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Instance Method Summary collapse
-
#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate
constructor
A new instance of AzureCertificate.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate
Returns a new instance of AzureCertificate.
2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 |
# File 'lib/models/porcelain.rb', line 2184 def initialize( app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @app_id = app_id == nil ? "" : app_id @bind_interface = bind_interface == nil ? "" : bind_interface @client_certificate = client_certificate == nil ? "" : client_certificate @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#app_id ⇒ Object
Returns the value of attribute app_id.
2160 2161 2162 |
# File 'lib/models/porcelain.rb', line 2160 def app_id @app_id end |
#bind_interface ⇒ Object
Bind interface
2162 2163 2164 |
# File 'lib/models/porcelain.rb', line 2162 def bind_interface @bind_interface end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
2164 2165 2166 |
# File 'lib/models/porcelain.rb', line 2164 def client_certificate @client_certificate end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2166 2167 2168 |
# File 'lib/models/porcelain.rb', line 2166 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2168 2169 2170 |
# File 'lib/models/porcelain.rb', line 2168 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2170 2171 2172 |
# File 'lib/models/porcelain.rb', line 2170 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2172 2173 2174 |
# File 'lib/models/porcelain.rb', line 2172 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2174 2175 2176 |
# File 'lib/models/porcelain.rb', line 2174 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2176 2177 2178 |
# File 'lib/models/porcelain.rb', line 2176 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2178 2179 2180 |
# File 'lib/models/porcelain.rb', line 2178 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2180 2181 2182 |
# File 'lib/models/porcelain.rb', line 2180 def @tags end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
2182 2183 2184 |
# File 'lib/models/porcelain.rb', line 2182 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2212 2213 2214 2215 2216 2217 2218 |
# File 'lib/models/porcelain.rb', line 2212 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |