Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
# File 'lib/models/porcelain.rb', line 2176

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

Returns the value of attribute app_id.



2152
2153
2154
# File 'lib/models/porcelain.rb', line 2152

def app_id
  @app_id
end

#bind_interfaceObject

Bind interface



2154
2155
2156
# File 'lib/models/porcelain.rb', line 2154

def bind_interface
  @bind_interface
end

#client_certificateObject

Returns the value of attribute client_certificate.



2156
2157
2158
# File 'lib/models/porcelain.rb', line 2156

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2158
2159
2160
# File 'lib/models/porcelain.rb', line 2158

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2160
2161
2162
# File 'lib/models/porcelain.rb', line 2160

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2162
2163
2164
# File 'lib/models/porcelain.rb', line 2162

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2164
2165
2166
# File 'lib/models/porcelain.rb', line 2164

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



2166
2167
2168
# File 'lib/models/porcelain.rb', line 2166

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2168
2169
2170
# File 'lib/models/porcelain.rb', line 2168

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2170
2171
2172
# File 'lib/models/porcelain.rb', line 2170

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2172
2173
2174
# File 'lib/models/porcelain.rb', line 2172

def tags
  @tags
end

#tenant_idObject

Returns the value of attribute tenant_id.



2174
2175
2176
# File 'lib/models/porcelain.rb', line 2174

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2204
2205
2206
2207
2208
2209
2210
# File 'lib/models/porcelain.rb', line 2204

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end