Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
# File 'lib/models/porcelain.rb', line 1965

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

Returns the value of attribute app_id.



1945
1946
1947
# File 'lib/models/porcelain.rb', line 1945

def app_id
  @app_id
end

#bind_interfaceObject

Bind interface



1947
1948
1949
# File 'lib/models/porcelain.rb', line 1947

def bind_interface
  @bind_interface
end

#client_certificateObject

Returns the value of attribute client_certificate.



1949
1950
1951
# File 'lib/models/porcelain.rb', line 1949

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1951
1952
1953
# File 'lib/models/porcelain.rb', line 1951

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1953
1954
1955
# File 'lib/models/porcelain.rb', line 1953

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1955
1956
1957
# File 'lib/models/porcelain.rb', line 1955

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1957
1958
1959
# File 'lib/models/porcelain.rb', line 1957

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1959
1960
1961
# File 'lib/models/porcelain.rb', line 1959

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1961
1962
1963
# File 'lib/models/porcelain.rb', line 1961

def tags
  @tags
end

#tenant_idObject

Returns the value of attribute tenant_id.



1963
1964
1965
# File 'lib/models/porcelain.rb', line 1963

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1989
1990
1991
1992
1993
1994
1995
# File 'lib/models/porcelain.rb', line 1989

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end