Class: SDM::AzureCertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate

Returns a new instance of AzureCertificate.



1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
# File 'lib/models/porcelain.rb', line 1627

def initialize(
  app_id: nil,
  bind_interface: nil,
  client_certificate: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  tags: nil,
  tenant_id: nil
)
  @app_id = app_id == nil ? "" : app_id
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#app_idObject

Returns the value of attribute app_id.



1607
1608
1609
# File 'lib/models/porcelain.rb', line 1607

def app_id
  @app_id
end

#bind_interfaceObject

Bind interface



1609
1610
1611
# File 'lib/models/porcelain.rb', line 1609

def bind_interface
  @bind_interface
end

#client_certificateObject

Returns the value of attribute client_certificate.



1611
1612
1613
# File 'lib/models/porcelain.rb', line 1611

def client_certificate
  @client_certificate
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1613
1614
1615
# File 'lib/models/porcelain.rb', line 1613

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1615
1616
1617
# File 'lib/models/porcelain.rb', line 1615

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1617
1618
1619
# File 'lib/models/porcelain.rb', line 1617

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1619
1620
1621
# File 'lib/models/porcelain.rb', line 1619

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1621
1622
1623
# File 'lib/models/porcelain.rb', line 1621

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1623
1624
1625
# File 'lib/models/porcelain.rb', line 1623

def tags
  @tags
end

#tenant_idObject

Returns the value of attribute tenant_id.



1625
1626
1627
# File 'lib/models/porcelain.rb', line 1625

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1651
1652
1653
1654
1655
1656
1657
# File 'lib/models/porcelain.rb', line 1651

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end