Class: SDM::AzureCertificate
- Inherits:
-
Object
- Object
- SDM::AzureCertificate
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
Returns the value of attribute app_id.
-
#bind_interface ⇒ Object
Bind interface.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Instance Method Summary collapse
-
#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate
constructor
A new instance of AzureCertificate.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, tags: nil, tenant_id: nil) ⇒ AzureCertificate
Returns a new instance of AzureCertificate.
1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 |
# File 'lib/models/porcelain.rb', line 1387 def initialize( app_id: nil, bind_interface: nil, client_certificate: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, tags: nil, tenant_id: nil ) @app_id = app_id == nil ? "" : app_id @bind_interface = bind_interface == nil ? "" : bind_interface @client_certificate = client_certificate == nil ? "" : client_certificate @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#app_id ⇒ Object
Returns the value of attribute app_id.
1367 1368 1369 |
# File 'lib/models/porcelain.rb', line 1367 def app_id @app_id end |
#bind_interface ⇒ Object
Bind interface
1369 1370 1371 |
# File 'lib/models/porcelain.rb', line 1369 def bind_interface @bind_interface end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
1371 1372 1373 |
# File 'lib/models/porcelain.rb', line 1371 def client_certificate @client_certificate end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1373 1374 1375 |
# File 'lib/models/porcelain.rb', line 1373 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1375 1376 1377 |
# File 'lib/models/porcelain.rb', line 1375 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1377 1378 1379 |
# File 'lib/models/porcelain.rb', line 1377 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1379 1380 1381 |
# File 'lib/models/porcelain.rb', line 1379 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1381 1382 1383 |
# File 'lib/models/porcelain.rb', line 1381 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1383 1384 1385 |
# File 'lib/models/porcelain.rb', line 1383 def @tags end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
1385 1386 1387 |
# File 'lib/models/porcelain.rb', line 1385 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/models/porcelain.rb', line 1411 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |