Class: SDM::AzureConnector
- Inherits:
-
Object
- Object
- SDM::AzureConnector
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#client_id ⇒ Object
ClientId is the ID of the Application / Service Account we're acting as.
-
#description ⇒ Object
Description of the Connector.
-
#exclude_tags ⇒ Object
ExcludeTags filters out discovered resources that have the tag and value.
-
#id ⇒ Object
Unique identifier of the Connector.
-
#include_tags ⇒ Object
IncludeTags only discovers cloud resources that have one of the included tags.
-
#name ⇒ Object
Unique human-readable name of the Connector.
-
#scan_period ⇒ Object
ScanPeriod identifies which remote system this Connector discovers.
-
#services ⇒ Object
Services is a list of services this connector should scan.
-
#subscription_ids ⇒ Object
SubscriptionIds are the targets of discovery.
-
#tenant_id ⇒ Object
TenantId is the Azure Tenant we're discovering in.
Instance Method Summary collapse
-
#initialize(client_id: nil, description: nil, exclude_tags: nil, id: nil, include_tags: nil, name: nil, scan_period: nil, services: nil, subscription_ids: nil, tenant_id: nil) ⇒ AzureConnector
constructor
A new instance of AzureConnector.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(client_id: nil, description: nil, exclude_tags: nil, id: nil, include_tags: nil, name: nil, scan_period: nil, services: nil, subscription_ids: nil, tenant_id: nil) ⇒ AzureConnector
Returns a new instance of AzureConnector.
4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 4532 |
# File 'lib/models/porcelain.rb', line 4510 def initialize( client_id: nil, description: nil, exclude_tags: nil, id: nil, include_tags: nil, name: nil, scan_period: nil, services: nil, subscription_ids: nil, tenant_id: nil ) @client_id = client_id == nil ? "" : client_id @description = description == nil ? "" : description @exclude_tags = == nil ? [] : @id = id == nil ? "" : id @include_tags = == nil ? [] : @name = name == nil ? "" : name @scan_period = scan_period == nil ? "" : scan_period @services = services == nil ? [] : services @subscription_ids = subscription_ids == nil ? [] : subscription_ids @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#client_id ⇒ Object
ClientId is the ID of the Application / Service Account we're acting as
4488 4489 4490 |
# File 'lib/models/porcelain.rb', line 4488 def client_id @client_id end |
#description ⇒ Object
Description of the Connector.
4490 4491 4492 |
# File 'lib/models/porcelain.rb', line 4490 def description @description end |
#exclude_tags ⇒ Object
ExcludeTags filters out discovered resources that have the tag and value. We do allow duplicate tag names for ExcludeTags to support multiple excluded values for the tag.
4493 4494 4495 |
# File 'lib/models/porcelain.rb', line 4493 def @exclude_tags end |
#id ⇒ Object
Unique identifier of the Connector.
4495 4496 4497 |
# File 'lib/models/porcelain.rb', line 4495 def id @id end |
#include_tags ⇒ Object
IncludeTags only discovers cloud resources that have one of the included tags. We do not allow duplicate tag names for IncludeTags
4498 4499 4500 |
# File 'lib/models/porcelain.rb', line 4498 def @include_tags end |
#name ⇒ Object
Unique human-readable name of the Connector.
4500 4501 4502 |
# File 'lib/models/porcelain.rb', line 4500 def name @name end |
#scan_period ⇒ Object
ScanPeriod identifies which remote system this Connector discovers
4502 4503 4504 |
# File 'lib/models/porcelain.rb', line 4502 def scan_period @scan_period end |
#services ⇒ Object
Services is a list of services this connector should scan.
4504 4505 4506 |
# File 'lib/models/porcelain.rb', line 4504 def services @services end |
#subscription_ids ⇒ Object
SubscriptionIds are the targets of discovery.
4506 4507 4508 |
# File 'lib/models/porcelain.rb', line 4506 def subscription_ids @subscription_ids end |
#tenant_id ⇒ Object
TenantId is the Azure Tenant we're discovering in
4508 4509 4510 |
# File 'lib/models/porcelain.rb', line 4508 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4534 4535 4536 4537 4538 4539 4540 |
# File 'lib/models/porcelain.rb', line 4534 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |