Class: SDM::AzureMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzureMysql

Returns a new instance of AzureMysql.



3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
# File 'lib/models/porcelain.rb', line 3732

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3698
3699
3700
# File 'lib/models/porcelain.rb', line 3698

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



3700
3701
3702
# File 'lib/models/porcelain.rb', line 3700

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3702
3703
3704
# File 'lib/models/porcelain.rb', line 3702

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3704
3705
3706
# File 'lib/models/porcelain.rb', line 3704

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3706
3707
3708
# File 'lib/models/porcelain.rb', line 3706

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3708
3709
3710
# File 'lib/models/porcelain.rb', line 3708

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3710
3711
3712
# File 'lib/models/porcelain.rb', line 3710

def name
  @name
end

#passwordObject

The password to authenticate with.



3712
3713
3714
# File 'lib/models/porcelain.rb', line 3712

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3714
3715
3716
# File 'lib/models/porcelain.rb', line 3714

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3716
3717
3718
# File 'lib/models/porcelain.rb', line 3716

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3718
3719
3720
# File 'lib/models/porcelain.rb', line 3718

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



3720
3721
3722
# File 'lib/models/porcelain.rb', line 3720

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3722
3723
3724
# File 'lib/models/porcelain.rb', line 3722

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3724
3725
3726
# File 'lib/models/porcelain.rb', line 3724

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3726
3727
3728
# File 'lib/models/porcelain.rb', line 3726

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



3728
3729
3730
# File 'lib/models/porcelain.rb', line 3728

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



3730
3731
3732
# File 'lib/models/porcelain.rb', line 3730

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3770
3771
3772
3773
3774
3775
3776
# File 'lib/models/porcelain.rb', line 3770

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end