Class: SDM::AzureMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzureMysql

Returns a new instance of AzureMysql.



3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
3265
# File 'lib/models/porcelain.rb', line 3231

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3199
3200
3201
# File 'lib/models/porcelain.rb', line 3199

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



3201
3202
3203
# File 'lib/models/porcelain.rb', line 3201

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3203
3204
3205
# File 'lib/models/porcelain.rb', line 3203

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3205
3206
3207
# File 'lib/models/porcelain.rb', line 3205

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3207
3208
3209
# File 'lib/models/porcelain.rb', line 3207

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3209
3210
3211
# File 'lib/models/porcelain.rb', line 3209

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3211
3212
3213
# File 'lib/models/porcelain.rb', line 3211

def name
  @name
end

#passwordObject

The password to authenticate with.



3213
3214
3215
# File 'lib/models/porcelain.rb', line 3213

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3215
3216
3217
# File 'lib/models/porcelain.rb', line 3215

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3217
3218
3219
# File 'lib/models/porcelain.rb', line 3217

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



3219
3220
3221
# File 'lib/models/porcelain.rb', line 3219

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3221
3222
3223
# File 'lib/models/porcelain.rb', line 3221

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3223
3224
3225
# File 'lib/models/porcelain.rb', line 3223

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3225
3226
3227
# File 'lib/models/porcelain.rb', line 3225

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



3227
3228
3229
# File 'lib/models/porcelain.rb', line 3227

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



3229
3230
3231
# File 'lib/models/porcelain.rb', line 3229

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3267
3268
3269
3270
3271
3272
3273
# File 'lib/models/porcelain.rb', line 3267

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end