Class: SDM::AzureMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzureMysql

Returns a new instance of AzureMysql.



2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
# File 'lib/models/porcelain.rb', line 2584

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2552
2553
2554
# File 'lib/models/porcelain.rb', line 2552

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



2554
2555
2556
# File 'lib/models/porcelain.rb', line 2554

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2556
2557
2558
# File 'lib/models/porcelain.rb', line 2556

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2558
2559
2560
# File 'lib/models/porcelain.rb', line 2558

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2560
2561
2562
# File 'lib/models/porcelain.rb', line 2560

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2562
2563
2564
# File 'lib/models/porcelain.rb', line 2562

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2564
2565
2566
# File 'lib/models/porcelain.rb', line 2564

def name
  @name
end

#passwordObject

The password to authenticate with.



2566
2567
2568
# File 'lib/models/porcelain.rb', line 2566

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2568
2569
2570
# File 'lib/models/porcelain.rb', line 2568

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2570
2571
2572
# File 'lib/models/porcelain.rb', line 2570

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



2572
2573
2574
# File 'lib/models/porcelain.rb', line 2572

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2574
2575
2576
# File 'lib/models/porcelain.rb', line 2574

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2576
2577
2578
# File 'lib/models/porcelain.rb', line 2576

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2578
2579
2580
# File 'lib/models/porcelain.rb', line 2578

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



2580
2581
2582
# File 'lib/models/porcelain.rb', line 2580

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



2582
2583
2584
# File 'lib/models/porcelain.rb', line 2582

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2620
2621
2622
2623
2624
2625
2626
# File 'lib/models/porcelain.rb', line 2620

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end