Class: SDM::AzureMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzureMysql

Returns a new instance of AzureMysql.



2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
# File 'lib/models/porcelain.rb', line 2547

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2515
2516
2517
# File 'lib/models/porcelain.rb', line 2515

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



2517
2518
2519
# File 'lib/models/porcelain.rb', line 2517

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2519
2520
2521
# File 'lib/models/porcelain.rb', line 2519

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2521
2522
2523
# File 'lib/models/porcelain.rb', line 2521

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2523
2524
2525
# File 'lib/models/porcelain.rb', line 2523

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2525
2526
2527
# File 'lib/models/porcelain.rb', line 2525

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2527
2528
2529
# File 'lib/models/porcelain.rb', line 2527

def name
  @name
end

#passwordObject

The password to authenticate with.



2529
2530
2531
# File 'lib/models/porcelain.rb', line 2529

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2531
2532
2533
# File 'lib/models/porcelain.rb', line 2531

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2533
2534
2535
# File 'lib/models/porcelain.rb', line 2533

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



2535
2536
2537
# File 'lib/models/porcelain.rb', line 2535

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2537
2538
2539
# File 'lib/models/porcelain.rb', line 2537

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2539
2540
2541
# File 'lib/models/porcelain.rb', line 2539

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2541
2542
2543
# File 'lib/models/porcelain.rb', line 2541

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



2543
2544
2545
# File 'lib/models/porcelain.rb', line 2543

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



2545
2546
2547
# File 'lib/models/porcelain.rb', line 2545

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2583
2584
2585
2586
2587
2588
2589
# File 'lib/models/porcelain.rb', line 2583

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end