Class: SDM::AzureMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzureMysql

Returns a new instance of AzureMysql.



2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
# File 'lib/models/porcelain.rb', line 2255

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2223
2224
2225
# File 'lib/models/porcelain.rb', line 2223

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2225
2226
2227
# File 'lib/models/porcelain.rb', line 2225

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2227
2228
2229
# File 'lib/models/porcelain.rb', line 2227

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2229
2230
2231
# File 'lib/models/porcelain.rb', line 2229

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2231
2232
2233
# File 'lib/models/porcelain.rb', line 2231

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2233
2234
2235
# File 'lib/models/porcelain.rb', line 2233

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2235
2236
2237
# File 'lib/models/porcelain.rb', line 2235

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2237
2238
2239
# File 'lib/models/porcelain.rb', line 2237

def password
  @password
end

#portObject

Returns the value of attribute port.



2239
2240
2241
# File 'lib/models/porcelain.rb', line 2239

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2241
2242
2243
# File 'lib/models/porcelain.rb', line 2241

def port_override
  @port_override
end

#require_native_authObject

Returns the value of attribute require_native_auth.



2243
2244
2245
# File 'lib/models/porcelain.rb', line 2243

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2245
2246
2247
# File 'lib/models/porcelain.rb', line 2245

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2247
2248
2249
# File 'lib/models/porcelain.rb', line 2247

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2249
2250
2251
# File 'lib/models/porcelain.rb', line 2249

def tags
  @tags
end

#use_azure_single_server_usernamesObject

Returns the value of attribute use_azure_single_server_usernames.



2251
2252
2253
# File 'lib/models/porcelain.rb', line 2251

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

Returns the value of attribute username.



2253
2254
2255
# File 'lib/models/porcelain.rb', line 2253

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2291
2292
2293
2294
2295
2296
2297
# File 'lib/models/porcelain.rb', line 2291

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end