Class: SDM::AzureMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AzureMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AzureMysql

Returns a new instance of AzureMysql.



2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
# File 'lib/models/porcelain.rb', line 2027

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2001
2002
2003
# File 'lib/models/porcelain.rb', line 2001

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2003
2004
2005
# File 'lib/models/porcelain.rb', line 2003

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2005
2006
2007
# File 'lib/models/porcelain.rb', line 2005

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2007
2008
2009
# File 'lib/models/porcelain.rb', line 2007

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2009
2010
2011
# File 'lib/models/porcelain.rb', line 2009

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2011
2012
2013
# File 'lib/models/porcelain.rb', line 2011

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2013
2014
2015
# File 'lib/models/porcelain.rb', line 2013

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2015
2016
2017
# File 'lib/models/porcelain.rb', line 2015

def password
  @password
end

#portObject

Returns the value of attribute port.



2017
2018
2019
# File 'lib/models/porcelain.rb', line 2017

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2019
2020
2021
# File 'lib/models/porcelain.rb', line 2019

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2021
2022
2023
# File 'lib/models/porcelain.rb', line 2021

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2023
2024
2025
# File 'lib/models/porcelain.rb', line 2023

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2025
2026
2027
# File 'lib/models/porcelain.rb', line 2025

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2057
2058
2059
2060
2061
2062
2063
# File 'lib/models/porcelain.rb', line 2057

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end