Class: SDM::AzureMysql
- Inherits:
-
Object
- Object
- SDM::AzureMysql
- Defined in:
- lib/models/porcelain.rb
Overview
AzureMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AzureMysql
constructor
A new instance of AzureMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AzureMysql
Returns a new instance of AzureMysql.
1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/models/porcelain.rb', line 1689 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1663 1664 1665 |
# File 'lib/models/porcelain.rb', line 1663 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
1665 1666 1667 |
# File 'lib/models/porcelain.rb', line 1665 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1667 1668 1669 |
# File 'lib/models/porcelain.rb', line 1667 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1669 1670 1671 |
# File 'lib/models/porcelain.rb', line 1669 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
1671 1672 1673 |
# File 'lib/models/porcelain.rb', line 1671 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1673 1674 1675 |
# File 'lib/models/porcelain.rb', line 1673 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1675 1676 1677 |
# File 'lib/models/porcelain.rb', line 1675 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
1677 1678 1679 |
# File 'lib/models/porcelain.rb', line 1677 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
1679 1680 1681 |
# File 'lib/models/porcelain.rb', line 1679 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1681 1682 1683 |
# File 'lib/models/porcelain.rb', line 1681 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1683 1684 1685 |
# File 'lib/models/porcelain.rb', line 1683 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1685 1686 1687 |
# File 'lib/models/porcelain.rb', line 1685 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
1687 1688 1689 |
# File 'lib/models/porcelain.rb', line 1687 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1719 1720 1721 1722 1723 1724 1725 |
# File 'lib/models/porcelain.rb', line 1719 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |