Class: SDM::AzureMysqlManagedIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzureMysqlManagedIdentity



4660
4661
4662
4663
4664
4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
# File 'lib/models/porcelain.rb', line 4660

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4628
4629
4630
# File 'lib/models/porcelain.rb', line 4628

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



4630
4631
4632
# File 'lib/models/porcelain.rb', line 4630

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4632
4633
4634
# File 'lib/models/porcelain.rb', line 4632

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4634
4635
4636
# File 'lib/models/porcelain.rb', line 4634

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4636
4637
4638
# File 'lib/models/porcelain.rb', line 4636

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4638
4639
4640
# File 'lib/models/porcelain.rb', line 4638

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4640
4641
4642
# File 'lib/models/porcelain.rb', line 4640

def name
  @name
end

#passwordObject

The password to authenticate with.



4642
4643
4644
# File 'lib/models/porcelain.rb', line 4642

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4644
4645
4646
# File 'lib/models/porcelain.rb', line 4644

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4646
4647
4648
# File 'lib/models/porcelain.rb', line 4646

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4648
4649
4650
# File 'lib/models/porcelain.rb', line 4648

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4650
4651
4652
# File 'lib/models/porcelain.rb', line 4650

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4652
4653
4654
# File 'lib/models/porcelain.rb', line 4652

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4654
4655
4656
# File 'lib/models/porcelain.rb', line 4654

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4656
4657
4658
# File 'lib/models/porcelain.rb', line 4656

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4658
4659
4660
# File 'lib/models/porcelain.rb', line 4658

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4696
4697
4698
4699
4700
4701
4702
# File 'lib/models/porcelain.rb', line 4696

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end