Class: SDM::AzurePostgres
- Inherits:
-
Object
- Object
- SDM::AzurePostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres
constructor
A new instance of AzurePostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres
Returns a new instance of AzurePostgres.
3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 |
# File 'lib/models/porcelain.rb', line 3813 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3781 3782 3783 |
# File 'lib/models/porcelain.rb', line 3781 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
3783 3784 3785 |
# File 'lib/models/porcelain.rb', line 3783 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3785 3786 3787 |
# File 'lib/models/porcelain.rb', line 3785 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3787 3788 3789 |
# File 'lib/models/porcelain.rb', line 3787 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3789 3790 3791 |
# File 'lib/models/porcelain.rb', line 3789 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3791 3792 3793 |
# File 'lib/models/porcelain.rb', line 3791 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3793 3794 3795 |
# File 'lib/models/porcelain.rb', line 3793 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
3795 3796 3797 |
# File 'lib/models/porcelain.rb', line 3795 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
3797 3798 3799 |
# File 'lib/models/porcelain.rb', line 3797 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3799 3800 3801 |
# File 'lib/models/porcelain.rb', line 3799 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3801 3802 3803 |
# File 'lib/models/porcelain.rb', line 3801 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3803 3804 3805 |
# File 'lib/models/porcelain.rb', line 3803 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3805 3806 3807 |
# File 'lib/models/porcelain.rb', line 3805 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3807 3808 3809 |
# File 'lib/models/porcelain.rb', line 3807 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3809 3810 3811 |
# File 'lib/models/porcelain.rb', line 3809 def @tags end |
#username ⇒ Object
The username to authenticate with. For Azure Postgres, this also will include the hostname of the target server for Azure Single Server compatibility. For Flexible servers, use the normal Postgres type.
3811 3812 3813 |
# File 'lib/models/porcelain.rb', line 3811 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3849 3850 3851 3852 3853 3854 3855 |
# File 'lib/models/porcelain.rb', line 3849 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |