Class: SDM::AzurePostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres

Returns a new instance of AzurePostgres.



3630
3631
3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
3664
# File 'lib/models/porcelain.rb', line 3630

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3598
3599
3600
# File 'lib/models/porcelain.rb', line 3598

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3600
3601
3602
# File 'lib/models/porcelain.rb', line 3600

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3602
3603
3604
# File 'lib/models/porcelain.rb', line 3602

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3604
3605
3606
# File 'lib/models/porcelain.rb', line 3604

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3606
3607
3608
# File 'lib/models/porcelain.rb', line 3606

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3608
3609
3610
# File 'lib/models/porcelain.rb', line 3608

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3610
3611
3612
# File 'lib/models/porcelain.rb', line 3610

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



3612
3613
3614
# File 'lib/models/porcelain.rb', line 3612

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



3614
3615
3616
# File 'lib/models/porcelain.rb', line 3614

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3616
3617
3618
# File 'lib/models/porcelain.rb', line 3616

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3618
3619
3620
# File 'lib/models/porcelain.rb', line 3618

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3620
3621
3622
# File 'lib/models/porcelain.rb', line 3620

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3622
3623
3624
# File 'lib/models/porcelain.rb', line 3622

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3624
3625
3626
# File 'lib/models/porcelain.rb', line 3624

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3626
3627
3628
# File 'lib/models/porcelain.rb', line 3626

def tags
  @tags
end

#usernameObject

The username to authenticate with. For Azure Postgres, this also will include the hostname of the target server for Azure Single Server compatibility. For Flexible servers, use the normal Postgres type.



3628
3629
3630
# File 'lib/models/porcelain.rb', line 3628

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3666
3667
3668
3669
3670
3671
3672
# File 'lib/models/porcelain.rb', line 3666

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end