Class: SDM::AzurePostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres

Returns a new instance of AzurePostgres.



3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
# File 'lib/models/porcelain.rb', line 3308

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3278
3279
3280
# File 'lib/models/porcelain.rb', line 3278

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3280
3281
3282
# File 'lib/models/porcelain.rb', line 3280

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3282
3283
3284
# File 'lib/models/porcelain.rb', line 3282

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3284
3285
3286
# File 'lib/models/porcelain.rb', line 3284

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3286
3287
3288
# File 'lib/models/porcelain.rb', line 3286

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3288
3289
3290
# File 'lib/models/porcelain.rb', line 3288

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3290
3291
3292
# File 'lib/models/porcelain.rb', line 3290

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



3292
3293
3294
# File 'lib/models/porcelain.rb', line 3292

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



3294
3295
3296
# File 'lib/models/porcelain.rb', line 3294

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3296
3297
3298
# File 'lib/models/porcelain.rb', line 3296

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3298
3299
3300
# File 'lib/models/porcelain.rb', line 3298

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3300
3301
3302
# File 'lib/models/porcelain.rb', line 3300

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3302
3303
3304
# File 'lib/models/porcelain.rb', line 3302

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3304
3305
3306
# File 'lib/models/porcelain.rb', line 3304

def tags
  @tags
end

#usernameObject

The username to authenticate with. For Azure Postgres, this also will include the hostname of the target server for Azure Single Server compatibility. For Flexible servers, use the normal Postgres type.



3306
3307
3308
# File 'lib/models/porcelain.rb', line 3306

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3342
3343
3344
3345
3346
3347
3348
# File 'lib/models/porcelain.rb', line 3342

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end