Class: SDM::AzurePostgres
- Inherits:
-
Object
- Object
- SDM::AzurePostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres
constructor
A new instance of AzurePostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres
Returns a new instance of AzurePostgres.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 |
# File 'lib/models/porcelain.rb', line 2509 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2479 2480 2481 |
# File 'lib/models/porcelain.rb', line 2479 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
2481 2482 2483 |
# File 'lib/models/porcelain.rb', line 2481 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2483 2484 2485 |
# File 'lib/models/porcelain.rb', line 2483 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2485 2486 2487 |
# File 'lib/models/porcelain.rb', line 2485 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
2487 2488 2489 |
# File 'lib/models/porcelain.rb', line 2487 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2489 2490 2491 |
# File 'lib/models/porcelain.rb', line 2489 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2491 2492 2493 |
# File 'lib/models/porcelain.rb', line 2491 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
2493 2494 2495 |
# File 'lib/models/porcelain.rb', line 2493 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
2495 2496 2497 |
# File 'lib/models/porcelain.rb', line 2495 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
2497 2498 2499 |
# File 'lib/models/porcelain.rb', line 2497 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2499 2500 2501 |
# File 'lib/models/porcelain.rb', line 2499 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2501 2502 2503 |
# File 'lib/models/porcelain.rb', line 2501 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2503 2504 2505 |
# File 'lib/models/porcelain.rb', line 2503 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2505 2506 2507 |
# File 'lib/models/porcelain.rb', line 2505 def @tags end |
#username ⇒ Object
The username to authenticate with.
2507 2508 2509 |
# File 'lib/models/porcelain.rb', line 2507 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/models/porcelain.rb', line 2543 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |