Class: SDM::AzurePostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres

Returns a new instance of AzurePostgres.



2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
# File 'lib/models/porcelain.rb', line 2345

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2315
2316
2317
# File 'lib/models/porcelain.rb', line 2315

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2317
2318
2319
# File 'lib/models/porcelain.rb', line 2317

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2319
2320
2321
# File 'lib/models/porcelain.rb', line 2319

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2321
2322
2323
# File 'lib/models/porcelain.rb', line 2321

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2323
2324
2325
# File 'lib/models/porcelain.rb', line 2323

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2325
2326
2327
# File 'lib/models/porcelain.rb', line 2325

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2327
2328
2329
# File 'lib/models/porcelain.rb', line 2327

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



2329
2330
2331
# File 'lib/models/porcelain.rb', line 2329

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



2331
2332
2333
# File 'lib/models/porcelain.rb', line 2331

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2333
2334
2335
# File 'lib/models/porcelain.rb', line 2333

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2335
2336
2337
# File 'lib/models/porcelain.rb', line 2335

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2337
2338
2339
# File 'lib/models/porcelain.rb', line 2337

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2339
2340
2341
# File 'lib/models/porcelain.rb', line 2339

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2341
2342
2343
# File 'lib/models/porcelain.rb', line 2341

def tags
  @tags
end

#usernameObject

The username to authenticate with.



2343
2344
2345
# File 'lib/models/porcelain.rb', line 2343

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2379
2380
2381
2382
2383
2384
2385
# File 'lib/models/porcelain.rb', line 2379

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end