Class: SDM::AzurePostgres
- Inherits:
-
Object
- Object
- SDM::AzurePostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres
constructor
A new instance of AzurePostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ AzurePostgres
Returns a new instance of AzurePostgres.
2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 2347 2348 |
# File 'lib/models/porcelain.rb', line 2316 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2286 2287 2288 |
# File 'lib/models/porcelain.rb', line 2286 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
2288 2289 2290 |
# File 'lib/models/porcelain.rb', line 2288 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2290 2291 2292 |
# File 'lib/models/porcelain.rb', line 2290 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2292 2293 2294 |
# File 'lib/models/porcelain.rb', line 2292 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2294 2295 2296 |
# File 'lib/models/porcelain.rb', line 2294 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2296 2297 2298 |
# File 'lib/models/porcelain.rb', line 2296 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2298 2299 2300 |
# File 'lib/models/porcelain.rb', line 2298 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
2300 2301 2302 |
# File 'lib/models/porcelain.rb', line 2300 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
2302 2303 2304 |
# File 'lib/models/porcelain.rb', line 2302 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2304 2305 2306 |
# File 'lib/models/porcelain.rb', line 2304 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2306 2307 2308 |
# File 'lib/models/porcelain.rb', line 2306 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2308 2309 2310 |
# File 'lib/models/porcelain.rb', line 2308 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2310 2311 2312 |
# File 'lib/models/porcelain.rb', line 2310 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2312 2313 2314 |
# File 'lib/models/porcelain.rb', line 2312 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2314 2315 2316 |
# File 'lib/models/porcelain.rb', line 2314 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2350 2351 2352 2353 2354 2355 2356 |
# File 'lib/models/porcelain.rb', line 2350 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |