Class: SDM::AzurePostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AzurePostgres

Returns a new instance of AzurePostgres.



2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/models/porcelain.rb', line 2096

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2068
2069
2070
# File 'lib/models/porcelain.rb', line 2068

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2070
2071
2072
# File 'lib/models/porcelain.rb', line 2070

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2072
2073
2074
# File 'lib/models/porcelain.rb', line 2072

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2074
2075
2076
# File 'lib/models/porcelain.rb', line 2074

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2076
2077
2078
# File 'lib/models/porcelain.rb', line 2076

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2078
2079
2080
# File 'lib/models/porcelain.rb', line 2078

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2080
2081
2082
# File 'lib/models/porcelain.rb', line 2080

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



2082
2083
2084
# File 'lib/models/porcelain.rb', line 2082

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



2084
2085
2086
# File 'lib/models/porcelain.rb', line 2084

def password
  @password
end

#portObject

Returns the value of attribute port.



2086
2087
2088
# File 'lib/models/porcelain.rb', line 2086

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2088
2089
2090
# File 'lib/models/porcelain.rb', line 2088

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2090
2091
2092
# File 'lib/models/porcelain.rb', line 2090

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2092
2093
2094
# File 'lib/models/porcelain.rb', line 2092

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2094
2095
2096
# File 'lib/models/porcelain.rb', line 2094

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2128
2129
2130
2131
2132
2133
2134
# File 'lib/models/porcelain.rb', line 2128

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end