Class: SDM::AzurePostgres
- Inherits:
-
Object
- Object
- SDM::AzurePostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AzurePostgres
constructor
A new instance of AzurePostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ AzurePostgres
Returns a new instance of AzurePostgres.
1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/models/porcelain.rb', line 1758 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
1730 1731 1732 |
# File 'lib/models/porcelain.rb', line 1730 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
1732 1733 1734 |
# File 'lib/models/porcelain.rb', line 1732 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1734 1735 1736 |
# File 'lib/models/porcelain.rb', line 1734 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1736 1737 1738 |
# File 'lib/models/porcelain.rb', line 1736 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
1738 1739 1740 |
# File 'lib/models/porcelain.rb', line 1738 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1740 1741 1742 |
# File 'lib/models/porcelain.rb', line 1740 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1742 1743 1744 |
# File 'lib/models/porcelain.rb', line 1742 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
1744 1745 1746 |
# File 'lib/models/porcelain.rb', line 1744 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
1746 1747 1748 |
# File 'lib/models/porcelain.rb', line 1746 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
1748 1749 1750 |
# File 'lib/models/porcelain.rb', line 1748 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1750 1751 1752 |
# File 'lib/models/porcelain.rb', line 1750 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1752 1753 1754 |
# File 'lib/models/porcelain.rb', line 1752 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1754 1755 1756 |
# File 'lib/models/porcelain.rb', line 1754 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
1756 1757 1758 |
# File 'lib/models/porcelain.rb', line 1756 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1790 1791 1792 1793 1794 1795 1796 |
# File 'lib/models/porcelain.rb', line 1790 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |