Class: SDM::AzurePostgresManagedIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzurePostgresManagedIdentity

Returns a new instance of AzurePostgresManagedIdentity.



3366
3367
3368
3369
3370
3371
3372
3373
3374
3375
3376
3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
# File 'lib/models/porcelain.rb', line 3366

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3334
3335
3336
# File 'lib/models/porcelain.rb', line 3334

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3336
3337
3338
# File 'lib/models/porcelain.rb', line 3336

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3338
3339
3340
# File 'lib/models/porcelain.rb', line 3338

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3340
3341
3342
# File 'lib/models/porcelain.rb', line 3340

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3342
3343
3344
# File 'lib/models/porcelain.rb', line 3342

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3344
3345
3346
# File 'lib/models/porcelain.rb', line 3344

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3346
3347
3348
# File 'lib/models/porcelain.rb', line 3346

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



3348
3349
3350
# File 'lib/models/porcelain.rb', line 3348

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



3350
3351
3352
# File 'lib/models/porcelain.rb', line 3350

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3352
3353
3354
# File 'lib/models/porcelain.rb', line 3352

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3354
3355
3356
# File 'lib/models/porcelain.rb', line 3354

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3356
3357
3358
# File 'lib/models/porcelain.rb', line 3356

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3358
3359
3360
# File 'lib/models/porcelain.rb', line 3358

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3360
3361
3362
# File 'lib/models/porcelain.rb', line 3360

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



3362
3363
3364
# File 'lib/models/porcelain.rb', line 3362

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



3364
3365
3366
# File 'lib/models/porcelain.rb', line 3364

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3402
3403
3404
3405
3406
3407
3408
# File 'lib/models/porcelain.rb', line 3402

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end