Class: SDM::AzurePostgresManagedIdentity
- Inherits:
-
Object
- Object
- SDM::AzurePostgresManagedIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
AzurePostgresManagedIdentity is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzurePostgresManagedIdentity
constructor
A new instance of AzurePostgresManagedIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzurePostgresManagedIdentity
Returns a new instance of AzurePostgresManagedIdentity.
2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 |
# File 'lib/models/porcelain.rb', line 2587 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2555 2556 2557 |
# File 'lib/models/porcelain.rb', line 2555 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
2557 2558 2559 |
# File 'lib/models/porcelain.rb', line 2557 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2559 2560 2561 |
# File 'lib/models/porcelain.rb', line 2559 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2561 2562 2563 |
# File 'lib/models/porcelain.rb', line 2561 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
2563 2564 2565 |
# File 'lib/models/porcelain.rb', line 2563 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2565 2566 2567 |
# File 'lib/models/porcelain.rb', line 2565 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2567 2568 2569 |
# File 'lib/models/porcelain.rb', line 2567 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
2569 2570 2571 |
# File 'lib/models/porcelain.rb', line 2569 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
2571 2572 2573 |
# File 'lib/models/porcelain.rb', line 2571 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
2573 2574 2575 |
# File 'lib/models/porcelain.rb', line 2573 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2575 2576 2577 |
# File 'lib/models/porcelain.rb', line 2575 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2577 2578 2579 |
# File 'lib/models/porcelain.rb', line 2577 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2579 2580 2581 |
# File 'lib/models/porcelain.rb', line 2579 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2581 2582 2583 |
# File 'lib/models/porcelain.rb', line 2581 def @tags end |
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address
2583 2584 2585 |
# File 'lib/models/porcelain.rb', line 2583 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
The username to authenticate with.
2585 2586 2587 |
# File 'lib/models/porcelain.rb', line 2585 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2623 2624 2625 2626 2627 2628 2629 |
# File 'lib/models/porcelain.rb', line 2623 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |