Class: SDM::AzurePostgresManagedIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

AzurePostgresManagedIdentity is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ AzurePostgresManagedIdentity

Returns a new instance of AzurePostgresManagedIdentity.



2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
# File 'lib/models/porcelain.rb', line 2423

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2391
2392
2393
# File 'lib/models/porcelain.rb', line 2391

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2393
2394
2395
# File 'lib/models/porcelain.rb', line 2393

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2395
2396
2397
# File 'lib/models/porcelain.rb', line 2395

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2397
2398
2399
# File 'lib/models/porcelain.rb', line 2397

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2399
2400
2401
# File 'lib/models/porcelain.rb', line 2399

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2401
2402
2403
# File 'lib/models/porcelain.rb', line 2401

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2403
2404
2405
# File 'lib/models/porcelain.rb', line 2403

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



2405
2406
2407
# File 'lib/models/porcelain.rb', line 2405

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



2407
2408
2409
# File 'lib/models/porcelain.rb', line 2407

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2409
2410
2411
# File 'lib/models/porcelain.rb', line 2409

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2411
2412
2413
# File 'lib/models/porcelain.rb', line 2411

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2413
2414
2415
# File 'lib/models/porcelain.rb', line 2413

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2415
2416
2417
# File 'lib/models/porcelain.rb', line 2415

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2417
2418
2419
# File 'lib/models/porcelain.rb', line 2417

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



2419
2420
2421
# File 'lib/models/porcelain.rb', line 2419

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



2421
2422
2423
# File 'lib/models/porcelain.rb', line 2421

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2459
2460
2461
2462
2463
2464
2465
# File 'lib/models/porcelain.rb', line 2459

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end