Class: SDM::BigQuery
- Inherits:
-
Object
- Object
- SDM::BigQuery
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#private_key ⇒ Object
The JSON Private key to authenticate with.
-
#project ⇒ Object
The project to connect to.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
constructor
A new instance of BigQuery.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
Returns a new instance of BigQuery.
4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 |
# File 'lib/models/porcelain.rb', line 4390 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @project = project == nil ? "" : project @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4362 4363 4364 |
# File 'lib/models/porcelain.rb', line 4362 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4364 4365 4366 |
# File 'lib/models/porcelain.rb', line 4364 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
4366 4367 4368 |
# File 'lib/models/porcelain.rb', line 4366 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4368 4369 4370 |
# File 'lib/models/porcelain.rb', line 4368 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4370 4371 4372 |
# File 'lib/models/porcelain.rb', line 4370 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4372 4373 4374 |
# File 'lib/models/porcelain.rb', line 4372 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4374 4375 4376 |
# File 'lib/models/porcelain.rb', line 4374 def port_override @port_override end |
#private_key ⇒ Object
The JSON Private key to authenticate with.
4376 4377 4378 |
# File 'lib/models/porcelain.rb', line 4376 def private_key @private_key end |
#project ⇒ Object
The project to connect to.
4378 4379 4380 |
# File 'lib/models/porcelain.rb', line 4378 def project @project end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4380 4381 4382 |
# File 'lib/models/porcelain.rb', line 4380 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4382 4383 4384 |
# File 'lib/models/porcelain.rb', line 4382 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4384 4385 4386 |
# File 'lib/models/porcelain.rb', line 4384 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4386 4387 4388 |
# File 'lib/models/porcelain.rb', line 4386 def @tags end |
#username ⇒ Object
The username to authenticate with.
4388 4389 4390 |
# File 'lib/models/porcelain.rb', line 4388 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4422 4423 4424 4425 4426 4427 4428 |
# File 'lib/models/porcelain.rb', line 4422 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |