Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery

Returns a new instance of BigQuery.



4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
# File 'lib/models/porcelain.rb', line 4081

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4053
4054
4055
# File 'lib/models/porcelain.rb', line 4053

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4055
4056
4057
# File 'lib/models/porcelain.rb', line 4055

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



4057
4058
4059
# File 'lib/models/porcelain.rb', line 4057

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4059
4060
4061
# File 'lib/models/porcelain.rb', line 4059

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4061
4062
4063
# File 'lib/models/porcelain.rb', line 4061

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4063
4064
4065
# File 'lib/models/porcelain.rb', line 4063

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



4065
4066
4067
# File 'lib/models/porcelain.rb', line 4065

def port_override
  @port_override
end

#private_keyObject

The JSON Private key to authenticate with.



4067
4068
4069
# File 'lib/models/porcelain.rb', line 4067

def private_key
  @private_key
end

#projectObject

The project to connect to.



4069
4070
4071
# File 'lib/models/porcelain.rb', line 4069

def project
  @project
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4071
4072
4073
# File 'lib/models/porcelain.rb', line 4071

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4073
4074
4075
# File 'lib/models/porcelain.rb', line 4073

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4075
4076
4077
# File 'lib/models/porcelain.rb', line 4075

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4077
4078
4079
# File 'lib/models/porcelain.rb', line 4077

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4079
4080
4081
# File 'lib/models/porcelain.rb', line 4079

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4113
4114
4115
4116
4117
4118
4119
# File 'lib/models/porcelain.rb', line 4113

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end