Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery

Returns a new instance of BigQuery.



4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
# File 'lib/models/porcelain.rb', line 4002

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3974
3975
3976
# File 'lib/models/porcelain.rb', line 3974

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3976
3977
3978
# File 'lib/models/porcelain.rb', line 3976

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



3978
3979
3980
# File 'lib/models/porcelain.rb', line 3978

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3980
3981
3982
# File 'lib/models/porcelain.rb', line 3980

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3982
3983
3984
# File 'lib/models/porcelain.rb', line 3982

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3984
3985
3986
# File 'lib/models/porcelain.rb', line 3984

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



3986
3987
3988
# File 'lib/models/porcelain.rb', line 3986

def port_override
  @port_override
end

#private_keyObject

The JSON Private key to authenticate with.



3988
3989
3990
# File 'lib/models/porcelain.rb', line 3988

def private_key
  @private_key
end

#projectObject

The project to connect to.



3990
3991
3992
# File 'lib/models/porcelain.rb', line 3990

def project
  @project
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3992
3993
3994
# File 'lib/models/porcelain.rb', line 3992

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3994
3995
3996
# File 'lib/models/porcelain.rb', line 3994

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3996
3997
3998
# File 'lib/models/porcelain.rb', line 3996

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3998
3999
4000
# File 'lib/models/porcelain.rb', line 3998

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4000
4001
4002
# File 'lib/models/porcelain.rb', line 4000

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4034
4035
4036
4037
4038
4039
4040
# File 'lib/models/porcelain.rb', line 4034

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end