Class: SDM::BigQuery
- Inherits:
-
Object
- Object
- SDM::BigQuery
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#private_key ⇒ Object
The JSON Private key to authenticate with.
-
#project ⇒ Object
The project to connect to.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
constructor
A new instance of BigQuery.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
Returns a new instance of BigQuery.
3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 |
# File 'lib/models/porcelain.rb', line 3897 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @project = project == nil ? "" : project @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3869 3870 3871 |
# File 'lib/models/porcelain.rb', line 3869 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3871 3872 3873 |
# File 'lib/models/porcelain.rb', line 3871 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
3873 3874 3875 |
# File 'lib/models/porcelain.rb', line 3873 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3875 3876 3877 |
# File 'lib/models/porcelain.rb', line 3875 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3877 3878 3879 |
# File 'lib/models/porcelain.rb', line 3877 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3879 3880 3881 |
# File 'lib/models/porcelain.rb', line 3879 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3881 3882 3883 |
# File 'lib/models/porcelain.rb', line 3881 def port_override @port_override end |
#private_key ⇒ Object
The JSON Private key to authenticate with.
3883 3884 3885 |
# File 'lib/models/porcelain.rb', line 3883 def private_key @private_key end |
#project ⇒ Object
The project to connect to.
3885 3886 3887 |
# File 'lib/models/porcelain.rb', line 3885 def project @project end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
3887 3888 3889 |
# File 'lib/models/porcelain.rb', line 3887 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3889 3890 3891 |
# File 'lib/models/porcelain.rb', line 3889 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3891 3892 3893 |
# File 'lib/models/porcelain.rb', line 3891 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3893 3894 3895 |
# File 'lib/models/porcelain.rb', line 3893 def @tags end |
#username ⇒ Object
The username to authenticate with.
3895 3896 3897 |
# File 'lib/models/porcelain.rb', line 3895 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/models/porcelain.rb', line 3929 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |