Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery

Returns a new instance of BigQuery.



3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
# File 'lib/models/porcelain.rb', line 3819

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3791
3792
3793
# File 'lib/models/porcelain.rb', line 3791

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3793
3794
3795
# File 'lib/models/porcelain.rb', line 3793

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



3795
3796
3797
# File 'lib/models/porcelain.rb', line 3795

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3797
3798
3799
# File 'lib/models/porcelain.rb', line 3797

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3799
3800
3801
# File 'lib/models/porcelain.rb', line 3799

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3801
3802
3803
# File 'lib/models/porcelain.rb', line 3801

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



3803
3804
3805
# File 'lib/models/porcelain.rb', line 3803

def port_override
  @port_override
end

#private_keyObject

The JSON Private key to authenticate with.



3805
3806
3807
# File 'lib/models/porcelain.rb', line 3805

def private_key
  @private_key
end

#projectObject

The project to connect to.



3807
3808
3809
# File 'lib/models/porcelain.rb', line 3807

def project
  @project
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3809
3810
3811
# File 'lib/models/porcelain.rb', line 3809

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3811
3812
3813
# File 'lib/models/porcelain.rb', line 3811

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3813
3814
3815
# File 'lib/models/porcelain.rb', line 3813

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3815
3816
3817
# File 'lib/models/porcelain.rb', line 3815

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3817
3818
3819
# File 'lib/models/porcelain.rb', line 3817

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3851
3852
3853
3854
3855
3856
3857
# File 'lib/models/porcelain.rb', line 3851

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end