Class: SDM::BigQuery
- Inherits:
-
Object
- Object
- SDM::BigQuery
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#private_key ⇒ Object
The JSON Private key to authenticate with.
-
#project ⇒ Object
The project to connect to.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
constructor
A new instance of BigQuery.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
Returns a new instance of BigQuery.
3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 |
# File 'lib/models/porcelain.rb', line 3489 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @project = project == nil ? "" : project @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3463 3464 3465 |
# File 'lib/models/porcelain.rb', line 3463 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3465 3466 3467 |
# File 'lib/models/porcelain.rb', line 3465 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
3467 3468 3469 |
# File 'lib/models/porcelain.rb', line 3467 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3469 3470 3471 |
# File 'lib/models/porcelain.rb', line 3469 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3471 3472 3473 |
# File 'lib/models/porcelain.rb', line 3471 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3473 3474 3475 |
# File 'lib/models/porcelain.rb', line 3473 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3475 3476 3477 |
# File 'lib/models/porcelain.rb', line 3475 def port_override @port_override end |
#private_key ⇒ Object
The JSON Private key to authenticate with.
3477 3478 3479 |
# File 'lib/models/porcelain.rb', line 3477 def private_key @private_key end |
#project ⇒ Object
The project to connect to.
3479 3480 3481 |
# File 'lib/models/porcelain.rb', line 3479 def project @project end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3481 3482 3483 |
# File 'lib/models/porcelain.rb', line 3481 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3483 3484 3485 |
# File 'lib/models/porcelain.rb', line 3483 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3485 3486 3487 |
# File 'lib/models/porcelain.rb', line 3485 def @tags end |
#username ⇒ Object
The username to authenticate with.
3487 3488 3489 |
# File 'lib/models/porcelain.rb', line 3487 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3519 3520 3521 3522 3523 3524 3525 |
# File 'lib/models/porcelain.rb', line 3519 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |