Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery

Returns a new instance of BigQuery.



2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/models/porcelain.rb', line 2842

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2816
2817
2818
# File 'lib/models/porcelain.rb', line 2816

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2818
2819
2820
# File 'lib/models/porcelain.rb', line 2818

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



2820
2821
2822
# File 'lib/models/porcelain.rb', line 2820

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2822
2823
2824
# File 'lib/models/porcelain.rb', line 2822

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2824
2825
2826
# File 'lib/models/porcelain.rb', line 2824

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2826
2827
2828
# File 'lib/models/porcelain.rb', line 2826

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



2828
2829
2830
# File 'lib/models/porcelain.rb', line 2828

def port_override
  @port_override
end

#private_keyObject

The JSON Private key to authenticate with.



2830
2831
2832
# File 'lib/models/porcelain.rb', line 2830

def private_key
  @private_key
end

#projectObject

The project to connect to.



2832
2833
2834
# File 'lib/models/porcelain.rb', line 2832

def project
  @project
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2834
2835
2836
# File 'lib/models/porcelain.rb', line 2834

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2836
2837
2838
# File 'lib/models/porcelain.rb', line 2836

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2838
2839
2840
# File 'lib/models/porcelain.rb', line 2838

def tags
  @tags
end

#usernameObject

The username to authenticate with.



2840
2841
2842
# File 'lib/models/porcelain.rb', line 2840

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2872
2873
2874
2875
2876
2877
2878
# File 'lib/models/porcelain.rb', line 2872

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end