Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery

Returns a new instance of BigQuery.



2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
# File 'lib/models/porcelain.rb', line 2730

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2704
2705
2706
# File 'lib/models/porcelain.rb', line 2704

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2706
2707
2708
# File 'lib/models/porcelain.rb', line 2706

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



2708
2709
2710
# File 'lib/models/porcelain.rb', line 2708

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2710
2711
2712
# File 'lib/models/porcelain.rb', line 2710

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2712
2713
2714
# File 'lib/models/porcelain.rb', line 2712

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2714
2715
2716
# File 'lib/models/porcelain.rb', line 2714

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



2716
2717
2718
# File 'lib/models/porcelain.rb', line 2716

def port_override
  @port_override
end

#private_keyObject

The JSON Private key to authenticate with.



2718
2719
2720
# File 'lib/models/porcelain.rb', line 2718

def private_key
  @private_key
end

#projectObject

The project to connect to.



2720
2721
2722
# File 'lib/models/porcelain.rb', line 2720

def project
  @project
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2722
2723
2724
# File 'lib/models/porcelain.rb', line 2722

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2724
2725
2726
# File 'lib/models/porcelain.rb', line 2724

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2726
2727
2728
# File 'lib/models/porcelain.rb', line 2726

def tags
  @tags
end

#usernameObject

The username to authenticate with.



2728
2729
2730
# File 'lib/models/porcelain.rb', line 2728

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2760
2761
2762
2763
2764
2765
2766
# File 'lib/models/porcelain.rb', line 2760

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end