Class: SDM::BigQuery
- Inherits:
-
Object
- Object
- SDM::BigQuery
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#private_key ⇒ Object
The JSON Private key to authenticate with.
-
#project ⇒ Object
The project to connect to.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
constructor
A new instance of BigQuery.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
Returns a new instance of BigQuery.
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 |
# File 'lib/models/porcelain.rb', line 2691 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @project = project == nil ? "" : project @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2665 2666 2667 |
# File 'lib/models/porcelain.rb', line 2665 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2667 2668 2669 |
# File 'lib/models/porcelain.rb', line 2667 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
2669 2670 2671 |
# File 'lib/models/porcelain.rb', line 2669 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2671 2672 2673 |
# File 'lib/models/porcelain.rb', line 2671 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2673 2674 2675 |
# File 'lib/models/porcelain.rb', line 2673 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2675 2676 2677 |
# File 'lib/models/porcelain.rb', line 2675 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2677 2678 2679 |
# File 'lib/models/porcelain.rb', line 2677 def port_override @port_override end |
#private_key ⇒ Object
The JSON Private key to authenticate with.
2679 2680 2681 |
# File 'lib/models/porcelain.rb', line 2679 def private_key @private_key end |
#project ⇒ Object
The project to connect to.
2681 2682 2683 |
# File 'lib/models/porcelain.rb', line 2681 def project @project end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2683 2684 2685 |
# File 'lib/models/porcelain.rb', line 2683 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2685 2686 2687 |
# File 'lib/models/porcelain.rb', line 2685 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2687 2688 2689 |
# File 'lib/models/porcelain.rb', line 2687 def @tags end |
#username ⇒ Object
The username to authenticate with.
2689 2690 2691 |
# File 'lib/models/porcelain.rb', line 2689 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2721 2722 2723 2724 2725 2726 2727 |
# File 'lib/models/porcelain.rb', line 2721 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |