Class: SDM::BigQuery
- Inherits:
-
Object
- Object
- SDM::BigQuery
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#private_key ⇒ Object
The JSON Private key to authenticate with.
-
#project ⇒ Object
The project to connect to.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
constructor
A new instance of BigQuery.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
Returns a new instance of BigQuery.
2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 |
# File 'lib/models/porcelain.rb', line 2527 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @project = project == nil ? "" : project @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2501 2502 2503 |
# File 'lib/models/porcelain.rb', line 2501 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2503 2504 2505 |
# File 'lib/models/porcelain.rb', line 2503 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
2505 2506 2507 |
# File 'lib/models/porcelain.rb', line 2505 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2507 2508 2509 |
# File 'lib/models/porcelain.rb', line 2507 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2509 2510 2511 |
# File 'lib/models/porcelain.rb', line 2509 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2511 2512 2513 |
# File 'lib/models/porcelain.rb', line 2511 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2513 2514 2515 |
# File 'lib/models/porcelain.rb', line 2513 def port_override @port_override end |
#private_key ⇒ Object
The JSON Private key to authenticate with.
2515 2516 2517 |
# File 'lib/models/porcelain.rb', line 2515 def private_key @private_key end |
#project ⇒ Object
The project to connect to.
2517 2518 2519 |
# File 'lib/models/porcelain.rb', line 2517 def project @project end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2519 2520 2521 |
# File 'lib/models/porcelain.rb', line 2519 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2521 2522 2523 |
# File 'lib/models/porcelain.rb', line 2521 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2523 2524 2525 |
# File 'lib/models/porcelain.rb', line 2523 def @tags end |
#username ⇒ Object
The username to authenticate with.
2525 2526 2527 |
# File 'lib/models/porcelain.rb', line 2525 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/models/porcelain.rb', line 2557 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |