Class: SDM::BigQuery
- Inherits:
-
Object
- Object
- SDM::BigQuery
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#private_key ⇒ Object
Returns the value of attribute private_key.
-
#project ⇒ Object
Returns the value of attribute project.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
constructor
A new instance of BigQuery.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery
Returns a new instance of BigQuery.
2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/models/porcelain.rb', line 2434 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @private_key = private_key == nil ? "" : private_key @project = project == nil ? "" : project @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2408 2409 2410 |
# File 'lib/models/porcelain.rb', line 2408 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2410 2411 2412 |
# File 'lib/models/porcelain.rb', line 2410 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
2412 2413 2414 |
# File 'lib/models/porcelain.rb', line 2412 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2414 2415 2416 |
# File 'lib/models/porcelain.rb', line 2414 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2416 2417 2418 |
# File 'lib/models/porcelain.rb', line 2416 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2418 2419 2420 |
# File 'lib/models/porcelain.rb', line 2418 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2420 2421 2422 |
# File 'lib/models/porcelain.rb', line 2420 def port_override @port_override end |
#private_key ⇒ Object
Returns the value of attribute private_key.
2422 2423 2424 |
# File 'lib/models/porcelain.rb', line 2422 def private_key @private_key end |
#project ⇒ Object
Returns the value of attribute project.
2424 2425 2426 |
# File 'lib/models/porcelain.rb', line 2424 def project @project end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2426 2427 2428 |
# File 'lib/models/porcelain.rb', line 2426 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2428 2429 2430 |
# File 'lib/models/porcelain.rb', line 2428 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2430 2431 2432 |
# File 'lib/models/porcelain.rb', line 2430 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2432 2433 2434 |
# File 'lib/models/porcelain.rb', line 2432 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2464 2465 2466 2467 2468 2469 2470 |
# File 'lib/models/porcelain.rb', line 2464 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |