Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ BigQuery

Returns a new instance of BigQuery.



2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
# File 'lib/models/porcelain.rb', line 2418

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2392
2393
2394
# File 'lib/models/porcelain.rb', line 2392

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2394
2395
2396
# File 'lib/models/porcelain.rb', line 2394

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



2396
2397
2398
# File 'lib/models/porcelain.rb', line 2396

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2398
2399
2400
# File 'lib/models/porcelain.rb', line 2398

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2400
2401
2402
# File 'lib/models/porcelain.rb', line 2400

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2402
2403
2404
# File 'lib/models/porcelain.rb', line 2402

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



2404
2405
2406
# File 'lib/models/porcelain.rb', line 2404

def port_override
  @port_override
end

#private_keyObject

Returns the value of attribute private_key.



2406
2407
2408
# File 'lib/models/porcelain.rb', line 2406

def private_key
  @private_key
end

#projectObject

Returns the value of attribute project.



2408
2409
2410
# File 'lib/models/porcelain.rb', line 2408

def project
  @project
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2410
2411
2412
# File 'lib/models/porcelain.rb', line 2410

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2412
2413
2414
# File 'lib/models/porcelain.rb', line 2412

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2414
2415
2416
# File 'lib/models/porcelain.rb', line 2414

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2416
2417
2418
# File 'lib/models/porcelain.rb', line 2416

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2448
2449
2450
2451
2452
2453
2454
# File 'lib/models/porcelain.rb', line 2448

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end