Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ BigQuery

Returns a new instance of BigQuery.



2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
# File 'lib/models/porcelain.rb', line 2194

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2170
2171
2172
# File 'lib/models/porcelain.rb', line 2170

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2172
2173
2174
# File 'lib/models/porcelain.rb', line 2172

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



2174
2175
2176
# File 'lib/models/porcelain.rb', line 2174

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2176
2177
2178
# File 'lib/models/porcelain.rb', line 2176

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2178
2179
2180
# File 'lib/models/porcelain.rb', line 2178

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2180
2181
2182
# File 'lib/models/porcelain.rb', line 2180

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



2182
2183
2184
# File 'lib/models/porcelain.rb', line 2182

def port_override
  @port_override
end

#private_keyObject

Returns the value of attribute private_key.



2184
2185
2186
# File 'lib/models/porcelain.rb', line 2184

def private_key
  @private_key
end

#projectObject

Returns the value of attribute project.



2186
2187
2188
# File 'lib/models/porcelain.rb', line 2186

def project
  @project
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2188
2189
2190
# File 'lib/models/porcelain.rb', line 2188

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2190
2191
2192
# File 'lib/models/porcelain.rb', line 2190

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2192
2193
2194
# File 'lib/models/porcelain.rb', line 2192

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2222
2223
2224
2225
2226
2227
2228
# File 'lib/models/porcelain.rb', line 2222

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end