Class: SDM::BigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ BigQuery

Returns a new instance of BigQuery.



1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/models/porcelain.rb', line 1856

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  private_key: nil,
  project: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @private_key = private_key == nil ? "" : private_key
  @project = project == nil ? "" : project
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



1832
1833
1834
# File 'lib/models/porcelain.rb', line 1832

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1834
1835
1836
# File 'lib/models/porcelain.rb', line 1834

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



1836
1837
1838
# File 'lib/models/porcelain.rb', line 1836

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1838
1839
1840
# File 'lib/models/porcelain.rb', line 1838

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



1840
1841
1842
# File 'lib/models/porcelain.rb', line 1840

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1842
1843
1844
# File 'lib/models/porcelain.rb', line 1842

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



1844
1845
1846
# File 'lib/models/porcelain.rb', line 1844

def port_override
  @port_override
end

#private_keyObject

Returns the value of attribute private_key.



1846
1847
1848
# File 'lib/models/porcelain.rb', line 1846

def private_key
  @private_key
end

#projectObject

Returns the value of attribute project.



1848
1849
1850
# File 'lib/models/porcelain.rb', line 1848

def project
  @project
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1850
1851
1852
# File 'lib/models/porcelain.rb', line 1850

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1852
1853
1854
# File 'lib/models/porcelain.rb', line 1852

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



1854
1855
1856
# File 'lib/models/porcelain.rb', line 1854

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1884
1885
1886
1887
1888
1889
1890
# File 'lib/models/porcelain.rb', line 1884

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end