Class: SDM::BigQuery
- Inherits:
-
Object
- Object
- SDM::BigQuery
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#private_key ⇒ Object
Returns the value of attribute private_key.
-
#project ⇒ Object
Returns the value of attribute project.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ BigQuery
constructor
A new instance of BigQuery.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ BigQuery
Returns a new instance of BigQuery.
1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 |
# File 'lib/models/porcelain.rb', line 1901 def initialize( egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, private_key: nil, project: nil, secret_store_id: nil, tags: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if endpoint != nil @endpoint = endpoint end if healthy != nil @healthy = healthy end if id != nil @id = id end if name != nil @name = name end if port_override != nil @port_override = port_override end if private_key != nil @private_key = private_key end if project != nil @project = project end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1879 1880 1881 |
# File 'lib/models/porcelain.rb', line 1879 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
1881 1882 1883 |
# File 'lib/models/porcelain.rb', line 1881 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1883 1884 1885 |
# File 'lib/models/porcelain.rb', line 1883 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
1885 1886 1887 |
# File 'lib/models/porcelain.rb', line 1885 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1887 1888 1889 |
# File 'lib/models/porcelain.rb', line 1887 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1889 1890 1891 |
# File 'lib/models/porcelain.rb', line 1889 def port_override @port_override end |
#private_key ⇒ Object
Returns the value of attribute private_key.
1891 1892 1893 |
# File 'lib/models/porcelain.rb', line 1891 def private_key @private_key end |
#project ⇒ Object
Returns the value of attribute project.
1893 1894 1895 |
# File 'lib/models/porcelain.rb', line 1893 def project @project end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1895 1896 1897 |
# File 'lib/models/porcelain.rb', line 1895 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1897 1898 1899 |
# File 'lib/models/porcelain.rb', line 1897 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
1899 1900 1901 |
# File 'lib/models/porcelain.rb', line 1899 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
1949 1950 1951 1952 1953 1954 1955 |
# File 'lib/models/porcelain.rb', line 1949 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |