Class: SDM::Cassandra
- Inherits:
-
Object
- Object
- SDM::Cassandra
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra
constructor
A new instance of Cassandra.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra
Returns a new instance of Cassandra.
5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 |
# File 'lib/models/porcelain.rb', line 5001 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
4971 4972 4973 |
# File 'lib/models/porcelain.rb', line 4971 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4973 4974 4975 |
# File 'lib/models/porcelain.rb', line 4973 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4975 4976 4977 |
# File 'lib/models/porcelain.rb', line 4975 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4977 4978 4979 |
# File 'lib/models/porcelain.rb', line 4977 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4979 4980 4981 |
# File 'lib/models/porcelain.rb', line 4979 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4981 4982 4983 |
# File 'lib/models/porcelain.rb', line 4981 def name @name end |
#password ⇒ Object
The password to authenticate with.
4983 4984 4985 |
# File 'lib/models/porcelain.rb', line 4983 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4985 4986 4987 |
# File 'lib/models/porcelain.rb', line 4985 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
4987 4988 4989 |
# File 'lib/models/porcelain.rb', line 4987 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4989 4990 4991 |
# File 'lib/models/porcelain.rb', line 4989 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4991 4992 4993 |
# File 'lib/models/porcelain.rb', line 4991 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
4993 4994 4995 |
# File 'lib/models/porcelain.rb', line 4993 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4995 4996 4997 |
# File 'lib/models/porcelain.rb', line 4995 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4997 4998 4999 |
# File 'lib/models/porcelain.rb', line 4997 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4999 5000 5001 |
# File 'lib/models/porcelain.rb', line 4999 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5035 5036 5037 5038 5039 5040 5041 |
# File 'lib/models/porcelain.rb', line 5035 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |