Class: SDM::Cassandra

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra

Returns a new instance of Cassandra.



3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
# File 'lib/models/porcelain.rb', line 3971

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3941
3942
3943
# File 'lib/models/porcelain.rb', line 3941

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3943
3944
3945
# File 'lib/models/porcelain.rb', line 3943

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3945
3946
3947
# File 'lib/models/porcelain.rb', line 3945

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3947
3948
3949
# File 'lib/models/porcelain.rb', line 3947

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3949
3950
3951
# File 'lib/models/porcelain.rb', line 3949

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3951
3952
3953
# File 'lib/models/porcelain.rb', line 3951

def name
  @name
end

#passwordObject

The password to authenticate with.



3953
3954
3955
# File 'lib/models/porcelain.rb', line 3953

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3955
3956
3957
# File 'lib/models/porcelain.rb', line 3955

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3957
3958
3959
# File 'lib/models/porcelain.rb', line 3957

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3959
3960
3961
# File 'lib/models/porcelain.rb', line 3959

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3961
3962
3963
# File 'lib/models/porcelain.rb', line 3961

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3963
3964
3965
# File 'lib/models/porcelain.rb', line 3963

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3965
3966
3967
# File 'lib/models/porcelain.rb', line 3965

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



3967
3968
3969
# File 'lib/models/porcelain.rb', line 3967

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



3969
3970
3971
# File 'lib/models/porcelain.rb', line 3969

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4005
4006
4007
4008
4009
4010
4011
# File 'lib/models/porcelain.rb', line 4005

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end