Class: SDM::Cassandra

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra

Returns a new instance of Cassandra.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
# File 'lib/models/porcelain.rb', line 3972

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3942
3943
3944
# File 'lib/models/porcelain.rb', line 3942

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3944
3945
3946
# File 'lib/models/porcelain.rb', line 3944

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3946
3947
3948
# File 'lib/models/porcelain.rb', line 3946

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3948
3949
3950
# File 'lib/models/porcelain.rb', line 3948

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3950
3951
3952
# File 'lib/models/porcelain.rb', line 3950

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3952
3953
3954
# File 'lib/models/porcelain.rb', line 3952

def name
  @name
end

#passwordObject

The password to authenticate with.



3954
3955
3956
# File 'lib/models/porcelain.rb', line 3954

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3956
3957
3958
# File 'lib/models/porcelain.rb', line 3956

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3958
3959
3960
# File 'lib/models/porcelain.rb', line 3958

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



3960
3961
3962
# File 'lib/models/porcelain.rb', line 3960

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3962
3963
3964
# File 'lib/models/porcelain.rb', line 3962

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3964
3965
3966
# File 'lib/models/porcelain.rb', line 3964

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3966
3967
3968
# File 'lib/models/porcelain.rb', line 3966

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



3968
3969
3970
# File 'lib/models/porcelain.rb', line 3968

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



3970
3971
3972
# File 'lib/models/porcelain.rb', line 3970

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4006
4007
4008
4009
4010
4011
4012
# File 'lib/models/porcelain.rb', line 4006

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end