Class: SDM::Cassandra
- Inherits:
-
Object
- Object
- SDM::Cassandra
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra
constructor
A new instance of Cassandra.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra
Returns a new instance of Cassandra.
2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 |
# File 'lib/models/porcelain.rb', line 2596 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2568 2569 2570 |
# File 'lib/models/porcelain.rb', line 2568 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2570 2571 2572 |
# File 'lib/models/porcelain.rb', line 2570 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2572 2573 2574 |
# File 'lib/models/porcelain.rb', line 2572 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
2574 2575 2576 |
# File 'lib/models/porcelain.rb', line 2574 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2576 2577 2578 |
# File 'lib/models/porcelain.rb', line 2576 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2578 2579 2580 |
# File 'lib/models/porcelain.rb', line 2578 def name @name end |
#password ⇒ Object
The password to authenticate with.
2580 2581 2582 |
# File 'lib/models/porcelain.rb', line 2580 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
2582 2583 2584 |
# File 'lib/models/porcelain.rb', line 2582 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2584 2585 2586 |
# File 'lib/models/porcelain.rb', line 2584 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2586 2587 2588 |
# File 'lib/models/porcelain.rb', line 2586 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2588 2589 2590 |
# File 'lib/models/porcelain.rb', line 2588 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2590 2591 2592 |
# File 'lib/models/porcelain.rb', line 2590 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
2592 2593 2594 |
# File 'lib/models/porcelain.rb', line 2592 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
2594 2595 2596 |
# File 'lib/models/porcelain.rb', line 2594 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2628 2629 2630 2631 2632 2633 2634 |
# File 'lib/models/porcelain.rb', line 2628 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |