Class: SDM::Cassandra
- Inherits:
-
Object
- Object
- SDM::Cassandra
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra
constructor
A new instance of Cassandra.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra
Returns a new instance of Cassandra.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/models/porcelain.rb', line 2503 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2475 2476 2477 |
# File 'lib/models/porcelain.rb', line 2475 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2477 2478 2479 |
# File 'lib/models/porcelain.rb', line 2477 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2479 2480 2481 |
# File 'lib/models/porcelain.rb', line 2479 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2481 2482 2483 |
# File 'lib/models/porcelain.rb', line 2481 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2483 2484 2485 |
# File 'lib/models/porcelain.rb', line 2483 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2485 2486 2487 |
# File 'lib/models/porcelain.rb', line 2485 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2487 2488 2489 |
# File 'lib/models/porcelain.rb', line 2487 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2489 2490 2491 |
# File 'lib/models/porcelain.rb', line 2489 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2491 2492 2493 |
# File 'lib/models/porcelain.rb', line 2491 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2493 2494 2495 |
# File 'lib/models/porcelain.rb', line 2493 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2495 2496 2497 |
# File 'lib/models/porcelain.rb', line 2495 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2497 2498 2499 |
# File 'lib/models/porcelain.rb', line 2497 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
2499 2500 2501 |
# File 'lib/models/porcelain.rb', line 2499 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
2501 2502 2503 |
# File 'lib/models/porcelain.rb', line 2501 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2535 2536 2537 2538 2539 2540 2541 |
# File 'lib/models/porcelain.rb', line 2535 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |