Class: SDM::Cassandra

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra

Returns a new instance of Cassandra.



2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
# File 'lib/models/porcelain.rb', line 2259

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2233
2234
2235
# File 'lib/models/porcelain.rb', line 2233

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2235
2236
2237
# File 'lib/models/porcelain.rb', line 2235

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2237
2238
2239
# File 'lib/models/porcelain.rb', line 2237

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2239
2240
2241
# File 'lib/models/porcelain.rb', line 2239

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2241
2242
2243
# File 'lib/models/porcelain.rb', line 2241

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2243
2244
2245
# File 'lib/models/porcelain.rb', line 2243

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2245
2246
2247
# File 'lib/models/porcelain.rb', line 2245

def password
  @password
end

#portObject

Returns the value of attribute port.



2247
2248
2249
# File 'lib/models/porcelain.rb', line 2247

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2249
2250
2251
# File 'lib/models/porcelain.rb', line 2249

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2251
2252
2253
# File 'lib/models/porcelain.rb', line 2251

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2253
2254
2255
# File 'lib/models/porcelain.rb', line 2253

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



2255
2256
2257
# File 'lib/models/porcelain.rb', line 2255

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



2257
2258
2259
# File 'lib/models/porcelain.rb', line 2257

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2289
2290
2291
2292
2293
2294
2295
# File 'lib/models/porcelain.rb', line 2289

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end