Class: SDM::Cassandra

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra

Returns a new instance of Cassandra.



1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/models/porcelain.rb', line 1921

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



1895
1896
1897
# File 'lib/models/porcelain.rb', line 1895

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1897
1898
1899
# File 'lib/models/porcelain.rb', line 1897

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1899
1900
1901
# File 'lib/models/porcelain.rb', line 1899

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



1901
1902
1903
# File 'lib/models/porcelain.rb', line 1901

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1903
1904
1905
# File 'lib/models/porcelain.rb', line 1903

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1905
1906
1907
# File 'lib/models/porcelain.rb', line 1905

def name
  @name
end

#passwordObject

Returns the value of attribute password.



1907
1908
1909
# File 'lib/models/porcelain.rb', line 1907

def password
  @password
end

#portObject

Returns the value of attribute port.



1909
1910
1911
# File 'lib/models/porcelain.rb', line 1909

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



1911
1912
1913
# File 'lib/models/porcelain.rb', line 1911

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1913
1914
1915
# File 'lib/models/porcelain.rb', line 1913

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1915
1916
1917
# File 'lib/models/porcelain.rb', line 1915

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



1917
1918
1919
# File 'lib/models/porcelain.rb', line 1917

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



1919
1920
1921
# File 'lib/models/porcelain.rb', line 1919

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1951
1952
1953
1954
1955
1956
1957
# File 'lib/models/porcelain.rb', line 1951

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end