Class: SDM::Cassandra
- Inherits:
-
Object
- Object
- SDM::Cassandra
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra
constructor
A new instance of Cassandra.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra
Returns a new instance of Cassandra.
1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 |
# File 'lib/models/porcelain.rb', line 1984 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
1960 1961 1962 |
# File 'lib/models/porcelain.rb', line 1960 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
1962 1963 1964 |
# File 'lib/models/porcelain.rb', line 1962 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
1964 1965 1966 |
# File 'lib/models/porcelain.rb', line 1964 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
1966 1967 1968 |
# File 'lib/models/porcelain.rb', line 1966 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
1968 1969 1970 |
# File 'lib/models/porcelain.rb', line 1968 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
1970 1971 1972 |
# File 'lib/models/porcelain.rb', line 1970 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
1972 1973 1974 |
# File 'lib/models/porcelain.rb', line 1972 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
1974 1975 1976 |
# File 'lib/models/porcelain.rb', line 1974 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
1976 1977 1978 |
# File 'lib/models/porcelain.rb', line 1976 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
1978 1979 1980 |
# File 'lib/models/porcelain.rb', line 1978 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
1980 1981 1982 |
# File 'lib/models/porcelain.rb', line 1980 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
1982 1983 1984 |
# File 'lib/models/porcelain.rb', line 1982 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2036 2037 2038 2039 2040 2041 2042 |
# File 'lib/models/porcelain.rb', line 2036 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |