Class: SDM::Cassandra

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Cassandra

Returns a new instance of Cassandra.



5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
# File 'lib/models/porcelain.rb', line 5000

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



4970
4971
4972
# File 'lib/models/porcelain.rb', line 4970

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4972
4973
4974
# File 'lib/models/porcelain.rb', line 4972

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4974
4975
4976
# File 'lib/models/porcelain.rb', line 4974

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4976
4977
4978
# File 'lib/models/porcelain.rb', line 4976

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4978
4979
4980
# File 'lib/models/porcelain.rb', line 4978

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4980
4981
4982
# File 'lib/models/porcelain.rb', line 4980

def name
  @name
end

#passwordObject

The password to authenticate with.



4982
4983
4984
# File 'lib/models/porcelain.rb', line 4982

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4984
4985
4986
# File 'lib/models/porcelain.rb', line 4984

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



4986
4987
4988
# File 'lib/models/porcelain.rb', line 4986

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4988
4989
4990
# File 'lib/models/porcelain.rb', line 4988

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4990
4991
4992
# File 'lib/models/porcelain.rb', line 4990

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



4992
4993
4994
# File 'lib/models/porcelain.rb', line 4992

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4994
4995
4996
# File 'lib/models/porcelain.rb', line 4994

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



4996
4997
4998
# File 'lib/models/porcelain.rb', line 4996

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



4998
4999
5000
# File 'lib/models/porcelain.rb', line 4998

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5034
5035
5036
5037
5038
5039
5040
# File 'lib/models/porcelain.rb', line 5034

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end