Class: SDM::Citus

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Citus

Returns a new instance of Citus.



5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
# File 'lib/models/porcelain.rb', line 5072

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



5040
5041
5042
# File 'lib/models/porcelain.rb', line 5040

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



5042
5043
5044
# File 'lib/models/porcelain.rb', line 5042

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5044
5045
5046
# File 'lib/models/porcelain.rb', line 5044

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5046
5047
5048
# File 'lib/models/porcelain.rb', line 5046

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5048
5049
5050
# File 'lib/models/porcelain.rb', line 5048

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5050
5051
5052
# File 'lib/models/porcelain.rb', line 5050

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5052
5053
5054
# File 'lib/models/porcelain.rb', line 5052

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



5054
5055
5056
# File 'lib/models/porcelain.rb', line 5054

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



5056
5057
5058
# File 'lib/models/porcelain.rb', line 5056

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5058
5059
5060
# File 'lib/models/porcelain.rb', line 5058

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



5060
5061
5062
# File 'lib/models/porcelain.rb', line 5060

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5062
5063
5064
# File 'lib/models/porcelain.rb', line 5062

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5064
5065
5066
# File 'lib/models/porcelain.rb', line 5064

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



5066
5067
5068
# File 'lib/models/porcelain.rb', line 5066

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5068
5069
5070
# File 'lib/models/porcelain.rb', line 5068

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5070
5071
5072
# File 'lib/models/porcelain.rb', line 5070

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5108
5109
5110
5111
5112
5113
5114
# File 'lib/models/porcelain.rb', line 5108

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end