Class: SDM::Citus
- Inherits:
-
Object
- Object
- SDM::Citus
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Citus
constructor
A new instance of Citus.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Citus
Returns a new instance of Citus.
4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 |
# File 'lib/models/porcelain.rb', line 4231 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4199 4200 4201 |
# File 'lib/models/porcelain.rb', line 4199 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4201 4202 4203 |
# File 'lib/models/porcelain.rb', line 4201 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4203 4204 4205 |
# File 'lib/models/porcelain.rb', line 4203 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4205 4206 4207 |
# File 'lib/models/porcelain.rb', line 4205 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4207 4208 4209 |
# File 'lib/models/porcelain.rb', line 4207 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4209 4210 4211 |
# File 'lib/models/porcelain.rb', line 4209 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4211 4212 4213 |
# File 'lib/models/porcelain.rb', line 4211 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
4213 4214 4215 |
# File 'lib/models/porcelain.rb', line 4213 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
4215 4216 4217 |
# File 'lib/models/porcelain.rb', line 4215 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4217 4218 4219 |
# File 'lib/models/porcelain.rb', line 4217 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4219 4220 4221 |
# File 'lib/models/porcelain.rb', line 4219 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4221 4222 4223 |
# File 'lib/models/porcelain.rb', line 4221 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4223 4224 4225 |
# File 'lib/models/porcelain.rb', line 4223 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4225 4226 4227 |
# File 'lib/models/porcelain.rb', line 4225 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4227 4228 4229 |
# File 'lib/models/porcelain.rb', line 4227 def @tags end |
#username ⇒ Object
The username to authenticate with.
4229 4230 4231 |
# File 'lib/models/porcelain.rb', line 4229 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4267 4268 4269 4270 4271 4272 4273 |
# File 'lib/models/porcelain.rb', line 4267 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |