Class: SDM::Citus
- Inherits:
-
Object
- Object
- SDM::Citus
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Citus
constructor
A new instance of Citus.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Citus
Returns a new instance of Citus.
2984 2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 |
# File 'lib/models/porcelain.rb', line 2984 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
2954 2955 2956 |
# File 'lib/models/porcelain.rb', line 2954 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
2956 2957 2958 |
# File 'lib/models/porcelain.rb', line 2956 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2958 2959 2960 |
# File 'lib/models/porcelain.rb', line 2958 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2960 2961 2962 |
# File 'lib/models/porcelain.rb', line 2960 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
2962 2963 2964 |
# File 'lib/models/porcelain.rb', line 2962 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2964 2965 2966 |
# File 'lib/models/porcelain.rb', line 2964 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2966 2967 2968 |
# File 'lib/models/porcelain.rb', line 2966 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
2968 2969 2970 |
# File 'lib/models/porcelain.rb', line 2968 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
2970 2971 2972 |
# File 'lib/models/porcelain.rb', line 2970 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
2972 2973 2974 |
# File 'lib/models/porcelain.rb', line 2972 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
2974 2975 2976 |
# File 'lib/models/porcelain.rb', line 2974 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2976 2977 2978 |
# File 'lib/models/porcelain.rb', line 2976 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2978 2979 2980 |
# File 'lib/models/porcelain.rb', line 2978 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2980 2981 2982 |
# File 'lib/models/porcelain.rb', line 2980 def @tags end |
#username ⇒ Object
The username to authenticate with.
2982 2983 2984 |
# File 'lib/models/porcelain.rb', line 2982 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3018 3019 3020 3021 3022 3023 3024 |
# File 'lib/models/porcelain.rb', line 3018 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |