Class: SDM::Citus

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Citus

Returns a new instance of Citus.



2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
# File 'lib/models/porcelain.rb', line 2669

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2639
2640
2641
# File 'lib/models/porcelain.rb', line 2639

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2641
2642
2643
# File 'lib/models/porcelain.rb', line 2641

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2643
2644
2645
# File 'lib/models/porcelain.rb', line 2643

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2645
2646
2647
# File 'lib/models/porcelain.rb', line 2645

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2647
2648
2649
# File 'lib/models/porcelain.rb', line 2647

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2649
2650
2651
# File 'lib/models/porcelain.rb', line 2649

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2651
2652
2653
# File 'lib/models/porcelain.rb', line 2651

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



2653
2654
2655
# File 'lib/models/porcelain.rb', line 2653

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



2655
2656
2657
# File 'lib/models/porcelain.rb', line 2655

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2657
2658
2659
# File 'lib/models/porcelain.rb', line 2657

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2659
2660
2661
# File 'lib/models/porcelain.rb', line 2659

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2661
2662
2663
# File 'lib/models/porcelain.rb', line 2661

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2663
2664
2665
# File 'lib/models/porcelain.rb', line 2663

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2665
2666
2667
# File 'lib/models/porcelain.rb', line 2665

def tags
  @tags
end

#usernameObject

The username to authenticate with.



2667
2668
2669
# File 'lib/models/porcelain.rb', line 2667

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2703
2704
2705
2706
2707
2708
2709
# File 'lib/models/porcelain.rb', line 2703

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end