Class: SDM::Citus

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Citus

Returns a new instance of Citus.



2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
# File 'lib/models/porcelain.rb', line 2560

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2530
2531
2532
# File 'lib/models/porcelain.rb', line 2530

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2532
2533
2534
# File 'lib/models/porcelain.rb', line 2532

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2534
2535
2536
# File 'lib/models/porcelain.rb', line 2534

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2536
2537
2538
# File 'lib/models/porcelain.rb', line 2536

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2538
2539
2540
# File 'lib/models/porcelain.rb', line 2538

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2540
2541
2542
# File 'lib/models/porcelain.rb', line 2540

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2542
2543
2544
# File 'lib/models/porcelain.rb', line 2542

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



2544
2545
2546
# File 'lib/models/porcelain.rb', line 2544

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



2546
2547
2548
# File 'lib/models/porcelain.rb', line 2546

def password
  @password
end

#portObject

Returns the value of attribute port.



2548
2549
2550
# File 'lib/models/porcelain.rb', line 2548

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2550
2551
2552
# File 'lib/models/porcelain.rb', line 2550

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2552
2553
2554
# File 'lib/models/porcelain.rb', line 2552

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2554
2555
2556
# File 'lib/models/porcelain.rb', line 2554

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2556
2557
2558
# File 'lib/models/porcelain.rb', line 2556

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2558
2559
2560
# File 'lib/models/porcelain.rb', line 2558

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2594
2595
2596
2597
2598
2599
2600
# File 'lib/models/porcelain.rb', line 2594

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end