Class: SDM::Citus

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Citus

Returns a new instance of Citus.



1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
# File 'lib/models/porcelain.rb', line 1682

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



1654
1655
1656
# File 'lib/models/porcelain.rb', line 1654

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



1656
1657
1658
# File 'lib/models/porcelain.rb', line 1656

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1658
1659
1660
# File 'lib/models/porcelain.rb', line 1658

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1660
1661
1662
# File 'lib/models/porcelain.rb', line 1660

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



1662
1663
1664
# File 'lib/models/porcelain.rb', line 1662

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1664
1665
1666
# File 'lib/models/porcelain.rb', line 1664

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1666
1667
1668
# File 'lib/models/porcelain.rb', line 1666

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



1668
1669
1670
# File 'lib/models/porcelain.rb', line 1668

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



1670
1671
1672
# File 'lib/models/porcelain.rb', line 1670

def password
  @password
end

#portObject

Returns the value of attribute port.



1672
1673
1674
# File 'lib/models/porcelain.rb', line 1672

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



1674
1675
1676
# File 'lib/models/porcelain.rb', line 1674

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1676
1677
1678
# File 'lib/models/porcelain.rb', line 1676

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1678
1679
1680
# File 'lib/models/porcelain.rb', line 1678

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



1680
1681
1682
# File 'lib/models/porcelain.rb', line 1680

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1714
1715
1716
1717
1718
1719
1720
# File 'lib/models/porcelain.rb', line 1714

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end