Class: SDM::Citus

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Citus

Returns a new instance of Citus.



1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
# File 'lib/models/porcelain.rb', line 1638

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



1610
1611
1612
# File 'lib/models/porcelain.rb', line 1610

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



1612
1613
1614
# File 'lib/models/porcelain.rb', line 1612

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1614
1615
1616
# File 'lib/models/porcelain.rb', line 1614

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1616
1617
1618
# File 'lib/models/porcelain.rb', line 1616

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



1618
1619
1620
# File 'lib/models/porcelain.rb', line 1618

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1620
1621
1622
# File 'lib/models/porcelain.rb', line 1620

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1622
1623
1624
# File 'lib/models/porcelain.rb', line 1622

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



1624
1625
1626
# File 'lib/models/porcelain.rb', line 1624

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



1626
1627
1628
# File 'lib/models/porcelain.rb', line 1626

def password
  @password
end

#portObject

Returns the value of attribute port.



1628
1629
1630
# File 'lib/models/porcelain.rb', line 1628

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



1630
1631
1632
# File 'lib/models/porcelain.rb', line 1630

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1632
1633
1634
# File 'lib/models/porcelain.rb', line 1632

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1634
1635
1636
# File 'lib/models/porcelain.rb', line 1634

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



1636
1637
1638
# File 'lib/models/porcelain.rb', line 1636

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1670
1671
1672
1673
1674
1675
1676
# File 'lib/models/porcelain.rb', line 1670

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end