Class: SDM::Citus
- Inherits:
-
Object
- Object
- SDM::Citus
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Citus
constructor
A new instance of Citus.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Citus
Returns a new instance of Citus.
2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 |
# File 'lib/models/porcelain.rb', line 2072 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if override_database != nil @override_database = override_database end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
2046 2047 2048 |
# File 'lib/models/porcelain.rb', line 2046 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2048 2049 2050 |
# File 'lib/models/porcelain.rb', line 2048 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2050 2051 2052 |
# File 'lib/models/porcelain.rb', line 2050 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2052 2053 2054 |
# File 'lib/models/porcelain.rb', line 2052 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2054 2055 2056 |
# File 'lib/models/porcelain.rb', line 2054 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2056 2057 2058 |
# File 'lib/models/porcelain.rb', line 2056 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
2058 2059 2060 |
# File 'lib/models/porcelain.rb', line 2058 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
2060 2061 2062 |
# File 'lib/models/porcelain.rb', line 2060 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2062 2063 2064 |
# File 'lib/models/porcelain.rb', line 2062 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2064 2065 2066 |
# File 'lib/models/porcelain.rb', line 2064 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2066 2067 2068 |
# File 'lib/models/porcelain.rb', line 2066 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2068 2069 2070 |
# File 'lib/models/porcelain.rb', line 2068 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2070 2071 2072 |
# File 'lib/models/porcelain.rb', line 2070 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2128 2129 2130 2131 2132 2133 2134 |
# File 'lib/models/porcelain.rb', line 2128 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |