Class: SDM::ClickHouseHTTP
- Inherits:
-
Object
- Object
- SDM::ClickHouseHTTP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP
constructor
A new instance of ClickHouseHTTP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP
Returns a new instance of ClickHouseHTTP.
4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 |
# File 'lib/models/porcelain.rb', line 4541 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4515 4516 4517 |
# File 'lib/models/porcelain.rb', line 4515 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4517 4518 4519 |
# File 'lib/models/porcelain.rb', line 4517 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4519 4520 4521 |
# File 'lib/models/porcelain.rb', line 4519 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4521 4522 4523 |
# File 'lib/models/porcelain.rb', line 4521 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4523 4524 4525 |
# File 'lib/models/porcelain.rb', line 4523 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4525 4526 4527 |
# File 'lib/models/porcelain.rb', line 4525 def name @name end |
#password ⇒ Object
The password to authenticate with.
4527 4528 4529 |
# File 'lib/models/porcelain.rb', line 4527 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4529 4530 4531 |
# File 'lib/models/porcelain.rb', line 4529 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4531 4532 4533 |
# File 'lib/models/porcelain.rb', line 4531 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4533 4534 4535 |
# File 'lib/models/porcelain.rb', line 4533 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4535 4536 4537 |
# File 'lib/models/porcelain.rb', line 4535 def @tags end |
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
4537 4538 4539 |
# File 'lib/models/porcelain.rb', line 4537 def url @url end |
#username ⇒ Object
The username to authenticate with.
4539 4540 4541 |
# File 'lib/models/porcelain.rb', line 4539 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/models/porcelain.rb', line 4571 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |