Class: SDM::ClickHouseHTTP
- Inherits:
-
Object
- Object
- SDM::ClickHouseHTTP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP
constructor
A new instance of ClickHouseHTTP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP
Returns a new instance of ClickHouseHTTP.
4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 |
# File 'lib/models/porcelain.rb', line 4225 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4199 4200 4201 |
# File 'lib/models/porcelain.rb', line 4199 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4201 4202 4203 |
# File 'lib/models/porcelain.rb', line 4201 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4203 4204 4205 |
# File 'lib/models/porcelain.rb', line 4203 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4205 4206 4207 |
# File 'lib/models/porcelain.rb', line 4205 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4207 4208 4209 |
# File 'lib/models/porcelain.rb', line 4207 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4209 4210 4211 |
# File 'lib/models/porcelain.rb', line 4209 def name @name end |
#password ⇒ Object
The password to authenticate with.
4211 4212 4213 |
# File 'lib/models/porcelain.rb', line 4211 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4213 4214 4215 |
# File 'lib/models/porcelain.rb', line 4213 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4215 4216 4217 |
# File 'lib/models/porcelain.rb', line 4215 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4217 4218 4219 |
# File 'lib/models/porcelain.rb', line 4217 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4219 4220 4221 |
# File 'lib/models/porcelain.rb', line 4219 def @tags end |
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
4221 4222 4223 |
# File 'lib/models/porcelain.rb', line 4221 def url @url end |
#username ⇒ Object
The username to authenticate with.
4223 4224 4225 |
# File 'lib/models/porcelain.rb', line 4223 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4255 4256 4257 4258 4259 4260 4261 |
# File 'lib/models/porcelain.rb', line 4255 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |