Class: SDM::ClickHouseHTTP
- Inherits:
-
Object
- Object
- SDM::ClickHouseHTTP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP
constructor
A new instance of ClickHouseHTTP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP
Returns a new instance of ClickHouseHTTP.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 |
# File 'lib/models/porcelain.rb', line 4118 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4092 4093 4094 |
# File 'lib/models/porcelain.rb', line 4092 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4094 4095 4096 |
# File 'lib/models/porcelain.rb', line 4094 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4096 4097 4098 |
# File 'lib/models/porcelain.rb', line 4096 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4098 4099 4100 |
# File 'lib/models/porcelain.rb', line 4098 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4100 4101 4102 |
# File 'lib/models/porcelain.rb', line 4100 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4102 4103 4104 |
# File 'lib/models/porcelain.rb', line 4102 def name @name end |
#password ⇒ Object
The password to authenticate with.
4104 4105 4106 |
# File 'lib/models/porcelain.rb', line 4104 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4106 4107 4108 |
# File 'lib/models/porcelain.rb', line 4106 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4108 4109 4110 |
# File 'lib/models/porcelain.rb', line 4108 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4110 4111 4112 |
# File 'lib/models/porcelain.rb', line 4110 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4112 4113 4114 |
# File 'lib/models/porcelain.rb', line 4112 def @tags end |
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
4114 4115 4116 |
# File 'lib/models/porcelain.rb', line 4114 def url @url end |
#username ⇒ Object
The username to authenticate with.
4116 4117 4118 |
# File 'lib/models/porcelain.rb', line 4116 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4148 4149 4150 4151 4152 4153 4154 |
# File 'lib/models/porcelain.rb', line 4148 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |