Class: SDM::ClickHouseHTTP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP

Returns a new instance of ClickHouseHTTP.



4042
4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
# File 'lib/models/porcelain.rb', line 4042

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4016
4017
4018
# File 'lib/models/porcelain.rb', line 4016

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4018
4019
4020
# File 'lib/models/porcelain.rb', line 4018

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4020
4021
4022
# File 'lib/models/porcelain.rb', line 4020

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4022
4023
4024
# File 'lib/models/porcelain.rb', line 4022

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4024
4025
4026
# File 'lib/models/porcelain.rb', line 4024

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4026
4027
4028
# File 'lib/models/porcelain.rb', line 4026

def name
  @name
end

#passwordObject

The password to authenticate with.



4028
4029
4030
# File 'lib/models/porcelain.rb', line 4028

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



4030
4031
4032
# File 'lib/models/porcelain.rb', line 4030

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4032
4033
4034
# File 'lib/models/porcelain.rb', line 4032

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4034
4035
4036
# File 'lib/models/porcelain.rb', line 4034

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4036
4037
4038
# File 'lib/models/porcelain.rb', line 4036

def tags
  @tags
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



4038
4039
4040
# File 'lib/models/porcelain.rb', line 4038

def url
  @url
end

#usernameObject

The username to authenticate with.



4040
4041
4042
# File 'lib/models/porcelain.rb', line 4040

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4072
4073
4074
4075
4076
4077
4078
# File 'lib/models/porcelain.rb', line 4072

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end