Class: SDM::ClickHouseHTTP
- Inherits:
-
Object
- Object
- SDM::ClickHouseHTTP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP
constructor
A new instance of ClickHouseHTTP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP
Returns a new instance of ClickHouseHTTP.
5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/models/porcelain.rb', line 5166 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
5140 5141 5142 |
# File 'lib/models/porcelain.rb', line 5140 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
5142 5143 5144 |
# File 'lib/models/porcelain.rb', line 5142 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5144 5145 5146 |
# File 'lib/models/porcelain.rb', line 5144 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5146 5147 5148 |
# File 'lib/models/porcelain.rb', line 5146 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5148 5149 5150 |
# File 'lib/models/porcelain.rb', line 5148 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5150 5151 5152 |
# File 'lib/models/porcelain.rb', line 5150 def name @name end |
#password ⇒ Object
The password to authenticate with.
5152 5153 5154 |
# File 'lib/models/porcelain.rb', line 5152 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
5154 5155 5156 |
# File 'lib/models/porcelain.rb', line 5154 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5156 5157 5158 |
# File 'lib/models/porcelain.rb', line 5156 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5158 5159 5160 |
# File 'lib/models/porcelain.rb', line 5158 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5160 5161 5162 |
# File 'lib/models/porcelain.rb', line 5160 def @tags end |
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
5162 5163 5164 |
# File 'lib/models/porcelain.rb', line 5162 def url @url end |
#username ⇒ Object
The username to authenticate with.
5164 5165 5166 |
# File 'lib/models/porcelain.rb', line 5164 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5196 5197 5198 5199 5200 5201 5202 |
# File 'lib/models/porcelain.rb', line 5196 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |