Class: SDM::ClickHouseHTTP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, tags: nil, url: nil, username: nil) ⇒ ClickHouseHTTP



4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
4317
4318
4319
4320
4321
# File 'lib/models/porcelain.rb', line 4293

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4267
4268
4269
# File 'lib/models/porcelain.rb', line 4267

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4269
4270
4271
# File 'lib/models/porcelain.rb', line 4269

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4271
4272
4273
# File 'lib/models/porcelain.rb', line 4271

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4273
4274
4275
# File 'lib/models/porcelain.rb', line 4273

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4275
4276
4277
# File 'lib/models/porcelain.rb', line 4275

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4277
4278
4279
# File 'lib/models/porcelain.rb', line 4277

def name
  @name
end

#passwordObject

The password to authenticate with.



4279
4280
4281
# File 'lib/models/porcelain.rb', line 4279

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



4281
4282
4283
# File 'lib/models/porcelain.rb', line 4281

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4283
4284
4285
# File 'lib/models/porcelain.rb', line 4283

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4285
4286
4287
# File 'lib/models/porcelain.rb', line 4285

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4287
4288
4289
# File 'lib/models/porcelain.rb', line 4287

def tags
  @tags
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



4289
4290
4291
# File 'lib/models/porcelain.rb', line 4289

def url
  @url
end

#usernameObject

The username to authenticate with.



4291
4292
4293
# File 'lib/models/porcelain.rb', line 4291

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4323
4324
4325
4326
4327
4328
4329
# File 'lib/models/porcelain.rb', line 4323

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end