Class: SDM::ClickHouseMySQL
- Inherits:
-
Object
- Object
- SDM::ClickHouseMySQL
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ ClickHouseMySQL
constructor
A new instance of ClickHouseMySQL.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ ClickHouseMySQL
Returns a new instance of ClickHouseMySQL.
4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 |
# File 'lib/models/porcelain.rb', line 4298 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4266 4267 4268 |
# File 'lib/models/porcelain.rb', line 4266 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests.
4268 4269 4270 |
# File 'lib/models/porcelain.rb', line 4268 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4270 4271 4272 |
# File 'lib/models/porcelain.rb', line 4270 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4272 4273 4274 |
# File 'lib/models/porcelain.rb', line 4272 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4274 4275 4276 |
# File 'lib/models/porcelain.rb', line 4274 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4276 4277 4278 |
# File 'lib/models/porcelain.rb', line 4276 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4278 4279 4280 |
# File 'lib/models/porcelain.rb', line 4278 def name @name end |
#password ⇒ Object
The password to authenticate with.
4280 4281 4282 |
# File 'lib/models/porcelain.rb', line 4280 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4282 4283 4284 |
# File 'lib/models/porcelain.rb', line 4282 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4284 4285 4286 |
# File 'lib/models/porcelain.rb', line 4284 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4286 4287 4288 |
# File 'lib/models/porcelain.rb', line 4286 def proxy_cluster_id @proxy_cluster_id end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
4288 4289 4290 |
# File 'lib/models/porcelain.rb', line 4288 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4290 4291 4292 |
# File 'lib/models/porcelain.rb', line 4290 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4292 4293 4294 |
# File 'lib/models/porcelain.rb', line 4292 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4294 4295 4296 |
# File 'lib/models/porcelain.rb', line 4294 def @tags end |
#username ⇒ Object
The username to authenticate with.
4296 4297 4298 |
# File 'lib/models/porcelain.rb', line 4296 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4334 4335 4336 4337 4338 4339 4340 |
# File 'lib/models/porcelain.rb', line 4334 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |