Class: SDM::ClickHouseMySQL
- Inherits:
-
Object
- Object
- SDM::ClickHouseMySQL
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ ClickHouseMySQL
constructor
A new instance of ClickHouseMySQL.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ ClickHouseMySQL
Returns a new instance of ClickHouseMySQL.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 |
# File 'lib/models/porcelain.rb', line 4115 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4083 4084 4085 |
# File 'lib/models/porcelain.rb', line 4083 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests.
4085 4086 4087 |
# File 'lib/models/porcelain.rb', line 4085 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4087 4088 4089 |
# File 'lib/models/porcelain.rb', line 4087 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4089 4090 4091 |
# File 'lib/models/porcelain.rb', line 4089 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4091 4092 4093 |
# File 'lib/models/porcelain.rb', line 4091 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4093 4094 4095 |
# File 'lib/models/porcelain.rb', line 4093 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4095 4096 4097 |
# File 'lib/models/porcelain.rb', line 4095 def name @name end |
#password ⇒ Object
The password to authenticate with.
4097 4098 4099 |
# File 'lib/models/porcelain.rb', line 4097 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4099 4100 4101 |
# File 'lib/models/porcelain.rb', line 4099 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4101 4102 4103 |
# File 'lib/models/porcelain.rb', line 4101 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4103 4104 4105 |
# File 'lib/models/porcelain.rb', line 4103 def proxy_cluster_id @proxy_cluster_id end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
4105 4106 4107 |
# File 'lib/models/porcelain.rb', line 4105 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4107 4108 4109 |
# File 'lib/models/porcelain.rb', line 4107 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4109 4110 4111 |
# File 'lib/models/porcelain.rb', line 4109 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4111 4112 4113 |
# File 'lib/models/porcelain.rb', line 4111 def @tags end |
#username ⇒ Object
The username to authenticate with.
4113 4114 4115 |
# File 'lib/models/porcelain.rb', line 4113 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4151 4152 4153 4154 4155 4156 4157 |
# File 'lib/models/porcelain.rb', line 4151 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |