Class: SDM::ClickHouseTCP
- Inherits:
-
Object
- Object
- SDM::ClickHouseTCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ClickHouseTCP
constructor
A new instance of ClickHouseTCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ClickHouseTCP
Returns a new instance of ClickHouseTCP.
4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 |
# File 'lib/models/porcelain.rb', line 4270 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4238 4239 4240 |
# File 'lib/models/porcelain.rb', line 4238 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4240 4241 4242 |
# File 'lib/models/porcelain.rb', line 4240 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4242 4243 4244 |
# File 'lib/models/porcelain.rb', line 4242 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4244 4245 4246 |
# File 'lib/models/porcelain.rb', line 4244 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4246 4247 4248 |
# File 'lib/models/porcelain.rb', line 4246 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4248 4249 4250 |
# File 'lib/models/porcelain.rb', line 4248 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4250 4251 4252 |
# File 'lib/models/porcelain.rb', line 4250 def name @name end |
#password ⇒ Object
The password to authenticate with.
4252 4253 4254 |
# File 'lib/models/porcelain.rb', line 4252 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4254 4255 4256 |
# File 'lib/models/porcelain.rb', line 4254 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4256 4257 4258 |
# File 'lib/models/porcelain.rb', line 4256 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4258 4259 4260 |
# File 'lib/models/porcelain.rb', line 4258 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4260 4261 4262 |
# File 'lib/models/porcelain.rb', line 4260 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4262 4263 4264 |
# File 'lib/models/porcelain.rb', line 4262 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4264 4265 4266 |
# File 'lib/models/porcelain.rb', line 4264 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4266 4267 4268 |
# File 'lib/models/porcelain.rb', line 4266 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4268 4269 4270 |
# File 'lib/models/porcelain.rb', line 4268 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4306 4307 4308 4309 4310 4311 4312 |
# File 'lib/models/porcelain.rb', line 4306 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |