Class: SDM::ClickHouseTCP
- Inherits:
-
Object
- Object
- SDM::ClickHouseTCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ClickHouseTCP
constructor
A new instance of ClickHouseTCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ClickHouseTCP
Returns a new instance of ClickHouseTCP.
5318 5319 5320 5321 5322 5323 5324 5325 5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 5351 5352 |
# File 'lib/models/porcelain.rb', line 5318 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
5286 5287 5288 |
# File 'lib/models/porcelain.rb', line 5286 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
5288 5289 5290 |
# File 'lib/models/porcelain.rb', line 5288 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5290 5291 5292 |
# File 'lib/models/porcelain.rb', line 5290 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5292 5293 5294 |
# File 'lib/models/porcelain.rb', line 5292 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5294 5295 5296 |
# File 'lib/models/porcelain.rb', line 5294 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5296 5297 5298 |
# File 'lib/models/porcelain.rb', line 5296 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5298 5299 5300 |
# File 'lib/models/porcelain.rb', line 5298 def name @name end |
#password ⇒ Object
The password to authenticate with.
5300 5301 5302 |
# File 'lib/models/porcelain.rb', line 5300 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5302 5303 5304 |
# File 'lib/models/porcelain.rb', line 5302 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
5304 5305 5306 |
# File 'lib/models/porcelain.rb', line 5304 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5306 5307 5308 |
# File 'lib/models/porcelain.rb', line 5306 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5308 5309 5310 |
# File 'lib/models/porcelain.rb', line 5308 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
5310 5311 5312 |
# File 'lib/models/porcelain.rb', line 5310 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5312 5313 5314 |
# File 'lib/models/porcelain.rb', line 5312 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5314 5315 5316 |
# File 'lib/models/porcelain.rb', line 5314 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5316 5317 5318 |
# File 'lib/models/porcelain.rb', line 5316 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5354 5355 5356 5357 5358 5359 5360 |
# File 'lib/models/porcelain.rb', line 5354 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |