Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



4458
4459
4460
4461
4462
4463
4464
4465
4466
4467
4468
4469
4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
4481
4482
4483
4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
# File 'lib/models/porcelain.rb', line 4458

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4424
4425
4426
# File 'lib/models/porcelain.rb', line 4424

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



4426
4427
4428
# File 'lib/models/porcelain.rb', line 4426

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4428
4429
4430
# File 'lib/models/porcelain.rb', line 4428

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4430
4431
4432
# File 'lib/models/porcelain.rb', line 4430

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4432
4433
4434
# File 'lib/models/porcelain.rb', line 4432

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4434
4435
4436
# File 'lib/models/porcelain.rb', line 4434

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4436
4437
4438
# File 'lib/models/porcelain.rb', line 4436

def name
  @name
end

#passwordObject

The password to authenticate with.



4438
4439
4440
# File 'lib/models/porcelain.rb', line 4438

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4440
4441
4442
# File 'lib/models/porcelain.rb', line 4440

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4442
4443
4444
# File 'lib/models/porcelain.rb', line 4442

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4444
4445
4446
# File 'lib/models/porcelain.rb', line 4444

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



4446
4447
4448
# File 'lib/models/porcelain.rb', line 4446

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4448
4449
4450
# File 'lib/models/porcelain.rb', line 4448

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4450
4451
4452
# File 'lib/models/porcelain.rb', line 4450

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4452
4453
4454
# File 'lib/models/porcelain.rb', line 4452

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4454
4455
4456
# File 'lib/models/porcelain.rb', line 4454

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4456
4457
4458
# File 'lib/models/porcelain.rb', line 4456

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4496
4497
4498
4499
4500
4501
4502
# File 'lib/models/porcelain.rb', line 4496

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end