Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



4355
4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
# File 'lib/models/porcelain.rb', line 4355

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4321
4322
4323
# File 'lib/models/porcelain.rb', line 4321

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



4323
4324
4325
# File 'lib/models/porcelain.rb', line 4323

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4325
4326
4327
# File 'lib/models/porcelain.rb', line 4325

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4327
4328
4329
# File 'lib/models/porcelain.rb', line 4327

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4329
4330
4331
# File 'lib/models/porcelain.rb', line 4329

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4331
4332
4333
# File 'lib/models/porcelain.rb', line 4331

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4333
4334
4335
# File 'lib/models/porcelain.rb', line 4333

def name
  @name
end

#passwordObject

The password to authenticate with.



4335
4336
4337
# File 'lib/models/porcelain.rb', line 4335

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4337
4338
4339
# File 'lib/models/porcelain.rb', line 4337

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4339
4340
4341
# File 'lib/models/porcelain.rb', line 4339

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4341
4342
4343
# File 'lib/models/porcelain.rb', line 4341

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



4343
4344
4345
# File 'lib/models/porcelain.rb', line 4343

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4345
4346
4347
# File 'lib/models/porcelain.rb', line 4345

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4347
4348
4349
# File 'lib/models/porcelain.rb', line 4347

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4349
4350
4351
# File 'lib/models/porcelain.rb', line 4349

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4351
4352
4353
# File 'lib/models/porcelain.rb', line 4351

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4353
4354
4355
# File 'lib/models/porcelain.rb', line 4353

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4393
4394
4395
4396
4397
4398
4399
# File 'lib/models/porcelain.rb', line 4393

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end