Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
# File 'lib/models/porcelain.rb', line 4275

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4241
4242
4243
# File 'lib/models/porcelain.rb', line 4241

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



4243
4244
4245
# File 'lib/models/porcelain.rb', line 4243

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4245
4246
4247
# File 'lib/models/porcelain.rb', line 4245

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4247
4248
4249
# File 'lib/models/porcelain.rb', line 4247

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4249
4250
4251
# File 'lib/models/porcelain.rb', line 4249

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4251
4252
4253
# File 'lib/models/porcelain.rb', line 4251

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4253
4254
4255
# File 'lib/models/porcelain.rb', line 4253

def name
  @name
end

#passwordObject

The password to authenticate with.



4255
4256
4257
# File 'lib/models/porcelain.rb', line 4255

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4257
4258
4259
# File 'lib/models/porcelain.rb', line 4257

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4259
4260
4261
# File 'lib/models/porcelain.rb', line 4259

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4261
4262
4263
# File 'lib/models/porcelain.rb', line 4261

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



4263
4264
4265
# File 'lib/models/porcelain.rb', line 4263

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4265
4266
4267
# File 'lib/models/porcelain.rb', line 4265

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4267
4268
4269
# File 'lib/models/porcelain.rb', line 4267

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4269
4270
4271
# File 'lib/models/porcelain.rb', line 4269

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4271
4272
4273
# File 'lib/models/porcelain.rb', line 4271

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4273
4274
4275
# File 'lib/models/porcelain.rb', line 4273

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4313
4314
4315
4316
4317
4318
4319
# File 'lib/models/porcelain.rb', line 4313

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end