Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
3093
3094
3095
# File 'lib/models/porcelain.rb', line 3061

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3029
3030
3031
# File 'lib/models/porcelain.rb', line 3029

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



3031
3032
3033
# File 'lib/models/porcelain.rb', line 3031

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3033
3034
3035
# File 'lib/models/porcelain.rb', line 3033

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3035
3036
3037
# File 'lib/models/porcelain.rb', line 3035

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3037
3038
3039
# File 'lib/models/porcelain.rb', line 3037

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3039
3040
3041
# File 'lib/models/porcelain.rb', line 3039

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3041
3042
3043
# File 'lib/models/porcelain.rb', line 3041

def name
  @name
end

#passwordObject

The password to authenticate with.



3043
3044
3045
# File 'lib/models/porcelain.rb', line 3043

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3045
3046
3047
# File 'lib/models/porcelain.rb', line 3045

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3047
3048
3049
# File 'lib/models/porcelain.rb', line 3047

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



3049
3050
3051
# File 'lib/models/porcelain.rb', line 3049

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3051
3052
3053
# File 'lib/models/porcelain.rb', line 3051

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3053
3054
3055
# File 'lib/models/porcelain.rb', line 3053

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3055
3056
3057
# File 'lib/models/porcelain.rb', line 3055

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



3057
3058
3059
# File 'lib/models/porcelain.rb', line 3057

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



3059
3060
3061
# File 'lib/models/porcelain.rb', line 3059

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3097
3098
3099
3100
3101
3102
3103
# File 'lib/models/porcelain.rb', line 3097

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end