Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
# File 'lib/models/porcelain.rb', line 2910

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2878
2879
2880
# File 'lib/models/porcelain.rb', line 2878

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2880
2881
2882
# File 'lib/models/porcelain.rb', line 2880

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2882
2883
2884
# File 'lib/models/porcelain.rb', line 2882

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2884
2885
2886
# File 'lib/models/porcelain.rb', line 2884

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2886
2887
2888
# File 'lib/models/porcelain.rb', line 2886

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2888
2889
2890
# File 'lib/models/porcelain.rb', line 2888

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2890
2891
2892
# File 'lib/models/porcelain.rb', line 2890

def name
  @name
end

#passwordObject

The password to authenticate with.



2892
2893
2894
# File 'lib/models/porcelain.rb', line 2892

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2894
2895
2896
# File 'lib/models/porcelain.rb', line 2894

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2896
2897
2898
# File 'lib/models/porcelain.rb', line 2896

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



2898
2899
2900
# File 'lib/models/porcelain.rb', line 2898

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2900
2901
2902
# File 'lib/models/porcelain.rb', line 2900

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2902
2903
2904
# File 'lib/models/porcelain.rb', line 2902

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2904
2905
2906
# File 'lib/models/porcelain.rb', line 2904

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



2906
2907
2908
# File 'lib/models/porcelain.rb', line 2906

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



2908
2909
2910
# File 'lib/models/porcelain.rb', line 2908

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2946
2947
2948
2949
2950
2951
2952
# File 'lib/models/porcelain.rb', line 2946

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end