Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
# File 'lib/models/porcelain.rb', line 2653

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2621
2622
2623
# File 'lib/models/porcelain.rb', line 2621

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2623
2624
2625
# File 'lib/models/porcelain.rb', line 2623

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2625
2626
2627
# File 'lib/models/porcelain.rb', line 2625

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2627
2628
2629
# File 'lib/models/porcelain.rb', line 2627

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2629
2630
2631
# File 'lib/models/porcelain.rb', line 2629

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2631
2632
2633
# File 'lib/models/porcelain.rb', line 2631

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2633
2634
2635
# File 'lib/models/porcelain.rb', line 2633

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2635
2636
2637
# File 'lib/models/porcelain.rb', line 2635

def password
  @password
end

#portObject

Returns the value of attribute port.



2637
2638
2639
# File 'lib/models/porcelain.rb', line 2637

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2639
2640
2641
# File 'lib/models/porcelain.rb', line 2639

def port_override
  @port_override
end

#require_native_authObject

Returns the value of attribute require_native_auth.



2641
2642
2643
# File 'lib/models/porcelain.rb', line 2641

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2643
2644
2645
# File 'lib/models/porcelain.rb', line 2643

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2645
2646
2647
# File 'lib/models/porcelain.rb', line 2645

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2647
2648
2649
# File 'lib/models/porcelain.rb', line 2647

def tags
  @tags
end

#use_azure_single_server_usernamesObject

Returns the value of attribute use_azure_single_server_usernames.



2649
2650
2651
# File 'lib/models/porcelain.rb', line 2649

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

Returns the value of attribute username.



2651
2652
2653
# File 'lib/models/porcelain.rb', line 2651

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2689
2690
2691
2692
2693
2694
2695
# File 'lib/models/porcelain.rb', line 2689

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end