Class: SDM::Clustrix
- Inherits:
-
Object
- Object
- SDM::Clustrix
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Clustrix
constructor
A new instance of Clustrix.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Clustrix
Returns a new instance of Clustrix.
2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/models/porcelain.rb', line 2633 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2605 2606 2607 |
# File 'lib/models/porcelain.rb', line 2605 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
2607 2608 2609 |
# File 'lib/models/porcelain.rb', line 2607 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2609 2610 2611 |
# File 'lib/models/porcelain.rb', line 2609 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2611 2612 2613 |
# File 'lib/models/porcelain.rb', line 2611 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2613 2614 2615 |
# File 'lib/models/porcelain.rb', line 2613 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2615 2616 2617 |
# File 'lib/models/porcelain.rb', line 2615 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2617 2618 2619 |
# File 'lib/models/porcelain.rb', line 2617 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2619 2620 2621 |
# File 'lib/models/porcelain.rb', line 2619 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2621 2622 2623 |
# File 'lib/models/porcelain.rb', line 2621 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2623 2624 2625 |
# File 'lib/models/porcelain.rb', line 2623 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2625 2626 2627 |
# File 'lib/models/porcelain.rb', line 2625 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2627 2628 2629 |
# File 'lib/models/porcelain.rb', line 2627 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2629 2630 2631 |
# File 'lib/models/porcelain.rb', line 2629 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2631 2632 2633 |
# File 'lib/models/porcelain.rb', line 2631 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2665 2666 2667 2668 2669 2670 2671 |
# File 'lib/models/porcelain.rb', line 2665 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |