Class: SDM::Clustrix
- Inherits:
-
Object
- Object
- SDM::Clustrix
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Clustrix
constructor
A new instance of Clustrix.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Clustrix
Returns a new instance of Clustrix.
2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 |
# File 'lib/models/porcelain.rb', line 2397 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2371 2372 2373 |
# File 'lib/models/porcelain.rb', line 2371 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
2373 2374 2375 |
# File 'lib/models/porcelain.rb', line 2373 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2375 2376 2377 |
# File 'lib/models/porcelain.rb', line 2375 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2377 2378 2379 |
# File 'lib/models/porcelain.rb', line 2377 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2379 2380 2381 |
# File 'lib/models/porcelain.rb', line 2379 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2381 2382 2383 |
# File 'lib/models/porcelain.rb', line 2381 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2383 2384 2385 |
# File 'lib/models/porcelain.rb', line 2383 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2385 2386 2387 |
# File 'lib/models/porcelain.rb', line 2385 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2387 2388 2389 |
# File 'lib/models/porcelain.rb', line 2387 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2389 2390 2391 |
# File 'lib/models/porcelain.rb', line 2389 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2391 2392 2393 |
# File 'lib/models/porcelain.rb', line 2391 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2393 2394 2395 |
# File 'lib/models/porcelain.rb', line 2393 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2395 2396 2397 |
# File 'lib/models/porcelain.rb', line 2395 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2427 2428 2429 2430 2431 2432 2433 |
# File 'lib/models/porcelain.rb', line 2427 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |