Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
# File 'lib/models/porcelain.rb', line 2059

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2033
2034
2035
# File 'lib/models/porcelain.rb', line 2033

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2035
2036
2037
# File 'lib/models/porcelain.rb', line 2035

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2037
2038
2039
# File 'lib/models/porcelain.rb', line 2037

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2039
2040
2041
# File 'lib/models/porcelain.rb', line 2039

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2041
2042
2043
# File 'lib/models/porcelain.rb', line 2041

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2043
2044
2045
# File 'lib/models/porcelain.rb', line 2043

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2045
2046
2047
# File 'lib/models/porcelain.rb', line 2045

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2047
2048
2049
# File 'lib/models/porcelain.rb', line 2047

def password
  @password
end

#portObject

Returns the value of attribute port.



2049
2050
2051
# File 'lib/models/porcelain.rb', line 2049

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2051
2052
2053
# File 'lib/models/porcelain.rb', line 2051

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2053
2054
2055
# File 'lib/models/porcelain.rb', line 2053

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2055
2056
2057
# File 'lib/models/porcelain.rb', line 2055

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2057
2058
2059
# File 'lib/models/porcelain.rb', line 2057

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2089
2090
2091
2092
2093
2094
2095
# File 'lib/models/porcelain.rb', line 2089

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end