Class: SDM::Clustrix

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Clustrix

Returns a new instance of Clustrix.



1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
# File 'lib/models/porcelain.rb', line 1751

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



1725
1726
1727
# File 'lib/models/porcelain.rb', line 1725

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



1727
1728
1729
# File 'lib/models/porcelain.rb', line 1727

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



1729
1730
1731
# File 'lib/models/porcelain.rb', line 1729

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



1731
1732
1733
# File 'lib/models/porcelain.rb', line 1731

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



1733
1734
1735
# File 'lib/models/porcelain.rb', line 1733

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



1735
1736
1737
# File 'lib/models/porcelain.rb', line 1735

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



1737
1738
1739
# File 'lib/models/porcelain.rb', line 1737

def name
  @name
end

#passwordObject

Returns the value of attribute password.



1739
1740
1741
# File 'lib/models/porcelain.rb', line 1739

def password
  @password
end

#portObject

Returns the value of attribute port.



1741
1742
1743
# File 'lib/models/porcelain.rb', line 1741

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



1743
1744
1745
# File 'lib/models/porcelain.rb', line 1743

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



1745
1746
1747
# File 'lib/models/porcelain.rb', line 1745

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



1747
1748
1749
# File 'lib/models/porcelain.rb', line 1747

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



1749
1750
1751
# File 'lib/models/porcelain.rb', line 1749

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



1781
1782
1783
1784
1785
1786
1787
# File 'lib/models/porcelain.rb', line 1781

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end