Class: SDM::Clustrix
- Inherits:
-
Object
- Object
- SDM::Clustrix
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Clustrix
constructor
A new instance of Clustrix.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Clustrix
Returns a new instance of Clustrix.
2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 |
# File 'lib/models/porcelain.rb', line 2162 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
2138 2139 2140 |
# File 'lib/models/porcelain.rb', line 2138 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2140 2141 2142 |
# File 'lib/models/porcelain.rb', line 2140 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2142 2143 2144 |
# File 'lib/models/porcelain.rb', line 2142 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2144 2145 2146 |
# File 'lib/models/porcelain.rb', line 2144 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2146 2147 2148 |
# File 'lib/models/porcelain.rb', line 2146 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2148 2149 2150 |
# File 'lib/models/porcelain.rb', line 2148 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2150 2151 2152 |
# File 'lib/models/porcelain.rb', line 2150 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2152 2153 2154 |
# File 'lib/models/porcelain.rb', line 2152 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2154 2155 2156 |
# File 'lib/models/porcelain.rb', line 2154 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2156 2157 2158 |
# File 'lib/models/porcelain.rb', line 2156 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2158 2159 2160 |
# File 'lib/models/porcelain.rb', line 2158 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2160 2161 2162 |
# File 'lib/models/porcelain.rb', line 2160 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2214 2215 2216 2217 2218 2219 2220 |
# File 'lib/models/porcelain.rb', line 2214 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |