Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
# File 'lib/models/porcelain.rb', line 5459

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



5427
5428
5429
# File 'lib/models/porcelain.rb', line 5427

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



5429
5430
5431
# File 'lib/models/porcelain.rb', line 5429

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5431
5432
5433
# File 'lib/models/porcelain.rb', line 5431

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5433
5434
5435
# File 'lib/models/porcelain.rb', line 5433

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5435
5436
5437
# File 'lib/models/porcelain.rb', line 5435

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5437
5438
5439
# File 'lib/models/porcelain.rb', line 5437

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5439
5440
5441
# File 'lib/models/porcelain.rb', line 5439

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



5441
5442
5443
# File 'lib/models/porcelain.rb', line 5441

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



5443
5444
5445
# File 'lib/models/porcelain.rb', line 5443

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5445
5446
5447
# File 'lib/models/porcelain.rb', line 5445

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



5447
5448
5449
# File 'lib/models/porcelain.rb', line 5447

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5449
5450
5451
# File 'lib/models/porcelain.rb', line 5449

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5451
5452
5453
# File 'lib/models/porcelain.rb', line 5451

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



5453
5454
5455
# File 'lib/models/porcelain.rb', line 5453

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5455
5456
5457
# File 'lib/models/porcelain.rb', line 5455

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5457
5458
5459
# File 'lib/models/porcelain.rb', line 5457

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5495
5496
5497
5498
5499
5500
5501
# File 'lib/models/porcelain.rb', line 5495

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end