Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
4637
4638
4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
4649
4650
4651
4652
# File 'lib/models/porcelain.rb', line 4618

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4586
4587
4588
# File 'lib/models/porcelain.rb', line 4586

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4588
4589
4590
# File 'lib/models/porcelain.rb', line 4588

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4590
4591
4592
# File 'lib/models/porcelain.rb', line 4590

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4592
4593
4594
# File 'lib/models/porcelain.rb', line 4592

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4594
4595
4596
# File 'lib/models/porcelain.rb', line 4594

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4596
4597
4598
# File 'lib/models/porcelain.rb', line 4596

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4598
4599
4600
# File 'lib/models/porcelain.rb', line 4598

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4600
4601
4602
# File 'lib/models/porcelain.rb', line 4600

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4602
4603
4604
# File 'lib/models/porcelain.rb', line 4602

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4604
4605
4606
# File 'lib/models/porcelain.rb', line 4604

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4606
4607
4608
# File 'lib/models/porcelain.rb', line 4606

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4608
4609
4610
# File 'lib/models/porcelain.rb', line 4608

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4610
4611
4612
# File 'lib/models/porcelain.rb', line 4610

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4612
4613
4614
# File 'lib/models/porcelain.rb', line 4612

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4614
4615
4616
# File 'lib/models/porcelain.rb', line 4614

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4616
4617
4618
# File 'lib/models/porcelain.rb', line 4616

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4654
4655
4656
4657
4658
4659
4660
# File 'lib/models/porcelain.rb', line 4654

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end