Class: SDM::Cockroach
- Inherits:
-
Object
- Object
- SDM::Cockroach
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach
constructor
A new instance of Cockroach.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach
Returns a new instance of Cockroach.
4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 |
# File 'lib/models/porcelain.rb', line 4618 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4586 4587 4588 |
# File 'lib/models/porcelain.rb', line 4586 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4588 4589 4590 |
# File 'lib/models/porcelain.rb', line 4588 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4590 4591 4592 |
# File 'lib/models/porcelain.rb', line 4590 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4592 4593 4594 |
# File 'lib/models/porcelain.rb', line 4592 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4594 4595 4596 |
# File 'lib/models/porcelain.rb', line 4594 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4596 4597 4598 |
# File 'lib/models/porcelain.rb', line 4596 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4598 4599 4600 |
# File 'lib/models/porcelain.rb', line 4598 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
4600 4601 4602 |
# File 'lib/models/porcelain.rb', line 4600 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
4602 4603 4604 |
# File 'lib/models/porcelain.rb', line 4602 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4604 4605 4606 |
# File 'lib/models/porcelain.rb', line 4604 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4606 4607 4608 |
# File 'lib/models/porcelain.rb', line 4606 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4608 4609 4610 |
# File 'lib/models/porcelain.rb', line 4608 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4610 4611 4612 |
# File 'lib/models/porcelain.rb', line 4610 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4612 4613 4614 |
# File 'lib/models/porcelain.rb', line 4612 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4614 4615 4616 |
# File 'lib/models/porcelain.rb', line 4614 def @tags end |
#username ⇒ Object
The username to authenticate with.
4616 4617 4618 |
# File 'lib/models/porcelain.rb', line 4616 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4654 4655 4656 4657 4658 4659 4660 |
# File 'lib/models/porcelain.rb', line 4654 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |