Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
4560
4561
4562
4563
4564
4565
4566
4567
4568
4569
4570
4571
4572
4573
# File 'lib/models/porcelain.rb', line 4539

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4507
4508
4509
# File 'lib/models/porcelain.rb', line 4507

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4509
4510
4511
# File 'lib/models/porcelain.rb', line 4509

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4511
4512
4513
# File 'lib/models/porcelain.rb', line 4511

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4513
4514
4515
# File 'lib/models/porcelain.rb', line 4513

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4515
4516
4517
# File 'lib/models/porcelain.rb', line 4515

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4517
4518
4519
# File 'lib/models/porcelain.rb', line 4517

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4519
4520
4521
# File 'lib/models/porcelain.rb', line 4519

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4521
4522
4523
# File 'lib/models/porcelain.rb', line 4521

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4523
4524
4525
# File 'lib/models/porcelain.rb', line 4523

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4525
4526
4527
# File 'lib/models/porcelain.rb', line 4525

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4527
4528
4529
# File 'lib/models/porcelain.rb', line 4527

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4529
4530
4531
# File 'lib/models/porcelain.rb', line 4529

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4531
4532
4533
# File 'lib/models/porcelain.rb', line 4531

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4533
4534
4535
# File 'lib/models/porcelain.rb', line 4533

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4535
4536
4537
# File 'lib/models/porcelain.rb', line 4535

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4537
4538
4539
# File 'lib/models/porcelain.rb', line 4537

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4575
4576
4577
4578
4579
4580
4581
# File 'lib/models/porcelain.rb', line 4575

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end