Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
4466
4467
4468
4469
4470
# File 'lib/models/porcelain.rb', line 4436

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4404
4405
4406
# File 'lib/models/porcelain.rb', line 4404

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4406
4407
4408
# File 'lib/models/porcelain.rb', line 4406

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4408
4409
4410
# File 'lib/models/porcelain.rb', line 4408

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4410
4411
4412
# File 'lib/models/porcelain.rb', line 4410

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4412
4413
4414
# File 'lib/models/porcelain.rb', line 4412

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4414
4415
4416
# File 'lib/models/porcelain.rb', line 4414

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4416
4417
4418
# File 'lib/models/porcelain.rb', line 4416

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4418
4419
4420
# File 'lib/models/porcelain.rb', line 4418

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4420
4421
4422
# File 'lib/models/porcelain.rb', line 4420

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4422
4423
4424
# File 'lib/models/porcelain.rb', line 4422

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4424
4425
4426
# File 'lib/models/porcelain.rb', line 4424

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4426
4427
4428
# File 'lib/models/porcelain.rb', line 4426

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4428
4429
4430
# File 'lib/models/porcelain.rb', line 4428

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4430
4431
4432
# File 'lib/models/porcelain.rb', line 4430

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4432
4433
4434
# File 'lib/models/porcelain.rb', line 4432

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4434
4435
4436
# File 'lib/models/porcelain.rb', line 4434

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4472
4473
4474
4475
4476
4477
4478
# File 'lib/models/porcelain.rb', line 4472

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end