Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
4317
4318
4319
# File 'lib/models/porcelain.rb', line 4285

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4253
4254
4255
# File 'lib/models/porcelain.rb', line 4253

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4255
4256
4257
# File 'lib/models/porcelain.rb', line 4255

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4257
4258
4259
# File 'lib/models/porcelain.rb', line 4257

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4259
4260
4261
# File 'lib/models/porcelain.rb', line 4259

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4261
4262
4263
# File 'lib/models/porcelain.rb', line 4261

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4263
4264
4265
# File 'lib/models/porcelain.rb', line 4263

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4265
4266
4267
# File 'lib/models/porcelain.rb', line 4265

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4267
4268
4269
# File 'lib/models/porcelain.rb', line 4267

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4269
4270
4271
# File 'lib/models/porcelain.rb', line 4269

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4271
4272
4273
# File 'lib/models/porcelain.rb', line 4271

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4273
4274
4275
# File 'lib/models/porcelain.rb', line 4273

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4275
4276
4277
# File 'lib/models/porcelain.rb', line 4275

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4277
4278
4279
# File 'lib/models/porcelain.rb', line 4277

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4279
4280
4281
# File 'lib/models/porcelain.rb', line 4279

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4281
4282
4283
# File 'lib/models/porcelain.rb', line 4281

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4283
4284
4285
# File 'lib/models/porcelain.rb', line 4283

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4321
4322
4323
4324
4325
4326
4327
# File 'lib/models/porcelain.rb', line 4321

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end