Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
# File 'lib/models/porcelain.rb', line 4060

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4028
4029
4030
# File 'lib/models/porcelain.rb', line 4028

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4030
4031
4032
# File 'lib/models/porcelain.rb', line 4030

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4032
4033
4034
# File 'lib/models/porcelain.rb', line 4032

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4034
4035
4036
# File 'lib/models/porcelain.rb', line 4034

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4036
4037
4038
# File 'lib/models/porcelain.rb', line 4036

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4038
4039
4040
# File 'lib/models/porcelain.rb', line 4038

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4040
4041
4042
# File 'lib/models/porcelain.rb', line 4040

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4042
4043
4044
# File 'lib/models/porcelain.rb', line 4042

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4044
4045
4046
# File 'lib/models/porcelain.rb', line 4044

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4046
4047
4048
# File 'lib/models/porcelain.rb', line 4046

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4048
4049
4050
# File 'lib/models/porcelain.rb', line 4048

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4050
4051
4052
# File 'lib/models/porcelain.rb', line 4050

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4052
4053
4054
# File 'lib/models/porcelain.rb', line 4052

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4054
4055
4056
# File 'lib/models/porcelain.rb', line 4054

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4056
4057
4058
# File 'lib/models/porcelain.rb', line 4056

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4058
4059
4060
# File 'lib/models/porcelain.rb', line 4058

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4096
4097
4098
4099
4100
4101
4102
# File 'lib/models/porcelain.rb', line 4096

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end