Class: SDM::Cockroach
- Inherits:
-
Object
- Object
- SDM::Cockroach
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach
constructor
A new instance of Cockroach.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach
Returns a new instance of Cockroach.
4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 |
# File 'lib/models/porcelain.rb', line 4060 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4028 4029 4030 |
# File 'lib/models/porcelain.rb', line 4028 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4030 4031 4032 |
# File 'lib/models/porcelain.rb', line 4030 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4032 4033 4034 |
# File 'lib/models/porcelain.rb', line 4032 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4034 4035 4036 |
# File 'lib/models/porcelain.rb', line 4034 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4036 4037 4038 |
# File 'lib/models/porcelain.rb', line 4036 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4038 4039 4040 |
# File 'lib/models/porcelain.rb', line 4038 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4040 4041 4042 |
# File 'lib/models/porcelain.rb', line 4040 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
4042 4043 4044 |
# File 'lib/models/porcelain.rb', line 4042 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
4044 4045 4046 |
# File 'lib/models/porcelain.rb', line 4044 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4046 4047 4048 |
# File 'lib/models/porcelain.rb', line 4046 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4048 4049 4050 |
# File 'lib/models/porcelain.rb', line 4048 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4050 4051 4052 |
# File 'lib/models/porcelain.rb', line 4050 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4052 4053 4054 |
# File 'lib/models/porcelain.rb', line 4052 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4054 4055 4056 |
# File 'lib/models/porcelain.rb', line 4054 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4056 4057 4058 |
# File 'lib/models/porcelain.rb', line 4056 def @tags end |
#username ⇒ Object
The username to authenticate with.
4058 4059 4060 |
# File 'lib/models/porcelain.rb', line 4058 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4096 4097 4098 4099 4100 4101 4102 |
# File 'lib/models/porcelain.rb', line 4096 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |