Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
# File 'lib/models/porcelain.rb', line 2823

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



2793
2794
2795
# File 'lib/models/porcelain.rb', line 2793

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



2795
2796
2797
# File 'lib/models/porcelain.rb', line 2795

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2797
2798
2799
# File 'lib/models/porcelain.rb', line 2797

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2799
2800
2801
# File 'lib/models/porcelain.rb', line 2799

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



2801
2802
2803
# File 'lib/models/porcelain.rb', line 2801

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2803
2804
2805
# File 'lib/models/porcelain.rb', line 2803

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2805
2806
2807
# File 'lib/models/porcelain.rb', line 2805

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



2807
2808
2809
# File 'lib/models/porcelain.rb', line 2807

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



2809
2810
2811
# File 'lib/models/porcelain.rb', line 2809

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



2811
2812
2813
# File 'lib/models/porcelain.rb', line 2811

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



2813
2814
2815
# File 'lib/models/porcelain.rb', line 2813

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2815
2816
2817
# File 'lib/models/porcelain.rb', line 2815

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2817
2818
2819
# File 'lib/models/porcelain.rb', line 2817

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2819
2820
2821
# File 'lib/models/porcelain.rb', line 2819

def tags
  @tags
end

#usernameObject

The username to authenticate with.



2821
2822
2823
# File 'lib/models/porcelain.rb', line 2821

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2857
2858
2859
2860
2861
2862
2863
# File 'lib/models/porcelain.rb', line 2857

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end