Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
# File 'lib/models/porcelain.rb', line 2730

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2700
2701
2702
# File 'lib/models/porcelain.rb', line 2700

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2702
2703
2704
# File 'lib/models/porcelain.rb', line 2702

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2704
2705
2706
# File 'lib/models/porcelain.rb', line 2704

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2706
2707
2708
# File 'lib/models/porcelain.rb', line 2706

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2708
2709
2710
# File 'lib/models/porcelain.rb', line 2708

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2710
2711
2712
# File 'lib/models/porcelain.rb', line 2710

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2712
2713
2714
# File 'lib/models/porcelain.rb', line 2712

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



2714
2715
2716
# File 'lib/models/porcelain.rb', line 2714

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



2716
2717
2718
# File 'lib/models/porcelain.rb', line 2716

def password
  @password
end

#portObject

Returns the value of attribute port.



2718
2719
2720
# File 'lib/models/porcelain.rb', line 2718

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2720
2721
2722
# File 'lib/models/porcelain.rb', line 2720

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2722
2723
2724
# File 'lib/models/porcelain.rb', line 2722

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2724
2725
2726
# File 'lib/models/porcelain.rb', line 2724

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2726
2727
2728
# File 'lib/models/porcelain.rb', line 2726

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2728
2729
2730
# File 'lib/models/porcelain.rb', line 2728

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2764
2765
2766
2767
2768
2769
2770
# File 'lib/models/porcelain.rb', line 2764

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end