Class: SDM::Cockroach
- Inherits:
-
Object
- Object
- SDM::Cockroach
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Cockroach
constructor
A new instance of Cockroach.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Cockroach
Returns a new instance of Cockroach.
2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 |
# File 'lib/models/porcelain.rb', line 2466 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2438 2439 2440 |
# File 'lib/models/porcelain.rb', line 2438 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
2440 2441 2442 |
# File 'lib/models/porcelain.rb', line 2440 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2442 2443 2444 |
# File 'lib/models/porcelain.rb', line 2442 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2444 2445 2446 |
# File 'lib/models/porcelain.rb', line 2444 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2446 2447 2448 |
# File 'lib/models/porcelain.rb', line 2446 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2448 2449 2450 |
# File 'lib/models/porcelain.rb', line 2448 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2450 2451 2452 |
# File 'lib/models/porcelain.rb', line 2450 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
2452 2453 2454 |
# File 'lib/models/porcelain.rb', line 2452 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
2454 2455 2456 |
# File 'lib/models/porcelain.rb', line 2454 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2456 2457 2458 |
# File 'lib/models/porcelain.rb', line 2456 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2458 2459 2460 |
# File 'lib/models/porcelain.rb', line 2458 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2460 2461 2462 |
# File 'lib/models/porcelain.rb', line 2460 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2462 2463 2464 |
# File 'lib/models/porcelain.rb', line 2462 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2464 2465 2466 |
# File 'lib/models/porcelain.rb', line 2464 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2498 2499 2500 2501 2502 2503 2504 |
# File 'lib/models/porcelain.rb', line 2498 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |