Class: SDM::Cockroach

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Cockroach

Returns a new instance of Cockroach.



2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/models/porcelain.rb', line 2128

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2100
2101
2102
# File 'lib/models/porcelain.rb', line 2100

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2102
2103
2104
# File 'lib/models/porcelain.rb', line 2102

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2104
2105
2106
# File 'lib/models/porcelain.rb', line 2104

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2106
2107
2108
# File 'lib/models/porcelain.rb', line 2106

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2108
2109
2110
# File 'lib/models/porcelain.rb', line 2108

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2110
2111
2112
# File 'lib/models/porcelain.rb', line 2110

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2112
2113
2114
# File 'lib/models/porcelain.rb', line 2112

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



2114
2115
2116
# File 'lib/models/porcelain.rb', line 2114

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



2116
2117
2118
# File 'lib/models/porcelain.rb', line 2116

def password
  @password
end

#portObject

Returns the value of attribute port.



2118
2119
2120
# File 'lib/models/porcelain.rb', line 2118

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2120
2121
2122
# File 'lib/models/porcelain.rb', line 2120

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2122
2123
2124
# File 'lib/models/porcelain.rb', line 2122

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2124
2125
2126
# File 'lib/models/porcelain.rb', line 2124

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2126
2127
2128
# File 'lib/models/porcelain.rb', line 2126

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2160
2161
2162
2163
2164
2165
2166
# File 'lib/models/porcelain.rb', line 2160

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end