Class: SDM::Cockroach
- Inherits:
-
Object
- Object
- SDM::Cockroach
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Cockroach
constructor
A new instance of Cockroach.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Cockroach
Returns a new instance of Cockroach.
2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 |
# File 'lib/models/porcelain.rb', line 2250 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if override_database != nil @override_database = override_database end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
2224 2225 2226 |
# File 'lib/models/porcelain.rb', line 2224 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2226 2227 2228 |
# File 'lib/models/porcelain.rb', line 2226 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2228 2229 2230 |
# File 'lib/models/porcelain.rb', line 2228 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2230 2231 2232 |
# File 'lib/models/porcelain.rb', line 2230 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2232 2233 2234 |
# File 'lib/models/porcelain.rb', line 2232 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2234 2235 2236 |
# File 'lib/models/porcelain.rb', line 2234 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
2236 2237 2238 |
# File 'lib/models/porcelain.rb', line 2236 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
2238 2239 2240 |
# File 'lib/models/porcelain.rb', line 2238 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2240 2241 2242 |
# File 'lib/models/porcelain.rb', line 2240 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2242 2243 2244 |
# File 'lib/models/porcelain.rb', line 2242 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2244 2245 2246 |
# File 'lib/models/porcelain.rb', line 2244 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2246 2247 2248 |
# File 'lib/models/porcelain.rb', line 2246 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2248 2249 2250 |
# File 'lib/models/porcelain.rb', line 2248 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/models/porcelain.rb', line 2306 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |