Class: SDM::CouchbaseDatabase
- Inherits:
-
Object
- Object
- SDM::CouchbaseDatabase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#n1ql_port ⇒ Object
The port number for N1QL queries.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase
constructor
A new instance of CouchbaseDatabase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase
Returns a new instance of CouchbaseDatabase.
5094 5095 5096 5097 5098 5099 5100 5101 5102 5103 5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/models/porcelain.rb', line 5094 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @n1ql_port = n1ql_port == nil ? 0 : n1ql_port @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5062 5063 5064 |
# File 'lib/models/porcelain.rb', line 5062 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5064 5065 5066 |
# File 'lib/models/porcelain.rb', line 5064 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5066 5067 5068 |
# File 'lib/models/porcelain.rb', line 5066 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5068 5069 5070 |
# File 'lib/models/porcelain.rb', line 5068 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5070 5071 5072 |
# File 'lib/models/porcelain.rb', line 5070 def id @id end |
#n1ql_port ⇒ Object
The port number for N1QL queries. Default HTTP is 8093. Default HTTPS is 18093.
5072 5073 5074 |
# File 'lib/models/porcelain.rb', line 5072 def n1ql_port @n1ql_port end |
#name ⇒ Object
Unique human-readable name of the Resource.
5074 5075 5076 |
# File 'lib/models/porcelain.rb', line 5074 def name @name end |
#password ⇒ Object
The password to authenticate with.
5076 5077 5078 |
# File 'lib/models/porcelain.rb', line 5076 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5078 5079 5080 |
# File 'lib/models/porcelain.rb', line 5078 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5080 5081 5082 |
# File 'lib/models/porcelain.rb', line 5080 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5082 5083 5084 |
# File 'lib/models/porcelain.rb', line 5082 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5084 5085 5086 |
# File 'lib/models/porcelain.rb', line 5084 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5086 5087 5088 |
# File 'lib/models/porcelain.rb', line 5086 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5088 5089 5090 |
# File 'lib/models/porcelain.rb', line 5088 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5090 5091 5092 |
# File 'lib/models/porcelain.rb', line 5090 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5092 5093 5094 |
# File 'lib/models/porcelain.rb', line 5092 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5130 5131 5132 5133 5134 5135 5136 |
# File 'lib/models/porcelain.rb', line 5130 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |