Class: SDM::CouchbaseDatabase

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase

Returns a new instance of CouchbaseDatabase.



4706
4707
4708
4709
4710
4711
4712
4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
# File 'lib/models/porcelain.rb', line 4706

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  n1ql_port: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @n1ql_port = n1ql_port == nil ? 0 : n1ql_port
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4674
4675
4676
# File 'lib/models/porcelain.rb', line 4674

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4676
4677
4678
# File 'lib/models/porcelain.rb', line 4676

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4678
4679
4680
# File 'lib/models/porcelain.rb', line 4678

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4680
4681
4682
# File 'lib/models/porcelain.rb', line 4680

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4682
4683
4684
# File 'lib/models/porcelain.rb', line 4682

def id
  @id
end

#n1ql_portObject

The port number for N1QL queries. Default HTTP is 8093. Default HTTPS is 18093.



4684
4685
4686
# File 'lib/models/porcelain.rb', line 4684

def n1ql_port
  @n1ql_port
end

#nameObject

Unique human-readable name of the Resource.



4686
4687
4688
# File 'lib/models/porcelain.rb', line 4686

def name
  @name
end

#passwordObject

The password to authenticate with.



4688
4689
4690
# File 'lib/models/porcelain.rb', line 4688

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4690
4691
4692
# File 'lib/models/porcelain.rb', line 4690

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4692
4693
4694
# File 'lib/models/porcelain.rb', line 4692

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4694
4695
4696
# File 'lib/models/porcelain.rb', line 4694

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4696
4697
4698
# File 'lib/models/porcelain.rb', line 4696

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4698
4699
4700
# File 'lib/models/porcelain.rb', line 4698

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4700
4701
4702
# File 'lib/models/porcelain.rb', line 4700

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



4702
4703
4704
# File 'lib/models/porcelain.rb', line 4702

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



4704
4705
4706
# File 'lib/models/porcelain.rb', line 4704

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4742
4743
4744
4745
4746
4747
4748
# File 'lib/models/porcelain.rb', line 4742

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end