Class: SDM::CouchbaseDatabase
- Inherits:
-
Object
- Object
- SDM::CouchbaseDatabase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#n1ql_port ⇒ Object
The port number for N1QL queries.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase
constructor
A new instance of CouchbaseDatabase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase
Returns a new instance of CouchbaseDatabase.
4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 |
# File 'lib/models/porcelain.rb', line 4601 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @n1ql_port = n1ql_port == nil ? 0 : n1ql_port @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4569 4570 4571 |
# File 'lib/models/porcelain.rb', line 4569 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4571 4572 4573 |
# File 'lib/models/porcelain.rb', line 4571 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4573 4574 4575 |
# File 'lib/models/porcelain.rb', line 4573 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4575 4576 4577 |
# File 'lib/models/porcelain.rb', line 4575 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4577 4578 4579 |
# File 'lib/models/porcelain.rb', line 4577 def id @id end |
#n1ql_port ⇒ Object
The port number for N1QL queries. Default HTTP is 8093. Default HTTPS is 18093.
4579 4580 4581 |
# File 'lib/models/porcelain.rb', line 4579 def n1ql_port @n1ql_port end |
#name ⇒ Object
Unique human-readable name of the Resource.
4581 4582 4583 |
# File 'lib/models/porcelain.rb', line 4581 def name @name end |
#password ⇒ Object
The password to authenticate with.
4583 4584 4585 |
# File 'lib/models/porcelain.rb', line 4583 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4585 4586 4587 |
# File 'lib/models/porcelain.rb', line 4585 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4587 4588 4589 |
# File 'lib/models/porcelain.rb', line 4587 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4589 4590 4591 |
# File 'lib/models/porcelain.rb', line 4589 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4591 4592 4593 |
# File 'lib/models/porcelain.rb', line 4591 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4593 4594 4595 |
# File 'lib/models/porcelain.rb', line 4593 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4595 4596 4597 |
# File 'lib/models/porcelain.rb', line 4595 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4597 4598 4599 |
# File 'lib/models/porcelain.rb', line 4597 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4599 4600 4601 |
# File 'lib/models/porcelain.rb', line 4599 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/models/porcelain.rb', line 4637 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |