Class: SDM::CouchbaseDatabase
- Inherits:
-
Object
- Object
- SDM::CouchbaseDatabase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#n1ql_port ⇒ Object
The port number for N1QL queries.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase
constructor
A new instance of CouchbaseDatabase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase
Returns a new instance of CouchbaseDatabase.
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 3966 3967 3968 3969 3970 3971 3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 |
# File 'lib/models/porcelain.rb', line 3953 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @n1ql_port = n1ql_port == nil ? 0 : n1ql_port @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3923 3924 3925 |
# File 'lib/models/porcelain.rb', line 3923 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3925 3926 3927 |
# File 'lib/models/porcelain.rb', line 3925 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3927 3928 3929 |
# File 'lib/models/porcelain.rb', line 3927 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3929 3930 3931 |
# File 'lib/models/porcelain.rb', line 3929 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3931 3932 3933 |
# File 'lib/models/porcelain.rb', line 3931 def id @id end |
#n1ql_port ⇒ Object
The port number for N1QL queries. Default HTTP is 8093. Default HTTPS is 18093.
3933 3934 3935 |
# File 'lib/models/porcelain.rb', line 3933 def n1ql_port @n1ql_port end |
#name ⇒ Object
Unique human-readable name of the Resource.
3935 3936 3937 |
# File 'lib/models/porcelain.rb', line 3935 def name @name end |
#password ⇒ Object
The password to authenticate with.
3937 3938 3939 |
# File 'lib/models/porcelain.rb', line 3937 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3939 3940 3941 |
# File 'lib/models/porcelain.rb', line 3939 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3941 3942 3943 |
# File 'lib/models/porcelain.rb', line 3941 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3943 3944 3945 |
# File 'lib/models/porcelain.rb', line 3943 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3945 3946 3947 |
# File 'lib/models/porcelain.rb', line 3945 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3947 3948 3949 |
# File 'lib/models/porcelain.rb', line 3947 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
3949 3950 3951 |
# File 'lib/models/porcelain.rb', line 3949 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
3951 3952 3953 |
# File 'lib/models/porcelain.rb', line 3951 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3987 3988 3989 3990 3991 3992 3993 |
# File 'lib/models/porcelain.rb', line 3987 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |