Class: SDM::CouchbaseDatabase
- Inherits:
-
Object
- Object
- SDM::CouchbaseDatabase
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#n1ql_port ⇒ Object
The port number for N1QL queries.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase
constructor
A new instance of CouchbaseDatabase.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ CouchbaseDatabase
Returns a new instance of CouchbaseDatabase.
5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 5937 5938 5939 5940 5941 5942 5943 5944 5945 |
# File 'lib/models/porcelain.rb', line 5911 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, n1ql_port: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @n1ql_port = n1ql_port == nil ? 0 : n1ql_port @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
5879 5880 5881 |
# File 'lib/models/porcelain.rb', line 5879 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5881 5882 5883 |
# File 'lib/models/porcelain.rb', line 5881 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5883 5884 5885 |
# File 'lib/models/porcelain.rb', line 5883 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5885 5886 5887 |
# File 'lib/models/porcelain.rb', line 5885 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5887 5888 5889 |
# File 'lib/models/porcelain.rb', line 5887 def id @id end |
#n1ql_port ⇒ Object
The port number for N1QL queries. Default HTTP is 8093. Default HTTPS is 18093.
5889 5890 5891 |
# File 'lib/models/porcelain.rb', line 5889 def n1ql_port @n1ql_port end |
#name ⇒ Object
Unique human-readable name of the Resource.
5891 5892 5893 |
# File 'lib/models/porcelain.rb', line 5891 def name @name end |
#password ⇒ Object
The password to authenticate with.
5893 5894 5895 |
# File 'lib/models/porcelain.rb', line 5893 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5895 5896 5897 |
# File 'lib/models/porcelain.rb', line 5895 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
5897 5898 5899 |
# File 'lib/models/porcelain.rb', line 5897 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5899 5900 5901 |
# File 'lib/models/porcelain.rb', line 5899 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5901 5902 5903 |
# File 'lib/models/porcelain.rb', line 5901 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
5903 5904 5905 |
# File 'lib/models/porcelain.rb', line 5903 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5905 5906 5907 |
# File 'lib/models/porcelain.rb', line 5905 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5907 5908 5909 |
# File 'lib/models/porcelain.rb', line 5907 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5909 5910 5911 |
# File 'lib/models/porcelain.rb', line 5909 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5947 5948 5949 5950 5951 5952 5953 |
# File 'lib/models/porcelain.rb', line 5947 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |