Class: SDM::CouchbaseWebUI

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI

Returns a new instance of CouchbaseWebUI.



5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
# File 'lib/models/porcelain.rb', line 5167

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5141
5142
5143
# File 'lib/models/porcelain.rb', line 5141

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5143
5144
5145
# File 'lib/models/porcelain.rb', line 5143

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5145
5146
5147
# File 'lib/models/porcelain.rb', line 5145

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5147
5148
5149
# File 'lib/models/porcelain.rb', line 5147

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5149
5150
5151
# File 'lib/models/porcelain.rb', line 5149

def name
  @name
end

#passwordObject

The password to authenticate with.



5151
5152
5153
# File 'lib/models/porcelain.rb', line 5151

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



5153
5154
5155
# File 'lib/models/porcelain.rb', line 5153

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5155
5156
5157
# File 'lib/models/porcelain.rb', line 5155

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5157
5158
5159
# File 'lib/models/porcelain.rb', line 5157

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5159
5160
5161
# File 'lib/models/porcelain.rb', line 5159

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5161
5162
5163
# File 'lib/models/porcelain.rb', line 5161

def tags
  @tags
end

#urlObject

The base address of your website without the path.



5163
5164
5165
# File 'lib/models/porcelain.rb', line 5163

def url
  @url
end

#usernameObject

The username to authenticate with.



5165
5166
5167
# File 'lib/models/porcelain.rb', line 5165

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5197
5198
5199
5200
5201
5202
5203
# File 'lib/models/porcelain.rb', line 5197

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end