Class: SDM::CouchbaseWebUI
- Inherits:
-
Object
- Object
- SDM::CouchbaseWebUI
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI
constructor
A new instance of CouchbaseWebUI.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI
Returns a new instance of CouchbaseWebUI.
5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 |
# File 'lib/models/porcelain.rb', line 5005 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4979 4980 4981 |
# File 'lib/models/porcelain.rb', line 4979 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4981 4982 4983 |
# File 'lib/models/porcelain.rb', line 4981 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4983 4984 4985 |
# File 'lib/models/porcelain.rb', line 4983 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4985 4986 4987 |
# File 'lib/models/porcelain.rb', line 4985 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4987 4988 4989 |
# File 'lib/models/porcelain.rb', line 4987 def name @name end |
#password ⇒ Object
The password to authenticate with.
4989 4990 4991 |
# File 'lib/models/porcelain.rb', line 4989 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4991 4992 4993 |
# File 'lib/models/porcelain.rb', line 4991 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4993 4994 4995 |
# File 'lib/models/porcelain.rb', line 4993 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4995 4996 4997 |
# File 'lib/models/porcelain.rb', line 4995 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4997 4998 4999 |
# File 'lib/models/porcelain.rb', line 4997 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4999 5000 5001 |
# File 'lib/models/porcelain.rb', line 4999 def @tags end |
#url ⇒ Object
The base address of your website without the path.
5001 5002 5003 |
# File 'lib/models/porcelain.rb', line 5001 def url @url end |
#username ⇒ Object
The username to authenticate with.
5003 5004 5005 |
# File 'lib/models/porcelain.rb', line 5003 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5035 5036 5037 5038 5039 5040 5041 |
# File 'lib/models/porcelain.rb', line 5035 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |