Class: SDM::CouchbaseWebUI

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI

Returns a new instance of CouchbaseWebUI.



4858
4859
4860
4861
4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
# File 'lib/models/porcelain.rb', line 4858

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4832
4833
4834
# File 'lib/models/porcelain.rb', line 4832

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4834
4835
4836
# File 'lib/models/porcelain.rb', line 4834

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4836
4837
4838
# File 'lib/models/porcelain.rb', line 4836

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4838
4839
4840
# File 'lib/models/porcelain.rb', line 4838

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4840
4841
4842
# File 'lib/models/porcelain.rb', line 4840

def name
  @name
end

#passwordObject

The password to authenticate with.



4842
4843
4844
# File 'lib/models/porcelain.rb', line 4842

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



4844
4845
4846
# File 'lib/models/porcelain.rb', line 4844

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4846
4847
4848
# File 'lib/models/porcelain.rb', line 4846

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4848
4849
4850
# File 'lib/models/porcelain.rb', line 4848

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4850
4851
4852
# File 'lib/models/porcelain.rb', line 4850

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4852
4853
4854
# File 'lib/models/porcelain.rb', line 4852

def tags
  @tags
end

#urlObject

The base address of your website without the path.



4854
4855
4856
# File 'lib/models/porcelain.rb', line 4854

def url
  @url
end

#usernameObject

The username to authenticate with.



4856
4857
4858
# File 'lib/models/porcelain.rb', line 4856

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4888
4889
4890
4891
4892
4893
4894
# File 'lib/models/porcelain.rb', line 4888

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end