Class: SDM::CouchbaseWebUI

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI

Returns a new instance of CouchbaseWebUI.



4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
# File 'lib/models/porcelain.rb', line 4779

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4753
4754
4755
# File 'lib/models/porcelain.rb', line 4753

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4755
4756
4757
# File 'lib/models/porcelain.rb', line 4755

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4757
4758
4759
# File 'lib/models/porcelain.rb', line 4757

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4759
4760
4761
# File 'lib/models/porcelain.rb', line 4759

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4761
4762
4763
# File 'lib/models/porcelain.rb', line 4761

def name
  @name
end

#passwordObject

The password to authenticate with.



4763
4764
4765
# File 'lib/models/porcelain.rb', line 4763

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



4765
4766
4767
# File 'lib/models/porcelain.rb', line 4765

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4767
4768
4769
# File 'lib/models/porcelain.rb', line 4767

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4769
4770
4771
# File 'lib/models/porcelain.rb', line 4769

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4771
4772
4773
# File 'lib/models/porcelain.rb', line 4771

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4773
4774
4775
# File 'lib/models/porcelain.rb', line 4773

def tags
  @tags
end

#urlObject

The base address of your website without the path.



4775
4776
4777
# File 'lib/models/porcelain.rb', line 4775

def url
  @url
end

#usernameObject

The username to authenticate with.



4777
4778
4779
# File 'lib/models/porcelain.rb', line 4777

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4809
4810
4811
4812
4813
4814
4815
# File 'lib/models/porcelain.rb', line 4809

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end