Class: SDM::CouchbaseWebUI
- Inherits:
-
Object
- Object
- SDM::CouchbaseWebUI
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI
constructor
A new instance of CouchbaseWebUI.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI
Returns a new instance of CouchbaseWebUI.
4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/models/porcelain.rb', line 4300 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4274 4275 4276 |
# File 'lib/models/porcelain.rb', line 4274 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4276 4277 4278 |
# File 'lib/models/porcelain.rb', line 4276 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4278 4279 4280 |
# File 'lib/models/porcelain.rb', line 4278 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4280 4281 4282 |
# File 'lib/models/porcelain.rb', line 4280 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4282 4283 4284 |
# File 'lib/models/porcelain.rb', line 4282 def name @name end |
#password ⇒ Object
The password to authenticate with.
4284 4285 4286 |
# File 'lib/models/porcelain.rb', line 4284 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4286 4287 4288 |
# File 'lib/models/porcelain.rb', line 4286 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4288 4289 4290 |
# File 'lib/models/porcelain.rb', line 4288 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4290 4291 4292 |
# File 'lib/models/porcelain.rb', line 4290 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4292 4293 4294 |
# File 'lib/models/porcelain.rb', line 4292 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4294 4295 4296 |
# File 'lib/models/porcelain.rb', line 4294 def @tags end |
#url ⇒ Object
The base address of your website without the path.
4296 4297 4298 |
# File 'lib/models/porcelain.rb', line 4296 def url @url end |
#username ⇒ Object
The username to authenticate with.
4298 4299 4300 |
# File 'lib/models/porcelain.rb', line 4298 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4330 4331 4332 4333 4334 4335 4336 |
# File 'lib/models/porcelain.rb', line 4330 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |