Class: SDM::CouchbaseWebUI
- Inherits:
-
Object
- Object
- SDM::CouchbaseWebUI
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI
constructor
A new instance of CouchbaseWebUI.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI
Returns a new instance of CouchbaseWebUI.
4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 |
# File 'lib/models/porcelain.rb', line 4022 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3998 3999 4000 |
# File 'lib/models/porcelain.rb', line 3998 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4000 4001 4002 |
# File 'lib/models/porcelain.rb', line 4000 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4002 4003 4004 |
# File 'lib/models/porcelain.rb', line 4002 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4004 4005 4006 |
# File 'lib/models/porcelain.rb', line 4004 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4006 4007 4008 |
# File 'lib/models/porcelain.rb', line 4006 def name @name end |
#password ⇒ Object
The password to authenticate with.
4008 4009 4010 |
# File 'lib/models/porcelain.rb', line 4008 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4010 4011 4012 |
# File 'lib/models/porcelain.rb', line 4010 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4012 4013 4014 |
# File 'lib/models/porcelain.rb', line 4012 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4014 4015 4016 |
# File 'lib/models/porcelain.rb', line 4014 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4016 4017 4018 |
# File 'lib/models/porcelain.rb', line 4016 def @tags end |
#url ⇒ Object
The base address of your website without the path.
4018 4019 4020 |
# File 'lib/models/porcelain.rb', line 4018 def url @url end |
#username ⇒ Object
The username to authenticate with.
4020 4021 4022 |
# File 'lib/models/porcelain.rb', line 4020 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4050 4051 4052 4053 4054 4055 4056 |
# File 'lib/models/porcelain.rb', line 4050 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |