Class: SDM::CouchbaseWebUI
- Inherits:
-
Object
- Object
- SDM::CouchbaseWebUI
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI
constructor
A new instance of CouchbaseWebUI.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ CouchbaseWebUI
4847 4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/models/porcelain.rb', line 4847 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4821 4822 4823 |
# File 'lib/models/porcelain.rb', line 4821 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4823 4824 4825 |
# File 'lib/models/porcelain.rb', line 4823 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4825 4826 4827 |
# File 'lib/models/porcelain.rb', line 4825 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4827 4828 4829 |
# File 'lib/models/porcelain.rb', line 4827 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4829 4830 4831 |
# File 'lib/models/porcelain.rb', line 4829 def name @name end |
#password ⇒ Object
The password to authenticate with.
4831 4832 4833 |
# File 'lib/models/porcelain.rb', line 4831 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4833 4834 4835 |
# File 'lib/models/porcelain.rb', line 4833 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4835 4836 4837 |
# File 'lib/models/porcelain.rb', line 4835 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4837 4838 4839 |
# File 'lib/models/porcelain.rb', line 4837 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4839 4840 4841 |
# File 'lib/models/porcelain.rb', line 4839 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4841 4842 4843 |
# File 'lib/models/porcelain.rb', line 4841 def end |
#url ⇒ Object
The base address of your website without the path.
4843 4844 4845 |
# File 'lib/models/porcelain.rb', line 4843 def url @url end |
#username ⇒ Object
The username to authenticate with.
4845 4846 4847 |
# File 'lib/models/porcelain.rb', line 4845 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/models/porcelain.rb', line 4877 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |