Class: SDM::DB2I

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I

Returns a new instance of DB2I.



5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
5936
# File 'lib/models/porcelain.rb', line 5904

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



5874
5875
5876
# File 'lib/models/porcelain.rb', line 5874

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5876
5877
5878
# File 'lib/models/porcelain.rb', line 5876

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5878
5879
5880
# File 'lib/models/porcelain.rb', line 5878

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5880
5881
5882
# File 'lib/models/porcelain.rb', line 5880

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5882
5883
5884
# File 'lib/models/porcelain.rb', line 5882

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5884
5885
5886
# File 'lib/models/porcelain.rb', line 5884

def name
  @name
end

#passwordObject

The password to authenticate with.



5886
5887
5888
# File 'lib/models/porcelain.rb', line 5886

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5888
5889
5890
# File 'lib/models/porcelain.rb', line 5888

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



5890
5891
5892
# File 'lib/models/porcelain.rb', line 5890

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5892
5893
5894
# File 'lib/models/porcelain.rb', line 5892

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5894
5895
5896
# File 'lib/models/porcelain.rb', line 5894

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



5896
5897
5898
# File 'lib/models/porcelain.rb', line 5896

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5898
5899
5900
# File 'lib/models/porcelain.rb', line 5898

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5900
5901
5902
# File 'lib/models/porcelain.rb', line 5900

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5902
5903
5904
# File 'lib/models/porcelain.rb', line 5902

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5938
5939
5940
5941
5942
5943
5944
# File 'lib/models/porcelain.rb', line 5938

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end