Class: SDM::DB2I

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I

Returns a new instance of DB2I.



4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
4981
4982
4983
4984
4985
4986
4987
4988
4989
4990
# File 'lib/models/porcelain.rb', line 4958

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4928
4929
4930
# File 'lib/models/porcelain.rb', line 4928

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4930
4931
4932
# File 'lib/models/porcelain.rb', line 4930

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4932
4933
4934
# File 'lib/models/porcelain.rb', line 4932

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4934
4935
4936
# File 'lib/models/porcelain.rb', line 4934

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4936
4937
4938
# File 'lib/models/porcelain.rb', line 4936

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4938
4939
4940
# File 'lib/models/porcelain.rb', line 4938

def name
  @name
end

#passwordObject

The password to authenticate with.



4940
4941
4942
# File 'lib/models/porcelain.rb', line 4940

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4942
4943
4944
# File 'lib/models/porcelain.rb', line 4942

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4944
4945
4946
# File 'lib/models/porcelain.rb', line 4944

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4946
4947
4948
# File 'lib/models/porcelain.rb', line 4946

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4948
4949
4950
# File 'lib/models/porcelain.rb', line 4948

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4950
4951
4952
# File 'lib/models/porcelain.rb', line 4950

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4952
4953
4954
# File 'lib/models/porcelain.rb', line 4952

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



4954
4955
4956
# File 'lib/models/porcelain.rb', line 4954

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



4956
4957
4958
# File 'lib/models/porcelain.rb', line 4956

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4992
4993
4994
4995
4996
4997
4998
# File 'lib/models/porcelain.rb', line 4992

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end