Class: SDM::DB2I
- Inherits:
-
Object
- Object
- SDM::DB2I
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
constructor
A new instance of DB2I.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
Returns a new instance of DB2I.
4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 4792 4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 |
# File 'lib/models/porcelain.rb', line 4775 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4745 4746 4747 |
# File 'lib/models/porcelain.rb', line 4745 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4747 4748 4749 |
# File 'lib/models/porcelain.rb', line 4747 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4749 4750 4751 |
# File 'lib/models/porcelain.rb', line 4749 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4751 4752 4753 |
# File 'lib/models/porcelain.rb', line 4751 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4753 4754 4755 |
# File 'lib/models/porcelain.rb', line 4753 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4755 4756 4757 |
# File 'lib/models/porcelain.rb', line 4755 def name @name end |
#password ⇒ Object
The password to authenticate with.
4757 4758 4759 |
# File 'lib/models/porcelain.rb', line 4757 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4759 4760 4761 |
# File 'lib/models/porcelain.rb', line 4759 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4761 4762 4763 |
# File 'lib/models/porcelain.rb', line 4761 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4763 4764 4765 |
# File 'lib/models/porcelain.rb', line 4763 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4765 4766 4767 |
# File 'lib/models/porcelain.rb', line 4765 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4767 4768 4769 |
# File 'lib/models/porcelain.rb', line 4767 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4769 4770 4771 |
# File 'lib/models/porcelain.rb', line 4769 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4771 4772 4773 |
# File 'lib/models/porcelain.rb', line 4771 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4773 4774 4775 |
# File 'lib/models/porcelain.rb', line 4773 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4809 4810 4811 4812 4813 4814 4815 |
# File 'lib/models/porcelain.rb', line 4809 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |