Class: SDM::DB2I
- Inherits:
-
Object
- Object
- SDM::DB2I
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
constructor
A new instance of DB2I.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
Returns a new instance of DB2I.
4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 |
# File 'lib/models/porcelain.rb', line 4479 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4449 4450 4451 |
# File 'lib/models/porcelain.rb', line 4449 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4451 4452 4453 |
# File 'lib/models/porcelain.rb', line 4451 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4453 4454 4455 |
# File 'lib/models/porcelain.rb', line 4453 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4455 4456 4457 |
# File 'lib/models/porcelain.rb', line 4455 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4457 4458 4459 |
# File 'lib/models/porcelain.rb', line 4457 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4459 4460 4461 |
# File 'lib/models/porcelain.rb', line 4459 def name @name end |
#password ⇒ Object
The password to authenticate with.
4461 4462 4463 |
# File 'lib/models/porcelain.rb', line 4461 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4463 4464 4465 |
# File 'lib/models/porcelain.rb', line 4463 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4465 4466 4467 |
# File 'lib/models/porcelain.rb', line 4465 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4467 4468 4469 |
# File 'lib/models/porcelain.rb', line 4467 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4469 4470 4471 |
# File 'lib/models/porcelain.rb', line 4469 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4471 4472 4473 |
# File 'lib/models/porcelain.rb', line 4471 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4473 4474 4475 |
# File 'lib/models/porcelain.rb', line 4473 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4475 4476 4477 |
# File 'lib/models/porcelain.rb', line 4475 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4477 4478 4479 |
# File 'lib/models/porcelain.rb', line 4477 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4513 4514 4515 4516 4517 4518 4519 |
# File 'lib/models/porcelain.rb', line 4513 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |