Class: SDM::DB2I

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I

Returns a new instance of DB2I.



4197
4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
4217
4218
4219
4220
4221
4222
4223
4224
4225
4226
4227
# File 'lib/models/porcelain.rb', line 4197

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4169
4170
4171
# File 'lib/models/porcelain.rb', line 4169

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4171
4172
4173
# File 'lib/models/porcelain.rb', line 4171

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4173
4174
4175
# File 'lib/models/porcelain.rb', line 4173

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4175
4176
4177
# File 'lib/models/porcelain.rb', line 4175

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4177
4178
4179
# File 'lib/models/porcelain.rb', line 4177

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4179
4180
4181
# File 'lib/models/porcelain.rb', line 4179

def name
  @name
end

#passwordObject

The password to authenticate with.



4181
4182
4183
# File 'lib/models/porcelain.rb', line 4181

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4183
4184
4185
# File 'lib/models/porcelain.rb', line 4183

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4185
4186
4187
# File 'lib/models/porcelain.rb', line 4185

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4187
4188
4189
# File 'lib/models/porcelain.rb', line 4187

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4189
4190
4191
# File 'lib/models/porcelain.rb', line 4189

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4191
4192
4193
# File 'lib/models/porcelain.rb', line 4191

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



4193
4194
4195
# File 'lib/models/porcelain.rb', line 4193

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



4195
4196
4197
# File 'lib/models/porcelain.rb', line 4195

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4229
4230
4231
4232
4233
4234
4235
# File 'lib/models/porcelain.rb', line 4229

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end