Class: SDM::DB2I
- Inherits:
-
Object
- Object
- SDM::DB2I
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
constructor
A new instance of DB2I.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
Returns a new instance of DB2I.
3226 3227 3228 3229 3230 3231 3232 3233 3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 |
# File 'lib/models/porcelain.rb', line 3226 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3198 3199 3200 |
# File 'lib/models/porcelain.rb', line 3198 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3200 3201 3202 |
# File 'lib/models/porcelain.rb', line 3200 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3202 3203 3204 |
# File 'lib/models/porcelain.rb', line 3202 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3204 3205 3206 |
# File 'lib/models/porcelain.rb', line 3204 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3206 3207 3208 |
# File 'lib/models/porcelain.rb', line 3206 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3208 3209 3210 |
# File 'lib/models/porcelain.rb', line 3208 def name @name end |
#password ⇒ Object
The password to authenticate with.
3210 3211 3212 |
# File 'lib/models/porcelain.rb', line 3210 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3212 3213 3214 |
# File 'lib/models/porcelain.rb', line 3212 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3214 3215 3216 |
# File 'lib/models/porcelain.rb', line 3214 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3216 3217 3218 |
# File 'lib/models/porcelain.rb', line 3216 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3218 3219 3220 |
# File 'lib/models/porcelain.rb', line 3218 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3220 3221 3222 |
# File 'lib/models/porcelain.rb', line 3220 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
3222 3223 3224 |
# File 'lib/models/porcelain.rb', line 3222 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
3224 3225 3226 |
# File 'lib/models/porcelain.rb', line 3224 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3258 3259 3260 3261 3262 3263 3264 |
# File 'lib/models/porcelain.rb', line 3258 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |