Class: SDM::DB2I

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I

Returns a new instance of DB2I.



2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
# File 'lib/models/porcelain.rb', line 2966

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2938
2939
2940
# File 'lib/models/porcelain.rb', line 2938

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2940
2941
2942
# File 'lib/models/porcelain.rb', line 2940

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2942
2943
2944
# File 'lib/models/porcelain.rb', line 2942

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2944
2945
2946
# File 'lib/models/porcelain.rb', line 2944

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2946
2947
2948
# File 'lib/models/porcelain.rb', line 2946

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2948
2949
2950
# File 'lib/models/porcelain.rb', line 2948

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2950
2951
2952
# File 'lib/models/porcelain.rb', line 2950

def password
  @password
end

#portObject

Returns the value of attribute port.



2952
2953
2954
# File 'lib/models/porcelain.rb', line 2952

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2954
2955
2956
# File 'lib/models/porcelain.rb', line 2954

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2956
2957
2958
# File 'lib/models/porcelain.rb', line 2956

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



2958
2959
2960
# File 'lib/models/porcelain.rb', line 2958

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



2960
2961
2962
# File 'lib/models/porcelain.rb', line 2960

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



2962
2963
2964
# File 'lib/models/porcelain.rb', line 2962

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



2964
2965
2966
# File 'lib/models/porcelain.rb', line 2964

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2998
2999
3000
3001
3002
3003
3004
# File 'lib/models/porcelain.rb', line 2998

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end