Class: SDM::DB2I
- Inherits:
-
Object
- Object
- SDM::DB2I
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
constructor
A new instance of DB2I.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
Returns a new instance of DB2I.
2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 |
# File 'lib/models/porcelain.rb', line 2780 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2752 2753 2754 |
# File 'lib/models/porcelain.rb', line 2752 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2754 2755 2756 |
# File 'lib/models/porcelain.rb', line 2754 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2756 2757 2758 |
# File 'lib/models/porcelain.rb', line 2756 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2758 2759 2760 |
# File 'lib/models/porcelain.rb', line 2758 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2760 2761 2762 |
# File 'lib/models/porcelain.rb', line 2760 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2762 2763 2764 |
# File 'lib/models/porcelain.rb', line 2762 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2764 2765 2766 |
# File 'lib/models/porcelain.rb', line 2764 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2766 2767 2768 |
# File 'lib/models/porcelain.rb', line 2766 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2768 2769 2770 |
# File 'lib/models/porcelain.rb', line 2768 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2770 2771 2772 |
# File 'lib/models/porcelain.rb', line 2770 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2772 2773 2774 |
# File 'lib/models/porcelain.rb', line 2772 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2774 2775 2776 |
# File 'lib/models/porcelain.rb', line 2774 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
2776 2777 2778 |
# File 'lib/models/porcelain.rb', line 2776 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
2778 2779 2780 |
# File 'lib/models/porcelain.rb', line 2778 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/models/porcelain.rb', line 2812 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |