Class: SDM::DB2I
- Inherits:
-
Object
- Object
- SDM::DB2I
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
constructor
A new instance of DB2I.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
Returns a new instance of DB2I.
2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 |
# File 'lib/models/porcelain.rb', line 2698 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2672 2673 2674 |
# File 'lib/models/porcelain.rb', line 2672 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2674 2675 2676 |
# File 'lib/models/porcelain.rb', line 2674 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2676 2677 2678 |
# File 'lib/models/porcelain.rb', line 2676 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2678 2679 2680 |
# File 'lib/models/porcelain.rb', line 2678 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2680 2681 2682 |
# File 'lib/models/porcelain.rb', line 2680 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2682 2683 2684 |
# File 'lib/models/porcelain.rb', line 2682 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2684 2685 2686 |
# File 'lib/models/porcelain.rb', line 2684 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2686 2687 2688 |
# File 'lib/models/porcelain.rb', line 2686 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2688 2689 2690 |
# File 'lib/models/porcelain.rb', line 2688 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2690 2691 2692 |
# File 'lib/models/porcelain.rb', line 2690 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2692 2693 2694 |
# File 'lib/models/porcelain.rb', line 2692 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
2694 2695 2696 |
# File 'lib/models/porcelain.rb', line 2694 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
2696 2697 2698 |
# File 'lib/models/porcelain.rb', line 2696 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2728 2729 2730 2731 2732 2733 2734 |
# File 'lib/models/porcelain.rb', line 2728 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |