Class: SDM::DB2I
- Inherits:
-
Object
- Object
- SDM::DB2I
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
constructor
A new instance of DB2I.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2I
Returns a new instance of DB2I.
2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 |
# File 'lib/models/porcelain.rb', line 2283 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2257 2258 2259 |
# File 'lib/models/porcelain.rb', line 2257 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2259 2260 2261 |
# File 'lib/models/porcelain.rb', line 2259 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2261 2262 2263 |
# File 'lib/models/porcelain.rb', line 2261 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2263 2264 2265 |
# File 'lib/models/porcelain.rb', line 2263 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2265 2266 2267 |
# File 'lib/models/porcelain.rb', line 2265 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2267 2268 2269 |
# File 'lib/models/porcelain.rb', line 2267 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2269 2270 2271 |
# File 'lib/models/porcelain.rb', line 2269 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2271 2272 2273 |
# File 'lib/models/porcelain.rb', line 2271 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2273 2274 2275 |
# File 'lib/models/porcelain.rb', line 2273 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2275 2276 2277 |
# File 'lib/models/porcelain.rb', line 2275 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2277 2278 2279 |
# File 'lib/models/porcelain.rb', line 2277 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
2279 2280 2281 |
# File 'lib/models/porcelain.rb', line 2279 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
2281 2282 2283 |
# File 'lib/models/porcelain.rb', line 2281 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/models/porcelain.rb', line 2313 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |