Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



6314
6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
# File 'lib/models/porcelain.rb', line 6314

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6282
6283
6284
# File 'lib/models/porcelain.rb', line 6282

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6284
6285
6286
# File 'lib/models/porcelain.rb', line 6284

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6286
6287
6288
# File 'lib/models/porcelain.rb', line 6286

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6288
6289
6290
# File 'lib/models/porcelain.rb', line 6288

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6290
6291
6292
# File 'lib/models/porcelain.rb', line 6290

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6292
6293
6294
# File 'lib/models/porcelain.rb', line 6292

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6294
6295
6296
# File 'lib/models/porcelain.rb', line 6294

def name
  @name
end

#passwordObject

The password to authenticate with.



6296
6297
6298
# File 'lib/models/porcelain.rb', line 6296

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6298
6299
6300
# File 'lib/models/porcelain.rb', line 6298

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6300
6301
6302
# File 'lib/models/porcelain.rb', line 6300

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6302
6303
6304
# File 'lib/models/porcelain.rb', line 6302

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6304
6305
6306
# File 'lib/models/porcelain.rb', line 6304

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6306
6307
6308
# File 'lib/models/porcelain.rb', line 6306

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6308
6309
6310
# File 'lib/models/porcelain.rb', line 6308

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



6310
6311
6312
# File 'lib/models/porcelain.rb', line 6310

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



6312
6313
6314
# File 'lib/models/porcelain.rb', line 6312

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6350
6351
6352
6353
6354
6355
6356
# File 'lib/models/porcelain.rb', line 6350

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end