Class: SDM::DB2LUW
- Inherits:
-
Object
- Object
- SDM::DB2LUW
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DB2LUW
constructor
A new instance of DB2LUW.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DB2LUW
Returns a new instance of DB2LUW.
5033 5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 |
# File 'lib/models/porcelain.rb', line 5033 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5003 5004 5005 |
# File 'lib/models/porcelain.rb', line 5003 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
5005 5006 5007 |
# File 'lib/models/porcelain.rb', line 5005 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5007 5008 5009 |
# File 'lib/models/porcelain.rb', line 5007 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5009 5010 5011 |
# File 'lib/models/porcelain.rb', line 5009 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5011 5012 5013 |
# File 'lib/models/porcelain.rb', line 5011 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5013 5014 5015 |
# File 'lib/models/porcelain.rb', line 5013 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5015 5016 5017 |
# File 'lib/models/porcelain.rb', line 5015 def name @name end |
#password ⇒ Object
The password to authenticate with.
5017 5018 5019 |
# File 'lib/models/porcelain.rb', line 5017 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5019 5020 5021 |
# File 'lib/models/porcelain.rb', line 5019 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5021 5022 5023 |
# File 'lib/models/porcelain.rb', line 5021 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5023 5024 5025 |
# File 'lib/models/porcelain.rb', line 5023 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5025 5026 5027 |
# File 'lib/models/porcelain.rb', line 5025 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5027 5028 5029 |
# File 'lib/models/porcelain.rb', line 5027 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5029 5030 5031 |
# File 'lib/models/porcelain.rb', line 5029 def @tags end |
#username ⇒ Object
The username to authenticate with.
5031 5032 5033 |
# File 'lib/models/porcelain.rb', line 5031 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5067 5068 5069 5070 5071 5072 5073 |
# File 'lib/models/porcelain.rb', line 5067 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |