Class: SDM::DB2LUW
- Inherits:
-
Object
- Object
- SDM::DB2LUW
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DB2LUW
constructor
A new instance of DB2LUW.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DB2LUW
Returns a new instance of DB2LUW.
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 |
# File 'lib/models/porcelain.rb', line 4850 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4820 4821 4822 |
# File 'lib/models/porcelain.rb', line 4820 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4822 4823 4824 |
# File 'lib/models/porcelain.rb', line 4822 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4824 4825 4826 |
# File 'lib/models/porcelain.rb', line 4824 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4826 4827 4828 |
# File 'lib/models/porcelain.rb', line 4826 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4828 4829 4830 |
# File 'lib/models/porcelain.rb', line 4828 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4830 4831 4832 |
# File 'lib/models/porcelain.rb', line 4830 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4832 4833 4834 |
# File 'lib/models/porcelain.rb', line 4832 def name @name end |
#password ⇒ Object
The password to authenticate with.
4834 4835 4836 |
# File 'lib/models/porcelain.rb', line 4834 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4836 4837 4838 |
# File 'lib/models/porcelain.rb', line 4836 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4838 4839 4840 |
# File 'lib/models/porcelain.rb', line 4838 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4840 4841 4842 |
# File 'lib/models/porcelain.rb', line 4840 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4842 4843 4844 |
# File 'lib/models/porcelain.rb', line 4842 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4844 4845 4846 |
# File 'lib/models/porcelain.rb', line 4844 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4846 4847 4848 |
# File 'lib/models/porcelain.rb', line 4846 def @tags end |
#username ⇒ Object
The username to authenticate with.
4848 4849 4850 |
# File 'lib/models/porcelain.rb', line 4848 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4884 4885 4886 4887 4888 4889 4890 |
# File 'lib/models/porcelain.rb', line 4884 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |