Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
# File 'lib/models/porcelain.rb', line 3297

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3269
3270
3271
# File 'lib/models/porcelain.rb', line 3269

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3271
3272
3273
# File 'lib/models/porcelain.rb', line 3271

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3273
3274
3275
# File 'lib/models/porcelain.rb', line 3273

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3275
3276
3277
# File 'lib/models/porcelain.rb', line 3275

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3277
3278
3279
# File 'lib/models/porcelain.rb', line 3277

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3279
3280
3281
# File 'lib/models/porcelain.rb', line 3279

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3281
3282
3283
# File 'lib/models/porcelain.rb', line 3281

def name
  @name
end

#passwordObject

The password to authenticate with.



3283
3284
3285
# File 'lib/models/porcelain.rb', line 3283

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3285
3286
3287
# File 'lib/models/porcelain.rb', line 3285

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3287
3288
3289
# File 'lib/models/porcelain.rb', line 3287

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3289
3290
3291
# File 'lib/models/porcelain.rb', line 3289

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3291
3292
3293
# File 'lib/models/porcelain.rb', line 3291

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3293
3294
3295
# File 'lib/models/porcelain.rb', line 3293

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3295
3296
3297
# File 'lib/models/porcelain.rb', line 3295

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3329
3330
3331
3332
3333
3334
3335
# File 'lib/models/porcelain.rb', line 3329

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end