Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
3148
3149
3150
3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
# File 'lib/models/porcelain.rb', line 3133

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3105
3106
3107
# File 'lib/models/porcelain.rb', line 3105

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



3107
3108
3109
# File 'lib/models/porcelain.rb', line 3107

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3109
3110
3111
# File 'lib/models/porcelain.rb', line 3109

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3111
3112
3113
# File 'lib/models/porcelain.rb', line 3111

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3113
3114
3115
# File 'lib/models/porcelain.rb', line 3113

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3115
3116
3117
# File 'lib/models/porcelain.rb', line 3115

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3117
3118
3119
# File 'lib/models/porcelain.rb', line 3117

def name
  @name
end

#passwordObject

The password to authenticate with.



3119
3120
3121
# File 'lib/models/porcelain.rb', line 3119

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3121
3122
3123
# File 'lib/models/porcelain.rb', line 3121

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3123
3124
3125
# File 'lib/models/porcelain.rb', line 3123

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3125
3126
3127
# File 'lib/models/porcelain.rb', line 3125

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3127
3128
3129
# File 'lib/models/porcelain.rb', line 3127

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3129
3130
3131
# File 'lib/models/porcelain.rb', line 3129

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3131
3132
3133
# File 'lib/models/porcelain.rb', line 3131

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3165
3166
3167
3168
3169
3170
3171
# File 'lib/models/porcelain.rb', line 3165

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end