Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



3037
3038
3039
3040
3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
# File 'lib/models/porcelain.rb', line 3037

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3009
3010
3011
# File 'lib/models/porcelain.rb', line 3009

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



3011
3012
3013
# File 'lib/models/porcelain.rb', line 3011

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3013
3014
3015
# File 'lib/models/porcelain.rb', line 3013

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3015
3016
3017
# File 'lib/models/porcelain.rb', line 3015

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3017
3018
3019
# File 'lib/models/porcelain.rb', line 3017

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3019
3020
3021
# File 'lib/models/porcelain.rb', line 3019

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3021
3022
3023
# File 'lib/models/porcelain.rb', line 3021

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3023
3024
3025
# File 'lib/models/porcelain.rb', line 3023

def password
  @password
end

#portObject

Returns the value of attribute port.



3025
3026
3027
# File 'lib/models/porcelain.rb', line 3025

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3027
3028
3029
# File 'lib/models/porcelain.rb', line 3027

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3029
3030
3031
# File 'lib/models/porcelain.rb', line 3029

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3031
3032
3033
# File 'lib/models/porcelain.rb', line 3031

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3033
3034
3035
# File 'lib/models/porcelain.rb', line 3033

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3035
3036
3037
# File 'lib/models/porcelain.rb', line 3035

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3069
3070
3071
3072
3073
3074
3075
# File 'lib/models/porcelain.rb', line 3069

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end