Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
# File 'lib/models/porcelain.rb', line 3013

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2985
2986
2987
# File 'lib/models/porcelain.rb', line 2985

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2987
2988
2989
# File 'lib/models/porcelain.rb', line 2987

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2989
2990
2991
# File 'lib/models/porcelain.rb', line 2989

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2991
2992
2993
# File 'lib/models/porcelain.rb', line 2991

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2993
2994
2995
# File 'lib/models/porcelain.rb', line 2993

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2995
2996
2997
# File 'lib/models/porcelain.rb', line 2995

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2997
2998
2999
# File 'lib/models/porcelain.rb', line 2997

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2999
3000
3001
# File 'lib/models/porcelain.rb', line 2999

def password
  @password
end

#portObject

Returns the value of attribute port.



3001
3002
3003
# File 'lib/models/porcelain.rb', line 3001

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3003
3004
3005
# File 'lib/models/porcelain.rb', line 3003

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3005
3006
3007
# File 'lib/models/porcelain.rb', line 3005

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3007
3008
3009
# File 'lib/models/porcelain.rb', line 3007

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3009
3010
3011
# File 'lib/models/porcelain.rb', line 3009

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3011
3012
3013
# File 'lib/models/porcelain.rb', line 3011

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3045
3046
3047
3048
3049
3050
3051
# File 'lib/models/porcelain.rb', line 3045

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end