Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



2765
2766
2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
# File 'lib/models/porcelain.rb', line 2765

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2739
2740
2741
# File 'lib/models/porcelain.rb', line 2739

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2741
2742
2743
# File 'lib/models/porcelain.rb', line 2741

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2743
2744
2745
# File 'lib/models/porcelain.rb', line 2743

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2745
2746
2747
# File 'lib/models/porcelain.rb', line 2745

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2747
2748
2749
# File 'lib/models/porcelain.rb', line 2747

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2749
2750
2751
# File 'lib/models/porcelain.rb', line 2749

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2751
2752
2753
# File 'lib/models/porcelain.rb', line 2751

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2753
2754
2755
# File 'lib/models/porcelain.rb', line 2753

def password
  @password
end

#portObject

Returns the value of attribute port.



2755
2756
2757
# File 'lib/models/porcelain.rb', line 2755

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2757
2758
2759
# File 'lib/models/porcelain.rb', line 2757

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2759
2760
2761
# File 'lib/models/porcelain.rb', line 2759

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2761
2762
2763
# File 'lib/models/porcelain.rb', line 2761

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2763
2764
2765
# File 'lib/models/porcelain.rb', line 2763

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2795
2796
2797
2798
2799
2800
2801
# File 'lib/models/porcelain.rb', line 2795

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end