Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
# File 'lib/models/porcelain.rb', line 2427

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2401
2402
2403
# File 'lib/models/porcelain.rb', line 2401

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2403
2404
2405
# File 'lib/models/porcelain.rb', line 2403

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2405
2406
2407
# File 'lib/models/porcelain.rb', line 2405

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2407
2408
2409
# File 'lib/models/porcelain.rb', line 2407

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2409
2410
2411
# File 'lib/models/porcelain.rb', line 2409

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2411
2412
2413
# File 'lib/models/porcelain.rb', line 2411

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2413
2414
2415
# File 'lib/models/porcelain.rb', line 2413

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2415
2416
2417
# File 'lib/models/porcelain.rb', line 2415

def password
  @password
end

#portObject

Returns the value of attribute port.



2417
2418
2419
# File 'lib/models/porcelain.rb', line 2417

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2419
2420
2421
# File 'lib/models/porcelain.rb', line 2419

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2421
2422
2423
# File 'lib/models/porcelain.rb', line 2421

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2423
2424
2425
# File 'lib/models/porcelain.rb', line 2423

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2425
2426
2427
# File 'lib/models/porcelain.rb', line 2425

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2457
2458
2459
2460
2461
2462
2463
# File 'lib/models/porcelain.rb', line 2457

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end