Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
# File 'lib/models/porcelain.rb', line 2319

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2293
2294
2295
# File 'lib/models/porcelain.rb', line 2293

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



2295
2296
2297
# File 'lib/models/porcelain.rb', line 2295

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2297
2298
2299
# File 'lib/models/porcelain.rb', line 2297

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2299
2300
2301
# File 'lib/models/porcelain.rb', line 2299

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2301
2302
2303
# File 'lib/models/porcelain.rb', line 2301

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2303
2304
2305
# File 'lib/models/porcelain.rb', line 2303

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2305
2306
2307
# File 'lib/models/porcelain.rb', line 2305

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2307
2308
2309
# File 'lib/models/porcelain.rb', line 2307

def password
  @password
end

#portObject

Returns the value of attribute port.



2309
2310
2311
# File 'lib/models/porcelain.rb', line 2309

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2311
2312
2313
# File 'lib/models/porcelain.rb', line 2311

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2313
2314
2315
# File 'lib/models/porcelain.rb', line 2313

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2315
2316
2317
# File 'lib/models/porcelain.rb', line 2315

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2317
2318
2319
# File 'lib/models/porcelain.rb', line 2317

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2349
2350
2351
2352
2353
2354
2355
# File 'lib/models/porcelain.rb', line 2349

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end