Class: SDM::DB2LUW

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ DB2LUW

Returns a new instance of DB2LUW.



6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
6321
6322
# File 'lib/models/porcelain.rb', line 6288

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6256
6257
6258
# File 'lib/models/porcelain.rb', line 6256

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6258
6259
6260
# File 'lib/models/porcelain.rb', line 6258

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6260
6261
6262
# File 'lib/models/porcelain.rb', line 6260

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6262
6263
6264
# File 'lib/models/porcelain.rb', line 6262

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6264
6265
6266
# File 'lib/models/porcelain.rb', line 6264

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6266
6267
6268
# File 'lib/models/porcelain.rb', line 6266

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6268
6269
6270
# File 'lib/models/porcelain.rb', line 6268

def name
  @name
end

#passwordObject

The password to authenticate with.



6270
6271
6272
# File 'lib/models/porcelain.rb', line 6270

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6272
6273
6274
# File 'lib/models/porcelain.rb', line 6272

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6274
6275
6276
# File 'lib/models/porcelain.rb', line 6274

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6276
6277
6278
# File 'lib/models/porcelain.rb', line 6276

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6278
6279
6280
# File 'lib/models/porcelain.rb', line 6278

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6280
6281
6282
# File 'lib/models/porcelain.rb', line 6280

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6282
6283
6284
# File 'lib/models/porcelain.rb', line 6282

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



6284
6285
6286
# File 'lib/models/porcelain.rb', line 6284

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



6286
6287
6288
# File 'lib/models/porcelain.rb', line 6286

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6324
6325
6326
6327
6328
6329
6330
# File 'lib/models/porcelain.rb', line 6324

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end