Class: SDM::Databricks

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_token: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, http_path: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Databricks

Returns a new instance of Databricks.



6389
6390
6391
6392
6393
6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
6410
6411
6412
6413
6414
6415
6416
6417
6418
6419
# File 'lib/models/porcelain.rb', line 6389

def initialize(
  access_token: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  http_path: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_token = access_token == nil ? "" : access_token
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @http_path = http_path == nil ? "" : http_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_tokenObject

Databricks Personal Access Token (PAT)



6361
6362
6363
# File 'lib/models/porcelain.rb', line 6361

def access_token
  @access_token
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6363
6364
6365
# File 'lib/models/porcelain.rb', line 6363

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6365
6366
6367
# File 'lib/models/porcelain.rb', line 6365

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6367
6368
6369
# File 'lib/models/porcelain.rb', line 6367

def healthy
  @healthy
end

#hostnameObject

The Databricks workspace hostname (e.g., dbc-xxx.cloud.databricks.com)



6369
6370
6371
# File 'lib/models/porcelain.rb', line 6369

def hostname
  @hostname
end

#http_pathObject

The HTTP path to the SQL warehouse or cluster (e.g., /sql/1.0/warehouses/xxx)



6371
6372
6373
# File 'lib/models/porcelain.rb', line 6371

def http_path
  @http_path
end

#idObject

Unique identifier of the Resource.



6373
6374
6375
# File 'lib/models/porcelain.rb', line 6373

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6375
6376
6377
# File 'lib/models/porcelain.rb', line 6375

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6377
6378
6379
# File 'lib/models/porcelain.rb', line 6377

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6379
6380
6381
# File 'lib/models/porcelain.rb', line 6379

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



6381
6382
6383
# File 'lib/models/porcelain.rb', line 6381

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6383
6384
6385
# File 'lib/models/porcelain.rb', line 6383

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6385
6386
6387
# File 'lib/models/porcelain.rb', line 6385

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6387
6388
6389
# File 'lib/models/porcelain.rb', line 6387

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6421
6422
6423
6424
6425
6426
6427
# File 'lib/models/porcelain.rb', line 6421

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end