Class: SDM::Databricks
- Inherits:
-
Object
- Object
- SDM::Databricks
- Defined in:
- lib/models/porcelain.rb
Overview
Databricks is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Databricks Personal Access Token (PAT).
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The Databricks workspace hostname (e.g., dbc-xxx.cloud.databricks.com).
-
#http_path ⇒ Object
The HTTP path to the SQL warehouse or cluster (e.g., /sql/1.0/warehouses/xxx).
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_token: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, http_path: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Databricks
constructor
A new instance of Databricks.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_token: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, http_path: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Databricks
Returns a new instance of Databricks.
6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 |
# File 'lib/models/porcelain.rb', line 6349 def initialize( access_token: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, http_path: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_token = access_token == nil ? "" : access_token @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @http_path = http_path == nil ? "" : http_path @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_token ⇒ Object
Databricks Personal Access Token (PAT)
6321 6322 6323 |
# File 'lib/models/porcelain.rb', line 6321 def access_token @access_token end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
6323 6324 6325 |
# File 'lib/models/porcelain.rb', line 6323 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6325 6326 6327 |
# File 'lib/models/porcelain.rb', line 6325 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6327 6328 6329 |
# File 'lib/models/porcelain.rb', line 6327 def healthy @healthy end |
#hostname ⇒ Object
The Databricks workspace hostname (e.g., dbc-xxx.cloud.databricks.com)
6329 6330 6331 |
# File 'lib/models/porcelain.rb', line 6329 def hostname @hostname end |
#http_path ⇒ Object
The HTTP path to the SQL warehouse or cluster (e.g., /sql/1.0/warehouses/xxx)
6331 6332 6333 |
# File 'lib/models/porcelain.rb', line 6331 def http_path @http_path end |
#id ⇒ Object
Unique identifier of the Resource.
6333 6334 6335 |
# File 'lib/models/porcelain.rb', line 6333 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6335 6336 6337 |
# File 'lib/models/porcelain.rb', line 6335 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
6337 6338 6339 |
# File 'lib/models/porcelain.rb', line 6337 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
6339 6340 6341 |
# File 'lib/models/porcelain.rb', line 6339 def proxy_cluster_id @proxy_cluster_id end |
#schema ⇒ Object
The Schema to use to direct initial requests.
6341 6342 6343 |
# File 'lib/models/porcelain.rb', line 6341 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6343 6344 6345 |
# File 'lib/models/porcelain.rb', line 6343 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
6345 6346 6347 |
# File 'lib/models/porcelain.rb', line 6345 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6347 6348 6349 |
# File 'lib/models/porcelain.rb', line 6347 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6381 6382 6383 6384 6385 6386 6387 |
# File 'lib/models/porcelain.rb', line 6381 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |