Class: SDM::Databricks

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Databricks is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_token: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, http_path: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Databricks

Returns a new instance of Databricks.



6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
# File 'lib/models/porcelain.rb', line 6348

def initialize(
  access_token: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  http_path: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_token = access_token == nil ? "" : access_token
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @http_path = http_path == nil ? "" : http_path
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_tokenObject

Databricks Personal Access Token (PAT)



6320
6321
6322
# File 'lib/models/porcelain.rb', line 6320

def access_token
  @access_token
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6322
6323
6324
# File 'lib/models/porcelain.rb', line 6322

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6324
6325
6326
# File 'lib/models/porcelain.rb', line 6324

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6326
6327
6328
# File 'lib/models/porcelain.rb', line 6326

def healthy
  @healthy
end

#hostnameObject

The Databricks workspace hostname (e.g., dbc-xxx.cloud.databricks.com)



6328
6329
6330
# File 'lib/models/porcelain.rb', line 6328

def hostname
  @hostname
end

#http_pathObject

The HTTP path to the SQL warehouse or cluster (e.g., /sql/1.0/warehouses/xxx)



6330
6331
6332
# File 'lib/models/porcelain.rb', line 6330

def http_path
  @http_path
end

#idObject

Unique identifier of the Resource.



6332
6333
6334
# File 'lib/models/porcelain.rb', line 6332

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6334
6335
6336
# File 'lib/models/porcelain.rb', line 6334

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6336
6337
6338
# File 'lib/models/porcelain.rb', line 6336

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6338
6339
6340
# File 'lib/models/porcelain.rb', line 6338

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



6340
6341
6342
# File 'lib/models/porcelain.rb', line 6340

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6342
6343
6344
# File 'lib/models/porcelain.rb', line 6342

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6344
6345
6346
# File 'lib/models/porcelain.rb', line 6344

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6346
6347
6348
# File 'lib/models/porcelain.rb', line 6346

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6380
6381
6382
6383
6384
6385
6386
# File 'lib/models/porcelain.rb', line 6380

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end