Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



6107
6108
6109
6110
6111
6112
6113
6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
6135
6136
6137
6138
6139
# File 'lib/models/porcelain.rb', line 6107

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



6077
6078
6079
# File 'lib/models/porcelain.rb', line 6077

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6079
6080
6081
# File 'lib/models/porcelain.rb', line 6079

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6081
6082
6083
# File 'lib/models/porcelain.rb', line 6081

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6083
6084
6085
# File 'lib/models/porcelain.rb', line 6083

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6085
6086
6087
# File 'lib/models/porcelain.rb', line 6085

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6087
6088
6089
# File 'lib/models/porcelain.rb', line 6087

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6089
6090
6091
# File 'lib/models/porcelain.rb', line 6089

def name
  @name
end

#passwordObject

The password to authenticate with.



6091
6092
6093
# File 'lib/models/porcelain.rb', line 6091

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6093
6094
6095
# File 'lib/models/porcelain.rb', line 6093

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6095
6096
6097
# File 'lib/models/porcelain.rb', line 6095

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6097
6098
6099
# File 'lib/models/porcelain.rb', line 6097

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6099
6100
6101
# File 'lib/models/porcelain.rb', line 6099

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6101
6102
6103
# File 'lib/models/porcelain.rb', line 6101

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6103
6104
6105
# File 'lib/models/porcelain.rb', line 6103

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6105
6106
6107
# File 'lib/models/porcelain.rb', line 6105

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6141
6142
6143
6144
6145
6146
6147
# File 'lib/models/porcelain.rb', line 6141

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end