Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
5186
5187
5188
5189
# File 'lib/models/porcelain.rb', line 5157

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5127
5128
5129
# File 'lib/models/porcelain.rb', line 5127

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5129
5130
5131
# File 'lib/models/porcelain.rb', line 5129

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5131
5132
5133
# File 'lib/models/porcelain.rb', line 5131

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5133
5134
5135
# File 'lib/models/porcelain.rb', line 5133

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5135
5136
5137
# File 'lib/models/porcelain.rb', line 5135

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5137
5138
5139
# File 'lib/models/porcelain.rb', line 5137

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5139
5140
5141
# File 'lib/models/porcelain.rb', line 5139

def name
  @name
end

#passwordObject

The password to authenticate with.



5141
5142
5143
# File 'lib/models/porcelain.rb', line 5141

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5143
5144
5145
# File 'lib/models/porcelain.rb', line 5143

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5145
5146
5147
# File 'lib/models/porcelain.rb', line 5145

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5147
5148
5149
# File 'lib/models/porcelain.rb', line 5147

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5149
5150
5151
# File 'lib/models/porcelain.rb', line 5149

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5151
5152
5153
# File 'lib/models/porcelain.rb', line 5151

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5153
5154
5155
# File 'lib/models/porcelain.rb', line 5153

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5155
5156
5157
# File 'lib/models/porcelain.rb', line 5155

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5191
5192
5193
5194
5195
5196
5197
# File 'lib/models/porcelain.rb', line 5191

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end