Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
# File 'lib/models/porcelain.rb', line 5054

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5024
5025
5026
# File 'lib/models/porcelain.rb', line 5024

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5026
5027
5028
# File 'lib/models/porcelain.rb', line 5026

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5028
5029
5030
# File 'lib/models/porcelain.rb', line 5028

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5030
5031
5032
# File 'lib/models/porcelain.rb', line 5030

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5032
5033
5034
# File 'lib/models/porcelain.rb', line 5032

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5034
5035
5036
# File 'lib/models/porcelain.rb', line 5034

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5036
5037
5038
# File 'lib/models/porcelain.rb', line 5036

def name
  @name
end

#passwordObject

The password to authenticate with.



5038
5039
5040
# File 'lib/models/porcelain.rb', line 5038

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5040
5041
5042
# File 'lib/models/porcelain.rb', line 5040

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5042
5043
5044
# File 'lib/models/porcelain.rb', line 5042

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5044
5045
5046
# File 'lib/models/porcelain.rb', line 5044

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5046
5047
5048
# File 'lib/models/porcelain.rb', line 5046

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5048
5049
5050
# File 'lib/models/porcelain.rb', line 5048

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5050
5051
5052
# File 'lib/models/porcelain.rb', line 5050

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5052
5053
5054
# File 'lib/models/porcelain.rb', line 5052

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5088
5089
5090
5091
5092
5093
5094
# File 'lib/models/porcelain.rb', line 5088

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end