Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
4708
4709
4710
# File 'lib/models/porcelain.rb', line 4678

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



4648
4649
4650
# File 'lib/models/porcelain.rb', line 4648

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4650
4651
4652
# File 'lib/models/porcelain.rb', line 4650

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4652
4653
4654
# File 'lib/models/porcelain.rb', line 4652

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4654
4655
4656
# File 'lib/models/porcelain.rb', line 4654

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4656
4657
4658
# File 'lib/models/porcelain.rb', line 4656

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4658
4659
4660
# File 'lib/models/porcelain.rb', line 4658

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4660
4661
4662
# File 'lib/models/porcelain.rb', line 4660

def name
  @name
end

#passwordObject

The password to authenticate with.



4662
4663
4664
# File 'lib/models/porcelain.rb', line 4662

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4664
4665
4666
# File 'lib/models/porcelain.rb', line 4664

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4666
4667
4668
# File 'lib/models/porcelain.rb', line 4666

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4668
4669
4670
# File 'lib/models/porcelain.rb', line 4668

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4670
4671
4672
# File 'lib/models/porcelain.rb', line 4670

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4672
4673
4674
# File 'lib/models/porcelain.rb', line 4672

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4674
4675
4676
# File 'lib/models/porcelain.rb', line 4674

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4676
4677
4678
# File 'lib/models/porcelain.rb', line 4676

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4712
4713
4714
4715
4716
4717
4718
# File 'lib/models/porcelain.rb', line 4712

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end