Class: SDM::DocumentDBHost
- Inherits:
-
Object
- Object
- SDM::DocumentDBHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost
constructor
A new instance of DocumentDBHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost
Returns a new instance of DocumentDBHost.
4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 4273 4274 4275 |
# File 'lib/models/porcelain.rb', line 4245 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
4217 4218 4219 |
# File 'lib/models/porcelain.rb', line 4217 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4219 4220 4221 |
# File 'lib/models/porcelain.rb', line 4219 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4221 4222 4223 |
# File 'lib/models/porcelain.rb', line 4221 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4223 4224 4225 |
# File 'lib/models/porcelain.rb', line 4223 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4225 4226 4227 |
# File 'lib/models/porcelain.rb', line 4225 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4227 4228 4229 |
# File 'lib/models/porcelain.rb', line 4227 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4229 4230 4231 |
# File 'lib/models/porcelain.rb', line 4229 def name @name end |
#password ⇒ Object
The password to authenticate with.
4231 4232 4233 |
# File 'lib/models/porcelain.rb', line 4231 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4233 4234 4235 |
# File 'lib/models/porcelain.rb', line 4233 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4235 4236 4237 |
# File 'lib/models/porcelain.rb', line 4235 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4237 4238 4239 |
# File 'lib/models/porcelain.rb', line 4237 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4239 4240 4241 |
# File 'lib/models/porcelain.rb', line 4239 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4241 4242 4243 |
# File 'lib/models/porcelain.rb', line 4241 def @tags end |
#username ⇒ Object
The username to authenticate with.
4243 4244 4245 |
# File 'lib/models/porcelain.rb', line 4243 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4277 4278 4279 4280 4281 4282 4283 |
# File 'lib/models/porcelain.rb', line 4277 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |