Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
3590
3591
3592
3593
3594
3595
3596
3597
3598
# File 'lib/models/porcelain.rb', line 3568

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



3540
3541
3542
# File 'lib/models/porcelain.rb', line 3540

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3542
3543
3544
# File 'lib/models/porcelain.rb', line 3542

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3544
3545
3546
# File 'lib/models/porcelain.rb', line 3544

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3546
3547
3548
# File 'lib/models/porcelain.rb', line 3546

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3548
3549
3550
# File 'lib/models/porcelain.rb', line 3548

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3550
3551
3552
# File 'lib/models/porcelain.rb', line 3550

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3552
3553
3554
# File 'lib/models/porcelain.rb', line 3552

def name
  @name
end

#passwordObject

The password to authenticate with.



3554
3555
3556
# File 'lib/models/porcelain.rb', line 3554

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3556
3557
3558
# File 'lib/models/porcelain.rb', line 3556

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3558
3559
3560
# File 'lib/models/porcelain.rb', line 3558

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3560
3561
3562
# File 'lib/models/porcelain.rb', line 3560

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3562
3563
3564
# File 'lib/models/porcelain.rb', line 3562

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3564
3565
3566
# File 'lib/models/porcelain.rb', line 3564

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3566
3567
3568
# File 'lib/models/porcelain.rb', line 3566

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3600
3601
3602
3603
3604
3605
3606
# File 'lib/models/porcelain.rb', line 3600

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end