Class: SDM::DocumentDBHost
- Inherits:
-
Object
- Object
- SDM::DocumentDBHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost
constructor
A new instance of DocumentDBHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost
Returns a new instance of DocumentDBHost.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 |
# File 'lib/models/porcelain.rb', line 3417 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
3389 3390 3391 |
# File 'lib/models/porcelain.rb', line 3389 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3391 3392 3393 |
# File 'lib/models/porcelain.rb', line 3391 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3393 3394 3395 |
# File 'lib/models/porcelain.rb', line 3393 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3395 3396 3397 |
# File 'lib/models/porcelain.rb', line 3395 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3397 3398 3399 |
# File 'lib/models/porcelain.rb', line 3397 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3399 3400 3401 |
# File 'lib/models/porcelain.rb', line 3399 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3401 3402 3403 |
# File 'lib/models/porcelain.rb', line 3401 def name @name end |
#password ⇒ Object
The password to authenticate with.
3403 3404 3405 |
# File 'lib/models/porcelain.rb', line 3403 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3405 3406 3407 |
# File 'lib/models/porcelain.rb', line 3405 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3407 3408 3409 |
# File 'lib/models/porcelain.rb', line 3407 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3409 3410 3411 |
# File 'lib/models/porcelain.rb', line 3409 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3411 3412 3413 |
# File 'lib/models/porcelain.rb', line 3411 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3413 3414 3415 |
# File 'lib/models/porcelain.rb', line 3413 def @tags end |
#username ⇒ Object
The username to authenticate with.
3415 3416 3417 |
# File 'lib/models/porcelain.rb', line 3415 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3449 3450 3451 3452 3453 3454 3455 |
# File 'lib/models/porcelain.rb', line 3449 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |