Class: SDM::DocumentDBHost
- Inherits:
-
Object
- Object
- SDM::DocumentDBHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost
constructor
A new instance of DocumentDBHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost
Returns a new instance of DocumentDBHost.
3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 3168 3169 3170 3171 3172 3173 3174 3175 3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 |
# File 'lib/models/porcelain.rb', line 3156 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
3128 3129 3130 |
# File 'lib/models/porcelain.rb', line 3128 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
3130 3131 3132 |
# File 'lib/models/porcelain.rb', line 3130 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3132 3133 3134 |
# File 'lib/models/porcelain.rb', line 3132 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3134 3135 3136 |
# File 'lib/models/porcelain.rb', line 3134 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3136 3137 3138 |
# File 'lib/models/porcelain.rb', line 3136 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3138 3139 3140 |
# File 'lib/models/porcelain.rb', line 3138 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3140 3141 3142 |
# File 'lib/models/porcelain.rb', line 3140 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3142 3143 3144 |
# File 'lib/models/porcelain.rb', line 3142 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3144 3145 3146 |
# File 'lib/models/porcelain.rb', line 3144 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3146 3147 3148 |
# File 'lib/models/porcelain.rb', line 3146 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3148 3149 3150 |
# File 'lib/models/porcelain.rb', line 3148 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3150 3151 3152 |
# File 'lib/models/porcelain.rb', line 3150 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3152 3153 3154 |
# File 'lib/models/porcelain.rb', line 3152 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3154 3155 3156 |
# File 'lib/models/porcelain.rb', line 3154 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3188 3189 3190 3191 3192 3193 3194 |
# File 'lib/models/porcelain.rb', line 3188 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |