Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
3148
3149
3150
3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
# File 'lib/models/porcelain.rb', line 3132

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



3104
3105
3106
# File 'lib/models/porcelain.rb', line 3104

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



3106
3107
3108
# File 'lib/models/porcelain.rb', line 3106

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3108
3109
3110
# File 'lib/models/porcelain.rb', line 3108

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3110
3111
3112
# File 'lib/models/porcelain.rb', line 3110

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3112
3113
3114
# File 'lib/models/porcelain.rb', line 3112

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3114
3115
3116
# File 'lib/models/porcelain.rb', line 3114

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3116
3117
3118
# File 'lib/models/porcelain.rb', line 3116

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3118
3119
3120
# File 'lib/models/porcelain.rb', line 3118

def password
  @password
end

#portObject

Returns the value of attribute port.



3120
3121
3122
# File 'lib/models/porcelain.rb', line 3120

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3122
3123
3124
# File 'lib/models/porcelain.rb', line 3122

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3124
3125
3126
# File 'lib/models/porcelain.rb', line 3124

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3126
3127
3128
# File 'lib/models/porcelain.rb', line 3126

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3128
3129
3130
# File 'lib/models/porcelain.rb', line 3128

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3130
3131
3132
# File 'lib/models/porcelain.rb', line 3130

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3164
3165
3166
3167
3168
3169
3170
# File 'lib/models/porcelain.rb', line 3164

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end