Class: SDM::DocumentDBHost
- Inherits:
-
Object
- Object
- SDM::DocumentDBHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost
constructor
A new instance of DocumentDBHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost
Returns a new instance of DocumentDBHost.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 |
# File 'lib/models/porcelain.rb', line 2970 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
2942 2943 2944 |
# File 'lib/models/porcelain.rb', line 2942 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
2944 2945 2946 |
# File 'lib/models/porcelain.rb', line 2944 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2946 2947 2948 |
# File 'lib/models/porcelain.rb', line 2946 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2948 2949 2950 |
# File 'lib/models/porcelain.rb', line 2948 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2950 2951 2952 |
# File 'lib/models/porcelain.rb', line 2950 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2952 2953 2954 |
# File 'lib/models/porcelain.rb', line 2952 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2954 2955 2956 |
# File 'lib/models/porcelain.rb', line 2954 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2956 2957 2958 |
# File 'lib/models/porcelain.rb', line 2956 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2958 2959 2960 |
# File 'lib/models/porcelain.rb', line 2958 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2960 2961 2962 |
# File 'lib/models/porcelain.rb', line 2960 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2962 2963 2964 |
# File 'lib/models/porcelain.rb', line 2962 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
2964 2965 2966 |
# File 'lib/models/porcelain.rb', line 2964 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2966 2967 2968 |
# File 'lib/models/porcelain.rb', line 2966 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2968 2969 2970 |
# File 'lib/models/porcelain.rb', line 2968 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3002 3003 3004 3005 3006 3007 3008 |
# File 'lib/models/porcelain.rb', line 3002 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |