Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
# File 'lib/models/porcelain.rb', line 2542

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



2516
2517
2518
# File 'lib/models/porcelain.rb', line 2516

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



2518
2519
2520
# File 'lib/models/porcelain.rb', line 2518

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2520
2521
2522
# File 'lib/models/porcelain.rb', line 2520

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2522
2523
2524
# File 'lib/models/porcelain.rb', line 2522

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2524
2525
2526
# File 'lib/models/porcelain.rb', line 2524

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2526
2527
2528
# File 'lib/models/porcelain.rb', line 2526

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2528
2529
2530
# File 'lib/models/porcelain.rb', line 2528

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2530
2531
2532
# File 'lib/models/porcelain.rb', line 2530

def password
  @password
end

#portObject

Returns the value of attribute port.



2532
2533
2534
# File 'lib/models/porcelain.rb', line 2532

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2534
2535
2536
# File 'lib/models/porcelain.rb', line 2534

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2536
2537
2538
# File 'lib/models/porcelain.rb', line 2536

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2538
2539
2540
# File 'lib/models/porcelain.rb', line 2538

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2540
2541
2542
# File 'lib/models/porcelain.rb', line 2540

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2572
2573
2574
2575
2576
2577
2578
# File 'lib/models/porcelain.rb', line 2572

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end