Class: SDM::DocumentDBHost
- Inherits:
-
Object
- Object
- SDM::DocumentDBHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBHost
constructor
A new instance of DocumentDBHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBHost
Returns a new instance of DocumentDBHost.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 |
# File 'lib/models/porcelain.rb', line 2435 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
2409 2410 2411 |
# File 'lib/models/porcelain.rb', line 2409 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
2411 2412 2413 |
# File 'lib/models/porcelain.rb', line 2411 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2413 2414 2415 |
# File 'lib/models/porcelain.rb', line 2413 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2415 2416 2417 |
# File 'lib/models/porcelain.rb', line 2415 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2417 2418 2419 |
# File 'lib/models/porcelain.rb', line 2417 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2419 2420 2421 |
# File 'lib/models/porcelain.rb', line 2419 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2421 2422 2423 |
# File 'lib/models/porcelain.rb', line 2421 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2423 2424 2425 |
# File 'lib/models/porcelain.rb', line 2423 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2425 2426 2427 |
# File 'lib/models/porcelain.rb', line 2425 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2427 2428 2429 |
# File 'lib/models/porcelain.rb', line 2427 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2429 2430 2431 |
# File 'lib/models/porcelain.rb', line 2429 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2431 2432 2433 |
# File 'lib/models/porcelain.rb', line 2431 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2433 2434 2435 |
# File 'lib/models/porcelain.rb', line 2433 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2465 2466 2467 2468 2469 2470 2471 |
# File 'lib/models/porcelain.rb', line 2465 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |