Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
# File 'lib/models/porcelain.rb', line 2106

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



2080
2081
2082
# File 'lib/models/porcelain.rb', line 2080

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



2082
2083
2084
# File 'lib/models/porcelain.rb', line 2082

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2084
2085
2086
# File 'lib/models/porcelain.rb', line 2084

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2086
2087
2088
# File 'lib/models/porcelain.rb', line 2086

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2088
2089
2090
# File 'lib/models/porcelain.rb', line 2088

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2090
2091
2092
# File 'lib/models/porcelain.rb', line 2090

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2092
2093
2094
# File 'lib/models/porcelain.rb', line 2092

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2094
2095
2096
# File 'lib/models/porcelain.rb', line 2094

def password
  @password
end

#portObject

Returns the value of attribute port.



2096
2097
2098
# File 'lib/models/porcelain.rb', line 2096

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2098
2099
2100
# File 'lib/models/porcelain.rb', line 2098

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2100
2101
2102
# File 'lib/models/porcelain.rb', line 2100

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2102
2103
2104
# File 'lib/models/porcelain.rb', line 2102

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2104
2105
2106
# File 'lib/models/porcelain.rb', line 2104

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2136
2137
2138
2139
2140
2141
2142
# File 'lib/models/porcelain.rb', line 2136

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end