Class: SDM::DocumentDBHost
- Inherits:
-
Object
- Object
- SDM::DocumentDBHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBHost
constructor
A new instance of DocumentDBHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBHost
Returns a new instance of DocumentDBHost.
2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/models/porcelain.rb', line 2108 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
2082 2083 2084 |
# File 'lib/models/porcelain.rb', line 2082 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
2084 2085 2086 |
# File 'lib/models/porcelain.rb', line 2084 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2086 2087 2088 |
# File 'lib/models/porcelain.rb', line 2086 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2088 2089 2090 |
# File 'lib/models/porcelain.rb', line 2088 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2090 2091 2092 |
# File 'lib/models/porcelain.rb', line 2090 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2092 2093 2094 |
# File 'lib/models/porcelain.rb', line 2092 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2094 2095 2096 |
# File 'lib/models/porcelain.rb', line 2094 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2096 2097 2098 |
# File 'lib/models/porcelain.rb', line 2096 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2098 2099 2100 |
# File 'lib/models/porcelain.rb', line 2098 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2100 2101 2102 |
# File 'lib/models/porcelain.rb', line 2100 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2102 2103 2104 |
# File 'lib/models/porcelain.rb', line 2102 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2104 2105 2106 |
# File 'lib/models/porcelain.rb', line 2104 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2106 2107 2108 |
# File 'lib/models/porcelain.rb', line 2106 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2138 2139 2140 2141 2142 2143 2144 |
# File 'lib/models/porcelain.rb', line 2138 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |