Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
2661
# File 'lib/models/porcelain.rb', line 2611

def initialize(
  auth_database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  if auth_database != nil
    @auth_database = auth_database
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if password != nil
    @password = password
  end
  if port != nil
    @port = port
  end
  if port_override != nil
    @port_override = port_override
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
  if username != nil
    @username = username
  end
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



2587
2588
2589
# File 'lib/models/porcelain.rb', line 2587

def auth_database
  @auth_database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2589
2590
2591
# File 'lib/models/porcelain.rb', line 2589

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2591
2592
2593
# File 'lib/models/porcelain.rb', line 2591

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2593
2594
2595
# File 'lib/models/porcelain.rb', line 2593

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2595
2596
2597
# File 'lib/models/porcelain.rb', line 2595

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2597
2598
2599
# File 'lib/models/porcelain.rb', line 2597

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2599
2600
2601
# File 'lib/models/porcelain.rb', line 2599

def password
  @password
end

#portObject

Returns the value of attribute port.



2601
2602
2603
# File 'lib/models/porcelain.rb', line 2601

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2603
2604
2605
# File 'lib/models/porcelain.rb', line 2603

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2605
2606
2607
# File 'lib/models/porcelain.rb', line 2605

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2607
2608
2609
# File 'lib/models/porcelain.rb', line 2607

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



2609
2610
2611
# File 'lib/models/porcelain.rb', line 2609

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2663
2664
2665
2666
2667
2668
2669
# File 'lib/models/porcelain.rb', line 2663

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end