Class: SDM::DocumentDBHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBHost

Returns a new instance of DocumentDBHost.



6485
6486
6487
6488
6489
6490
6491
6492
6493
6494
6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
6505
6506
6507
6508
6509
6510
6511
6512
6513
6514
6515
6516
6517
# File 'lib/models/porcelain.rb', line 6485

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



6455
6456
6457
# File 'lib/models/porcelain.rb', line 6455

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6457
6458
6459
# File 'lib/models/porcelain.rb', line 6457

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6459
6460
6461
# File 'lib/models/porcelain.rb', line 6459

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6461
6462
6463
# File 'lib/models/porcelain.rb', line 6461

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6463
6464
6465
# File 'lib/models/porcelain.rb', line 6463

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6465
6466
6467
# File 'lib/models/porcelain.rb', line 6465

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6467
6468
6469
# File 'lib/models/porcelain.rb', line 6467

def name
  @name
end

#passwordObject

The password to authenticate with.



6469
6470
6471
# File 'lib/models/porcelain.rb', line 6469

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6471
6472
6473
# File 'lib/models/porcelain.rb', line 6471

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6473
6474
6475
# File 'lib/models/porcelain.rb', line 6473

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6475
6476
6477
# File 'lib/models/porcelain.rb', line 6475

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6477
6478
6479
# File 'lib/models/porcelain.rb', line 6477

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6479
6480
6481
# File 'lib/models/porcelain.rb', line 6479

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6481
6482
6483
# File 'lib/models/porcelain.rb', line 6481

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6483
6484
6485
# File 'lib/models/porcelain.rb', line 6483

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6519
6520
6521
6522
6523
6524
6525
# File 'lib/models/porcelain.rb', line 6519

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end