Class: SDM::DocumentDBHostIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM

Returns a new instance of DocumentDBHostIAM.



6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
6638
6639
6640
6641
6642
6643
6644
6645
6646
# File 'lib/models/porcelain.rb', line 6618

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6592
6593
6594
# File 'lib/models/porcelain.rb', line 6592

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6594
6595
6596
# File 'lib/models/porcelain.rb', line 6594

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6596
6597
6598
# File 'lib/models/porcelain.rb', line 6596

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6598
6599
6600
# File 'lib/models/porcelain.rb', line 6598

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6600
6601
6602
# File 'lib/models/porcelain.rb', line 6600

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6602
6603
6604
# File 'lib/models/porcelain.rb', line 6602

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6604
6605
6606
# File 'lib/models/porcelain.rb', line 6604

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6606
6607
6608
# File 'lib/models/porcelain.rb', line 6606

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6608
6609
6610
# File 'lib/models/porcelain.rb', line 6608

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



6610
6611
6612
# File 'lib/models/porcelain.rb', line 6610

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6612
6613
6614
# File 'lib/models/porcelain.rb', line 6612

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6614
6615
6616
# File 'lib/models/porcelain.rb', line 6614

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6616
6617
6618
# File 'lib/models/porcelain.rb', line 6616

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6648
6649
6650
6651
6652
6653
6654
# File 'lib/models/porcelain.rb', line 6648

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end