Class: SDM::DocumentDBHostIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM

Returns a new instance of DocumentDBHostIAM.



6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
# File 'lib/models/porcelain.rb', line 6178

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6152
6153
6154
# File 'lib/models/porcelain.rb', line 6152

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6154
6155
6156
# File 'lib/models/porcelain.rb', line 6154

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6156
6157
6158
# File 'lib/models/porcelain.rb', line 6156

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6158
6159
6160
# File 'lib/models/porcelain.rb', line 6158

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6160
6161
6162
# File 'lib/models/porcelain.rb', line 6160

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6162
6163
6164
# File 'lib/models/porcelain.rb', line 6162

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6164
6165
6166
# File 'lib/models/porcelain.rb', line 6164

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6166
6167
6168
# File 'lib/models/porcelain.rb', line 6166

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6168
6169
6170
# File 'lib/models/porcelain.rb', line 6168

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



6170
6171
6172
# File 'lib/models/porcelain.rb', line 6170

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6172
6173
6174
# File 'lib/models/porcelain.rb', line 6172

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6174
6175
6176
# File 'lib/models/porcelain.rb', line 6174

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6176
6177
6178
# File 'lib/models/porcelain.rb', line 6176

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6208
6209
6210
6211
6212
6213
6214
# File 'lib/models/porcelain.rb', line 6208

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end