Class: SDM::DocumentDBHostIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM

Returns a new instance of DocumentDBHostIAM.



5548
5549
5550
5551
5552
5553
5554
5555
5556
5557
5558
5559
5560
5561
5562
5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
5573
5574
5575
5576
# File 'lib/models/porcelain.rb', line 5548

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5522
5523
5524
# File 'lib/models/porcelain.rb', line 5522

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5524
5525
5526
# File 'lib/models/porcelain.rb', line 5524

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5526
5527
5528
# File 'lib/models/porcelain.rb', line 5526

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5528
5529
5530
# File 'lib/models/porcelain.rb', line 5528

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5530
5531
5532
# File 'lib/models/porcelain.rb', line 5530

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5532
5533
5534
# File 'lib/models/porcelain.rb', line 5532

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5534
5535
5536
# File 'lib/models/porcelain.rb', line 5534

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5536
5537
5538
# File 'lib/models/porcelain.rb', line 5536

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5538
5539
5540
# File 'lib/models/porcelain.rb', line 5538

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



5540
5541
5542
# File 'lib/models/porcelain.rb', line 5540

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5542
5543
5544
# File 'lib/models/porcelain.rb', line 5542

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5544
5545
5546
# File 'lib/models/porcelain.rb', line 5544

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5546
5547
5548
# File 'lib/models/porcelain.rb', line 5546

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5578
5579
5580
5581
5582
5583
5584
# File 'lib/models/porcelain.rb', line 5578

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end