Class: SDM::DocumentDBHostIAM
- Inherits:
-
Object
- Object
- SDM::DocumentDBHostIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM
constructor
A new instance of DocumentDBHostIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM
Returns a new instance of DocumentDBHostIAM.
5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 5319 5320 5321 5322 5323 5324 5325 5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 |
# File 'lib/models/porcelain.rb', line 5307 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5281 5282 5283 |
# File 'lib/models/porcelain.rb', line 5281 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5283 5284 5285 |
# File 'lib/models/porcelain.rb', line 5283 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5285 5286 5287 |
# File 'lib/models/porcelain.rb', line 5285 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5287 5288 5289 |
# File 'lib/models/porcelain.rb', line 5287 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5289 5290 5291 |
# File 'lib/models/porcelain.rb', line 5289 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5291 5292 5293 |
# File 'lib/models/porcelain.rb', line 5291 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5293 5294 5295 |
# File 'lib/models/porcelain.rb', line 5293 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5295 5296 5297 |
# File 'lib/models/porcelain.rb', line 5295 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5297 5298 5299 |
# File 'lib/models/porcelain.rb', line 5297 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
5299 5300 5301 |
# File 'lib/models/porcelain.rb', line 5299 def region @region end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5301 5302 5303 |
# File 'lib/models/porcelain.rb', line 5301 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5303 5304 5305 |
# File 'lib/models/porcelain.rb', line 5303 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5305 5306 5307 |
# File 'lib/models/porcelain.rb', line 5305 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5337 5338 5339 5340 5341 5342 5343 |
# File 'lib/models/porcelain.rb', line 5337 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |