Class: SDM::DocumentDBHostIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM

Returns a new instance of DocumentDBHostIAM.



5125
5126
5127
5128
5129
5130
5131
5132
5133
5134
5135
5136
5137
5138
5139
5140
5141
5142
5143
5144
5145
5146
5147
5148
5149
5150
5151
5152
5153
# File 'lib/models/porcelain.rb', line 5125

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5099
5100
5101
# File 'lib/models/porcelain.rb', line 5099

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5101
5102
5103
# File 'lib/models/porcelain.rb', line 5101

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5103
5104
5105
# File 'lib/models/porcelain.rb', line 5103

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5105
5106
5107
# File 'lib/models/porcelain.rb', line 5105

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5107
5108
5109
# File 'lib/models/porcelain.rb', line 5107

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5109
5110
5111
# File 'lib/models/porcelain.rb', line 5109

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5111
5112
5113
# File 'lib/models/porcelain.rb', line 5111

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5113
5114
5115
# File 'lib/models/porcelain.rb', line 5113

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5115
5116
5117
# File 'lib/models/porcelain.rb', line 5115

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



5117
5118
5119
# File 'lib/models/porcelain.rb', line 5117

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5119
5120
5121
# File 'lib/models/porcelain.rb', line 5119

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5121
5122
5123
# File 'lib/models/porcelain.rb', line 5121

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5123
5124
5125
# File 'lib/models/porcelain.rb', line 5123

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5155
5156
5157
5158
5159
5160
5161
# File 'lib/models/porcelain.rb', line 5155

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end