Class: SDM::DocumentDBHostIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM

Returns a new instance of DocumentDBHostIAM.



5045
5046
5047
5048
5049
5050
5051
5052
5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
# File 'lib/models/porcelain.rb', line 5045

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5019
5020
5021
# File 'lib/models/porcelain.rb', line 5019

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5021
5022
5023
# File 'lib/models/porcelain.rb', line 5021

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5023
5024
5025
# File 'lib/models/porcelain.rb', line 5023

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5025
5026
5027
# File 'lib/models/porcelain.rb', line 5025

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5027
5028
5029
# File 'lib/models/porcelain.rb', line 5027

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5029
5030
5031
# File 'lib/models/porcelain.rb', line 5029

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5031
5032
5033
# File 'lib/models/porcelain.rb', line 5031

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5033
5034
5035
# File 'lib/models/porcelain.rb', line 5033

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5035
5036
5037
# File 'lib/models/porcelain.rb', line 5035

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



5037
5038
5039
# File 'lib/models/porcelain.rb', line 5037

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5039
5040
5041
# File 'lib/models/porcelain.rb', line 5039

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5041
5042
5043
# File 'lib/models/porcelain.rb', line 5041

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5043
5044
5045
# File 'lib/models/porcelain.rb', line 5043

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5075
5076
5077
5078
5079
5080
5081
# File 'lib/models/porcelain.rb', line 5075

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end