Class: SDM::DocumentDBHostIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM

Returns a new instance of DocumentDBHostIAM.



4974
4975
4976
4977
4978
4979
4980
4981
4982
4983
4984
4985
4986
4987
4988
4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
# File 'lib/models/porcelain.rb', line 4974

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4948
4949
4950
# File 'lib/models/porcelain.rb', line 4948

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4950
4951
4952
# File 'lib/models/porcelain.rb', line 4950

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4952
4953
4954
# File 'lib/models/porcelain.rb', line 4952

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4954
4955
4956
# File 'lib/models/porcelain.rb', line 4954

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4956
4957
4958
# File 'lib/models/porcelain.rb', line 4956

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4958
4959
4960
# File 'lib/models/porcelain.rb', line 4958

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4960
4961
4962
# File 'lib/models/porcelain.rb', line 4960

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4962
4963
4964
# File 'lib/models/porcelain.rb', line 4962

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4964
4965
4966
# File 'lib/models/porcelain.rb', line 4964

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



4966
4967
4968
# File 'lib/models/porcelain.rb', line 4966

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4968
4969
4970
# File 'lib/models/porcelain.rb', line 4968

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4970
4971
4972
# File 'lib/models/porcelain.rb', line 4970

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4972
4973
4974
# File 'lib/models/porcelain.rb', line 4972

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5004
5005
5006
5007
5008
5009
5010
# File 'lib/models/porcelain.rb', line 5004

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end