Class: SDM::DocumentDBHostIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM

Returns a new instance of DocumentDBHostIAM.



6556
6557
6558
6559
6560
6561
6562
6563
6564
6565
6566
6567
6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
6579
6580
6581
6582
6583
6584
# File 'lib/models/porcelain.rb', line 6556

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6530
6531
6532
# File 'lib/models/porcelain.rb', line 6530

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6532
6533
6534
# File 'lib/models/porcelain.rb', line 6532

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6534
6535
6536
# File 'lib/models/porcelain.rb', line 6534

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6536
6537
6538
# File 'lib/models/porcelain.rb', line 6536

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6538
6539
6540
# File 'lib/models/porcelain.rb', line 6538

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6540
6541
6542
# File 'lib/models/porcelain.rb', line 6540

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6542
6543
6544
# File 'lib/models/porcelain.rb', line 6542

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6544
6545
6546
# File 'lib/models/porcelain.rb', line 6544

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6546
6547
6548
# File 'lib/models/porcelain.rb', line 6546

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



6548
6549
6550
# File 'lib/models/porcelain.rb', line 6548

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6550
6551
6552
# File 'lib/models/porcelain.rb', line 6550

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6552
6553
6554
# File 'lib/models/porcelain.rb', line 6552

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6554
6555
6556
# File 'lib/models/porcelain.rb', line 6554

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6586
6587
6588
6589
6590
6591
6592
# File 'lib/models/porcelain.rb', line 6586

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end