Class: SDM::DocumentDBHostIAM
- Inherits:
-
Object
- Object
- SDM::DocumentDBHostIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM
constructor
A new instance of DocumentDBHostIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBHostIAM
Returns a new instance of DocumentDBHostIAM.
6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 6642 6643 6644 6645 6646 6647 |
# File 'lib/models/porcelain.rb', line 6619 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
6593 6594 6595 |
# File 'lib/models/porcelain.rb', line 6593 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6595 6596 6597 |
# File 'lib/models/porcelain.rb', line 6595 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6597 6598 6599 |
# File 'lib/models/porcelain.rb', line 6597 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6599 6600 6601 |
# File 'lib/models/porcelain.rb', line 6599 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6601 6602 6603 |
# File 'lib/models/porcelain.rb', line 6601 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6603 6604 6605 |
# File 'lib/models/porcelain.rb', line 6603 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6605 6606 6607 |
# File 'lib/models/porcelain.rb', line 6605 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
6607 6608 6609 |
# File 'lib/models/porcelain.rb', line 6607 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
6609 6610 6611 |
# File 'lib/models/porcelain.rb', line 6609 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
6611 6612 6613 |
# File 'lib/models/porcelain.rb', line 6611 def region @region end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6613 6614 6615 |
# File 'lib/models/porcelain.rb', line 6613 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
6615 6616 6617 |
# File 'lib/models/porcelain.rb', line 6615 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6617 6618 6619 |
# File 'lib/models/porcelain.rb', line 6617 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6649 6650 6651 6652 6653 6654 6655 |
# File 'lib/models/porcelain.rb', line 6649 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |