Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
6673
6674
6675
6676
6677
6678
6679
6680
6681
6682
6683
6684
6685
# File 'lib/models/porcelain.rb', line 6653

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



6623
6624
6625
# File 'lib/models/porcelain.rb', line 6623

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6625
6626
6627
# File 'lib/models/porcelain.rb', line 6625

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



6627
6628
6629
# File 'lib/models/porcelain.rb', line 6627

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6629
6630
6631
# File 'lib/models/porcelain.rb', line 6629

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6631
6632
6633
# File 'lib/models/porcelain.rb', line 6631

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



6633
6634
6635
# File 'lib/models/porcelain.rb', line 6633

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6635
6636
6637
# File 'lib/models/porcelain.rb', line 6635

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6637
6638
6639
# File 'lib/models/porcelain.rb', line 6637

def name
  @name
end

#passwordObject

The password to authenticate with.



6639
6640
6641
# File 'lib/models/porcelain.rb', line 6639

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6641
6642
6643
# File 'lib/models/porcelain.rb', line 6641

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6643
6644
6645
# File 'lib/models/porcelain.rb', line 6643

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6645
6646
6647
# File 'lib/models/porcelain.rb', line 6645

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6647
6648
6649
# File 'lib/models/porcelain.rb', line 6647

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6649
6650
6651
# File 'lib/models/porcelain.rb', line 6649

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6651
6652
6653
# File 'lib/models/porcelain.rb', line 6651

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6687
6688
6689
6690
6691
6692
6693
# File 'lib/models/porcelain.rb', line 6687

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end