Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
# File 'lib/models/porcelain.rb', line 6249

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



6219
6220
6221
# File 'lib/models/porcelain.rb', line 6219

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6221
6222
6223
# File 'lib/models/porcelain.rb', line 6221

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



6223
6224
6225
# File 'lib/models/porcelain.rb', line 6223

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6225
6226
6227
# File 'lib/models/porcelain.rb', line 6225

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6227
6228
6229
# File 'lib/models/porcelain.rb', line 6227

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



6229
6230
6231
# File 'lib/models/porcelain.rb', line 6229

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6231
6232
6233
# File 'lib/models/porcelain.rb', line 6231

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6233
6234
6235
# File 'lib/models/porcelain.rb', line 6233

def name
  @name
end

#passwordObject

The password to authenticate with.



6235
6236
6237
# File 'lib/models/porcelain.rb', line 6235

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6237
6238
6239
# File 'lib/models/porcelain.rb', line 6237

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6239
6240
6241
# File 'lib/models/porcelain.rb', line 6239

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6241
6242
6243
# File 'lib/models/porcelain.rb', line 6241

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6243
6244
6245
# File 'lib/models/porcelain.rb', line 6243

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6245
6246
6247
# File 'lib/models/porcelain.rb', line 6245

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6247
6248
6249
# File 'lib/models/porcelain.rb', line 6247

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6283
6284
6285
6286
6287
6288
6289
# File 'lib/models/porcelain.rb', line 6283

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end