Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



5301
5302
5303
5304
5305
5306
5307
5308
5309
5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
5330
5331
5332
5333
5334
5335
# File 'lib/models/porcelain.rb', line 5301

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5269
5270
5271
# File 'lib/models/porcelain.rb', line 5269

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5271
5272
5273
# File 'lib/models/porcelain.rb', line 5271

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



5273
5274
5275
# File 'lib/models/porcelain.rb', line 5273

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5275
5276
5277
# File 'lib/models/porcelain.rb', line 5275

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5277
5278
5279
# File 'lib/models/porcelain.rb', line 5277

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



5279
5280
5281
# File 'lib/models/porcelain.rb', line 5279

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5281
5282
5283
# File 'lib/models/porcelain.rb', line 5281

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5283
5284
5285
# File 'lib/models/porcelain.rb', line 5283

def name
  @name
end

#passwordObject

The password to authenticate with.



5285
5286
5287
# File 'lib/models/porcelain.rb', line 5285

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



5287
5288
5289
# File 'lib/models/porcelain.rb', line 5287

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5289
5290
5291
# File 'lib/models/porcelain.rb', line 5289

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



5291
5292
5293
# File 'lib/models/porcelain.rb', line 5291

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5293
5294
5295
# File 'lib/models/porcelain.rb', line 5293

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5295
5296
5297
# File 'lib/models/porcelain.rb', line 5295

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5297
5298
5299
# File 'lib/models/porcelain.rb', line 5297

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5299
5300
5301
# File 'lib/models/porcelain.rb', line 5299

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5337
5338
5339
5340
5341
5342
5343
# File 'lib/models/porcelain.rb', line 5337

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end