Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



5118
5119
5120
5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
5131
5132
5133
5134
5135
5136
5137
5138
5139
5140
5141
5142
5143
5144
5145
5146
5147
5148
5149
5150
5151
5152
# File 'lib/models/porcelain.rb', line 5118

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5086
5087
5088
# File 'lib/models/porcelain.rb', line 5086

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5088
5089
5090
# File 'lib/models/porcelain.rb', line 5088

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



5090
5091
5092
# File 'lib/models/porcelain.rb', line 5090

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5092
5093
5094
# File 'lib/models/porcelain.rb', line 5092

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5094
5095
5096
# File 'lib/models/porcelain.rb', line 5094

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



5096
5097
5098
# File 'lib/models/porcelain.rb', line 5096

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5098
5099
5100
# File 'lib/models/porcelain.rb', line 5098

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5100
5101
5102
# File 'lib/models/porcelain.rb', line 5100

def name
  @name
end

#passwordObject

The password to authenticate with.



5102
5103
5104
# File 'lib/models/porcelain.rb', line 5102

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



5104
5105
5106
# File 'lib/models/porcelain.rb', line 5104

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5106
5107
5108
# File 'lib/models/porcelain.rb', line 5106

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



5108
5109
5110
# File 'lib/models/porcelain.rb', line 5108

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5110
5111
5112
# File 'lib/models/porcelain.rb', line 5110

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5112
5113
5114
# File 'lib/models/porcelain.rb', line 5112

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5114
5115
5116
# File 'lib/models/porcelain.rb', line 5114

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5116
5117
5118
# File 'lib/models/porcelain.rb', line 5116

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5154
5155
5156
5157
5158
5159
5160
# File 'lib/models/porcelain.rb', line 5154

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end