Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



5047
5048
5049
5050
5051
5052
5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
# File 'lib/models/porcelain.rb', line 5047

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5015
5016
5017
# File 'lib/models/porcelain.rb', line 5015

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5017
5018
5019
# File 'lib/models/porcelain.rb', line 5017

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



5019
5020
5021
# File 'lib/models/porcelain.rb', line 5019

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5021
5022
5023
# File 'lib/models/porcelain.rb', line 5021

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5023
5024
5025
# File 'lib/models/porcelain.rb', line 5023

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



5025
5026
5027
# File 'lib/models/porcelain.rb', line 5025

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5027
5028
5029
# File 'lib/models/porcelain.rb', line 5027

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5029
5030
5031
# File 'lib/models/porcelain.rb', line 5029

def name
  @name
end

#passwordObject

The password to authenticate with.



5031
5032
5033
# File 'lib/models/porcelain.rb', line 5031

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



5033
5034
5035
# File 'lib/models/porcelain.rb', line 5033

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5035
5036
5037
# File 'lib/models/porcelain.rb', line 5035

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



5037
5038
5039
# File 'lib/models/porcelain.rb', line 5037

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5039
5040
5041
# File 'lib/models/porcelain.rb', line 5039

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5041
5042
5043
# File 'lib/models/porcelain.rb', line 5041

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5043
5044
5045
# File 'lib/models/porcelain.rb', line 5043

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5045
5046
5047
# File 'lib/models/porcelain.rb', line 5045

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5083
5084
5085
5086
5087
5088
5089
# File 'lib/models/porcelain.rb', line 5083

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end