Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



4755
4756
4757
4758
4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
4789
# File 'lib/models/porcelain.rb', line 4755

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



4723
4724
4725
# File 'lib/models/porcelain.rb', line 4723

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4725
4726
4727
# File 'lib/models/porcelain.rb', line 4725

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



4727
4728
4729
# File 'lib/models/porcelain.rb', line 4727

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4729
4730
4731
# File 'lib/models/porcelain.rb', line 4729

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4731
4732
4733
# File 'lib/models/porcelain.rb', line 4731

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



4733
4734
4735
# File 'lib/models/porcelain.rb', line 4733

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4735
4736
4737
# File 'lib/models/porcelain.rb', line 4735

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4737
4738
4739
# File 'lib/models/porcelain.rb', line 4737

def name
  @name
end

#passwordObject

The password to authenticate with.



4739
4740
4741
# File 'lib/models/porcelain.rb', line 4739

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



4741
4742
4743
# File 'lib/models/porcelain.rb', line 4741

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4743
4744
4745
# File 'lib/models/porcelain.rb', line 4743

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



4745
4746
4747
# File 'lib/models/porcelain.rb', line 4745

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4747
4748
4749
# File 'lib/models/porcelain.rb', line 4747

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4749
4750
4751
# File 'lib/models/porcelain.rb', line 4749

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4751
4752
4753
# File 'lib/models/porcelain.rb', line 4751

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4753
4754
4755
# File 'lib/models/porcelain.rb', line 4753

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4791
4792
4793
4794
4795
4796
4797
# File 'lib/models/porcelain.rb', line 4791

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end