Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



4318
4319
4320
4321
4322
4323
4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
4345
4346
4347
4348
4349
4350
# File 'lib/models/porcelain.rb', line 4318

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



4288
4289
4290
# File 'lib/models/porcelain.rb', line 4288

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4290
4291
4292
# File 'lib/models/porcelain.rb', line 4290

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



4292
4293
4294
# File 'lib/models/porcelain.rb', line 4292

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4294
4295
4296
# File 'lib/models/porcelain.rb', line 4294

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4296
4297
4298
# File 'lib/models/porcelain.rb', line 4296

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



4298
4299
4300
# File 'lib/models/porcelain.rb', line 4298

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4300
4301
4302
# File 'lib/models/porcelain.rb', line 4300

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4302
4303
4304
# File 'lib/models/porcelain.rb', line 4302

def name
  @name
end

#passwordObject

The password to authenticate with.



4304
4305
4306
# File 'lib/models/porcelain.rb', line 4304

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



4306
4307
4308
# File 'lib/models/porcelain.rb', line 4306

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



4308
4309
4310
# File 'lib/models/porcelain.rb', line 4308

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4310
4311
4312
# File 'lib/models/porcelain.rb', line 4310

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4312
4313
4314
# File 'lib/models/porcelain.rb', line 4312

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4314
4315
4316
# File 'lib/models/porcelain.rb', line 4314

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4316
4317
4318
# File 'lib/models/porcelain.rb', line 4316

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4352
4353
4354
4355
4356
4357
4358
# File 'lib/models/porcelain.rb', line 4352

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end