Class: SDM::DocumentDBReplicaSet
- Inherits:
-
Object
- Object
- SDM::DocumentDBReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
constructor
A new instance of DocumentDBReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
Returns a new instance of DocumentDBReplicaSet.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/models/porcelain.rb', line 3490 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
3460 3461 3462 |
# File 'lib/models/porcelain.rb', line 3460 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3462 3463 3464 |
# File 'lib/models/porcelain.rb', line 3462 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
3464 3465 3466 |
# File 'lib/models/porcelain.rb', line 3464 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3466 3467 3468 |
# File 'lib/models/porcelain.rb', line 3466 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3468 3469 3470 |
# File 'lib/models/porcelain.rb', line 3468 def healthy @healthy end |
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
3470 3471 3472 |
# File 'lib/models/porcelain.rb', line 3470 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3472 3473 3474 |
# File 'lib/models/porcelain.rb', line 3472 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3474 3475 3476 |
# File 'lib/models/porcelain.rb', line 3474 def name @name end |
#password ⇒ Object
The password to authenticate with.
3476 3477 3478 |
# File 'lib/models/porcelain.rb', line 3476 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3478 3479 3480 |
# File 'lib/models/porcelain.rb', line 3478 def port_override @port_override end |
#replica_set ⇒ Object
The name of the mongo replicaset.
3480 3481 3482 |
# File 'lib/models/porcelain.rb', line 3480 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3482 3483 3484 |
# File 'lib/models/porcelain.rb', line 3482 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3484 3485 3486 |
# File 'lib/models/porcelain.rb', line 3484 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3486 3487 3488 |
# File 'lib/models/porcelain.rb', line 3486 def @tags end |
#username ⇒ Object
The username to authenticate with.
3488 3489 3490 |
# File 'lib/models/porcelain.rb', line 3488 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3524 3525 3526 3527 3528 3529 3530 |
# File 'lib/models/porcelain.rb', line 3524 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |