Class: SDM::DocumentDBReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet

Returns a new instance of DocumentDBReplicaSet.



3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
# File 'lib/models/porcelain.rb', line 3326

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



3296
3297
3298
# File 'lib/models/porcelain.rb', line 3296

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3298
3299
3300
# File 'lib/models/porcelain.rb', line 3298

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



3300
3301
3302
# File 'lib/models/porcelain.rb', line 3300

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3302
3303
3304
# File 'lib/models/porcelain.rb', line 3302

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3304
3305
3306
# File 'lib/models/porcelain.rb', line 3304

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



3306
3307
3308
# File 'lib/models/porcelain.rb', line 3306

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3308
3309
3310
# File 'lib/models/porcelain.rb', line 3308

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3310
3311
3312
# File 'lib/models/porcelain.rb', line 3310

def name
  @name
end

#passwordObject

The password to authenticate with.



3312
3313
3314
# File 'lib/models/porcelain.rb', line 3312

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



3314
3315
3316
# File 'lib/models/porcelain.rb', line 3314

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



3316
3317
3318
# File 'lib/models/porcelain.rb', line 3316

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3318
3319
3320
# File 'lib/models/porcelain.rb', line 3318

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3320
3321
3322
# File 'lib/models/porcelain.rb', line 3320

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3322
3323
3324
# File 'lib/models/porcelain.rb', line 3322

def tags
  @tags
end

#usernameObject

The username to authenticate with.



3324
3325
3326
# File 'lib/models/porcelain.rb', line 3324

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3360
3361
3362
3363
3364
3365
3366
# File 'lib/models/porcelain.rb', line 3360

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end