Class: SDM::DocumentDBReplicaSet
- Inherits:
-
Object
- Object
- SDM::DocumentDBReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
constructor
A new instance of DocumentDBReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
Returns a new instance of DocumentDBReplicaSet.
3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 3232 3233 3234 3235 3236 |
# File 'lib/models/porcelain.rb', line 3204 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
3174 3175 3176 |
# File 'lib/models/porcelain.rb', line 3174 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
3176 3177 3178 |
# File 'lib/models/porcelain.rb', line 3176 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
3178 3179 3180 |
# File 'lib/models/porcelain.rb', line 3178 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3180 3181 3182 |
# File 'lib/models/porcelain.rb', line 3180 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3182 3183 3184 |
# File 'lib/models/porcelain.rb', line 3182 def healthy @healthy end |
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
3184 3185 3186 |
# File 'lib/models/porcelain.rb', line 3184 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3186 3187 3188 |
# File 'lib/models/porcelain.rb', line 3186 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3188 3189 3190 |
# File 'lib/models/porcelain.rb', line 3188 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3190 3191 3192 |
# File 'lib/models/porcelain.rb', line 3190 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3192 3193 3194 |
# File 'lib/models/porcelain.rb', line 3192 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
3194 3195 3196 |
# File 'lib/models/porcelain.rb', line 3194 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3196 3197 3198 |
# File 'lib/models/porcelain.rb', line 3196 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3198 3199 3200 |
# File 'lib/models/porcelain.rb', line 3198 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3200 3201 3202 |
# File 'lib/models/porcelain.rb', line 3200 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3202 3203 3204 |
# File 'lib/models/porcelain.rb', line 3202 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3238 3239 3240 3241 3242 3243 3244 |
# File 'lib/models/porcelain.rb', line 3238 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |