Class: SDM::DocumentDBReplicaSet
- Inherits:
-
Object
- Object
- SDM::DocumentDBReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
constructor
A new instance of DocumentDBReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
Returns a new instance of DocumentDBReplicaSet.
2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/models/porcelain.rb', line 2948 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
2920 2921 2922 |
# File 'lib/models/porcelain.rb', line 2920 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
2922 2923 2924 |
# File 'lib/models/porcelain.rb', line 2922 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
2924 2925 2926 |
# File 'lib/models/porcelain.rb', line 2924 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2926 2927 2928 |
# File 'lib/models/porcelain.rb', line 2926 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2928 2929 2930 |
# File 'lib/models/porcelain.rb', line 2928 def healthy @healthy end |
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
2930 2931 2932 |
# File 'lib/models/porcelain.rb', line 2930 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2932 2933 2934 |
# File 'lib/models/porcelain.rb', line 2932 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2934 2935 2936 |
# File 'lib/models/porcelain.rb', line 2934 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2936 2937 2938 |
# File 'lib/models/porcelain.rb', line 2936 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2938 2939 2940 |
# File 'lib/models/porcelain.rb', line 2938 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
2940 2941 2942 |
# File 'lib/models/porcelain.rb', line 2940 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2942 2943 2944 |
# File 'lib/models/porcelain.rb', line 2942 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2944 2945 2946 |
# File 'lib/models/porcelain.rb', line 2944 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2946 2947 2948 |
# File 'lib/models/porcelain.rb', line 2946 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/models/porcelain.rb', line 2980 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |