Class: SDM::DocumentDBReplicaSet
- Inherits:
-
Object
- Object
- SDM::DocumentDBReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
constructor
A new instance of DocumentDBReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
Returns a new instance of DocumentDBReplicaSet.
2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 |
# File 'lib/models/porcelain.rb', line 2610 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
2582 2583 2584 |
# File 'lib/models/porcelain.rb', line 2582 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
2584 2585 2586 |
# File 'lib/models/porcelain.rb', line 2584 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
2586 2587 2588 |
# File 'lib/models/porcelain.rb', line 2586 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2588 2589 2590 |
# File 'lib/models/porcelain.rb', line 2588 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2590 2591 2592 |
# File 'lib/models/porcelain.rb', line 2590 def healthy @healthy end |
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
2592 2593 2594 |
# File 'lib/models/porcelain.rb', line 2592 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2594 2595 2596 |
# File 'lib/models/porcelain.rb', line 2594 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2596 2597 2598 |
# File 'lib/models/porcelain.rb', line 2596 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2598 2599 2600 |
# File 'lib/models/porcelain.rb', line 2598 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2600 2601 2602 |
# File 'lib/models/porcelain.rb', line 2600 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
2602 2603 2604 |
# File 'lib/models/porcelain.rb', line 2602 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2604 2605 2606 |
# File 'lib/models/porcelain.rb', line 2604 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2606 2607 2608 |
# File 'lib/models/porcelain.rb', line 2606 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2608 2609 2610 |
# File 'lib/models/porcelain.rb', line 2608 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2642 2643 2644 2645 2646 2647 2648 |
# File 'lib/models/porcelain.rb', line 2642 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |