Class: SDM::DocumentDBReplicaSet
- Inherits:
-
Object
- Object
- SDM::DocumentDBReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
constructor
A new instance of DocumentDBReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
Returns a new instance of DocumentDBReplicaSet.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/models/porcelain.rb', line 2503 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
2475 2476 2477 |
# File 'lib/models/porcelain.rb', line 2475 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
2477 2478 2479 |
# File 'lib/models/porcelain.rb', line 2477 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
2479 2480 2481 |
# File 'lib/models/porcelain.rb', line 2479 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2481 2482 2483 |
# File 'lib/models/porcelain.rb', line 2481 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2483 2484 2485 |
# File 'lib/models/porcelain.rb', line 2483 def healthy @healthy end |
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
2485 2486 2487 |
# File 'lib/models/porcelain.rb', line 2485 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2487 2488 2489 |
# File 'lib/models/porcelain.rb', line 2487 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2489 2490 2491 |
# File 'lib/models/porcelain.rb', line 2489 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2491 2492 2493 |
# File 'lib/models/porcelain.rb', line 2491 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2493 2494 2495 |
# File 'lib/models/porcelain.rb', line 2493 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
2495 2496 2497 |
# File 'lib/models/porcelain.rb', line 2495 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2497 2498 2499 |
# File 'lib/models/porcelain.rb', line 2497 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2499 2500 2501 |
# File 'lib/models/porcelain.rb', line 2499 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2501 2502 2503 |
# File 'lib/models/porcelain.rb', line 2501 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2535 2536 2537 2538 2539 2540 2541 |
# File 'lib/models/porcelain.rb', line 2535 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |