Class: SDM::DocumentDBReplicaSet
- Inherits:
-
Object
- Object
- SDM::DocumentDBReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
constructor
A new instance of DocumentDBReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ DocumentDBReplicaSet
Returns a new instance of DocumentDBReplicaSet.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 |
# File 'lib/models/porcelain.rb', line 2699 def initialize( auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, username: nil ) if auth_database != nil @auth_database = auth_database end if connect_to_replica != nil @connect_to_replica = connect_to_replica end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port_override != nil @port_override = port_override end if replica_set != nil @replica_set = replica_set end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
2673 2674 2675 |
# File 'lib/models/porcelain.rb', line 2673 def auth_database @auth_database end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
2675 2676 2677 |
# File 'lib/models/porcelain.rb', line 2675 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2677 2678 2679 |
# File 'lib/models/porcelain.rb', line 2677 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2679 2680 2681 |
# File 'lib/models/porcelain.rb', line 2679 def healthy @healthy end |
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
2681 2682 2683 |
# File 'lib/models/porcelain.rb', line 2681 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2683 2684 2685 |
# File 'lib/models/porcelain.rb', line 2683 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2685 2686 2687 |
# File 'lib/models/porcelain.rb', line 2685 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2687 2688 2689 |
# File 'lib/models/porcelain.rb', line 2687 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2689 2690 2691 |
# File 'lib/models/porcelain.rb', line 2689 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
2691 2692 2693 |
# File 'lib/models/porcelain.rb', line 2691 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2693 2694 2695 |
# File 'lib/models/porcelain.rb', line 2693 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2695 2696 2697 |
# File 'lib/models/porcelain.rb', line 2695 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2697 2698 2699 |
# File 'lib/models/porcelain.rb', line 2697 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/models/porcelain.rb', line 2755 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |