Class: SDM::DocumentDBReplicaSetIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

DocumentDBReplicaSetIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBReplicaSetIAM

Returns a new instance of DocumentDBReplicaSetIAM.



6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
6720
6721
6722
6723
6724
6725
6726
6727
6728
6729
# File 'lib/models/porcelain.rb', line 6701

def initialize(
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6675
6676
6677
# File 'lib/models/porcelain.rb', line 6675

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



6677
6678
6679
# File 'lib/models/porcelain.rb', line 6677

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6679
6680
6681
# File 'lib/models/porcelain.rb', line 6679

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6681
6682
6683
# File 'lib/models/porcelain.rb', line 6681

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



6683
6684
6685
# File 'lib/models/porcelain.rb', line 6683

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6685
6686
6687
# File 'lib/models/porcelain.rb', line 6685

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6687
6688
6689
# File 'lib/models/porcelain.rb', line 6687

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6689
6690
6691
# File 'lib/models/porcelain.rb', line 6689

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6691
6692
6693
# File 'lib/models/porcelain.rb', line 6691

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region of the document db cluster



6693
6694
6695
# File 'lib/models/porcelain.rb', line 6693

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6695
6696
6697
# File 'lib/models/porcelain.rb', line 6695

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6697
6698
6699
# File 'lib/models/porcelain.rb', line 6697

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6699
6700
6701
# File 'lib/models/porcelain.rb', line 6699

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6731
6732
6733
6734
6735
6736
6737
# File 'lib/models/porcelain.rb', line 6731

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end