Class: SDM::DocumentDBReplicaSetIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

DocumentDBReplicaSetIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBReplicaSetIAM

Returns a new instance of DocumentDBReplicaSetIAM.



6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
# File 'lib/models/porcelain.rb', line 6321

def initialize(
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6295
6296
6297
# File 'lib/models/porcelain.rb', line 6295

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



6297
6298
6299
# File 'lib/models/porcelain.rb', line 6297

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6299
6300
6301
# File 'lib/models/porcelain.rb', line 6299

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6301
6302
6303
# File 'lib/models/porcelain.rb', line 6301

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



6303
6304
6305
# File 'lib/models/porcelain.rb', line 6303

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6305
6306
6307
# File 'lib/models/porcelain.rb', line 6305

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6307
6308
6309
# File 'lib/models/porcelain.rb', line 6307

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6309
6310
6311
# File 'lib/models/porcelain.rb', line 6309

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6311
6312
6313
# File 'lib/models/porcelain.rb', line 6311

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region of the document db cluster



6313
6314
6315
# File 'lib/models/porcelain.rb', line 6313

def region
  @region
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6315
6316
6317
# File 'lib/models/porcelain.rb', line 6315

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6317
6318
6319
# File 'lib/models/porcelain.rb', line 6317

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6319
6320
6321
# File 'lib/models/porcelain.rb', line 6319

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6351
6352
6353
6354
6355
6356
6357
# File 'lib/models/porcelain.rb', line 6351

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end