Class: SDM::DocumentDBReplicaSetIAM
- Inherits:
-
Object
- Object
- SDM::DocumentDBReplicaSetIAM
- Defined in:
- lib/models/porcelain.rb
Overview
DocumentDBReplicaSetIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The region of the document db cluster.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBReplicaSetIAM
constructor
A new instance of DocumentDBReplicaSetIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBReplicaSetIAM
Returns a new instance of DocumentDBReplicaSetIAM.
5443 5444 5445 5446 5447 5448 5449 5450 5451 5452 5453 5454 5455 5456 5457 5458 5459 5460 5461 5462 5463 5464 5465 5466 5467 5468 5469 5470 5471 |
# File 'lib/models/porcelain.rb', line 5443 def initialize( bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5417 5418 5419 |
# File 'lib/models/porcelain.rb', line 5417 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
5419 5420 5421 |
# File 'lib/models/porcelain.rb', line 5419 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5421 5422 5423 |
# File 'lib/models/porcelain.rb', line 5421 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5423 5424 5425 |
# File 'lib/models/porcelain.rb', line 5423 def healthy @healthy end |
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
5425 5426 5427 |
# File 'lib/models/porcelain.rb', line 5425 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5427 5428 5429 |
# File 'lib/models/porcelain.rb', line 5427 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5429 5430 5431 |
# File 'lib/models/porcelain.rb', line 5429 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5431 5432 5433 |
# File 'lib/models/porcelain.rb', line 5431 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5433 5434 5435 |
# File 'lib/models/porcelain.rb', line 5433 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The region of the document db cluster
5435 5436 5437 |
# File 'lib/models/porcelain.rb', line 5435 def region @region end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5437 5438 5439 |
# File 'lib/models/porcelain.rb', line 5437 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5439 5440 5441 |
# File 'lib/models/porcelain.rb', line 5439 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5441 5442 5443 |
# File 'lib/models/porcelain.rb', line 5441 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5473 5474 5475 5476 5477 5478 5479 |
# File 'lib/models/porcelain.rb', line 5473 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |