Class: SDM::DocumentDBReplicaSetIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

DocumentDBReplicaSetIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DocumentDBReplicaSetIAM

Returns a new instance of DocumentDBReplicaSetIAM.



6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
6783
6784
6785
6786
6787
6788
6789
6790
# File 'lib/models/porcelain.rb', line 6762

def initialize(
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6736
6737
6738
# File 'lib/models/porcelain.rb', line 6736

def bind_interface
  @bind_interface
end

#connect_to_replica ⇒ Object

Set to connect to a replica instead of the primary node.



6738
6739
6740
# File 'lib/models/porcelain.rb', line 6738

def connect_to_replica
  @connect_to_replica
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



6740
6741
6742
# File 'lib/models/porcelain.rb', line 6740

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



6742
6743
6744
# File 'lib/models/porcelain.rb', line 6742

def healthy
  @healthy
end

#hostname ⇒ Object

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



6744
6745
6746
# File 'lib/models/porcelain.rb', line 6744

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



6746
6747
6748
# File 'lib/models/porcelain.rb', line 6746

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



6748
6749
6750
# File 'lib/models/porcelain.rb', line 6748

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6750
6751
6752
# File 'lib/models/porcelain.rb', line 6750

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



6752
6753
6754
# File 'lib/models/porcelain.rb', line 6752

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The region of the document db cluster



6754
6755
6756
# File 'lib/models/porcelain.rb', line 6754

def region
  @region
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



6756
6757
6758
# File 'lib/models/porcelain.rb', line 6756

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6758
6759
6760
# File 'lib/models/porcelain.rb', line 6758

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



6760
6761
6762
# File 'lib/models/porcelain.rb', line 6760

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6792
6793
6794
6795
6796
6797
6798
# File 'lib/models/porcelain.rb', line 6792

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end