Class: SDM::Druid

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid

Returns a new instance of Druid.



6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
# File 'lib/models/porcelain.rb', line 6830

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6802
6803
6804
# File 'lib/models/porcelain.rb', line 6802

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6804
6805
6806
# File 'lib/models/porcelain.rb', line 6804

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6806
6807
6808
# File 'lib/models/porcelain.rb', line 6806

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6808
6809
6810
# File 'lib/models/porcelain.rb', line 6808

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6810
6811
6812
# File 'lib/models/porcelain.rb', line 6810

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6812
6813
6814
# File 'lib/models/porcelain.rb', line 6812

def name
  @name
end

#passwordObject

The password to authenticate with.



6814
6815
6816
# File 'lib/models/porcelain.rb', line 6814

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6816
6817
6818
# File 'lib/models/porcelain.rb', line 6816

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6818
6819
6820
# File 'lib/models/porcelain.rb', line 6818

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6820
6821
6822
# File 'lib/models/porcelain.rb', line 6820

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6822
6823
6824
# File 'lib/models/porcelain.rb', line 6822

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6824
6825
6826
# File 'lib/models/porcelain.rb', line 6824

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6826
6827
6828
# File 'lib/models/porcelain.rb', line 6826

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6828
6829
6830
# File 'lib/models/porcelain.rb', line 6828

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6862
6863
6864
6865
6866
6867
6868
# File 'lib/models/porcelain.rb', line 6862

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end