Class: SDM::Druid

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid

Returns a new instance of Druid.



6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
# File 'lib/models/porcelain.rb', line 6794

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6766
6767
6768
# File 'lib/models/porcelain.rb', line 6766

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6768
6769
6770
# File 'lib/models/porcelain.rb', line 6768

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6770
6771
6772
# File 'lib/models/porcelain.rb', line 6770

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6772
6773
6774
# File 'lib/models/porcelain.rb', line 6772

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6774
6775
6776
# File 'lib/models/porcelain.rb', line 6774

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6776
6777
6778
# File 'lib/models/porcelain.rb', line 6776

def name
  @name
end

#passwordObject

The password to authenticate with.



6778
6779
6780
# File 'lib/models/porcelain.rb', line 6778

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6780
6781
6782
# File 'lib/models/porcelain.rb', line 6780

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6782
6783
6784
# File 'lib/models/porcelain.rb', line 6782

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6784
6785
6786
# File 'lib/models/porcelain.rb', line 6784

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6786
6787
6788
# File 'lib/models/porcelain.rb', line 6786

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6788
6789
6790
# File 'lib/models/porcelain.rb', line 6788

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6790
6791
6792
# File 'lib/models/porcelain.rb', line 6790

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6792
6793
6794
# File 'lib/models/porcelain.rb', line 6792

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6826
6827
6828
6829
6830
6831
6832
# File 'lib/models/porcelain.rb', line 6826

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end