Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 5699 5700 5701 |
# File 'lib/models/porcelain.rb', line 5671 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5643 5644 5645 |
# File 'lib/models/porcelain.rb', line 5643 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5645 5646 5647 |
# File 'lib/models/porcelain.rb', line 5645 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5647 5648 5649 |
# File 'lib/models/porcelain.rb', line 5647 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5649 5650 5651 |
# File 'lib/models/porcelain.rb', line 5649 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5651 5652 5653 |
# File 'lib/models/porcelain.rb', line 5651 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5653 5654 5655 |
# File 'lib/models/porcelain.rb', line 5653 def name @name end |
#password ⇒ Object
The password to authenticate with.
5655 5656 5657 |
# File 'lib/models/porcelain.rb', line 5655 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5657 5658 5659 |
# File 'lib/models/porcelain.rb', line 5657 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5659 5660 5661 |
# File 'lib/models/porcelain.rb', line 5659 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5661 5662 5663 |
# File 'lib/models/porcelain.rb', line 5661 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5663 5664 5665 |
# File 'lib/models/porcelain.rb', line 5663 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5665 5666 5667 |
# File 'lib/models/porcelain.rb', line 5665 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5667 5668 5669 |
# File 'lib/models/porcelain.rb', line 5667 def @tags end |
#username ⇒ Object
The username to authenticate with.
5669 5670 5671 |
# File 'lib/models/porcelain.rb', line 5669 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5703 5704 5705 5706 5707 5708 5709 |
# File 'lib/models/porcelain.rb', line 5703 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |