Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 |
# File 'lib/models/porcelain.rb', line 5523 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5495 5496 5497 |
# File 'lib/models/porcelain.rb', line 5495 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5497 5498 5499 |
# File 'lib/models/porcelain.rb', line 5497 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5499 5500 5501 |
# File 'lib/models/porcelain.rb', line 5499 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5501 5502 5503 |
# File 'lib/models/porcelain.rb', line 5501 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5503 5504 5505 |
# File 'lib/models/porcelain.rb', line 5503 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5505 5506 5507 |
# File 'lib/models/porcelain.rb', line 5505 def name @name end |
#password ⇒ Object
The password to authenticate with.
5507 5508 5509 |
# File 'lib/models/porcelain.rb', line 5507 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5509 5510 5511 |
# File 'lib/models/porcelain.rb', line 5509 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5511 5512 5513 |
# File 'lib/models/porcelain.rb', line 5511 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5513 5514 5515 |
# File 'lib/models/porcelain.rb', line 5513 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5515 5516 5517 |
# File 'lib/models/porcelain.rb', line 5515 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5517 5518 5519 |
# File 'lib/models/porcelain.rb', line 5517 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5519 5520 5521 |
# File 'lib/models/porcelain.rb', line 5519 def @tags end |
#username ⇒ Object
The username to authenticate with.
5521 5522 5523 |
# File 'lib/models/porcelain.rb', line 5521 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5555 5556 5557 5558 5559 5560 5561 |
# File 'lib/models/porcelain.rb', line 5555 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |