Class: SDM::Druid

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid

Returns a new instance of Druid.



5376
5377
5378
5379
5380
5381
5382
5383
5384
5385
5386
5387
5388
5389
5390
5391
5392
5393
5394
5395
5396
5397
5398
5399
5400
5401
5402
5403
5404
5405
5406
# File 'lib/models/porcelain.rb', line 5376

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5348
5349
5350
# File 'lib/models/porcelain.rb', line 5348

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5350
5351
5352
# File 'lib/models/porcelain.rb', line 5350

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5352
5353
5354
# File 'lib/models/porcelain.rb', line 5352

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5354
5355
5356
# File 'lib/models/porcelain.rb', line 5354

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5356
5357
5358
# File 'lib/models/porcelain.rb', line 5356

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5358
5359
5360
# File 'lib/models/porcelain.rb', line 5358

def name
  @name
end

#passwordObject

The password to authenticate with.



5360
5361
5362
# File 'lib/models/porcelain.rb', line 5360

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5362
5363
5364
# File 'lib/models/porcelain.rb', line 5362

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5364
5365
5366
# File 'lib/models/porcelain.rb', line 5364

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5366
5367
5368
# File 'lib/models/porcelain.rb', line 5366

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5368
5369
5370
# File 'lib/models/porcelain.rb', line 5368

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5370
5371
5372
# File 'lib/models/porcelain.rb', line 5370

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5372
5373
5374
# File 'lib/models/porcelain.rb', line 5372

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5374
5375
5376
# File 'lib/models/porcelain.rb', line 5374

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5408
5409
5410
5411
5412
5413
5414
# File 'lib/models/porcelain.rb', line 5408

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end