Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 5223 |
# File 'lib/models/porcelain.rb', line 5193 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5165 5166 5167 |
# File 'lib/models/porcelain.rb', line 5165 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5167 5168 5169 |
# File 'lib/models/porcelain.rb', line 5167 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5169 5170 5171 |
# File 'lib/models/porcelain.rb', line 5169 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5171 5172 5173 |
# File 'lib/models/porcelain.rb', line 5171 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5173 5174 5175 |
# File 'lib/models/porcelain.rb', line 5173 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5175 5176 5177 |
# File 'lib/models/porcelain.rb', line 5175 def name @name end |
#password ⇒ Object
The password to authenticate with.
5177 5178 5179 |
# File 'lib/models/porcelain.rb', line 5177 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5179 5180 5181 |
# File 'lib/models/porcelain.rb', line 5179 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5181 5182 5183 |
# File 'lib/models/porcelain.rb', line 5181 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5183 5184 5185 |
# File 'lib/models/porcelain.rb', line 5183 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5185 5186 5187 |
# File 'lib/models/porcelain.rb', line 5185 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5187 5188 5189 |
# File 'lib/models/porcelain.rb', line 5187 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5189 5190 5191 |
# File 'lib/models/porcelain.rb', line 5189 def @tags end |
#username ⇒ Object
The username to authenticate with.
5191 5192 5193 |
# File 'lib/models/porcelain.rb', line 5191 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5225 5226 5227 5228 5229 5230 5231 |
# File 'lib/models/porcelain.rb', line 5225 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |