Class: SDM::Druid

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid

Returns a new instance of Druid.



4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/models/porcelain.rb', line 4830

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4802
4803
4804
# File 'lib/models/porcelain.rb', line 4802

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4804
4805
4806
# File 'lib/models/porcelain.rb', line 4804

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4806
4807
4808
# File 'lib/models/porcelain.rb', line 4806

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4808
4809
4810
# File 'lib/models/porcelain.rb', line 4808

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4810
4811
4812
# File 'lib/models/porcelain.rb', line 4810

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4812
4813
4814
# File 'lib/models/porcelain.rb', line 4812

def name
  @name
end

#passwordObject

The password to authenticate with.



4814
4815
4816
# File 'lib/models/porcelain.rb', line 4814

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4816
4817
4818
# File 'lib/models/porcelain.rb', line 4816

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4818
4819
4820
# File 'lib/models/porcelain.rb', line 4818

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



4820
4821
4822
# File 'lib/models/porcelain.rb', line 4820

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4822
4823
4824
# File 'lib/models/porcelain.rb', line 4822

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4824
4825
4826
# File 'lib/models/porcelain.rb', line 4824

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4826
4827
4828
# File 'lib/models/porcelain.rb', line 4826

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4828
4829
4830
# File 'lib/models/porcelain.rb', line 4828

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4862
4863
4864
4865
4866
4867
4868
# File 'lib/models/porcelain.rb', line 4862

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end