Class: SDM::Druid

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid

Returns a new instance of Druid.



4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
4560
# File 'lib/models/porcelain.rb', line 4532

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4506
4507
4508
# File 'lib/models/porcelain.rb', line 4506

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4508
4509
4510
# File 'lib/models/porcelain.rb', line 4508

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4510
4511
4512
# File 'lib/models/porcelain.rb', line 4510

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4512
4513
4514
# File 'lib/models/porcelain.rb', line 4512

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4514
4515
4516
# File 'lib/models/porcelain.rb', line 4514

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4516
4517
4518
# File 'lib/models/porcelain.rb', line 4516

def name
  @name
end

#passwordObject

The password to authenticate with.



4518
4519
4520
# File 'lib/models/porcelain.rb', line 4518

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4520
4521
4522
# File 'lib/models/porcelain.rb', line 4520

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4522
4523
4524
# File 'lib/models/porcelain.rb', line 4522

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4524
4525
4526
# File 'lib/models/porcelain.rb', line 4524

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4526
4527
4528
# File 'lib/models/porcelain.rb', line 4526

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4528
4529
4530
# File 'lib/models/porcelain.rb', line 4528

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4530
4531
4532
# File 'lib/models/porcelain.rb', line 4530

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4562
4563
4564
4565
4566
4567
4568
# File 'lib/models/porcelain.rb', line 4562

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end