Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
4389 4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 |
# File 'lib/models/porcelain.rb', line 4389 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4363 4364 4365 |
# File 'lib/models/porcelain.rb', line 4363 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4365 4366 4367 |
# File 'lib/models/porcelain.rb', line 4365 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4367 4368 4369 |
# File 'lib/models/porcelain.rb', line 4367 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4369 4370 4371 |
# File 'lib/models/porcelain.rb', line 4369 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4371 4372 4373 |
# File 'lib/models/porcelain.rb', line 4371 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4373 4374 4375 |
# File 'lib/models/porcelain.rb', line 4373 def name @name end |
#password ⇒ Object
The password to authenticate with.
4375 4376 4377 |
# File 'lib/models/porcelain.rb', line 4375 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4377 4378 4379 |
# File 'lib/models/porcelain.rb', line 4377 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4379 4380 4381 |
# File 'lib/models/porcelain.rb', line 4379 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4381 4382 4383 |
# File 'lib/models/porcelain.rb', line 4381 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4383 4384 4385 |
# File 'lib/models/porcelain.rb', line 4383 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4385 4386 4387 |
# File 'lib/models/porcelain.rb', line 4385 def @tags end |
#username ⇒ Object
The username to authenticate with.
4387 4388 4389 |
# File 'lib/models/porcelain.rb', line 4387 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4419 4420 4421 4422 4423 4424 4425 |
# File 'lib/models/porcelain.rb', line 4419 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |