Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 |
# File 'lib/models/porcelain.rb', line 3397 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3371 3372 3373 |
# File 'lib/models/porcelain.rb', line 3371 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3373 3374 3375 |
# File 'lib/models/porcelain.rb', line 3373 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3375 3376 3377 |
# File 'lib/models/porcelain.rb', line 3375 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3377 3378 3379 |
# File 'lib/models/porcelain.rb', line 3377 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3379 3380 3381 |
# File 'lib/models/porcelain.rb', line 3379 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3381 3382 3383 |
# File 'lib/models/porcelain.rb', line 3381 def name @name end |
#password ⇒ Object
The password to authenticate with.
3383 3384 3385 |
# File 'lib/models/porcelain.rb', line 3383 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3385 3386 3387 |
# File 'lib/models/porcelain.rb', line 3385 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3387 3388 3389 |
# File 'lib/models/porcelain.rb', line 3387 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3389 3390 3391 |
# File 'lib/models/porcelain.rb', line 3389 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3391 3392 3393 |
# File 'lib/models/porcelain.rb', line 3391 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3393 3394 3395 |
# File 'lib/models/porcelain.rb', line 3393 def @tags end |
#username ⇒ Object
The username to authenticate with.
3395 3396 3397 |
# File 'lib/models/porcelain.rb', line 3395 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3427 3428 3429 3430 3431 3432 3433 |
# File 'lib/models/porcelain.rb', line 3427 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |