Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 |
# File 'lib/models/porcelain.rb', line 3275 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3249 3250 3251 |
# File 'lib/models/porcelain.rb', line 3249 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3251 3252 3253 |
# File 'lib/models/porcelain.rb', line 3251 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3253 3254 3255 |
# File 'lib/models/porcelain.rb', line 3253 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3255 3256 3257 |
# File 'lib/models/porcelain.rb', line 3255 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3257 3258 3259 |
# File 'lib/models/porcelain.rb', line 3257 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3259 3260 3261 |
# File 'lib/models/porcelain.rb', line 3259 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3261 3262 3263 |
# File 'lib/models/porcelain.rb', line 3261 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3263 3264 3265 |
# File 'lib/models/porcelain.rb', line 3263 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3265 3266 3267 |
# File 'lib/models/porcelain.rb', line 3265 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3267 3268 3269 |
# File 'lib/models/porcelain.rb', line 3267 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3269 3270 3271 |
# File 'lib/models/porcelain.rb', line 3269 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3271 3272 3273 |
# File 'lib/models/porcelain.rb', line 3271 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3273 3274 3275 |
# File 'lib/models/porcelain.rb', line 3273 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3305 3306 3307 3308 3309 3310 3311 |
# File 'lib/models/porcelain.rb', line 3305 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |