Class: SDM::Druid

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Druid

Returns a new instance of Druid.



3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
# File 'lib/models/porcelain.rb', line 3113

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3087
3088
3089
# File 'lib/models/porcelain.rb', line 3087

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3089
3090
3091
# File 'lib/models/porcelain.rb', line 3089

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3091
3092
3093
# File 'lib/models/porcelain.rb', line 3091

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3093
3094
3095
# File 'lib/models/porcelain.rb', line 3093

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3095
3096
3097
# File 'lib/models/porcelain.rb', line 3095

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3097
3098
3099
# File 'lib/models/porcelain.rb', line 3097

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3099
3100
3101
# File 'lib/models/porcelain.rb', line 3099

def password
  @password
end

#portObject

Returns the value of attribute port.



3101
3102
3103
# File 'lib/models/porcelain.rb', line 3101

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3103
3104
3105
# File 'lib/models/porcelain.rb', line 3103

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3105
3106
3107
# File 'lib/models/porcelain.rb', line 3105

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3107
3108
3109
# File 'lib/models/porcelain.rb', line 3107

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3109
3110
3111
# File 'lib/models/porcelain.rb', line 3109

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3111
3112
3113
# File 'lib/models/porcelain.rb', line 3111

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3143
3144
3145
3146
3147
3148
3149
# File 'lib/models/porcelain.rb', line 3143

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end