Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 |
# File 'lib/models/porcelain.rb', line 3015 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2991 2992 2993 |
# File 'lib/models/porcelain.rb', line 2991 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2993 2994 2995 |
# File 'lib/models/porcelain.rb', line 2993 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2995 2996 2997 |
# File 'lib/models/porcelain.rb', line 2995 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2997 2998 2999 |
# File 'lib/models/porcelain.rb', line 2997 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2999 3000 3001 |
# File 'lib/models/porcelain.rb', line 2999 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3001 3002 3003 |
# File 'lib/models/porcelain.rb', line 3001 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3003 3004 3005 |
# File 'lib/models/porcelain.rb', line 3003 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3005 3006 3007 |
# File 'lib/models/porcelain.rb', line 3005 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3007 3008 3009 |
# File 'lib/models/porcelain.rb', line 3007 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3009 3010 3011 |
# File 'lib/models/porcelain.rb', line 3009 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3011 3012 3013 |
# File 'lib/models/porcelain.rb', line 3011 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3013 3014 3015 |
# File 'lib/models/porcelain.rb', line 3013 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3043 3044 3045 3046 3047 3048 3049 |
# File 'lib/models/porcelain.rb', line 3043 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |