Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 |
# File 'lib/models/porcelain.rb', line 2678 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2654 2655 2656 |
# File 'lib/models/porcelain.rb', line 2654 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2656 2657 2658 |
# File 'lib/models/porcelain.rb', line 2656 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2658 2659 2660 |
# File 'lib/models/porcelain.rb', line 2658 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2660 2661 2662 |
# File 'lib/models/porcelain.rb', line 2660 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2662 2663 2664 |
# File 'lib/models/porcelain.rb', line 2662 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2664 2665 2666 |
# File 'lib/models/porcelain.rb', line 2664 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2666 2667 2668 |
# File 'lib/models/porcelain.rb', line 2666 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2668 2669 2670 |
# File 'lib/models/porcelain.rb', line 2668 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2670 2671 2672 |
# File 'lib/models/porcelain.rb', line 2670 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2672 2673 2674 |
# File 'lib/models/porcelain.rb', line 2672 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2674 2675 2676 |
# File 'lib/models/porcelain.rb', line 2674 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2676 2677 2678 |
# File 'lib/models/porcelain.rb', line 2676 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2706 2707 2708 2709 2710 2711 2712 |
# File 'lib/models/porcelain.rb', line 2706 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |