Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 |
# File 'lib/models/porcelain.rb', line 2570 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2546 2547 2548 |
# File 'lib/models/porcelain.rb', line 2546 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2548 2549 2550 |
# File 'lib/models/porcelain.rb', line 2548 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2550 2551 2552 |
# File 'lib/models/porcelain.rb', line 2550 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2552 2553 2554 |
# File 'lib/models/porcelain.rb', line 2552 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2554 2555 2556 |
# File 'lib/models/porcelain.rb', line 2554 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2556 2557 2558 |
# File 'lib/models/porcelain.rb', line 2556 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2558 2559 2560 |
# File 'lib/models/porcelain.rb', line 2558 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2560 2561 2562 |
# File 'lib/models/porcelain.rb', line 2560 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2562 2563 2564 |
# File 'lib/models/porcelain.rb', line 2562 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2564 2565 2566 |
# File 'lib/models/porcelain.rb', line 2564 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2566 2567 2568 |
# File 'lib/models/porcelain.rb', line 2566 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2568 2569 2570 |
# File 'lib/models/porcelain.rb', line 2568 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/models/porcelain.rb', line 2598 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |