Class: SDM::Druid
- Inherits:
-
Object
- Object
- SDM::Druid
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Druid
constructor
A new instance of Druid.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Druid
Returns a new instance of Druid.
2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 |
# File 'lib/models/porcelain.rb', line 2788 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2766 2767 2768 |
# File 'lib/models/porcelain.rb', line 2766 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2768 2769 2770 |
# File 'lib/models/porcelain.rb', line 2768 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2770 2771 2772 |
# File 'lib/models/porcelain.rb', line 2770 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2772 2773 2774 |
# File 'lib/models/porcelain.rb', line 2772 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2774 2775 2776 |
# File 'lib/models/porcelain.rb', line 2774 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2776 2777 2778 |
# File 'lib/models/porcelain.rb', line 2776 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2778 2779 2780 |
# File 'lib/models/porcelain.rb', line 2778 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2780 2781 2782 |
# File 'lib/models/porcelain.rb', line 2780 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2782 2783 2784 |
# File 'lib/models/porcelain.rb', line 2782 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2784 2785 2786 |
# File 'lib/models/porcelain.rb', line 2784 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
2786 2787 2788 |
# File 'lib/models/porcelain.rb', line 2786 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/models/porcelain.rb', line 2836 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |