Class: SDM::DynamoDB

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB

Returns a new instance of DynamoDB.



6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
# File 'lib/models/porcelain.rb', line 6843

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



6811
6812
6813
# File 'lib/models/porcelain.rb', line 6811

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6813
6814
6815
# File 'lib/models/porcelain.rb', line 6813

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6815
6816
6817
# File 'lib/models/porcelain.rb', line 6815

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



6817
6818
6819
# File 'lib/models/porcelain.rb', line 6817

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6819
6820
6821
# File 'lib/models/porcelain.rb', line 6819

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6821
6822
6823
# File 'lib/models/porcelain.rb', line 6821

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6823
6824
6825
# File 'lib/models/porcelain.rb', line 6823

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6825
6826
6827
# File 'lib/models/porcelain.rb', line 6825

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6827
6828
6829
# File 'lib/models/porcelain.rb', line 6827

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



6829
6830
6831
# File 'lib/models/porcelain.rb', line 6829

def region
  @region
end

#role_arnObject

The role to assume after logging in.



6831
6832
6833
# File 'lib/models/porcelain.rb', line 6831

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



6833
6834
6835
# File 'lib/models/porcelain.rb', line 6833

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



6835
6836
6837
# File 'lib/models/porcelain.rb', line 6835

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6837
6838
6839
# File 'lib/models/porcelain.rb', line 6837

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6839
6840
6841
# File 'lib/models/porcelain.rb', line 6839

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6841
6842
6843
# File 'lib/models/porcelain.rb', line 6841

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6879
6880
6881
6882
6883
6884
6885
# File 'lib/models/porcelain.rb', line 6879

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end