Class: SDM::DynamoDB
- Inherits:
-
Object
- Object
- SDM::DynamoDB
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The region to authenticate requests against e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB
constructor
A new instance of DynamoDB.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB
Returns a new instance of DynamoDB.
6755 6756 6757 6758 6759 6760 6761 6762 6763 6764 6765 6766 6767 6768 6769 6770 6771 6772 6773 6774 6775 6776 6777 6778 6779 6780 6781 6782 6783 6784 6785 6786 6787 6788 6789 |
# File 'lib/models/porcelain.rb', line 6755 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
6723 6724 6725 |
# File 'lib/models/porcelain.rb', line 6723 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
6725 6726 6727 |
# File 'lib/models/porcelain.rb', line 6725 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6727 6728 6729 |
# File 'lib/models/porcelain.rb', line 6727 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. dynamodb.region.amazonaws.com
6729 6730 6731 |
# File 'lib/models/porcelain.rb', line 6729 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6731 6732 6733 |
# File 'lib/models/porcelain.rb', line 6731 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
6733 6734 6735 |
# File 'lib/models/porcelain.rb', line 6733 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6735 6736 6737 |
# File 'lib/models/porcelain.rb', line 6735 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
6737 6738 6739 |
# File 'lib/models/porcelain.rb', line 6737 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
6739 6740 6741 |
# File 'lib/models/porcelain.rb', line 6739 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The region to authenticate requests against e.g. us-east-1
6741 6742 6743 |
# File 'lib/models/porcelain.rb', line 6741 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
6743 6744 6745 |
# File 'lib/models/porcelain.rb', line 6743 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
6745 6746 6747 |
# File 'lib/models/porcelain.rb', line 6745 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
6747 6748 6749 |
# File 'lib/models/porcelain.rb', line 6747 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6749 6750 6751 |
# File 'lib/models/porcelain.rb', line 6749 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
6751 6752 6753 |
# File 'lib/models/porcelain.rb', line 6751 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6753 6754 6755 |
# File 'lib/models/porcelain.rb', line 6753 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6791 6792 6793 6794 6795 6796 6797 |
# File 'lib/models/porcelain.rb', line 6791 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |