Class: SDM::DynamoDB

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB

Returns a new instance of DynamoDB.



6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
6783
6784
6785
# File 'lib/models/porcelain.rb', line 6751

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



6719
6720
6721
# File 'lib/models/porcelain.rb', line 6719

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6721
6722
6723
# File 'lib/models/porcelain.rb', line 6721

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6723
6724
6725
# File 'lib/models/porcelain.rb', line 6723

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



6725
6726
6727
# File 'lib/models/porcelain.rb', line 6725

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6727
6728
6729
# File 'lib/models/porcelain.rb', line 6727

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6729
6730
6731
# File 'lib/models/porcelain.rb', line 6729

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6731
6732
6733
# File 'lib/models/porcelain.rb', line 6731

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6733
6734
6735
# File 'lib/models/porcelain.rb', line 6733

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6735
6736
6737
# File 'lib/models/porcelain.rb', line 6735

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



6737
6738
6739
# File 'lib/models/porcelain.rb', line 6737

def region
  @region
end

#role_arnObject

The role to assume after logging in.



6739
6740
6741
# File 'lib/models/porcelain.rb', line 6739

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



6741
6742
6743
# File 'lib/models/porcelain.rb', line 6741

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



6743
6744
6745
# File 'lib/models/porcelain.rb', line 6743

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6745
6746
6747
# File 'lib/models/porcelain.rb', line 6745

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6747
6748
6749
# File 'lib/models/porcelain.rb', line 6747

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6749
6750
6751
# File 'lib/models/porcelain.rb', line 6749

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6787
6788
6789
6790
6791
6792
6793
# File 'lib/models/porcelain.rb', line 6787

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end