Class: SDM::DynamoDB

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB

Returns a new instance of DynamoDB.



6465
6466
6467
6468
6469
6470
6471
6472
6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
6491
6492
6493
6494
6495
6496
6497
6498
6499
# File 'lib/models/porcelain.rb', line 6465

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



6433
6434
6435
# File 'lib/models/porcelain.rb', line 6433

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6435
6436
6437
# File 'lib/models/porcelain.rb', line 6435

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6437
6438
6439
# File 'lib/models/porcelain.rb', line 6437

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



6439
6440
6441
# File 'lib/models/porcelain.rb', line 6439

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6441
6442
6443
# File 'lib/models/porcelain.rb', line 6441

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6443
6444
6445
# File 'lib/models/porcelain.rb', line 6443

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6445
6446
6447
# File 'lib/models/porcelain.rb', line 6445

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6447
6448
6449
# File 'lib/models/porcelain.rb', line 6447

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6449
6450
6451
# File 'lib/models/porcelain.rb', line 6449

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



6451
6452
6453
# File 'lib/models/porcelain.rb', line 6451

def region
  @region
end

#role_arnObject

The role to assume after logging in.



6453
6454
6455
# File 'lib/models/porcelain.rb', line 6453

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



6455
6456
6457
# File 'lib/models/porcelain.rb', line 6455

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



6457
6458
6459
# File 'lib/models/porcelain.rb', line 6457

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6459
6460
6461
# File 'lib/models/porcelain.rb', line 6459

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6461
6462
6463
# File 'lib/models/porcelain.rb', line 6461

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6463
6464
6465
# File 'lib/models/porcelain.rb', line 6463

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6501
6502
6503
6504
6505
6506
6507
# File 'lib/models/porcelain.rb', line 6501

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end