Class: SDM::DynamoDB
- Inherits:
-
Object
- Object
- SDM::DynamoDB
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The region to authenticate requests against e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB
constructor
A new instance of DynamoDB.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB
Returns a new instance of DynamoDB.
5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 |
# File 'lib/models/porcelain.rb', line 5746 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
5714 5715 5716 |
# File 'lib/models/porcelain.rb', line 5714 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5716 5717 5718 |
# File 'lib/models/porcelain.rb', line 5716 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5718 5719 5720 |
# File 'lib/models/porcelain.rb', line 5718 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. dynamodb.region.amazonaws.com
5720 5721 5722 |
# File 'lib/models/porcelain.rb', line 5720 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5722 5723 5724 |
# File 'lib/models/porcelain.rb', line 5722 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5724 5725 5726 |
# File 'lib/models/porcelain.rb', line 5724 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5726 5727 5728 |
# File 'lib/models/porcelain.rb', line 5726 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5728 5729 5730 |
# File 'lib/models/porcelain.rb', line 5728 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5730 5731 5732 |
# File 'lib/models/porcelain.rb', line 5730 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The region to authenticate requests against e.g. us-east-1
5732 5733 5734 |
# File 'lib/models/porcelain.rb', line 5732 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
5734 5735 5736 |
# File 'lib/models/porcelain.rb', line 5734 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
5736 5737 5738 |
# File 'lib/models/porcelain.rb', line 5736 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
5738 5739 5740 |
# File 'lib/models/porcelain.rb', line 5738 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5740 5741 5742 |
# File 'lib/models/porcelain.rb', line 5740 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5742 5743 5744 |
# File 'lib/models/porcelain.rb', line 5742 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5744 5745 5746 |
# File 'lib/models/porcelain.rb', line 5744 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5782 5783 5784 5785 5786 5787 5788 |
# File 'lib/models/porcelain.rb', line 5782 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |