Class: SDM::DynamoDB
- Inherits:
-
Object
- Object
- SDM::DynamoDB
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The region to authenticate requests against e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB
constructor
A new instance of DynamoDB.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB
Returns a new instance of DynamoDB.
5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 5229 5230 5231 |
# File 'lib/models/porcelain.rb', line 5197 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
5165 5166 5167 |
# File 'lib/models/porcelain.rb', line 5165 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5167 5168 5169 |
# File 'lib/models/porcelain.rb', line 5167 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5169 5170 5171 |
# File 'lib/models/porcelain.rb', line 5169 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. dynamodb.region.amazonaws.com
5171 5172 5173 |
# File 'lib/models/porcelain.rb', line 5171 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5173 5174 5175 |
# File 'lib/models/porcelain.rb', line 5173 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5175 5176 5177 |
# File 'lib/models/porcelain.rb', line 5175 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5177 5178 5179 |
# File 'lib/models/porcelain.rb', line 5177 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5179 5180 5181 |
# File 'lib/models/porcelain.rb', line 5179 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5181 5182 5183 |
# File 'lib/models/porcelain.rb', line 5181 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The region to authenticate requests against e.g. us-east-1
5183 5184 5185 |
# File 'lib/models/porcelain.rb', line 5183 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
5185 5186 5187 |
# File 'lib/models/porcelain.rb', line 5185 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
5187 5188 5189 |
# File 'lib/models/porcelain.rb', line 5187 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
5189 5190 5191 |
# File 'lib/models/porcelain.rb', line 5189 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5191 5192 5193 |
# File 'lib/models/porcelain.rb', line 5191 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5193 5194 5195 |
# File 'lib/models/porcelain.rb', line 5193 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5195 5196 5197 |
# File 'lib/models/porcelain.rb', line 5195 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5233 5234 5235 5236 5237 5238 5239 |
# File 'lib/models/porcelain.rb', line 5233 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |