Class: SDM::DynamoDB

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDB

Returns a new instance of DynamoDB.



3369
3370
3371
3372
3373
3374
3375
3376
3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
# File 'lib/models/porcelain.rb', line 3369

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



3339
3340
3341
# File 'lib/models/porcelain.rb', line 3339

def access_key
  @access_key
end

#bind_interfaceObject

Bind interface



3341
3342
3343
# File 'lib/models/porcelain.rb', line 3341

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3343
3344
3345
# File 'lib/models/porcelain.rb', line 3343

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3345
3346
3347
# File 'lib/models/porcelain.rb', line 3345

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3347
3348
3349
# File 'lib/models/porcelain.rb', line 3347

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3349
3350
3351
# File 'lib/models/porcelain.rb', line 3349

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3351
3352
3353
# File 'lib/models/porcelain.rb', line 3351

def name
  @name
end

#port_overrideObject

Returns the value of attribute port_override.



3353
3354
3355
# File 'lib/models/porcelain.rb', line 3353

def port_override
  @port_override
end

#regionObject

Returns the value of attribute region.



3355
3356
3357
# File 'lib/models/porcelain.rb', line 3355

def region
  @region
end

#role_arnObject

Returns the value of attribute role_arn.



3357
3358
3359
# File 'lib/models/porcelain.rb', line 3357

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



3359
3360
3361
# File 'lib/models/porcelain.rb', line 3359

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



3361
3362
3363
# File 'lib/models/porcelain.rb', line 3361

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3363
3364
3365
# File 'lib/models/porcelain.rb', line 3363

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3365
3366
3367
# File 'lib/models/porcelain.rb', line 3365

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3367
3368
3369
# File 'lib/models/porcelain.rb', line 3367

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3403
3404
3405
3406
3407
3408
3409
# File 'lib/models/porcelain.rb', line 3403

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end