Class: SDM::DynamoDB
- Inherits:
-
Object
- Object
- SDM::DynamoDB
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
constructor
A new instance of DynamoDB.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
Returns a new instance of DynamoDB.
3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 3110 3111 |
# File 'lib/models/porcelain.rb', line 3081 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
3053 3054 3055 |
# File 'lib/models/porcelain.rb', line 3053 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
3055 3056 3057 |
# File 'lib/models/porcelain.rb', line 3055 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3057 3058 3059 |
# File 'lib/models/porcelain.rb', line 3057 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
3059 3060 3061 |
# File 'lib/models/porcelain.rb', line 3059 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3061 3062 3063 |
# File 'lib/models/porcelain.rb', line 3061 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3063 3064 3065 |
# File 'lib/models/porcelain.rb', line 3063 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3065 3066 3067 |
# File 'lib/models/porcelain.rb', line 3065 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3067 3068 3069 |
# File 'lib/models/porcelain.rb', line 3067 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
3069 3070 3071 |
# File 'lib/models/porcelain.rb', line 3069 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
3071 3072 3073 |
# File 'lib/models/porcelain.rb', line 3071 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
3073 3074 3075 |
# File 'lib/models/porcelain.rb', line 3073 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
3075 3076 3077 |
# File 'lib/models/porcelain.rb', line 3075 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3077 3078 3079 |
# File 'lib/models/porcelain.rb', line 3077 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3079 3080 3081 |
# File 'lib/models/porcelain.rb', line 3079 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3113 3114 3115 3116 3117 3118 3119 |
# File 'lib/models/porcelain.rb', line 3113 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |