Class: SDM::DynamoDB
- Inherits:
-
Object
- Object
- SDM::DynamoDB
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
constructor
A new instance of DynamoDB.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
Returns a new instance of DynamoDB.
2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 |
# File 'lib/models/porcelain.rb', line 2743 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
2715 2716 2717 |
# File 'lib/models/porcelain.rb', line 2715 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
2717 2718 2719 |
# File 'lib/models/porcelain.rb', line 2717 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2719 2720 2721 |
# File 'lib/models/porcelain.rb', line 2719 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
2721 2722 2723 |
# File 'lib/models/porcelain.rb', line 2721 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2723 2724 2725 |
# File 'lib/models/porcelain.rb', line 2723 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2725 2726 2727 |
# File 'lib/models/porcelain.rb', line 2725 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2727 2728 2729 |
# File 'lib/models/porcelain.rb', line 2727 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2729 2730 2731 |
# File 'lib/models/porcelain.rb', line 2729 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
2731 2732 2733 |
# File 'lib/models/porcelain.rb', line 2731 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
2733 2734 2735 |
# File 'lib/models/porcelain.rb', line 2733 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
2735 2736 2737 |
# File 'lib/models/porcelain.rb', line 2735 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
2737 2738 2739 |
# File 'lib/models/porcelain.rb', line 2737 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2739 2740 2741 |
# File 'lib/models/porcelain.rb', line 2739 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2741 2742 2743 |
# File 'lib/models/porcelain.rb', line 2741 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2775 2776 2777 2778 2779 2780 2781 |
# File 'lib/models/porcelain.rb', line 2775 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |