Class: SDM::DynamoDB
- Inherits:
-
Object
- Object
- SDM::DynamoDB
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
constructor
A new instance of DynamoDB.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
Returns a new instance of DynamoDB.
2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 2774 |
# File 'lib/models/porcelain.rb', line 2744 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
2716 2717 2718 |
# File 'lib/models/porcelain.rb', line 2716 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
2718 2719 2720 |
# File 'lib/models/porcelain.rb', line 2718 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2720 2721 2722 |
# File 'lib/models/porcelain.rb', line 2720 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
2722 2723 2724 |
# File 'lib/models/porcelain.rb', line 2722 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2724 2725 2726 |
# File 'lib/models/porcelain.rb', line 2724 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2726 2727 2728 |
# File 'lib/models/porcelain.rb', line 2726 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2728 2729 2730 |
# File 'lib/models/porcelain.rb', line 2728 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2730 2731 2732 |
# File 'lib/models/porcelain.rb', line 2730 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
2732 2733 2734 |
# File 'lib/models/porcelain.rb', line 2732 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
2734 2735 2736 |
# File 'lib/models/porcelain.rb', line 2734 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
2736 2737 2738 |
# File 'lib/models/porcelain.rb', line 2736 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
2738 2739 2740 |
# File 'lib/models/porcelain.rb', line 2738 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2740 2741 2742 |
# File 'lib/models/porcelain.rb', line 2740 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2742 2743 2744 |
# File 'lib/models/porcelain.rb', line 2742 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2776 2777 2778 2779 2780 2781 2782 |
# File 'lib/models/porcelain.rb', line 2776 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |