Class: SDM::DynamoDB
- Inherits:
-
Object
- Object
- SDM::DynamoDB
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
constructor
A new instance of DynamoDB.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
Returns a new instance of DynamoDB.
2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 |
# File 'lib/models/porcelain.rb', line 2636 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
2608 2609 2610 |
# File 'lib/models/porcelain.rb', line 2608 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
2610 2611 2612 |
# File 'lib/models/porcelain.rb', line 2610 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2612 2613 2614 |
# File 'lib/models/porcelain.rb', line 2612 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
2614 2615 2616 |
# File 'lib/models/porcelain.rb', line 2614 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2616 2617 2618 |
# File 'lib/models/porcelain.rb', line 2616 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2618 2619 2620 |
# File 'lib/models/porcelain.rb', line 2618 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2620 2621 2622 |
# File 'lib/models/porcelain.rb', line 2620 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2622 2623 2624 |
# File 'lib/models/porcelain.rb', line 2622 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
2624 2625 2626 |
# File 'lib/models/porcelain.rb', line 2624 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
2626 2627 2628 |
# File 'lib/models/porcelain.rb', line 2626 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
2628 2629 2630 |
# File 'lib/models/porcelain.rb', line 2628 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
2630 2631 2632 |
# File 'lib/models/porcelain.rb', line 2630 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2632 2633 2634 |
# File 'lib/models/porcelain.rb', line 2632 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2634 2635 2636 |
# File 'lib/models/porcelain.rb', line 2634 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2668 2669 2670 2671 2672 2673 2674 |
# File 'lib/models/porcelain.rb', line 2668 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |