Class: SDM::DynamoDB
- Inherits:
-
Object
- Object
- SDM::DynamoDB
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
constructor
A new instance of DynamoDB.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ DynamoDB
Returns a new instance of DynamoDB.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 |
# File 'lib/models/porcelain.rb', line 2872 def initialize( access_key: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) if access_key != nil @access_key = access_key end if egress_filter != nil @egress_filter = egress_filter end if endpoint != nil @endpoint = endpoint end if healthy != nil @healthy = healthy end if id != nil @id = id end if name != nil @name = name end if port_override != nil @port_override = port_override end if region != nil @region = region end if role_arn != nil @role_arn = role_arn end if role_external_id != nil @role_external_id = role_external_id end if secret_access_key != nil @secret_access_key = secret_access_key end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
2846 2847 2848 |
# File 'lib/models/porcelain.rb', line 2846 def access_key @access_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2848 2849 2850 |
# File 'lib/models/porcelain.rb', line 2848 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
2850 2851 2852 |
# File 'lib/models/porcelain.rb', line 2850 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2852 2853 2854 |
# File 'lib/models/porcelain.rb', line 2852 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
2854 2855 2856 |
# File 'lib/models/porcelain.rb', line 2854 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2856 2857 2858 |
# File 'lib/models/porcelain.rb', line 2856 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2858 2859 2860 |
# File 'lib/models/porcelain.rb', line 2858 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
2860 2861 2862 |
# File 'lib/models/porcelain.rb', line 2860 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
2862 2863 2864 |
# File 'lib/models/porcelain.rb', line 2862 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
2864 2865 2866 |
# File 'lib/models/porcelain.rb', line 2864 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
2866 2867 2868 |
# File 'lib/models/porcelain.rb', line 2866 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2868 2869 2870 |
# File 'lib/models/porcelain.rb', line 2868 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2870 2871 2872 |
# File 'lib/models/porcelain.rb', line 2870 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2928 2929 2930 2931 2932 2933 2934 |
# File 'lib/models/porcelain.rb', line 2928 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |