Class: SDM::DynamoDBIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM

Returns a new instance of DynamoDBIAM.



6944
6945
6946
6947
6948
6949
6950
6951
6952
6953
6954
6955
6956
6957
6958
6959
6960
6961
6962
6963
6964
6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
# File 'lib/models/porcelain.rb', line 6944

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6916
6917
6918
# File 'lib/models/porcelain.rb', line 6916

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6918
6919
6920
# File 'lib/models/porcelain.rb', line 6918

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



6920
6921
6922
# File 'lib/models/porcelain.rb', line 6920

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6922
6923
6924
# File 'lib/models/porcelain.rb', line 6922

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6924
6925
6926
# File 'lib/models/porcelain.rb', line 6924

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6926
6927
6928
# File 'lib/models/porcelain.rb', line 6926

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6928
6929
6930
# File 'lib/models/porcelain.rb', line 6928

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6930
6931
6932
# File 'lib/models/porcelain.rb', line 6930

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



6932
6933
6934
# File 'lib/models/porcelain.rb', line 6932

def region
  @region
end

#role_arnObject

The role to assume after logging in.



6934
6935
6936
# File 'lib/models/porcelain.rb', line 6934

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



6936
6937
6938
# File 'lib/models/porcelain.rb', line 6936

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6938
6939
6940
# File 'lib/models/porcelain.rb', line 6938

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6940
6941
6942
# File 'lib/models/porcelain.rb', line 6940

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6942
6943
6944
# File 'lib/models/porcelain.rb', line 6942

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6976
6977
6978
6979
6980
6981
6982
# File 'lib/models/porcelain.rb', line 6976

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end