Class: SDM::DynamoDBIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM

Returns a new instance of DynamoDBIAM.



5824
5825
5826
5827
5828
5829
5830
5831
5832
5833
5834
5835
5836
5837
5838
5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
# File 'lib/models/porcelain.rb', line 5824

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5796
5797
5798
# File 'lib/models/porcelain.rb', line 5796

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5798
5799
5800
# File 'lib/models/porcelain.rb', line 5798

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



5800
5801
5802
# File 'lib/models/porcelain.rb', line 5800

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5802
5803
5804
# File 'lib/models/porcelain.rb', line 5802

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5804
5805
5806
# File 'lib/models/porcelain.rb', line 5804

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5806
5807
5808
# File 'lib/models/porcelain.rb', line 5806

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5808
5809
5810
# File 'lib/models/porcelain.rb', line 5808

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5810
5811
5812
# File 'lib/models/porcelain.rb', line 5810

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



5812
5813
5814
# File 'lib/models/porcelain.rb', line 5812

def region
  @region
end

#role_arnObject

The role to assume after logging in.



5814
5815
5816
# File 'lib/models/porcelain.rb', line 5814

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



5816
5817
5818
# File 'lib/models/porcelain.rb', line 5816

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5818
5819
5820
# File 'lib/models/porcelain.rb', line 5818

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5820
5821
5822
# File 'lib/models/porcelain.rb', line 5820

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5822
5823
5824
# File 'lib/models/porcelain.rb', line 5822

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5856
5857
5858
5859
5860
5861
5862
# File 'lib/models/porcelain.rb', line 5856

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end