Class: SDM::DynamoDBIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM

Returns a new instance of DynamoDBIAM.



5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
# File 'lib/models/porcelain.rb', line 5673

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5645
5646
5647
# File 'lib/models/porcelain.rb', line 5645

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5647
5648
5649
# File 'lib/models/porcelain.rb', line 5647

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



5649
5650
5651
# File 'lib/models/porcelain.rb', line 5649

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5651
5652
5653
# File 'lib/models/porcelain.rb', line 5651

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5653
5654
5655
# File 'lib/models/porcelain.rb', line 5653

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5655
5656
5657
# File 'lib/models/porcelain.rb', line 5655

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5657
5658
5659
# File 'lib/models/porcelain.rb', line 5657

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5659
5660
5661
# File 'lib/models/porcelain.rb', line 5659

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



5661
5662
5663
# File 'lib/models/porcelain.rb', line 5661

def region
  @region
end

#role_arnObject

The role to assume after logging in.



5663
5664
5665
# File 'lib/models/porcelain.rb', line 5663

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



5665
5666
5667
# File 'lib/models/porcelain.rb', line 5665

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5667
5668
5669
# File 'lib/models/porcelain.rb', line 5667

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5669
5670
5671
# File 'lib/models/porcelain.rb', line 5669

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5671
5672
5673
# File 'lib/models/porcelain.rb', line 5671

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5705
5706
5707
5708
5709
5710
5711
# File 'lib/models/porcelain.rb', line 5705

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end