Class: SDM::DynamoDBIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM

Returns a new instance of DynamoDBIAM.



5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
5692
# File 'lib/models/porcelain.rb', line 5662

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5634
5635
5636
# File 'lib/models/porcelain.rb', line 5634

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5636
5637
5638
# File 'lib/models/porcelain.rb', line 5636

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



5638
5639
5640
# File 'lib/models/porcelain.rb', line 5638

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5640
5641
5642
# File 'lib/models/porcelain.rb', line 5640

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5642
5643
5644
# File 'lib/models/porcelain.rb', line 5642

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5644
5645
5646
# File 'lib/models/porcelain.rb', line 5644

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5646
5647
5648
# File 'lib/models/porcelain.rb', line 5646

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5648
5649
5650
# File 'lib/models/porcelain.rb', line 5648

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



5650
5651
5652
# File 'lib/models/porcelain.rb', line 5650

def region
  @region
end

#role_arnObject

The role to assume after logging in.



5652
5653
5654
# File 'lib/models/porcelain.rb', line 5652

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



5654
5655
5656
# File 'lib/models/porcelain.rb', line 5654

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5656
5657
5658
# File 'lib/models/porcelain.rb', line 5656

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5658
5659
5660
# File 'lib/models/porcelain.rb', line 5658

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5660
5661
5662
# File 'lib/models/porcelain.rb', line 5660

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5694
5695
5696
5697
5698
5699
5700
# File 'lib/models/porcelain.rb', line 5694

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end