Class: SDM::DynamoDBIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM

Returns a new instance of DynamoDBIAM.



5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
5438
5439
5440
5441
5442
5443
5444
5445
5446
5447
5448
5449
5450
5451
# File 'lib/models/porcelain.rb', line 5421

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5393
5394
5395
# File 'lib/models/porcelain.rb', line 5393

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5395
5396
5397
# File 'lib/models/porcelain.rb', line 5395

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



5397
5398
5399
# File 'lib/models/porcelain.rb', line 5397

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5399
5400
5401
# File 'lib/models/porcelain.rb', line 5399

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5401
5402
5403
# File 'lib/models/porcelain.rb', line 5401

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5403
5404
5405
# File 'lib/models/porcelain.rb', line 5403

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5405
5406
5407
# File 'lib/models/porcelain.rb', line 5405

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5407
5408
5409
# File 'lib/models/porcelain.rb', line 5407

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



5409
5410
5411
# File 'lib/models/porcelain.rb', line 5409

def region
  @region
end

#role_arnObject

The role to assume after logging in.



5411
5412
5413
# File 'lib/models/porcelain.rb', line 5411

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



5413
5414
5415
# File 'lib/models/porcelain.rb', line 5413

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5415
5416
5417
# File 'lib/models/porcelain.rb', line 5415

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5417
5418
5419
# File 'lib/models/porcelain.rb', line 5417

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5419
5420
5421
# File 'lib/models/porcelain.rb', line 5419

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5453
5454
5455
5456
5457
5458
5459
# File 'lib/models/porcelain.rb', line 5453

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end