Class: SDM::DynamoDBIAM
- Inherits:
-
Object
- Object
- SDM::DynamoDBIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The region to authenticate requests against e.g.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM
constructor
A new instance of DynamoDBIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM
Returns a new instance of DynamoDBIAM.
5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 |
# File 'lib/models/porcelain.rb', line 5272 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5244 5245 5246 |
# File 'lib/models/porcelain.rb', line 5244 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5246 5247 5248 |
# File 'lib/models/porcelain.rb', line 5246 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. dynamodb.region.amazonaws.com
5248 5249 5250 |
# File 'lib/models/porcelain.rb', line 5248 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5250 5251 5252 |
# File 'lib/models/porcelain.rb', line 5250 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5252 5253 5254 |
# File 'lib/models/porcelain.rb', line 5252 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5254 5255 5256 |
# File 'lib/models/porcelain.rb', line 5254 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5256 5257 5258 |
# File 'lib/models/porcelain.rb', line 5256 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5258 5259 5260 |
# File 'lib/models/porcelain.rb', line 5258 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The region to authenticate requests against e.g. us-east-1
5260 5261 5262 |
# File 'lib/models/porcelain.rb', line 5260 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
5262 5263 5264 |
# File 'lib/models/porcelain.rb', line 5262 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
5264 5265 5266 |
# File 'lib/models/porcelain.rb', line 5264 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5266 5267 5268 |
# File 'lib/models/porcelain.rb', line 5266 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5268 5269 5270 |
# File 'lib/models/porcelain.rb', line 5268 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5270 5271 5272 |
# File 'lib/models/porcelain.rb', line 5270 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5304 5305 5306 5307 5308 5309 5310 |
# File 'lib/models/porcelain.rb', line 5304 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |