Class: SDM::DynamoDBIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ DynamoDBIAM

Returns a new instance of DynamoDBIAM.



6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
6932
6933
# File 'lib/models/porcelain.rb', line 6903

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6875
6876
6877
# File 'lib/models/porcelain.rb', line 6875

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6877
6878
6879
# File 'lib/models/porcelain.rb', line 6877

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. dynamodb.region.amazonaws.com



6879
6880
6881
# File 'lib/models/porcelain.rb', line 6879

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6881
6882
6883
# File 'lib/models/porcelain.rb', line 6881

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6883
6884
6885
# File 'lib/models/porcelain.rb', line 6883

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6885
6886
6887
# File 'lib/models/porcelain.rb', line 6885

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6887
6888
6889
# File 'lib/models/porcelain.rb', line 6887

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6889
6890
6891
# File 'lib/models/porcelain.rb', line 6889

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The region to authenticate requests against e.g. us-east-1



6891
6892
6893
# File 'lib/models/porcelain.rb', line 6891

def region
  @region
end

#role_arnObject

The role to assume after logging in.



6893
6894
6895
# File 'lib/models/porcelain.rb', line 6893

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



6895
6896
6897
# File 'lib/models/porcelain.rb', line 6895

def role_external_id
  @role_external_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6897
6898
6899
# File 'lib/models/porcelain.rb', line 6897

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6899
6900
6901
# File 'lib/models/porcelain.rb', line 6899

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6901
6902
6903
# File 'lib/models/porcelain.rb', line 6901

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6935
6936
6937
6938
6939
6940
6941
# File 'lib/models/porcelain.rb', line 6935

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end