Class: SDM::Elastic

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic

Returns a new instance of Elastic.



5987
5988
5989
5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
# File 'lib/models/porcelain.rb', line 5987

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5957
5958
5959
# File 'lib/models/porcelain.rb', line 5957

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5959
5960
5961
# File 'lib/models/porcelain.rb', line 5959

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5961
5962
5963
# File 'lib/models/porcelain.rb', line 5961

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5963
5964
5965
# File 'lib/models/porcelain.rb', line 5963

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5965
5966
5967
# File 'lib/models/porcelain.rb', line 5965

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5967
5968
5969
# File 'lib/models/porcelain.rb', line 5967

def name
  @name
end

#passwordObject

The password to authenticate with.



5969
5970
5971
# File 'lib/models/porcelain.rb', line 5969

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5971
5972
5973
# File 'lib/models/porcelain.rb', line 5971

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5973
5974
5975
# File 'lib/models/porcelain.rb', line 5973

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5975
5976
5977
# File 'lib/models/porcelain.rb', line 5975

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5977
5978
5979
# File 'lib/models/porcelain.rb', line 5977

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5979
5980
5981
# File 'lib/models/porcelain.rb', line 5979

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5981
5982
5983
# File 'lib/models/porcelain.rb', line 5981

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5983
5984
5985
# File 'lib/models/porcelain.rb', line 5983

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5985
5986
5987
# File 'lib/models/porcelain.rb', line 5985

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6021
6022
6023
6024
6025
6026
6027
# File 'lib/models/porcelain.rb', line 6021

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end