Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/models/porcelain.rb', line 5735 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5705 5706 5707 |
# File 'lib/models/porcelain.rb', line 5705 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5707 5708 5709 |
# File 'lib/models/porcelain.rb', line 5707 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5709 5710 5711 |
# File 'lib/models/porcelain.rb', line 5709 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5711 5712 5713 |
# File 'lib/models/porcelain.rb', line 5711 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5713 5714 5715 |
# File 'lib/models/porcelain.rb', line 5713 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5715 5716 5717 |
# File 'lib/models/porcelain.rb', line 5715 def name @name end |
#password ⇒ Object
The password to authenticate with.
5717 5718 5719 |
# File 'lib/models/porcelain.rb', line 5717 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5719 5720 5721 |
# File 'lib/models/porcelain.rb', line 5719 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5721 5722 5723 |
# File 'lib/models/porcelain.rb', line 5721 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5723 5724 5725 |
# File 'lib/models/porcelain.rb', line 5723 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5725 5726 5727 |
# File 'lib/models/porcelain.rb', line 5725 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5727 5728 5729 |
# File 'lib/models/porcelain.rb', line 5727 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5729 5730 5731 |
# File 'lib/models/porcelain.rb', line 5729 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5731 5732 5733 |
# File 'lib/models/porcelain.rb', line 5731 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5733 5734 5735 |
# File 'lib/models/porcelain.rb', line 5733 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5769 5770 5771 5772 5773 5774 5775 |
# File 'lib/models/porcelain.rb', line 5769 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |