Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
5345 5346 5347 5348 5349 5350 5351 5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/models/porcelain.rb', line 5345 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5315 5316 5317 |
# File 'lib/models/porcelain.rb', line 5315 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5317 5318 5319 |
# File 'lib/models/porcelain.rb', line 5317 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5319 5320 5321 |
# File 'lib/models/porcelain.rb', line 5319 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5321 5322 5323 |
# File 'lib/models/porcelain.rb', line 5321 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5323 5324 5325 |
# File 'lib/models/porcelain.rb', line 5323 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5325 5326 5327 |
# File 'lib/models/porcelain.rb', line 5325 def name @name end |
#password ⇒ Object
The password to authenticate with.
5327 5328 5329 |
# File 'lib/models/porcelain.rb', line 5327 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5329 5330 5331 |
# File 'lib/models/porcelain.rb', line 5329 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5331 5332 5333 |
# File 'lib/models/porcelain.rb', line 5331 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5333 5334 5335 |
# File 'lib/models/porcelain.rb', line 5333 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5335 5336 5337 |
# File 'lib/models/porcelain.rb', line 5335 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5337 5338 5339 |
# File 'lib/models/porcelain.rb', line 5337 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5339 5340 5341 |
# File 'lib/models/porcelain.rb', line 5339 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5341 5342 5343 |
# File 'lib/models/porcelain.rb', line 5341 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5343 5344 5345 |
# File 'lib/models/porcelain.rb', line 5343 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5379 5380 5381 5382 5383 5384 5385 |
# File 'lib/models/porcelain.rb', line 5379 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |