Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 |
# File 'lib/models/porcelain.rb', line 4982 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4952 4953 4954 |
# File 'lib/models/porcelain.rb', line 4952 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4954 4955 4956 |
# File 'lib/models/porcelain.rb', line 4954 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4956 4957 4958 |
# File 'lib/models/porcelain.rb', line 4956 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4958 4959 4960 |
# File 'lib/models/porcelain.rb', line 4958 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4960 4961 4962 |
# File 'lib/models/porcelain.rb', line 4960 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4962 4963 4964 |
# File 'lib/models/porcelain.rb', line 4962 def name @name end |
#password ⇒ Object
The password to authenticate with.
4964 4965 4966 |
# File 'lib/models/porcelain.rb', line 4964 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4966 4967 4968 |
# File 'lib/models/porcelain.rb', line 4966 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4968 4969 4970 |
# File 'lib/models/porcelain.rb', line 4968 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
4970 4971 4972 |
# File 'lib/models/porcelain.rb', line 4970 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4972 4973 4974 |
# File 'lib/models/porcelain.rb', line 4972 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4974 4975 4976 |
# File 'lib/models/porcelain.rb', line 4974 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4976 4977 4978 |
# File 'lib/models/porcelain.rb', line 4976 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4978 4979 4980 |
# File 'lib/models/porcelain.rb', line 4978 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4980 4981 4982 |
# File 'lib/models/porcelain.rb', line 4980 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5016 5017 5018 5019 5020 5021 5022 |
# File 'lib/models/porcelain.rb', line 5016 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |