Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
4676 4677 4678 4679 4680 4681 4682 4683 4684 4685 4686 4687 4688 4689 4690 4691 4692 4693 4694 4695 4696 4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 |
# File 'lib/models/porcelain.rb', line 4676 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4648 4649 4650 |
# File 'lib/models/porcelain.rb', line 4648 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4650 4651 4652 |
# File 'lib/models/porcelain.rb', line 4650 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4652 4653 4654 |
# File 'lib/models/porcelain.rb', line 4652 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4654 4655 4656 |
# File 'lib/models/porcelain.rb', line 4654 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4656 4657 4658 |
# File 'lib/models/porcelain.rb', line 4656 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4658 4659 4660 |
# File 'lib/models/porcelain.rb', line 4658 def name @name end |
#password ⇒ Object
The password to authenticate with.
4660 4661 4662 |
# File 'lib/models/porcelain.rb', line 4660 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4662 4663 4664 |
# File 'lib/models/porcelain.rb', line 4662 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4664 4665 4666 |
# File 'lib/models/porcelain.rb', line 4664 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4666 4667 4668 |
# File 'lib/models/porcelain.rb', line 4666 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4668 4669 4670 |
# File 'lib/models/porcelain.rb', line 4668 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4670 4671 4672 |
# File 'lib/models/porcelain.rb', line 4670 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4672 4673 4674 |
# File 'lib/models/porcelain.rb', line 4672 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4674 4675 4676 |
# File 'lib/models/porcelain.rb', line 4674 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4708 4709 4710 4711 4712 4713 4714 |
# File 'lib/models/porcelain.rb', line 4708 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |