Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 |
# File 'lib/models/porcelain.rb', line 4533 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4505 4506 4507 |
# File 'lib/models/porcelain.rb', line 4505 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4507 4508 4509 |
# File 'lib/models/porcelain.rb', line 4507 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4509 4510 4511 |
# File 'lib/models/porcelain.rb', line 4509 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4511 4512 4513 |
# File 'lib/models/porcelain.rb', line 4511 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4513 4514 4515 |
# File 'lib/models/porcelain.rb', line 4513 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4515 4516 4517 |
# File 'lib/models/porcelain.rb', line 4515 def name @name end |
#password ⇒ Object
The password to authenticate with.
4517 4518 4519 |
# File 'lib/models/porcelain.rb', line 4517 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4519 4520 4521 |
# File 'lib/models/porcelain.rb', line 4519 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4521 4522 4523 |
# File 'lib/models/porcelain.rb', line 4521 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4523 4524 4525 |
# File 'lib/models/porcelain.rb', line 4523 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4525 4526 4527 |
# File 'lib/models/porcelain.rb', line 4525 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4527 4528 4529 |
# File 'lib/models/porcelain.rb', line 4527 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4529 4530 4531 |
# File 'lib/models/porcelain.rb', line 4529 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4531 4532 4533 |
# File 'lib/models/porcelain.rb', line 4531 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4565 4566 4567 4568 4569 4570 4571 |
# File 'lib/models/porcelain.rb', line 4565 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |