Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 |
# File 'lib/models/porcelain.rb', line 3856 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3828 3829 3830 |
# File 'lib/models/porcelain.rb', line 3828 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3830 3831 3832 |
# File 'lib/models/porcelain.rb', line 3830 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3832 3833 3834 |
# File 'lib/models/porcelain.rb', line 3832 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3834 3835 3836 |
# File 'lib/models/porcelain.rb', line 3834 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3836 3837 3838 |
# File 'lib/models/porcelain.rb', line 3836 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3838 3839 3840 |
# File 'lib/models/porcelain.rb', line 3838 def name @name end |
#password ⇒ Object
The password to authenticate with.
3840 3841 3842 |
# File 'lib/models/porcelain.rb', line 3840 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3842 3843 3844 |
# File 'lib/models/porcelain.rb', line 3842 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3844 3845 3846 |
# File 'lib/models/porcelain.rb', line 3844 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3846 3847 3848 |
# File 'lib/models/porcelain.rb', line 3846 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3848 3849 3850 |
# File 'lib/models/porcelain.rb', line 3848 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3850 3851 3852 |
# File 'lib/models/porcelain.rb', line 3850 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
3852 3853 3854 |
# File 'lib/models/porcelain.rb', line 3852 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
3854 3855 3856 |
# File 'lib/models/porcelain.rb', line 3854 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3888 3889 3890 3891 3892 3893 3894 |
# File 'lib/models/porcelain.rb', line 3888 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |