Class: SDM::Elastic

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic

Returns a new instance of Elastic.



3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
# File 'lib/models/porcelain.rb', line 3705

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3677
3678
3679
# File 'lib/models/porcelain.rb', line 3677

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3679
3680
3681
# File 'lib/models/porcelain.rb', line 3679

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3681
3682
3683
# File 'lib/models/porcelain.rb', line 3681

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



3683
3684
3685
# File 'lib/models/porcelain.rb', line 3683

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3685
3686
3687
# File 'lib/models/porcelain.rb', line 3685

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3687
3688
3689
# File 'lib/models/porcelain.rb', line 3687

def name
  @name
end

#passwordObject

The password to authenticate with.



3689
3690
3691
# File 'lib/models/porcelain.rb', line 3689

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



3691
3692
3693
# File 'lib/models/porcelain.rb', line 3691

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



3693
3694
3695
# File 'lib/models/porcelain.rb', line 3693

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3695
3696
3697
# File 'lib/models/porcelain.rb', line 3695

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3697
3698
3699
# File 'lib/models/porcelain.rb', line 3697

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3699
3700
3701
# File 'lib/models/porcelain.rb', line 3699

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



3701
3702
3703
# File 'lib/models/porcelain.rb', line 3701

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



3703
3704
3705
# File 'lib/models/porcelain.rb', line 3703

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3737
3738
3739
3740
3741
3742
3743
# File 'lib/models/porcelain.rb', line 3737

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end