Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 |
# File 'lib/models/porcelain.rb', line 3541 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3513 3514 3515 |
# File 'lib/models/porcelain.rb', line 3513 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3515 3516 3517 |
# File 'lib/models/porcelain.rb', line 3515 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3517 3518 3519 |
# File 'lib/models/porcelain.rb', line 3517 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3519 3520 3521 |
# File 'lib/models/porcelain.rb', line 3519 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3521 3522 3523 |
# File 'lib/models/porcelain.rb', line 3521 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3523 3524 3525 |
# File 'lib/models/porcelain.rb', line 3523 def name @name end |
#password ⇒ Object
The password to authenticate with.
3525 3526 3527 |
# File 'lib/models/porcelain.rb', line 3525 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3527 3528 3529 |
# File 'lib/models/porcelain.rb', line 3527 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3529 3530 3531 |
# File 'lib/models/porcelain.rb', line 3529 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3531 3532 3533 |
# File 'lib/models/porcelain.rb', line 3531 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3533 3534 3535 |
# File 'lib/models/porcelain.rb', line 3533 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3535 3536 3537 |
# File 'lib/models/porcelain.rb', line 3535 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
3537 3538 3539 |
# File 'lib/models/porcelain.rb', line 3537 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
3539 3540 3541 |
# File 'lib/models/porcelain.rb', line 3539 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/models/porcelain.rb', line 3573 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |