Class: SDM::Elastic

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic

Returns a new instance of Elastic.



3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
3445
3446
3447
3448
# File 'lib/models/porcelain.rb', line 3418

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3390
3391
3392
# File 'lib/models/porcelain.rb', line 3390

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3392
3393
3394
# File 'lib/models/porcelain.rb', line 3392

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3394
3395
3396
# File 'lib/models/porcelain.rb', line 3394

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3396
3397
3398
# File 'lib/models/porcelain.rb', line 3396

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3398
3399
3400
# File 'lib/models/porcelain.rb', line 3398

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3400
3401
3402
# File 'lib/models/porcelain.rb', line 3400

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3402
3403
3404
# File 'lib/models/porcelain.rb', line 3402

def password
  @password
end

#portObject

Returns the value of attribute port.



3404
3405
3406
# File 'lib/models/porcelain.rb', line 3404

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3406
3407
3408
# File 'lib/models/porcelain.rb', line 3406

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3408
3409
3410
# File 'lib/models/porcelain.rb', line 3408

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3410
3411
3412
# File 'lib/models/porcelain.rb', line 3410

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3412
3413
3414
# File 'lib/models/porcelain.rb', line 3412

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



3414
3415
3416
# File 'lib/models/porcelain.rb', line 3414

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



3416
3417
3418
# File 'lib/models/porcelain.rb', line 3416

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3450
3451
3452
3453
3454
3455
3456
# File 'lib/models/porcelain.rb', line 3450

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end