Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 |
# File 'lib/models/porcelain.rb', line 3397 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3369 3370 3371 |
# File 'lib/models/porcelain.rb', line 3369 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3371 3372 3373 |
# File 'lib/models/porcelain.rb', line 3371 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3373 3374 3375 |
# File 'lib/models/porcelain.rb', line 3373 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3375 3376 3377 |
# File 'lib/models/porcelain.rb', line 3375 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3377 3378 3379 |
# File 'lib/models/porcelain.rb', line 3377 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3379 3380 3381 |
# File 'lib/models/porcelain.rb', line 3379 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3381 3382 3383 |
# File 'lib/models/porcelain.rb', line 3381 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3383 3384 3385 |
# File 'lib/models/porcelain.rb', line 3383 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3385 3386 3387 |
# File 'lib/models/porcelain.rb', line 3385 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3387 3388 3389 |
# File 'lib/models/porcelain.rb', line 3387 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3389 3390 3391 |
# File 'lib/models/porcelain.rb', line 3389 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3391 3392 3393 |
# File 'lib/models/porcelain.rb', line 3391 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
3393 3394 3395 |
# File 'lib/models/porcelain.rb', line 3393 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
3395 3396 3397 |
# File 'lib/models/porcelain.rb', line 3395 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3429 3430 3431 3432 3433 3434 3435 |
# File 'lib/models/porcelain.rb', line 3429 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |