Class: SDM::Elastic

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic

Returns a new instance of Elastic.



3150
3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
3174
3175
3176
3177
3178
# File 'lib/models/porcelain.rb', line 3150

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3124
3125
3126
# File 'lib/models/porcelain.rb', line 3124

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3126
3127
3128
# File 'lib/models/porcelain.rb', line 3126

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3128
3129
3130
# File 'lib/models/porcelain.rb', line 3128

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3130
3131
3132
# File 'lib/models/porcelain.rb', line 3130

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3132
3133
3134
# File 'lib/models/porcelain.rb', line 3132

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3134
3135
3136
# File 'lib/models/porcelain.rb', line 3134

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3136
3137
3138
# File 'lib/models/porcelain.rb', line 3136

def password
  @password
end

#portObject

Returns the value of attribute port.



3138
3139
3140
# File 'lib/models/porcelain.rb', line 3138

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3140
3141
3142
# File 'lib/models/porcelain.rb', line 3140

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3142
3143
3144
# File 'lib/models/porcelain.rb', line 3142

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3144
3145
3146
# File 'lib/models/porcelain.rb', line 3144

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



3146
3147
3148
# File 'lib/models/porcelain.rb', line 3146

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



3148
3149
3150
# File 'lib/models/porcelain.rb', line 3148

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3180
3181
3182
3183
3184
3185
3186
# File 'lib/models/porcelain.rb', line 3180

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end