Class: SDM::Elastic

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic

Returns a new instance of Elastic.



2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
# File 'lib/models/porcelain.rb', line 2812

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2786
2787
2788
# File 'lib/models/porcelain.rb', line 2786

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2788
2789
2790
# File 'lib/models/porcelain.rb', line 2788

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2790
2791
2792
# File 'lib/models/porcelain.rb', line 2790

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2792
2793
2794
# File 'lib/models/porcelain.rb', line 2792

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2794
2795
2796
# File 'lib/models/porcelain.rb', line 2794

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2796
2797
2798
# File 'lib/models/porcelain.rb', line 2796

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2798
2799
2800
# File 'lib/models/porcelain.rb', line 2798

def password
  @password
end

#portObject

Returns the value of attribute port.



2800
2801
2802
# File 'lib/models/porcelain.rb', line 2800

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2802
2803
2804
# File 'lib/models/porcelain.rb', line 2802

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2804
2805
2806
# File 'lib/models/porcelain.rb', line 2804

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2806
2807
2808
# File 'lib/models/porcelain.rb', line 2806

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



2808
2809
2810
# File 'lib/models/porcelain.rb', line 2808

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



2810
2811
2812
# File 'lib/models/porcelain.rb', line 2810

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2842
2843
2844
2845
2846
2847
2848
# File 'lib/models/porcelain.rb', line 2842

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end