Class: SDM::Elastic

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic

Returns a new instance of Elastic.



2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
# File 'lib/models/porcelain.rb', line 2736

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2710
2711
2712
# File 'lib/models/porcelain.rb', line 2710

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2712
2713
2714
# File 'lib/models/porcelain.rb', line 2712

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2714
2715
2716
# File 'lib/models/porcelain.rb', line 2714

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2716
2717
2718
# File 'lib/models/porcelain.rb', line 2716

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2718
2719
2720
# File 'lib/models/porcelain.rb', line 2718

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2720
2721
2722
# File 'lib/models/porcelain.rb', line 2720

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2722
2723
2724
# File 'lib/models/porcelain.rb', line 2722

def password
  @password
end

#portObject

Returns the value of attribute port.



2724
2725
2726
# File 'lib/models/porcelain.rb', line 2724

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2726
2727
2728
# File 'lib/models/porcelain.rb', line 2726

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2728
2729
2730
# File 'lib/models/porcelain.rb', line 2728

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2730
2731
2732
# File 'lib/models/porcelain.rb', line 2730

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



2732
2733
2734
# File 'lib/models/porcelain.rb', line 2732

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



2734
2735
2736
# File 'lib/models/porcelain.rb', line 2734

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2766
2767
2768
2769
2770
2771
2772
# File 'lib/models/porcelain.rb', line 2766

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end