Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 |
# File 'lib/models/porcelain.rb', line 2705 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2679 2680 2681 |
# File 'lib/models/porcelain.rb', line 2679 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2681 2682 2683 |
# File 'lib/models/porcelain.rb', line 2681 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2683 2684 2685 |
# File 'lib/models/porcelain.rb', line 2683 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2685 2686 2687 |
# File 'lib/models/porcelain.rb', line 2685 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2687 2688 2689 |
# File 'lib/models/porcelain.rb', line 2687 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2689 2690 2691 |
# File 'lib/models/porcelain.rb', line 2689 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2691 2692 2693 |
# File 'lib/models/porcelain.rb', line 2691 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2693 2694 2695 |
# File 'lib/models/porcelain.rb', line 2693 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2695 2696 2697 |
# File 'lib/models/porcelain.rb', line 2695 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2697 2698 2699 |
# File 'lib/models/porcelain.rb', line 2697 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2699 2700 2701 |
# File 'lib/models/porcelain.rb', line 2699 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
2701 2702 2703 |
# File 'lib/models/porcelain.rb', line 2701 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
2703 2704 2705 |
# File 'lib/models/porcelain.rb', line 2703 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/models/porcelain.rb', line 2735 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |