Class: SDM::Elastic
- Inherits:
-
Object
- Object
- SDM::Elastic
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
constructor
A new instance of Elastic.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Elastic
Returns a new instance of Elastic.
2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 |
# File 'lib/models/porcelain.rb', line 2963 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2939 2940 2941 |
# File 'lib/models/porcelain.rb', line 2939 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2941 2942 2943 |
# File 'lib/models/porcelain.rb', line 2941 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2943 2944 2945 |
# File 'lib/models/porcelain.rb', line 2943 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2945 2946 2947 |
# File 'lib/models/porcelain.rb', line 2945 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2947 2948 2949 |
# File 'lib/models/porcelain.rb', line 2947 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2949 2950 2951 |
# File 'lib/models/porcelain.rb', line 2949 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2951 2952 2953 |
# File 'lib/models/porcelain.rb', line 2951 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2953 2954 2955 |
# File 'lib/models/porcelain.rb', line 2953 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2955 2956 2957 |
# File 'lib/models/porcelain.rb', line 2955 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2957 2958 2959 |
# File 'lib/models/porcelain.rb', line 2957 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
2959 2960 2961 |
# File 'lib/models/porcelain.rb', line 2959 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
2961 2962 2963 |
# File 'lib/models/porcelain.rb', line 2961 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3015 3016 3017 3018 3019 3020 3021 |
# File 'lib/models/porcelain.rb', line 3015 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |