Class: SDM::ElasticacheRedis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis

Returns a new instance of ElasticacheRedis.



6688
6689
6690
6691
6692
6693
6694
6695
6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
6720
# File 'lib/models/porcelain.rb', line 6688

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6658
6659
6660
# File 'lib/models/porcelain.rb', line 6658

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6660
6661
6662
# File 'lib/models/porcelain.rb', line 6660

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6662
6663
6664
# File 'lib/models/porcelain.rb', line 6662

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6664
6665
6666
# File 'lib/models/porcelain.rb', line 6664

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6666
6667
6668
# File 'lib/models/porcelain.rb', line 6666

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6668
6669
6670
# File 'lib/models/porcelain.rb', line 6668

def name
  @name
end

#passwordObject

The password to authenticate with.



6670
6671
6672
# File 'lib/models/porcelain.rb', line 6670

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6672
6673
6674
# File 'lib/models/porcelain.rb', line 6672

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6674
6675
6676
# File 'lib/models/porcelain.rb', line 6674

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6676
6677
6678
# File 'lib/models/porcelain.rb', line 6676

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6678
6679
6680
# File 'lib/models/porcelain.rb', line 6678

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6680
6681
6682
# File 'lib/models/porcelain.rb', line 6680

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6682
6683
6684
# File 'lib/models/porcelain.rb', line 6682

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



6684
6685
6686
# File 'lib/models/porcelain.rb', line 6684

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



6686
6687
6688
# File 'lib/models/porcelain.rb', line 6686

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6722
6723
6724
6725
6726
6727
6728
# File 'lib/models/porcelain.rb', line 6722

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end