Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 |
# File 'lib/models/porcelain.rb', line 5972 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5942 5943 5944 |
# File 'lib/models/porcelain.rb', line 5942 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5944 5945 5946 |
# File 'lib/models/porcelain.rb', line 5944 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5946 5947 5948 |
# File 'lib/models/porcelain.rb', line 5946 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5948 5949 5950 |
# File 'lib/models/porcelain.rb', line 5948 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5950 5951 5952 |
# File 'lib/models/porcelain.rb', line 5950 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5952 5953 5954 |
# File 'lib/models/porcelain.rb', line 5952 def name @name end |
#password ⇒ Object
The password to authenticate with.
5954 5955 5956 |
# File 'lib/models/porcelain.rb', line 5954 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5956 5957 5958 |
# File 'lib/models/porcelain.rb', line 5956 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5958 5959 5960 |
# File 'lib/models/porcelain.rb', line 5958 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5960 5961 5962 |
# File 'lib/models/porcelain.rb', line 5960 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5962 5963 5964 |
# File 'lib/models/porcelain.rb', line 5962 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5964 5965 5966 |
# File 'lib/models/porcelain.rb', line 5964 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5966 5967 5968 |
# File 'lib/models/porcelain.rb', line 5966 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5968 5969 5970 |
# File 'lib/models/porcelain.rb', line 5968 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5970 5971 5972 |
# File 'lib/models/porcelain.rb', line 5970 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6006 6007 6008 6009 6010 6011 6012 |
# File 'lib/models/porcelain.rb', line 6006 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |