Class: SDM::ElasticacheRedis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis

Returns a new instance of ElasticacheRedis.



5821
5822
5823
5824
5825
5826
5827
5828
5829
5830
5831
5832
5833
5834
5835
5836
5837
5838
5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
# File 'lib/models/porcelain.rb', line 5821

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5791
5792
5793
# File 'lib/models/porcelain.rb', line 5791

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5793
5794
5795
# File 'lib/models/porcelain.rb', line 5793

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5795
5796
5797
# File 'lib/models/porcelain.rb', line 5795

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5797
5798
5799
# File 'lib/models/porcelain.rb', line 5797

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5799
5800
5801
# File 'lib/models/porcelain.rb', line 5799

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5801
5802
5803
# File 'lib/models/porcelain.rb', line 5801

def name
  @name
end

#passwordObject

The password to authenticate with.



5803
5804
5805
# File 'lib/models/porcelain.rb', line 5803

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5805
5806
5807
# File 'lib/models/porcelain.rb', line 5805

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5807
5808
5809
# File 'lib/models/porcelain.rb', line 5807

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5809
5810
5811
# File 'lib/models/porcelain.rb', line 5809

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5811
5812
5813
# File 'lib/models/porcelain.rb', line 5811

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5813
5814
5815
# File 'lib/models/porcelain.rb', line 5813

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5815
5816
5817
# File 'lib/models/porcelain.rb', line 5815

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5817
5818
5819
# File 'lib/models/porcelain.rb', line 5817

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5819
5820
5821
# File 'lib/models/porcelain.rb', line 5819

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5855
5856
5857
5858
5859
5860
5861
# File 'lib/models/porcelain.rb', line 5855

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end