Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
5810 5811 5812 5813 5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 5842 |
# File 'lib/models/porcelain.rb', line 5810 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5780 5781 5782 |
# File 'lib/models/porcelain.rb', line 5780 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5782 5783 5784 |
# File 'lib/models/porcelain.rb', line 5782 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5784 5785 5786 |
# File 'lib/models/porcelain.rb', line 5784 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5786 5787 5788 |
# File 'lib/models/porcelain.rb', line 5786 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5788 5789 5790 |
# File 'lib/models/porcelain.rb', line 5788 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5790 5791 5792 |
# File 'lib/models/porcelain.rb', line 5790 def name @name end |
#password ⇒ Object
The password to authenticate with.
5792 5793 5794 |
# File 'lib/models/porcelain.rb', line 5792 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5794 5795 5796 |
# File 'lib/models/porcelain.rb', line 5794 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5796 5797 5798 |
# File 'lib/models/porcelain.rb', line 5796 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5798 5799 5800 |
# File 'lib/models/porcelain.rb', line 5798 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5800 5801 5802 |
# File 'lib/models/porcelain.rb', line 5800 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5802 5803 5804 |
# File 'lib/models/porcelain.rb', line 5802 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5804 5805 5806 |
# File 'lib/models/porcelain.rb', line 5804 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5806 5807 5808 |
# File 'lib/models/porcelain.rb', line 5806 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5808 5809 5810 |
# File 'lib/models/porcelain.rb', line 5808 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5844 5845 5846 5847 5848 5849 5850 |
# File 'lib/models/porcelain.rb', line 5844 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |