Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 |
# File 'lib/models/porcelain.rb', line 5491 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5461 5462 5463 |
# File 'lib/models/porcelain.rb', line 5461 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5463 5464 5465 |
# File 'lib/models/porcelain.rb', line 5463 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5465 5466 5467 |
# File 'lib/models/porcelain.rb', line 5465 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5467 5468 5469 |
# File 'lib/models/porcelain.rb', line 5467 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5469 5470 5471 |
# File 'lib/models/porcelain.rb', line 5469 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5471 5472 5473 |
# File 'lib/models/porcelain.rb', line 5471 def name @name end |
#password ⇒ Object
The password to authenticate with.
5473 5474 5475 |
# File 'lib/models/porcelain.rb', line 5473 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5475 5476 5477 |
# File 'lib/models/porcelain.rb', line 5475 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5477 5478 5479 |
# File 'lib/models/porcelain.rb', line 5477 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5479 5480 5481 |
# File 'lib/models/porcelain.rb', line 5479 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5481 5482 5483 |
# File 'lib/models/porcelain.rb', line 5481 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5483 5484 5485 |
# File 'lib/models/porcelain.rb', line 5483 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5485 5486 5487 |
# File 'lib/models/porcelain.rb', line 5485 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5487 5488 5489 |
# File 'lib/models/porcelain.rb', line 5487 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5489 5490 5491 |
# File 'lib/models/porcelain.rb', line 5489 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5525 5526 5527 5528 5529 5530 5531 |
# File 'lib/models/porcelain.rb', line 5525 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |