Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 |
# File 'lib/models/porcelain.rb', line 5057 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5027 5028 5029 |
# File 'lib/models/porcelain.rb', line 5027 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5029 5030 5031 |
# File 'lib/models/porcelain.rb', line 5029 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5031 5032 5033 |
# File 'lib/models/porcelain.rb', line 5031 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5033 5034 5035 |
# File 'lib/models/porcelain.rb', line 5033 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5035 5036 5037 |
# File 'lib/models/porcelain.rb', line 5035 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5037 5038 5039 |
# File 'lib/models/porcelain.rb', line 5037 def name @name end |
#password ⇒ Object
The password to authenticate with.
5039 5040 5041 |
# File 'lib/models/porcelain.rb', line 5039 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5041 5042 5043 |
# File 'lib/models/porcelain.rb', line 5041 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5043 5044 5045 |
# File 'lib/models/porcelain.rb', line 5043 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5045 5046 5047 |
# File 'lib/models/porcelain.rb', line 5045 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5047 5048 5049 |
# File 'lib/models/porcelain.rb', line 5047 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5049 5050 5051 |
# File 'lib/models/porcelain.rb', line 5049 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5051 5052 5053 |
# File 'lib/models/porcelain.rb', line 5051 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5053 5054 5055 |
# File 'lib/models/porcelain.rb', line 5053 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5055 5056 5057 |
# File 'lib/models/porcelain.rb', line 5055 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5091 5092 5093 5094 5095 5096 5097 |
# File 'lib/models/porcelain.rb', line 5091 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |