Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
4747 4748 4749 4750 4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 |
# File 'lib/models/porcelain.rb', line 4747 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4719 4720 4721 |
# File 'lib/models/porcelain.rb', line 4719 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4721 4722 4723 |
# File 'lib/models/porcelain.rb', line 4721 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4723 4724 4725 |
# File 'lib/models/porcelain.rb', line 4723 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4725 4726 4727 |
# File 'lib/models/porcelain.rb', line 4725 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4727 4728 4729 |
# File 'lib/models/porcelain.rb', line 4727 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4729 4730 4731 |
# File 'lib/models/porcelain.rb', line 4729 def name @name end |
#password ⇒ Object
The password to authenticate with.
4731 4732 4733 |
# File 'lib/models/porcelain.rb', line 4731 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4733 4734 4735 |
# File 'lib/models/porcelain.rb', line 4733 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4735 4736 4737 |
# File 'lib/models/porcelain.rb', line 4735 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4737 4738 4739 |
# File 'lib/models/porcelain.rb', line 4737 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4739 4740 4741 |
# File 'lib/models/porcelain.rb', line 4739 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4741 4742 4743 |
# File 'lib/models/porcelain.rb', line 4741 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4743 4744 4745 |
# File 'lib/models/porcelain.rb', line 4743 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4745 4746 4747 |
# File 'lib/models/porcelain.rb', line 4745 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4779 4780 4781 4782 4783 4784 4785 |
# File 'lib/models/porcelain.rb', line 4779 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |