Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
4604 4605 4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 |
# File 'lib/models/porcelain.rb', line 4604 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4576 4577 4578 |
# File 'lib/models/porcelain.rb', line 4576 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4578 4579 4580 |
# File 'lib/models/porcelain.rb', line 4578 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4580 4581 4582 |
# File 'lib/models/porcelain.rb', line 4580 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4582 4583 4584 |
# File 'lib/models/porcelain.rb', line 4582 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4584 4585 4586 |
# File 'lib/models/porcelain.rb', line 4584 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4586 4587 4588 |
# File 'lib/models/porcelain.rb', line 4586 def name @name end |
#password ⇒ Object
The password to authenticate with.
4588 4589 4590 |
# File 'lib/models/porcelain.rb', line 4588 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4590 4591 4592 |
# File 'lib/models/porcelain.rb', line 4590 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4592 4593 4594 |
# File 'lib/models/porcelain.rb', line 4592 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4594 4595 4596 |
# File 'lib/models/porcelain.rb', line 4594 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4596 4597 4598 |
# File 'lib/models/porcelain.rb', line 4596 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4598 4599 4600 |
# File 'lib/models/porcelain.rb', line 4598 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
4600 4601 4602 |
# File 'lib/models/porcelain.rb', line 4600 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
4602 4603 4604 |
# File 'lib/models/porcelain.rb', line 4602 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4636 4637 4638 4639 4640 4641 4642 |
# File 'lib/models/porcelain.rb', line 4636 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |