Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 |
# File 'lib/models/porcelain.rb', line 3776 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3748 3749 3750 |
# File 'lib/models/porcelain.rb', line 3748 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3750 3751 3752 |
# File 'lib/models/porcelain.rb', line 3750 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3752 3753 3754 |
# File 'lib/models/porcelain.rb', line 3752 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3754 3755 3756 |
# File 'lib/models/porcelain.rb', line 3754 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3756 3757 3758 |
# File 'lib/models/porcelain.rb', line 3756 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3758 3759 3760 |
# File 'lib/models/porcelain.rb', line 3758 def name @name end |
#password ⇒ Object
The password to authenticate with.
3760 3761 3762 |
# File 'lib/models/porcelain.rb', line 3760 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3762 3763 3764 |
# File 'lib/models/porcelain.rb', line 3762 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3764 3765 3766 |
# File 'lib/models/porcelain.rb', line 3764 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3766 3767 3768 |
# File 'lib/models/porcelain.rb', line 3766 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3768 3769 3770 |
# File 'lib/models/porcelain.rb', line 3768 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3770 3771 3772 |
# File 'lib/models/porcelain.rb', line 3770 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
3772 3773 3774 |
# File 'lib/models/porcelain.rb', line 3772 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
3774 3775 3776 |
# File 'lib/models/porcelain.rb', line 3774 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3808 3809 3810 3811 3812 3813 3814 |
# File 'lib/models/porcelain.rb', line 3808 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |