Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 |
# File 'lib/models/porcelain.rb', line 3612 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3584 3585 3586 |
# File 'lib/models/porcelain.rb', line 3584 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3586 3587 3588 |
# File 'lib/models/porcelain.rb', line 3586 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3588 3589 3590 |
# File 'lib/models/porcelain.rb', line 3588 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3590 3591 3592 |
# File 'lib/models/porcelain.rb', line 3590 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3592 3593 3594 |
# File 'lib/models/porcelain.rb', line 3592 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3594 3595 3596 |
# File 'lib/models/porcelain.rb', line 3594 def name @name end |
#password ⇒ Object
The password to authenticate with.
3596 3597 3598 |
# File 'lib/models/porcelain.rb', line 3596 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3598 3599 3600 |
# File 'lib/models/porcelain.rb', line 3598 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3600 3601 3602 |
# File 'lib/models/porcelain.rb', line 3600 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3602 3603 3604 |
# File 'lib/models/porcelain.rb', line 3602 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3604 3605 3606 |
# File 'lib/models/porcelain.rb', line 3604 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3606 3607 3608 |
# File 'lib/models/porcelain.rb', line 3606 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
3608 3609 3610 |
# File 'lib/models/porcelain.rb', line 3608 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
3610 3611 3612 |
# File 'lib/models/porcelain.rb', line 3610 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/models/porcelain.rb', line 3644 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |