Class: SDM::ElasticacheRedis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis

Returns a new instance of ElasticacheRedis.



3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
3542
3543
# File 'lib/models/porcelain.rb', line 3513

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3485
3486
3487
# File 'lib/models/porcelain.rb', line 3485

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3487
3488
3489
# File 'lib/models/porcelain.rb', line 3487

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3489
3490
3491
# File 'lib/models/porcelain.rb', line 3489

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3491
3492
3493
# File 'lib/models/porcelain.rb', line 3491

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3493
3494
3495
# File 'lib/models/porcelain.rb', line 3493

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3495
3496
3497
# File 'lib/models/porcelain.rb', line 3495

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3497
3498
3499
# File 'lib/models/porcelain.rb', line 3497

def password
  @password
end

#portObject

Returns the value of attribute port.



3499
3500
3501
# File 'lib/models/porcelain.rb', line 3499

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3501
3502
3503
# File 'lib/models/porcelain.rb', line 3501

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3503
3504
3505
# File 'lib/models/porcelain.rb', line 3503

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3505
3506
3507
# File 'lib/models/porcelain.rb', line 3505

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3507
3508
3509
# File 'lib/models/porcelain.rb', line 3507

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



3509
3510
3511
# File 'lib/models/porcelain.rb', line 3509

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



3511
3512
3513
# File 'lib/models/porcelain.rb', line 3511

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3545
3546
3547
3548
3549
3550
3551
# File 'lib/models/porcelain.rb', line 3545

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end