Class: SDM::ElasticacheRedis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis

Returns a new instance of ElasticacheRedis.



3489
3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
# File 'lib/models/porcelain.rb', line 3489

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3461
3462
3463
# File 'lib/models/porcelain.rb', line 3461

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3463
3464
3465
# File 'lib/models/porcelain.rb', line 3463

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3465
3466
3467
# File 'lib/models/porcelain.rb', line 3465

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3467
3468
3469
# File 'lib/models/porcelain.rb', line 3467

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3469
3470
3471
# File 'lib/models/porcelain.rb', line 3469

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3471
3472
3473
# File 'lib/models/porcelain.rb', line 3471

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3473
3474
3475
# File 'lib/models/porcelain.rb', line 3473

def password
  @password
end

#portObject

Returns the value of attribute port.



3475
3476
3477
# File 'lib/models/porcelain.rb', line 3475

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3477
3478
3479
# File 'lib/models/porcelain.rb', line 3477

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3479
3480
3481
# File 'lib/models/porcelain.rb', line 3479

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3481
3482
3483
# File 'lib/models/porcelain.rb', line 3481

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3483
3484
3485
# File 'lib/models/porcelain.rb', line 3483

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



3485
3486
3487
# File 'lib/models/porcelain.rb', line 3485

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



3487
3488
3489
# File 'lib/models/porcelain.rb', line 3487

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3521
3522
3523
3524
3525
3526
3527
# File 'lib/models/porcelain.rb', line 3521

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end