Class: SDM::ElasticacheRedis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis

Returns a new instance of ElasticacheRedis.



3217
3218
3219
3220
3221
3222
3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
# File 'lib/models/porcelain.rb', line 3217

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3191
3192
3193
# File 'lib/models/porcelain.rb', line 3191

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3193
3194
3195
# File 'lib/models/porcelain.rb', line 3193

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3195
3196
3197
# File 'lib/models/porcelain.rb', line 3195

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3197
3198
3199
# File 'lib/models/porcelain.rb', line 3197

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3199
3200
3201
# File 'lib/models/porcelain.rb', line 3199

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3201
3202
3203
# File 'lib/models/porcelain.rb', line 3201

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3203
3204
3205
# File 'lib/models/porcelain.rb', line 3203

def password
  @password
end

#portObject

Returns the value of attribute port.



3205
3206
3207
# File 'lib/models/porcelain.rb', line 3205

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3207
3208
3209
# File 'lib/models/porcelain.rb', line 3207

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3209
3210
3211
# File 'lib/models/porcelain.rb', line 3209

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3211
3212
3213
# File 'lib/models/porcelain.rb', line 3211

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



3213
3214
3215
# File 'lib/models/porcelain.rb', line 3213

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



3215
3216
3217
# File 'lib/models/porcelain.rb', line 3215

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3247
3248
3249
3250
3251
3252
3253
# File 'lib/models/porcelain.rb', line 3247

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end