Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/models/porcelain.rb', line 2879 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
2853 2854 2855 |
# File 'lib/models/porcelain.rb', line 2853 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
2855 2856 2857 |
# File 'lib/models/porcelain.rb', line 2855 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
2857 2858 2859 |
# File 'lib/models/porcelain.rb', line 2857 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
2859 2860 2861 |
# File 'lib/models/porcelain.rb', line 2859 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
2861 2862 2863 |
# File 'lib/models/porcelain.rb', line 2861 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
2863 2864 2865 |
# File 'lib/models/porcelain.rb', line 2863 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
2865 2866 2867 |
# File 'lib/models/porcelain.rb', line 2865 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
2867 2868 2869 |
# File 'lib/models/porcelain.rb', line 2867 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
2869 2870 2871 |
# File 'lib/models/porcelain.rb', line 2869 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
2871 2872 2873 |
# File 'lib/models/porcelain.rb', line 2871 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
2873 2874 2875 |
# File 'lib/models/porcelain.rb', line 2873 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
2875 2876 2877 |
# File 'lib/models/porcelain.rb', line 2875 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
2877 2878 2879 |
# File 'lib/models/porcelain.rb', line 2877 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
2909 2910 2911 2912 2913 2914 2915 |
# File 'lib/models/porcelain.rb', line 2909 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |