Class: SDM::ElasticacheRedis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis

Returns a new instance of ElasticacheRedis.



2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
# File 'lib/models/porcelain.rb', line 2880

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2854
2855
2856
# File 'lib/models/porcelain.rb', line 2854

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2856
2857
2858
# File 'lib/models/porcelain.rb', line 2856

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2858
2859
2860
# File 'lib/models/porcelain.rb', line 2858

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2860
2861
2862
# File 'lib/models/porcelain.rb', line 2860

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2862
2863
2864
# File 'lib/models/porcelain.rb', line 2862

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2864
2865
2866
# File 'lib/models/porcelain.rb', line 2864

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2866
2867
2868
# File 'lib/models/porcelain.rb', line 2866

def password
  @password
end

#portObject

Returns the value of attribute port.



2868
2869
2870
# File 'lib/models/porcelain.rb', line 2868

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2870
2871
2872
# File 'lib/models/porcelain.rb', line 2870

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2872
2873
2874
# File 'lib/models/porcelain.rb', line 2872

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2874
2875
2876
# File 'lib/models/porcelain.rb', line 2874

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



2876
2877
2878
# File 'lib/models/porcelain.rb', line 2876

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



2878
2879
2880
# File 'lib/models/porcelain.rb', line 2878

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2910
2911
2912
2913
2914
2915
2916
# File 'lib/models/porcelain.rb', line 2910

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end