Class: SDM::ElasticacheRedis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedis

Returns a new instance of ElasticacheRedis.



2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
# File 'lib/models/porcelain.rb', line 2772

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2746
2747
2748
# File 'lib/models/porcelain.rb', line 2746

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2748
2749
2750
# File 'lib/models/porcelain.rb', line 2748

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2750
2751
2752
# File 'lib/models/porcelain.rb', line 2750

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



2752
2753
2754
# File 'lib/models/porcelain.rb', line 2752

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



2754
2755
2756
# File 'lib/models/porcelain.rb', line 2754

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2756
2757
2758
# File 'lib/models/porcelain.rb', line 2756

def name
  @name
end

#passwordObject

Returns the value of attribute password.



2758
2759
2760
# File 'lib/models/porcelain.rb', line 2758

def password
  @password
end

#portObject

Returns the value of attribute port.



2760
2761
2762
# File 'lib/models/porcelain.rb', line 2760

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



2762
2763
2764
# File 'lib/models/porcelain.rb', line 2762

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2764
2765
2766
# File 'lib/models/porcelain.rb', line 2764

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2766
2767
2768
# File 'lib/models/porcelain.rb', line 2766

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



2768
2769
2770
# File 'lib/models/porcelain.rb', line 2768

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



2770
2771
2772
# File 'lib/models/porcelain.rb', line 2770

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2802
2803
2804
2805
2806
2807
2808
# File 'lib/models/porcelain.rb', line 2802

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end