Class: SDM::ElasticacheRedis
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil) ⇒ ElasticacheRedis
constructor
A new instance of ElasticacheRedis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil) ⇒ ElasticacheRedis
Returns a new instance of ElasticacheRedis.
3048 3049 3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 |
# File 'lib/models/porcelain.rb', line 3048 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3026 3027 3028 |
# File 'lib/models/porcelain.rb', line 3026 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3028 3029 3030 |
# File 'lib/models/porcelain.rb', line 3028 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3030 3031 3032 |
# File 'lib/models/porcelain.rb', line 3030 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3032 3033 3034 |
# File 'lib/models/porcelain.rb', line 3032 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3034 3035 3036 |
# File 'lib/models/porcelain.rb', line 3034 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3036 3037 3038 |
# File 'lib/models/porcelain.rb', line 3036 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3038 3039 3040 |
# File 'lib/models/porcelain.rb', line 3038 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3040 3041 3042 |
# File 'lib/models/porcelain.rb', line 3040 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3042 3043 3044 |
# File 'lib/models/porcelain.rb', line 3042 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3044 3045 3046 |
# File 'lib/models/porcelain.rb', line 3044 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
3046 3047 3048 |
# File 'lib/models/porcelain.rb', line 3046 def tls_required @tls_required end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3096 3097 3098 3099 3100 3101 3102 |
# File 'lib/models/porcelain.rb', line 3096 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |