Class: SDM::ElasticacheRedisIAM
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedisIAM
- Defined in:
- lib/models/porcelain.rb
Overview
ElasticacheRedisIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
AWS region is needed in addition to hostname to generate the IAM signature.
-
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedisIAM
constructor
A new instance of ElasticacheRedisIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedisIAM
Returns a new instance of ElasticacheRedisIAM.
7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/models/porcelain.rb', line 7208 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7174 7175 7176 |
# File 'lib/models/porcelain.rb', line 7174 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7176 7177 7178 |
# File 'lib/models/porcelain.rb', line 7176 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7178 7179 7180 |
# File 'lib/models/porcelain.rb', line 7178 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7180 7181 7182 |
# File 'lib/models/porcelain.rb', line 7180 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7182 7183 7184 |
# File 'lib/models/porcelain.rb', line 7182 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7184 7185 7186 |
# File 'lib/models/porcelain.rb', line 7184 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7186 7187 7188 |
# File 'lib/models/porcelain.rb', line 7186 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
7188 7189 7190 |
# File 'lib/models/porcelain.rb', line 7188 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7190 7191 7192 |
# File 'lib/models/porcelain.rb', line 7190 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
AWS region is needed in addition to hostname to generate the IAM signature
7192 7193 7194 |
# File 'lib/models/porcelain.rb', line 7192 def region @region end |
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
7194 7195 7196 |
# File 'lib/models/porcelain.rb', line 7194 def role_assumption_arn @role_assumption_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
7196 7197 7198 |
# File 'lib/models/porcelain.rb', line 7196 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7198 7199 7200 |
# File 'lib/models/porcelain.rb', line 7198 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
7200 7201 7202 |
# File 'lib/models/porcelain.rb', line 7200 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7202 7203 7204 |
# File 'lib/models/porcelain.rb', line 7202 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7204 7205 7206 |
# File 'lib/models/porcelain.rb', line 7204 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7206 7207 7208 |
# File 'lib/models/porcelain.rb', line 7206 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7246 7247 7248 7249 7250 7251 7252 |
# File 'lib/models/porcelain.rb', line 7246 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |