Class: SDM::ElasticacheRedisIAM
- Inherits:
-
Object
- Object
- SDM::ElasticacheRedisIAM
- Defined in:
- lib/models/porcelain.rb
Overview
ElasticacheRedisIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
AWS region is needed in addition to hostname to generate the IAM signature.
-
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedisIAM
constructor
A new instance of ElasticacheRedisIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ ElasticacheRedisIAM
Returns a new instance of ElasticacheRedisIAM.
7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/models/porcelain.rb', line 7132 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, role_external_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7098 7099 7100 |
# File 'lib/models/porcelain.rb', line 7098 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7100 7101 7102 |
# File 'lib/models/porcelain.rb', line 7100 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7102 7103 7104 |
# File 'lib/models/porcelain.rb', line 7102 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7104 7105 7106 |
# File 'lib/models/porcelain.rb', line 7104 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7106 7107 7108 |
# File 'lib/models/porcelain.rb', line 7106 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7108 7109 7110 |
# File 'lib/models/porcelain.rb', line 7108 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7110 7111 7112 |
# File 'lib/models/porcelain.rb', line 7110 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
7112 7113 7114 |
# File 'lib/models/porcelain.rb', line 7112 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7114 7115 7116 |
# File 'lib/models/porcelain.rb', line 7114 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
AWS region is needed in addition to hostname to generate the IAM signature
7116 7117 7118 |
# File 'lib/models/porcelain.rb', line 7116 def region @region end |
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
7118 7119 7120 |
# File 'lib/models/porcelain.rb', line 7118 def role_assumption_arn @role_assumption_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
7120 7121 7122 |
# File 'lib/models/porcelain.rb', line 7120 def role_external_id @role_external_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7122 7123 7124 |
# File 'lib/models/porcelain.rb', line 7122 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
7124 7125 7126 |
# File 'lib/models/porcelain.rb', line 7124 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7126 7127 7128 |
# File 'lib/models/porcelain.rb', line 7126 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7128 7129 7130 |
# File 'lib/models/porcelain.rb', line 7128 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7130 7131 7132 |
# File 'lib/models/porcelain.rb', line 7130 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7170 7171 7172 7173 7174 7175 7176 |
# File 'lib/models/porcelain.rb', line 7170 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |