Class: SDM::EntraID
- Inherits:
-
Object
- Object
- SDM::EntraID
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#discovery_enabled ⇒ Object
If true, configures discovery of the tenant to be run from a node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#group_names ⇒ Object
comma separated list of group names to filter by.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#management_group_id ⇒ Object
The management group ID to authenticate scope Privileges to.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#privilege_levels ⇒ Object
The privilege levels specify which Groups are managed externally.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#resource_group_id ⇒ Object
filters discovered groups to the specified Resource Group.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#subscription_id ⇒ Object
The subscription ID to authenticate scope Privileges to.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
The connector ID to authenticate through.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil) ⇒ EntraID
constructor
A new instance of EntraID.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil) ⇒ EntraID
Returns a new instance of EntraID.
7291 7292 7293 7294 7295 7296 7297 7298 7299 7300 7301 7302 7303 7304 7305 7306 7307 7308 7309 7310 7311 7312 7313 7314 7315 7316 7317 7318 7319 7320 7321 7322 7323 7324 7325 7326 7327 |
# File 'lib/models/porcelain.rb', line 7291 def initialize( bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled @egress_filter = egress_filter == nil ? "" : egress_filter @group_names = group_names == nil ? "" : group_names @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_set_id = identity_set_id == nil ? "" : identity_set_id @management_group_id = management_group_id == nil ? "" : management_group_id @name = name == nil ? "" : name @privilege_levels = privilege_levels == nil ? "" : privilege_levels @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @resource_group_id = resource_group_id == nil ? "" : resource_group_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @subscription_id = subscription_id == nil ? "" : subscription_id @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7257 7258 7259 |
# File 'lib/models/porcelain.rb', line 7257 def bind_interface @bind_interface end |
#discovery_enabled ⇒ Object
If true, configures discovery of the tenant to be run from a node.
7259 7260 7261 |
# File 'lib/models/porcelain.rb', line 7259 def discovery_enabled @discovery_enabled end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7261 7262 7263 |
# File 'lib/models/porcelain.rb', line 7261 def egress_filter @egress_filter end |
#group_names ⇒ Object
comma separated list of group names to filter by. Supports wildcards (*)
7263 7264 7265 |
# File 'lib/models/porcelain.rb', line 7263 def group_names @group_names end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7265 7266 7267 |
# File 'lib/models/porcelain.rb', line 7265 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7267 7268 7269 |
# File 'lib/models/porcelain.rb', line 7267 def id @id end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
7269 7270 7271 |
# File 'lib/models/porcelain.rb', line 7269 def identity_set_id @identity_set_id end |
#management_group_id ⇒ Object
The management group ID to authenticate scope Privileges to.
7271 7272 7273 |
# File 'lib/models/porcelain.rb', line 7271 def management_group_id @management_group_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7273 7274 7275 |
# File 'lib/models/porcelain.rb', line 7273 def name @name end |
#privilege_levels ⇒ Object
The privilege levels specify which Groups are managed externally
7275 7276 7277 |
# File 'lib/models/porcelain.rb', line 7275 def privilege_levels @privilege_levels end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7277 7278 7279 |
# File 'lib/models/porcelain.rb', line 7277 def proxy_cluster_id @proxy_cluster_id end |
#resource_group_id ⇒ Object
filters discovered groups to the specified Resource Group
7279 7280 7281 |
# File 'lib/models/porcelain.rb', line 7279 def resource_group_id @resource_group_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7281 7282 7283 |
# File 'lib/models/porcelain.rb', line 7281 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
7283 7284 7285 |
# File 'lib/models/porcelain.rb', line 7283 def subdomain @subdomain end |
#subscription_id ⇒ Object
The subscription ID to authenticate scope Privileges to.
7285 7286 7287 |
# File 'lib/models/porcelain.rb', line 7285 def subscription_id @subscription_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7287 7288 7289 |
# File 'lib/models/porcelain.rb', line 7287 def @tags end |
#tenant_id ⇒ Object
The connector ID to authenticate through.
7289 7290 7291 |
# File 'lib/models/porcelain.rb', line 7289 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7329 7330 7331 7332 7333 7334 7335 |
# File 'lib/models/porcelain.rb', line 7329 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |