Class: SDM::EntraID

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil) ⇒ EntraID

Returns a new instance of EntraID.



7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
7158
7159
7160
7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
# File 'lib/models/porcelain.rb', line 7141

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  management_group_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  resource_group_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  subscription_id: nil,
  tags: nil,
  tenant_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @management_group_id = management_group_id == nil ? "" : management_group_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @resource_group_id = resource_group_id == nil ? "" : resource_group_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @subscription_id = subscription_id == nil ? "" : subscription_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7107
7108
7109
# File 'lib/models/porcelain.rb', line 7107

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the tenant to be run from a node.



7109
7110
7111
# File 'lib/models/porcelain.rb', line 7109

def discovery_enabled
  @discovery_enabled
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7111
7112
7113
# File 'lib/models/porcelain.rb', line 7111

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



7113
7114
7115
# File 'lib/models/porcelain.rb', line 7113

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7115
7116
7117
# File 'lib/models/porcelain.rb', line 7115

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7117
7118
7119
# File 'lib/models/porcelain.rb', line 7117

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



7119
7120
7121
# File 'lib/models/porcelain.rb', line 7119

def identity_set_id
  @identity_set_id
end

#management_group_idObject

The management group ID to authenticate scope Privileges to.



7121
7122
7123
# File 'lib/models/porcelain.rb', line 7121

def management_group_id
  @management_group_id
end

#nameObject

Unique human-readable name of the Resource.



7123
7124
7125
# File 'lib/models/porcelain.rb', line 7123

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



7125
7126
7127
# File 'lib/models/porcelain.rb', line 7125

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7127
7128
7129
# File 'lib/models/porcelain.rb', line 7127

def proxy_cluster_id
  @proxy_cluster_id
end

#resource_group_idObject

filters discovered groups to the specified Resource Group



7129
7130
7131
# File 'lib/models/porcelain.rb', line 7129

def resource_group_id
  @resource_group_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7131
7132
7133
# File 'lib/models/porcelain.rb', line 7131

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7133
7134
7135
# File 'lib/models/porcelain.rb', line 7133

def subdomain
  @subdomain
end

#subscription_idObject

The subscription ID to authenticate scope Privileges to.



7135
7136
7137
# File 'lib/models/porcelain.rb', line 7135

def subscription_id
  @subscription_id
end

#tagsObject

Tags is a map of key, value pairs.



7137
7138
7139
# File 'lib/models/porcelain.rb', line 7137

def tags
  @tags
end

#tenant_idObject

The connector ID to authenticate through.



7139
7140
7141
# File 'lib/models/porcelain.rb', line 7139

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7179
7180
7181
7182
7183
7184
7185
# File 'lib/models/porcelain.rb', line 7179

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end