Class: SDM::EntraID
- Inherits:
-
Object
- Object
- SDM::EntraID
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#discovery_enabled ⇒ Object
If true, configures discovery of the tenant to be run from a node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#group_names ⇒ Object
comma separated list of group names to filter by.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#management_group_id ⇒ Object
The management group ID to authenticate scope Privileges to.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#privilege_levels ⇒ Object
The privilege levels specify which Groups are managed externally.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#resource_group_id ⇒ Object
filters discovered groups to the specified Resource Group.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#subscription_id ⇒ Object
The subscription ID to authenticate scope Privileges to.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
The connector ID to authenticate through.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil) ⇒ EntraID
constructor
A new instance of EntraID.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil) ⇒ EntraID
Returns a new instance of EntraID.
7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 7171 7172 7173 |
# File 'lib/models/porcelain.rb', line 7137 def initialize( bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled @egress_filter = egress_filter == nil ? "" : egress_filter @group_names = group_names == nil ? "" : group_names @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_set_id = identity_set_id == nil ? "" : identity_set_id @management_group_id = management_group_id == nil ? "" : management_group_id @name = name == nil ? "" : name @privilege_levels = privilege_levels == nil ? "" : privilege_levels @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @resource_group_id = resource_group_id == nil ? "" : resource_group_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @subscription_id = subscription_id == nil ? "" : subscription_id @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7103 7104 7105 |
# File 'lib/models/porcelain.rb', line 7103 def bind_interface @bind_interface end |
#discovery_enabled ⇒ Object
If true, configures discovery of the tenant to be run from a node.
7105 7106 7107 |
# File 'lib/models/porcelain.rb', line 7105 def discovery_enabled @discovery_enabled end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7107 7108 7109 |
# File 'lib/models/porcelain.rb', line 7107 def egress_filter @egress_filter end |
#group_names ⇒ Object
comma separated list of group names to filter by. Supports wildcards (*)
7109 7110 7111 |
# File 'lib/models/porcelain.rb', line 7109 def group_names @group_names end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7111 7112 7113 |
# File 'lib/models/porcelain.rb', line 7111 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7113 7114 7115 |
# File 'lib/models/porcelain.rb', line 7113 def id @id end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
7115 7116 7117 |
# File 'lib/models/porcelain.rb', line 7115 def identity_set_id @identity_set_id end |
#management_group_id ⇒ Object
The management group ID to authenticate scope Privileges to.
7117 7118 7119 |
# File 'lib/models/porcelain.rb', line 7117 def management_group_id @management_group_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7119 7120 7121 |
# File 'lib/models/porcelain.rb', line 7119 def name @name end |
#privilege_levels ⇒ Object
The privilege levels specify which Groups are managed externally
7121 7122 7123 |
# File 'lib/models/porcelain.rb', line 7121 def privilege_levels @privilege_levels end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7123 7124 7125 |
# File 'lib/models/porcelain.rb', line 7123 def proxy_cluster_id @proxy_cluster_id end |
#resource_group_id ⇒ Object
filters discovered groups to the specified Resource Group
7125 7126 7127 |
# File 'lib/models/porcelain.rb', line 7125 def resource_group_id @resource_group_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7127 7128 7129 |
# File 'lib/models/porcelain.rb', line 7127 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
7129 7130 7131 |
# File 'lib/models/porcelain.rb', line 7129 def subdomain @subdomain end |
#subscription_id ⇒ Object
The subscription ID to authenticate scope Privileges to.
7131 7132 7133 |
# File 'lib/models/porcelain.rb', line 7131 def subscription_id @subscription_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7133 7134 7135 |
# File 'lib/models/porcelain.rb', line 7133 def @tags end |
#tenant_id ⇒ Object
The connector ID to authenticate through.
7135 7136 7137 |
# File 'lib/models/porcelain.rb', line 7135 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7175 7176 7177 7178 7179 7180 7181 |
# File 'lib/models/porcelain.rb', line 7175 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |