Class: SDM::EntraID

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil) ⇒ EntraID

Returns a new instance of EntraID.



6391
6392
6393
6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
6410
6411
6412
6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
# File 'lib/models/porcelain.rb', line 6391

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  management_group_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  resource_group_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  subscription_id: nil,
  tags: nil,
  tenant_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @management_group_id = management_group_id == nil ? "" : management_group_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @resource_group_id = resource_group_id == nil ? "" : resource_group_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @subscription_id = subscription_id == nil ? "" : subscription_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6357
6358
6359
# File 'lib/models/porcelain.rb', line 6357

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the tenant to be run from a node.



6359
6360
6361
# File 'lib/models/porcelain.rb', line 6359

def discovery_enabled
  @discovery_enabled
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6361
6362
6363
# File 'lib/models/porcelain.rb', line 6361

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



6363
6364
6365
# File 'lib/models/porcelain.rb', line 6363

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6365
6366
6367
# File 'lib/models/porcelain.rb', line 6365

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6367
6368
6369
# File 'lib/models/porcelain.rb', line 6367

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



6369
6370
6371
# File 'lib/models/porcelain.rb', line 6369

def identity_set_id
  @identity_set_id
end

#management_group_idObject

The management group ID to authenticate scope Privileges to.



6371
6372
6373
# File 'lib/models/porcelain.rb', line 6371

def management_group_id
  @management_group_id
end

#nameObject

Unique human-readable name of the Resource.



6373
6374
6375
# File 'lib/models/porcelain.rb', line 6373

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



6375
6376
6377
# File 'lib/models/porcelain.rb', line 6375

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6377
6378
6379
# File 'lib/models/porcelain.rb', line 6377

def proxy_cluster_id
  @proxy_cluster_id
end

#resource_group_idObject

filters discovered groups to the specified Resource Group



6379
6380
6381
# File 'lib/models/porcelain.rb', line 6379

def resource_group_id
  @resource_group_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6381
6382
6383
# File 'lib/models/porcelain.rb', line 6381

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6383
6384
6385
# File 'lib/models/porcelain.rb', line 6383

def subdomain
  @subdomain
end

#subscription_idObject

The subscription ID to authenticate scope Privileges to.



6385
6386
6387
# File 'lib/models/porcelain.rb', line 6385

def subscription_id
  @subscription_id
end

#tagsObject

Tags is a map of key, value pairs.



6387
6388
6389
# File 'lib/models/porcelain.rb', line 6387

def tags
  @tags
end

#tenant_idObject

The connector ID to authenticate through.



6389
6390
6391
# File 'lib/models/porcelain.rb', line 6389

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6429
6430
6431
6432
6433
6434
6435
# File 'lib/models/porcelain.rb', line 6429

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end