Class: SDM::EntraID

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

EntraID is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil) ⇒ EntraID

Returns a new instance of EntraID.



6142
6143
6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
# File 'lib/models/porcelain.rb', line 6142

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  management_group_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  resource_group_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  subscription_id: nil,
  tags: nil,
  tenant_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @management_group_id = management_group_id == nil ? "" : management_group_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @resource_group_id = resource_group_id == nil ? "" : resource_group_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @subscription_id = subscription_id == nil ? "" : subscription_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6108
6109
6110
# File 'lib/models/porcelain.rb', line 6108

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the tenant to be run from a node.



6110
6111
6112
# File 'lib/models/porcelain.rb', line 6110

def discovery_enabled
  @discovery_enabled
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6112
6113
6114
# File 'lib/models/porcelain.rb', line 6112

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



6114
6115
6116
# File 'lib/models/porcelain.rb', line 6114

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6116
6117
6118
# File 'lib/models/porcelain.rb', line 6116

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6118
6119
6120
# File 'lib/models/porcelain.rb', line 6118

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



6120
6121
6122
# File 'lib/models/porcelain.rb', line 6120

def identity_set_id
  @identity_set_id
end

#management_group_idObject

The management group ID to authenticate scope Privileges to.



6122
6123
6124
# File 'lib/models/porcelain.rb', line 6122

def management_group_id
  @management_group_id
end

#nameObject

Unique human-readable name of the Resource.



6124
6125
6126
# File 'lib/models/porcelain.rb', line 6124

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



6126
6127
6128
# File 'lib/models/porcelain.rb', line 6126

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6128
6129
6130
# File 'lib/models/porcelain.rb', line 6128

def proxy_cluster_id
  @proxy_cluster_id
end

#resource_group_idObject

filters discovered groups to the specified Resource Group



6130
6131
6132
# File 'lib/models/porcelain.rb', line 6130

def resource_group_id
  @resource_group_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6132
6133
6134
# File 'lib/models/porcelain.rb', line 6132

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6134
6135
6136
# File 'lib/models/porcelain.rb', line 6134

def subdomain
  @subdomain
end

#subscription_idObject

The subscription ID to authenticate scope Privileges to.



6136
6137
6138
# File 'lib/models/porcelain.rb', line 6136

def subscription_id
  @subscription_id
end

#tagsObject

Tags is a map of key, value pairs.



6138
6139
6140
# File 'lib/models/porcelain.rb', line 6138

def tags
  @tags
end

#tenant_idObject

The connector ID to authenticate through.



6140
6141
6142
# File 'lib/models/porcelain.rb', line 6140

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6180
6181
6182
6183
6184
6185
6186
# File 'lib/models/porcelain.rb', line 6180

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end