Class: SDM::EntraID

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, management_group_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, resource_group_id: nil, secret_store_id: nil, subdomain: nil, subscription_id: nil, tags: nil, tenant_id: nil) ⇒ EntraID

Returns a new instance of EntraID.



7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
# File 'lib/models/porcelain.rb', line 7215

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  management_group_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  resource_group_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  subscription_id: nil,
  tags: nil,
  tenant_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @management_group_id = management_group_id == nil ? "" : management_group_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @resource_group_id = resource_group_id == nil ? "" : resource_group_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @subscription_id = subscription_id == nil ? "" : subscription_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7181
7182
7183
# File 'lib/models/porcelain.rb', line 7181

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the tenant to be run from a node.



7183
7184
7185
# File 'lib/models/porcelain.rb', line 7183

def discovery_enabled
  @discovery_enabled
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7185
7186
7187
# File 'lib/models/porcelain.rb', line 7185

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



7187
7188
7189
# File 'lib/models/porcelain.rb', line 7187

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7189
7190
7191
# File 'lib/models/porcelain.rb', line 7189

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7191
7192
7193
# File 'lib/models/porcelain.rb', line 7191

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



7193
7194
7195
# File 'lib/models/porcelain.rb', line 7193

def identity_set_id
  @identity_set_id
end

#management_group_idObject

The management group ID to authenticate scope Privileges to.



7195
7196
7197
# File 'lib/models/porcelain.rb', line 7195

def management_group_id
  @management_group_id
end

#nameObject

Unique human-readable name of the Resource.



7197
7198
7199
# File 'lib/models/porcelain.rb', line 7197

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



7199
7200
7201
# File 'lib/models/porcelain.rb', line 7199

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7201
7202
7203
# File 'lib/models/porcelain.rb', line 7201

def proxy_cluster_id
  @proxy_cluster_id
end

#resource_group_idObject

filters discovered groups to the specified Resource Group



7203
7204
7205
# File 'lib/models/porcelain.rb', line 7203

def resource_group_id
  @resource_group_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7205
7206
7207
# File 'lib/models/porcelain.rb', line 7205

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7207
7208
7209
# File 'lib/models/porcelain.rb', line 7207

def subdomain
  @subdomain
end

#subscription_idObject

The subscription ID to authenticate scope Privileges to.



7209
7210
7211
# File 'lib/models/porcelain.rb', line 7209

def subscription_id
  @subscription_id
end

#tagsObject

Tags is a map of key, value pairs.



7211
7212
7213
# File 'lib/models/porcelain.rb', line 7211

def tags
  @tags
end

#tenant_idObject

The connector ID to authenticate through.



7213
7214
7215
# File 'lib/models/porcelain.rb', line 7213

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7253
7254
7255
7256
7257
7258
7259
# File 'lib/models/porcelain.rb', line 7253

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end