Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



7328
7329
7330
7331
7332
7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
# File 'lib/models/porcelain.rb', line 7328

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7304
7305
7306
# File 'lib/models/porcelain.rb', line 7304

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7306
7307
7308
# File 'lib/models/porcelain.rb', line 7306

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7308
7309
7310
# File 'lib/models/porcelain.rb', line 7308

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7310
7311
7312
# File 'lib/models/porcelain.rb', line 7310

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



7312
7313
7314
# File 'lib/models/porcelain.rb', line 7312

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



7314
7315
7316
# File 'lib/models/porcelain.rb', line 7314

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7316
7317
7318
# File 'lib/models/porcelain.rb', line 7316

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7318
7319
7320
# File 'lib/models/porcelain.rb', line 7318

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



7320
7321
7322
# File 'lib/models/porcelain.rb', line 7320

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7322
7323
7324
# File 'lib/models/porcelain.rb', line 7322

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7324
7325
7326
# File 'lib/models/porcelain.rb', line 7324

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7326
7327
7328
# File 'lib/models/porcelain.rb', line 7326

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7356
7357
7358
7359
7360
7361
7362
# File 'lib/models/porcelain.rb', line 7356

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end