Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



6215
6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
# File 'lib/models/porcelain.rb', line 6215

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6191
6192
6193
# File 'lib/models/porcelain.rb', line 6191

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6193
6194
6195
# File 'lib/models/porcelain.rb', line 6193

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6195
6196
6197
# File 'lib/models/porcelain.rb', line 6195

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6197
6198
6199
# File 'lib/models/porcelain.rb', line 6197

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



6199
6200
6201
# File 'lib/models/porcelain.rb', line 6199

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



6201
6202
6203
# File 'lib/models/porcelain.rb', line 6201

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



6203
6204
6205
# File 'lib/models/porcelain.rb', line 6203

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6205
6206
6207
# File 'lib/models/porcelain.rb', line 6205

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



6207
6208
6209
# File 'lib/models/porcelain.rb', line 6207

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6209
6210
6211
# File 'lib/models/porcelain.rb', line 6209

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6211
6212
6213
# File 'lib/models/porcelain.rb', line 6211

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6213
6214
6215
# File 'lib/models/porcelain.rb', line 6213

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6243
6244
6245
6246
6247
6248
6249
# File 'lib/models/porcelain.rb', line 6243

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end