Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
# File 'lib/models/porcelain.rb', line 5890

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5866
5867
5868
# File 'lib/models/porcelain.rb', line 5866

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5868
5869
5870
# File 'lib/models/porcelain.rb', line 5868

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5870
5871
5872
# File 'lib/models/porcelain.rb', line 5870

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5872
5873
5874
# File 'lib/models/porcelain.rb', line 5872

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



5874
5875
5876
# File 'lib/models/porcelain.rb', line 5874

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



5876
5877
5878
# File 'lib/models/porcelain.rb', line 5876

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5878
5879
5880
# File 'lib/models/porcelain.rb', line 5878

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5880
5881
5882
# File 'lib/models/porcelain.rb', line 5880

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



5882
5883
5884
# File 'lib/models/porcelain.rb', line 5882

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5884
5885
5886
# File 'lib/models/porcelain.rb', line 5884

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5886
5887
5888
# File 'lib/models/porcelain.rb', line 5886

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5888
5889
5890
# File 'lib/models/porcelain.rb', line 5888

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5918
5919
5920
5921
5922
5923
5924
# File 'lib/models/porcelain.rb', line 5918

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end