Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



5743
5744
5745
5746
5747
5748
5749
5750
5751
5752
5753
5754
5755
5756
5757
5758
5759
5760
5761
5762
5763
5764
5765
5766
5767
5768
5769
# File 'lib/models/porcelain.rb', line 5743

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5719
5720
5721
# File 'lib/models/porcelain.rb', line 5719

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5721
5722
5723
# File 'lib/models/porcelain.rb', line 5721

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5723
5724
5725
# File 'lib/models/porcelain.rb', line 5723

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5725
5726
5727
# File 'lib/models/porcelain.rb', line 5725

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



5727
5728
5729
# File 'lib/models/porcelain.rb', line 5727

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



5729
5730
5731
# File 'lib/models/porcelain.rb', line 5729

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5731
5732
5733
# File 'lib/models/porcelain.rb', line 5731

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5733
5734
5735
# File 'lib/models/porcelain.rb', line 5733

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



5735
5736
5737
# File 'lib/models/porcelain.rb', line 5735

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5737
5738
5739
# File 'lib/models/porcelain.rb', line 5737

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5739
5740
5741
# File 'lib/models/porcelain.rb', line 5739

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5741
5742
5743
# File 'lib/models/porcelain.rb', line 5741

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5771
5772
5773
5774
5775
5776
5777
# File 'lib/models/porcelain.rb', line 5771

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end