Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



5640
5641
5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
# File 'lib/models/porcelain.rb', line 5640

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5616
5617
5618
# File 'lib/models/porcelain.rb', line 5616

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5618
5619
5620
# File 'lib/models/porcelain.rb', line 5618

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5620
5621
5622
# File 'lib/models/porcelain.rb', line 5620

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5622
5623
5624
# File 'lib/models/porcelain.rb', line 5622

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



5624
5625
5626
# File 'lib/models/porcelain.rb', line 5624

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



5626
5627
5628
# File 'lib/models/porcelain.rb', line 5626

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5628
5629
5630
# File 'lib/models/porcelain.rb', line 5628

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5630
5631
5632
# File 'lib/models/porcelain.rb', line 5630

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



5632
5633
5634
# File 'lib/models/porcelain.rb', line 5632

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5634
5635
5636
# File 'lib/models/porcelain.rb', line 5634

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5636
5637
5638
# File 'lib/models/porcelain.rb', line 5636

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5638
5639
5640
# File 'lib/models/porcelain.rb', line 5638

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5668
5669
5670
5671
5672
5673
5674
# File 'lib/models/porcelain.rb', line 5668

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end