Class: SDM::GCP
- Inherits:
-
Object
- Object
- SDM::GCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keyfile ⇒ Object
The service account keyfile to authenticate with.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
constructor
A new instance of GCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
Returns a new instance of GCP.
5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 |
# File 'lib/models/porcelain.rb', line 5560 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @keyfile = keyfile == nil ? "" : keyfile @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @scopes = scopes == nil ? "" : scopes @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5536 5537 5538 |
# File 'lib/models/porcelain.rb', line 5536 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5538 5539 5540 |
# File 'lib/models/porcelain.rb', line 5538 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5540 5541 5542 |
# File 'lib/models/porcelain.rb', line 5540 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5542 5543 5544 |
# File 'lib/models/porcelain.rb', line 5542 def id @id end |
#keyfile ⇒ Object
The service account keyfile to authenticate with.
5544 5545 5546 |
# File 'lib/models/porcelain.rb', line 5544 def keyfile @keyfile end |
#name ⇒ Object
Unique human-readable name of the Resource.
5546 5547 5548 |
# File 'lib/models/porcelain.rb', line 5546 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5548 5549 5550 |
# File 'lib/models/porcelain.rb', line 5548 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5550 5551 5552 |
# File 'lib/models/porcelain.rb', line 5550 def proxy_cluster_id @proxy_cluster_id end |
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
5552 5553 5554 |
# File 'lib/models/porcelain.rb', line 5552 def scopes @scopes end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5554 5555 5556 |
# File 'lib/models/porcelain.rb', line 5554 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5556 5557 5558 |
# File 'lib/models/porcelain.rb', line 5556 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5558 5559 5560 |
# File 'lib/models/porcelain.rb', line 5558 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5588 5589 5590 5591 5592 5593 5594 |
# File 'lib/models/porcelain.rb', line 5588 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |