Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
# File 'lib/models/porcelain.rb', line 5489

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5465
5466
5467
# File 'lib/models/porcelain.rb', line 5465

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5467
5468
5469
# File 'lib/models/porcelain.rb', line 5467

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5469
5470
5471
# File 'lib/models/porcelain.rb', line 5469

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5471
5472
5473
# File 'lib/models/porcelain.rb', line 5471

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



5473
5474
5475
# File 'lib/models/porcelain.rb', line 5473

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



5475
5476
5477
# File 'lib/models/porcelain.rb', line 5475

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5477
5478
5479
# File 'lib/models/porcelain.rb', line 5477

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5479
5480
5481
# File 'lib/models/porcelain.rb', line 5479

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



5481
5482
5483
# File 'lib/models/porcelain.rb', line 5481

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5483
5484
5485
# File 'lib/models/porcelain.rb', line 5483

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5485
5486
5487
# File 'lib/models/porcelain.rb', line 5485

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5487
5488
5489
# File 'lib/models/porcelain.rb', line 5487

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5517
5518
5519
5520
5521
5522
5523
# File 'lib/models/porcelain.rb', line 5517

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end