Class: SDM::GCP
- Inherits:
-
Object
- Object
- SDM::GCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keyfile ⇒ Object
The service account keyfile to authenticate with.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
constructor
A new instance of GCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
Returns a new instance of GCP.
5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 5511 5512 5513 5514 5515 5516 |
# File 'lib/models/porcelain.rb', line 5490 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @keyfile = keyfile == nil ? "" : keyfile @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @scopes = scopes == nil ? "" : scopes @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5466 5467 5468 |
# File 'lib/models/porcelain.rb', line 5466 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5468 5469 5470 |
# File 'lib/models/porcelain.rb', line 5468 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5470 5471 5472 |
# File 'lib/models/porcelain.rb', line 5470 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5472 5473 5474 |
# File 'lib/models/porcelain.rb', line 5472 def id @id end |
#keyfile ⇒ Object
The service account keyfile to authenticate with.
5474 5475 5476 |
# File 'lib/models/porcelain.rb', line 5474 def keyfile @keyfile end |
#name ⇒ Object
Unique human-readable name of the Resource.
5476 5477 5478 |
# File 'lib/models/porcelain.rb', line 5476 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5478 5479 5480 |
# File 'lib/models/porcelain.rb', line 5478 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5480 5481 5482 |
# File 'lib/models/porcelain.rb', line 5480 def proxy_cluster_id @proxy_cluster_id end |
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
5482 5483 5484 |
# File 'lib/models/porcelain.rb', line 5482 def scopes @scopes end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5484 5485 5486 |
# File 'lib/models/porcelain.rb', line 5484 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5486 5487 5488 |
# File 'lib/models/porcelain.rb', line 5486 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5488 5489 5490 |
# File 'lib/models/porcelain.rb', line 5488 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5518 5519 5520 5521 5522 5523 5524 |
# File 'lib/models/porcelain.rb', line 5518 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |