Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



5126
5127
5128
5129
5130
5131
5132
5133
5134
5135
5136
5137
5138
5139
5140
5141
5142
5143
5144
5145
5146
5147
5148
5149
5150
5151
5152
# File 'lib/models/porcelain.rb', line 5126

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5102
5103
5104
# File 'lib/models/porcelain.rb', line 5102

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5104
5105
5106
# File 'lib/models/porcelain.rb', line 5104

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5106
5107
5108
# File 'lib/models/porcelain.rb', line 5106

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5108
5109
5110
# File 'lib/models/porcelain.rb', line 5108

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



5110
5111
5112
# File 'lib/models/porcelain.rb', line 5110

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



5112
5113
5114
# File 'lib/models/porcelain.rb', line 5112

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5114
5115
5116
# File 'lib/models/porcelain.rb', line 5114

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5116
5117
5118
# File 'lib/models/porcelain.rb', line 5116

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



5118
5119
5120
# File 'lib/models/porcelain.rb', line 5118

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5120
5121
5122
# File 'lib/models/porcelain.rb', line 5120

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5122
5123
5124
# File 'lib/models/porcelain.rb', line 5122

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5124
5125
5126
# File 'lib/models/porcelain.rb', line 5124

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5154
5155
5156
5157
5158
5159
5160
# File 'lib/models/porcelain.rb', line 5154

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end