Class: SDM::GCP
- Inherits:
-
Object
- Object
- SDM::GCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keyfile ⇒ Object
The service account keyfile to authenticate with.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
constructor
A new instance of GCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
Returns a new instance of GCP.
4812 4813 4814 4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 4825 4826 4827 4828 4829 4830 4831 4832 4833 4834 4835 4836 |
# File 'lib/models/porcelain.rb', line 4812 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @keyfile = keyfile == nil ? "" : keyfile @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @scopes = scopes == nil ? "" : scopes @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4790 4791 4792 |
# File 'lib/models/porcelain.rb', line 4790 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4792 4793 4794 |
# File 'lib/models/porcelain.rb', line 4792 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4794 4795 4796 |
# File 'lib/models/porcelain.rb', line 4794 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4796 4797 4798 |
# File 'lib/models/porcelain.rb', line 4796 def id @id end |
#keyfile ⇒ Object
The service account keyfile to authenticate with.
4798 4799 4800 |
# File 'lib/models/porcelain.rb', line 4798 def keyfile @keyfile end |
#name ⇒ Object
Unique human-readable name of the Resource.
4800 4801 4802 |
# File 'lib/models/porcelain.rb', line 4800 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4802 4803 4804 |
# File 'lib/models/porcelain.rb', line 4802 def port_override @port_override end |
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
4804 4805 4806 |
# File 'lib/models/porcelain.rb', line 4804 def scopes @scopes end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4806 4807 4808 |
# File 'lib/models/porcelain.rb', line 4806 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4808 4809 4810 |
# File 'lib/models/porcelain.rb', line 4808 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4810 4811 4812 |
# File 'lib/models/porcelain.rb', line 4810 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4838 4839 4840 4841 4842 4843 4844 |
# File 'lib/models/porcelain.rb', line 4838 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |