Class: SDM::GCP
- Inherits:
-
Object
- Object
- SDM::GCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keyfile ⇒ Object
The service account keyfile to authenticate with.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
constructor
A new instance of GCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
Returns a new instance of GCP.
3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 |
# File 'lib/models/porcelain.rb', line 3841 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @keyfile = keyfile == nil ? "" : keyfile @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @scopes = scopes == nil ? "" : scopes @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3819 3820 3821 |
# File 'lib/models/porcelain.rb', line 3819 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3821 3822 3823 |
# File 'lib/models/porcelain.rb', line 3821 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3823 3824 3825 |
# File 'lib/models/porcelain.rb', line 3823 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3825 3826 3827 |
# File 'lib/models/porcelain.rb', line 3825 def id @id end |
#keyfile ⇒ Object
The service account keyfile to authenticate with.
3827 3828 3829 |
# File 'lib/models/porcelain.rb', line 3827 def keyfile @keyfile end |
#name ⇒ Object
Unique human-readable name of the Resource.
3829 3830 3831 |
# File 'lib/models/porcelain.rb', line 3829 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3831 3832 3833 |
# File 'lib/models/porcelain.rb', line 3831 def port_override @port_override end |
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
3833 3834 3835 |
# File 'lib/models/porcelain.rb', line 3833 def scopes @scopes end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3835 3836 3837 |
# File 'lib/models/porcelain.rb', line 3835 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3837 3838 3839 |
# File 'lib/models/porcelain.rb', line 3837 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3839 3840 3841 |
# File 'lib/models/porcelain.rb', line 3839 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3867 3868 3869 3870 3871 3872 3873 |
# File 'lib/models/porcelain.rb', line 3867 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |