Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



3677
3678
3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
# File 'lib/models/porcelain.rb', line 3677

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3655
3656
3657
# File 'lib/models/porcelain.rb', line 3655

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3657
3658
3659
# File 'lib/models/porcelain.rb', line 3657

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3659
3660
3661
# File 'lib/models/porcelain.rb', line 3659

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3661
3662
3663
# File 'lib/models/porcelain.rb', line 3661

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



3663
3664
3665
# File 'lib/models/porcelain.rb', line 3663

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



3665
3666
3667
# File 'lib/models/porcelain.rb', line 3665

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



3667
3668
3669
# File 'lib/models/porcelain.rb', line 3667

def port_override
  @port_override
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



3669
3670
3671
# File 'lib/models/porcelain.rb', line 3669

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3671
3672
3673
# File 'lib/models/porcelain.rb', line 3671

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3673
3674
3675
# File 'lib/models/porcelain.rb', line 3673

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3675
3676
3677
# File 'lib/models/porcelain.rb', line 3675

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3703
3704
3705
3706
3707
3708
3709
# File 'lib/models/porcelain.rb', line 3703

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end