Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
# File 'lib/models/porcelain.rb', line 3744

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  port_override: nil,
  scopes: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3722
3723
3724
# File 'lib/models/porcelain.rb', line 3722

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3724
3725
3726
# File 'lib/models/porcelain.rb', line 3724

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3726
3727
3728
# File 'lib/models/porcelain.rb', line 3726

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3728
3729
3730
# File 'lib/models/porcelain.rb', line 3728

def id
  @id
end

#keyfileObject

The service account keyfile to authenticate with.



3730
3731
3732
# File 'lib/models/porcelain.rb', line 3730

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



3732
3733
3734
# File 'lib/models/porcelain.rb', line 3732

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



3734
3735
3736
# File 'lib/models/porcelain.rb', line 3734

def port_override
  @port_override
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



3736
3737
3738
# File 'lib/models/porcelain.rb', line 3736

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3738
3739
3740
# File 'lib/models/porcelain.rb', line 3738

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3740
3741
3742
# File 'lib/models/porcelain.rb', line 3740

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3742
3743
3744
# File 'lib/models/porcelain.rb', line 3742

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3770
3771
3772
3773
3774
3775
3776
# File 'lib/models/porcelain.rb', line 3770

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end