Class: SDM::GCP
- Inherits:
-
Object
- Object
- SDM::GCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keyfile ⇒ Object
Returns the value of attribute keyfile.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#scopes ⇒ Object
Returns the value of attribute scopes.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
constructor
A new instance of GCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ GCP
Returns a new instance of GCP.
3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 |
# File 'lib/models/porcelain.rb', line 3578 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, port_override: nil, scopes: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @keyfile = keyfile == nil ? "" : keyfile @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @scopes = scopes == nil ? "" : scopes @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3556 3557 3558 |
# File 'lib/models/porcelain.rb', line 3556 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3558 3559 3560 |
# File 'lib/models/porcelain.rb', line 3558 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3560 3561 3562 |
# File 'lib/models/porcelain.rb', line 3560 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3562 3563 3564 |
# File 'lib/models/porcelain.rb', line 3562 def id @id end |
#keyfile ⇒ Object
Returns the value of attribute keyfile.
3564 3565 3566 |
# File 'lib/models/porcelain.rb', line 3564 def keyfile @keyfile end |
#name ⇒ Object
Unique human-readable name of the Resource.
3566 3567 3568 |
# File 'lib/models/porcelain.rb', line 3566 def name @name end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3568 3569 3570 |
# File 'lib/models/porcelain.rb', line 3568 def port_override @port_override end |
#scopes ⇒ Object
Returns the value of attribute scopes.
3570 3571 3572 |
# File 'lib/models/porcelain.rb', line 3570 def scopes @scopes end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3572 3573 3574 |
# File 'lib/models/porcelain.rb', line 3572 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3574 3575 3576 |
# File 'lib/models/porcelain.rb', line 3574 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3576 3577 3578 |
# File 'lib/models/porcelain.rb', line 3576 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3604 3605 3606 3607 3608 3609 3610 |
# File 'lib/models/porcelain.rb', line 3604 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |