Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, scopes: nil, secret_store_id: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
3296
# File 'lib/models/porcelain.rb', line 3276

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  scopes: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3258
3259
3260
# File 'lib/models/porcelain.rb', line 3258

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3260
3261
3262
# File 'lib/models/porcelain.rb', line 3260

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3262
3263
3264
# File 'lib/models/porcelain.rb', line 3262

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3264
3265
3266
# File 'lib/models/porcelain.rb', line 3264

def id
  @id
end

#keyfileObject

Returns the value of attribute keyfile.



3266
3267
3268
# File 'lib/models/porcelain.rb', line 3266

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



3268
3269
3270
# File 'lib/models/porcelain.rb', line 3268

def name
  @name
end

#scopesObject

Returns the value of attribute scopes.



3270
3271
3272
# File 'lib/models/porcelain.rb', line 3270

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3272
3273
3274
# File 'lib/models/porcelain.rb', line 3272

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3274
3275
3276
# File 'lib/models/porcelain.rb', line 3274

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3298
3299
3300
3301
3302
3303
3304
# File 'lib/models/porcelain.rb', line 3298

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end