Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, scopes: nil, secret_store_id: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
# File 'lib/models/porcelain.rb', line 2938

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  scopes: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2920
2921
2922
# File 'lib/models/porcelain.rb', line 2920

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2922
2923
2924
# File 'lib/models/porcelain.rb', line 2922

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2924
2925
2926
# File 'lib/models/porcelain.rb', line 2924

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2926
2927
2928
# File 'lib/models/porcelain.rb', line 2926

def id
  @id
end

#keyfileObject

Returns the value of attribute keyfile.



2928
2929
2930
# File 'lib/models/porcelain.rb', line 2928

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



2930
2931
2932
# File 'lib/models/porcelain.rb', line 2930

def name
  @name
end

#scopesObject

Returns the value of attribute scopes.



2932
2933
2934
# File 'lib/models/porcelain.rb', line 2932

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2934
2935
2936
# File 'lib/models/porcelain.rb', line 2934

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2936
2937
2938
# File 'lib/models/porcelain.rb', line 2936

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2960
2961
2962
2963
2964
2965
2966
# File 'lib/models/porcelain.rb', line 2960

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end