Class: SDM::GCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, scopes: nil, secret_store_id: nil, tags: nil) ⇒ GCP

Returns a new instance of GCP.



2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
# File 'lib/models/porcelain.rb', line 2827

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  keyfile: nil,
  name: nil,
  scopes: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @keyfile = keyfile == nil ? "" : keyfile
  @name = name == nil ? "" : name
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2809
2810
2811
# File 'lib/models/porcelain.rb', line 2809

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2811
2812
2813
# File 'lib/models/porcelain.rb', line 2811

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2813
2814
2815
# File 'lib/models/porcelain.rb', line 2813

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2815
2816
2817
# File 'lib/models/porcelain.rb', line 2815

def id
  @id
end

#keyfileObject

Returns the value of attribute keyfile.



2817
2818
2819
# File 'lib/models/porcelain.rb', line 2817

def keyfile
  @keyfile
end

#nameObject

Unique human-readable name of the Resource.



2819
2820
2821
# File 'lib/models/porcelain.rb', line 2819

def name
  @name
end

#scopesObject

Returns the value of attribute scopes.



2821
2822
2823
# File 'lib/models/porcelain.rb', line 2821

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2823
2824
2825
# File 'lib/models/porcelain.rb', line 2823

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



2825
2826
2827
# File 'lib/models/porcelain.rb', line 2825

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2849
2850
2851
2852
2853
2854
2855
# File 'lib/models/porcelain.rb', line 2849

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end