Class: SDM::GCP
- Inherits:
-
Object
- Object
- SDM::GCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keyfile ⇒ Object
Returns the value of attribute keyfile.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#scopes ⇒ Object
Returns the value of attribute scopes.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, scopes: nil, secret_store_id: nil, tags: nil) ⇒ GCP
constructor
A new instance of GCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, scopes: nil, secret_store_id: nil, tags: nil) ⇒ GCP
Returns a new instance of GCP.
3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 3145 3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 |
# File 'lib/models/porcelain.rb', line 3123 def initialize( egress_filter: nil, healthy: nil, id: nil, keyfile: nil, name: nil, scopes: nil, secret_store_id: nil, tags: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if id != nil @id = id end if keyfile != nil @keyfile = keyfile end if name != nil @name = name end if scopes != nil @scopes = scopes end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3107 3108 3109 |
# File 'lib/models/porcelain.rb', line 3107 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3109 3110 3111 |
# File 'lib/models/porcelain.rb', line 3109 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3111 3112 3113 |
# File 'lib/models/porcelain.rb', line 3111 def id @id end |
#keyfile ⇒ Object
Returns the value of attribute keyfile.
3113 3114 3115 |
# File 'lib/models/porcelain.rb', line 3113 def keyfile @keyfile end |
#name ⇒ Object
Unique human-readable name of the Resource.
3115 3116 3117 |
# File 'lib/models/porcelain.rb', line 3115 def name @name end |
#scopes ⇒ Object
Returns the value of attribute scopes.
3117 3118 3119 |
# File 'lib/models/porcelain.rb', line 3117 def scopes @scopes end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3119 3120 3121 |
# File 'lib/models/porcelain.rb', line 3119 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3121 3122 3123 |
# File 'lib/models/porcelain.rb', line 3121 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3159 3160 3161 3162 3163 3164 3165 |
# File 'lib/models/porcelain.rb', line 3159 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |