Class: SDM::GCPConnector
- Inherits:
-
Object
- Object
- SDM::GCPConnector
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Description of the Connector.
-
#exclude_tags ⇒ Object
ExcludeTags filters out discovered resources that have the tag and value.
-
#id ⇒ Object
Unique identifier of the Connector.
-
#include_tags ⇒ Object
IncludeTags only discovers cloud resources that have one of the included tags.
-
#name ⇒ Object
Unique human-readable name of the Connector.
-
#project_ids ⇒ Object
ProjectIds is the list of GCP Projects the connector will scan.
-
#scan_period ⇒ Object
ScanPeriod identifies which remote system this Connector discovers.
-
#services ⇒ Object
Services is a list of services this connector should scan.
-
#workload_pool_id ⇒ Object
WorkloadPoolId is the GCP Workload Pool Identifier used to authenticate our JWT.
-
#workload_project_id ⇒ Object
WorkloadProjectId is the GCP Project ID where the Workload Pool is defined.
-
#workload_project_number ⇒ Object
WorkloadProjectNumber is the GCP Project Number where the Workload Pool is defined.
-
#workload_provider_id ⇒ Object
WorkloadProviderId is the GCP Workload Provider Identifier used to authenticate our JWT.
Instance Method Summary collapse
-
#initialize(description: nil, exclude_tags: nil, id: nil, include_tags: nil, name: nil, project_ids: nil, scan_period: nil, services: nil, workload_pool_id: nil, workload_project_id: nil, workload_project_number: nil, workload_provider_id: nil) ⇒ GCPConnector
constructor
A new instance of GCPConnector.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, exclude_tags: nil, id: nil, include_tags: nil, name: nil, project_ids: nil, scan_period: nil, services: nil, workload_pool_id: nil, workload_project_id: nil, workload_project_number: nil, workload_provider_id: nil) ⇒ GCPConnector
Returns a new instance of GCPConnector.
7400 7401 7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 7424 7425 7426 |
# File 'lib/models/porcelain.rb', line 7400 def initialize( description: nil, exclude_tags: nil, id: nil, include_tags: nil, name: nil, project_ids: nil, scan_period: nil, services: nil, workload_pool_id: nil, workload_project_id: nil, workload_project_number: nil, workload_provider_id: nil ) @description = description == nil ? "" : description = == nil ? [] : @id = id == nil ? "" : id = == nil ? [] : @name = name == nil ? "" : name @project_ids = project_ids == nil ? [] : project_ids @scan_period = scan_period == nil ? "" : scan_period @services = services == nil ? [] : services @workload_pool_id = workload_pool_id == nil ? "" : workload_pool_id @workload_project_id = workload_project_id == nil ? "" : workload_project_id @workload_project_number = workload_project_number == nil ? "" : workload_project_number @workload_provider_id = workload_provider_id == nil ? "" : workload_provider_id end |
Instance Attribute Details
#description ⇒ Object
Description of the Connector.
7374 7375 7376 |
# File 'lib/models/porcelain.rb', line 7374 def description @description end |
#exclude_tags ⇒ Object
ExcludeTags filters out discovered resources that have the tag and value. We do allow duplicate tag names for ExcludeTags to support multiple excluded values for the tag.
7377 7378 7379 |
# File 'lib/models/porcelain.rb', line 7377 def end |
#id ⇒ Object
Unique identifier of the Connector.
7379 7380 7381 |
# File 'lib/models/porcelain.rb', line 7379 def id @id end |
#include_tags ⇒ Object
IncludeTags only discovers cloud resources that have one of the included tags. We do not allow duplicate tag names for IncludeTags
7382 7383 7384 |
# File 'lib/models/porcelain.rb', line 7382 def end |
#name ⇒ Object
Unique human-readable name of the Connector.
7384 7385 7386 |
# File 'lib/models/porcelain.rb', line 7384 def name @name end |
#project_ids ⇒ Object
ProjectIds is the list of GCP Projects the connector will scan
7386 7387 7388 |
# File 'lib/models/porcelain.rb', line 7386 def project_ids @project_ids end |
#scan_period ⇒ Object
ScanPeriod identifies which remote system this Connector discovers
7388 7389 7390 |
# File 'lib/models/porcelain.rb', line 7388 def scan_period @scan_period end |
#services ⇒ Object
Services is a list of services this connector should scan.
7390 7391 7392 |
# File 'lib/models/porcelain.rb', line 7390 def services @services end |
#workload_pool_id ⇒ Object
WorkloadPoolId is the GCP Workload Pool Identifier used to authenticate our JWT
7392 7393 7394 |
# File 'lib/models/porcelain.rb', line 7392 def workload_pool_id @workload_pool_id end |
#workload_project_id ⇒ Object
WorkloadProjectId is the GCP Project ID where the Workload Pool is defined
7394 7395 7396 |
# File 'lib/models/porcelain.rb', line 7394 def workload_project_id @workload_project_id end |
#workload_project_number ⇒ Object
WorkloadProjectNumber is the GCP Project Number where the Workload Pool is defined
7396 7397 7398 |
# File 'lib/models/porcelain.rb', line 7396 def workload_project_number @workload_project_number end |
#workload_provider_id ⇒ Object
WorkloadProviderId is the GCP Workload Provider Identifier used to authenticate our JWT
7398 7399 7400 |
# File 'lib/models/porcelain.rb', line 7398 def workload_provider_id @workload_provider_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7428 7429 7430 7431 7432 7433 7434 |
# File 'lib/models/porcelain.rb', line 7428 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |