Class: SDM::GCPConsole
- Inherits:
-
Object
- Object
- SDM::GCPConsole
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
-
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole
constructor
A new instance of GCPConsole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole
Returns a new instance of GCPConsole.
5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/models/porcelain.rb', line 5995 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @session_expiry = session_expiry == nil ? 0 : session_expiry @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5965 5966 5967 |
# File 'lib/models/porcelain.rb', line 5965 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5967 5968 5969 |
# File 'lib/models/porcelain.rb', line 5967 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5969 5970 5971 |
# File 'lib/models/porcelain.rb', line 5969 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5971 5972 5973 |
# File 'lib/models/porcelain.rb', line 5971 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
5973 5974 5975 |
# File 'lib/models/porcelain.rb', line 5973 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
5975 5976 5977 |
# File 'lib/models/porcelain.rb', line 5975 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5977 5978 5979 |
# File 'lib/models/porcelain.rb', line 5977 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5979 5980 5981 |
# File 'lib/models/porcelain.rb', line 5979 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5981 5982 5983 |
# File 'lib/models/porcelain.rb', line 5981 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5983 5984 5985 |
# File 'lib/models/porcelain.rb', line 5983 def secret_store_id @secret_store_id end |
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
5985 5986 5987 |
# File 'lib/models/porcelain.rb', line 5985 def session_expiry @session_expiry end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5987 5988 5989 |
# File 'lib/models/porcelain.rb', line 5987 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5989 5990 5991 |
# File 'lib/models/porcelain.rb', line 5989 def @tags end |
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
5991 5992 5993 |
# File 'lib/models/porcelain.rb', line 5991 def workforce_pool_id @workforce_pool_id end |
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
5993 5994 5995 |
# File 'lib/models/porcelain.rb', line 5993 def workforce_provider_id @workforce_provider_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6029 6030 6031 6032 6033 6034 6035 |
# File 'lib/models/porcelain.rb', line 6029 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |