Class: SDM::GCPConsole
- Inherits:
-
Object
- Object
- SDM::GCPConsole
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
-
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole
constructor
A new instance of GCPConsole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole
Returns a new instance of GCPConsole.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 |
# File 'lib/models/porcelain.rb', line 5605 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @session_expiry = session_expiry == nil ? 0 : session_expiry @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5575 5576 5577 |
# File 'lib/models/porcelain.rb', line 5575 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5577 5578 5579 |
# File 'lib/models/porcelain.rb', line 5577 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5579 5580 5581 |
# File 'lib/models/porcelain.rb', line 5579 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5581 5582 5583 |
# File 'lib/models/porcelain.rb', line 5581 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
5583 5584 5585 |
# File 'lib/models/porcelain.rb', line 5583 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
5585 5586 5587 |
# File 'lib/models/porcelain.rb', line 5585 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5587 5588 5589 |
# File 'lib/models/porcelain.rb', line 5587 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5589 5590 5591 |
# File 'lib/models/porcelain.rb', line 5589 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5591 5592 5593 |
# File 'lib/models/porcelain.rb', line 5591 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5593 5594 5595 |
# File 'lib/models/porcelain.rb', line 5593 def secret_store_id @secret_store_id end |
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
5595 5596 5597 |
# File 'lib/models/porcelain.rb', line 5595 def session_expiry @session_expiry end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5597 5598 5599 |
# File 'lib/models/porcelain.rb', line 5597 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5599 5600 5601 |
# File 'lib/models/porcelain.rb', line 5599 def @tags end |
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
5601 5602 5603 |
# File 'lib/models/porcelain.rb', line 5601 def workforce_pool_id @workforce_pool_id end |
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
5603 5604 5605 |
# File 'lib/models/porcelain.rb', line 5603 def workforce_provider_id @workforce_provider_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5639 5640 5641 5642 5643 5644 5645 |
# File 'lib/models/porcelain.rb', line 5639 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |