Class: SDM::GCPConsole
- Inherits:
-
Object
- Object
- SDM::GCPConsole
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
-
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole
constructor
A new instance of GCPConsole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole
Returns a new instance of GCPConsole.
5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 |
# File 'lib/models/porcelain.rb', line 5539 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @session_expiry = session_expiry == nil ? 0 : session_expiry @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5509 5510 5511 |
# File 'lib/models/porcelain.rb', line 5509 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5511 5512 5513 |
# File 'lib/models/porcelain.rb', line 5511 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5513 5514 5515 |
# File 'lib/models/porcelain.rb', line 5513 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5515 5516 5517 |
# File 'lib/models/porcelain.rb', line 5515 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
5517 5518 5519 |
# File 'lib/models/porcelain.rb', line 5517 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
5519 5520 5521 |
# File 'lib/models/porcelain.rb', line 5519 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5521 5522 5523 |
# File 'lib/models/porcelain.rb', line 5521 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5523 5524 5525 |
# File 'lib/models/porcelain.rb', line 5523 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
5525 5526 5527 |
# File 'lib/models/porcelain.rb', line 5525 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5527 5528 5529 |
# File 'lib/models/porcelain.rb', line 5527 def secret_store_id @secret_store_id end |
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
5529 5530 5531 |
# File 'lib/models/porcelain.rb', line 5529 def session_expiry @session_expiry end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5531 5532 5533 |
# File 'lib/models/porcelain.rb', line 5531 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5533 5534 5535 |
# File 'lib/models/porcelain.rb', line 5533 def @tags end |
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
5535 5536 5537 |
# File 'lib/models/porcelain.rb', line 5535 def workforce_pool_id @workforce_pool_id end |
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
5537 5538 5539 |
# File 'lib/models/porcelain.rb', line 5537 def workforce_provider_id @workforce_provider_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5573 5574 5575 5576 5577 5578 5579 |
# File 'lib/models/porcelain.rb', line 5573 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |