Class: SDM::GCPConsole

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GCPConsole is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole

Returns a new instance of GCPConsole.



5243
5244
5245
5246
5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
5272
5273
5274
5275
# File 'lib/models/porcelain.rb', line 5243

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  session_expiry: nil,
  subdomain: nil,
  tags: nil,
  workforce_pool_id: nil,
  workforce_provider_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @session_expiry = session_expiry == nil ? 0 : session_expiry
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id
  @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5213
5214
5215
# File 'lib/models/porcelain.rb', line 5213

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5215
5216
5217
# File 'lib/models/porcelain.rb', line 5215

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5217
5218
5219
# File 'lib/models/porcelain.rb', line 5217

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5219
5220
5221
# File 'lib/models/porcelain.rb', line 5219

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5221
5222
5223
# File 'lib/models/porcelain.rb', line 5221

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5223
5224
5225
# File 'lib/models/porcelain.rb', line 5223

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5225
5226
5227
# File 'lib/models/porcelain.rb', line 5225

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5227
5228
5229
# File 'lib/models/porcelain.rb', line 5227

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5229
5230
5231
# File 'lib/models/porcelain.rb', line 5229

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5231
5232
5233
# File 'lib/models/porcelain.rb', line 5231

def secret_store_id
  @secret_store_id
end

#session_expiryObject

The length of time in seconds console sessions will live before needing to reauthenticate.



5233
5234
5235
# File 'lib/models/porcelain.rb', line 5233

def session_expiry
  @session_expiry
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5235
5236
5237
# File 'lib/models/porcelain.rb', line 5235

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5237
5238
5239
# File 'lib/models/porcelain.rb', line 5237

def tags
  @tags
end

#workforce_pool_idObject

The ID of the Workforce Identity Pool in GCP to use for federated authentication.



5239
5240
5241
# File 'lib/models/porcelain.rb', line 5239

def workforce_pool_id
  @workforce_pool_id
end

#workforce_provider_idObject

The ID of the Workforce Identity Provider in GCP to use for federated authentication.



5241
5242
5243
# File 'lib/models/porcelain.rb', line 5241

def workforce_provider_id
  @workforce_provider_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5277
5278
5279
5280
5281
5282
5283
# File 'lib/models/porcelain.rb', line 5277

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end