Class: SDM::GCPConsole
- Inherits:
-
Object
- Object
- SDM::GCPConsole
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
-
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole
constructor
A new instance of GCPConsole.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPConsole
Returns a new instance of GCPConsole.
7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 |
# File 'lib/models/porcelain.rb', line 7469 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @session_expiry = session_expiry == nil ? 0 : session_expiry @subdomain = subdomain == nil ? "" : subdomain = == nil ? SDM::() : @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7439 7440 7441 |
# File 'lib/models/porcelain.rb', line 7439 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7441 7442 7443 |
# File 'lib/models/porcelain.rb', line 7441 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7443 7444 7445 |
# File 'lib/models/porcelain.rb', line 7443 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7445 7446 7447 |
# File 'lib/models/porcelain.rb', line 7445 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
7447 7448 7449 |
# File 'lib/models/porcelain.rb', line 7447 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
7449 7450 7451 |
# File 'lib/models/porcelain.rb', line 7449 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7451 7452 7453 |
# File 'lib/models/porcelain.rb', line 7451 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
7453 7454 7455 |
# File 'lib/models/porcelain.rb', line 7453 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7455 7456 7457 |
# File 'lib/models/porcelain.rb', line 7455 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7457 7458 7459 |
# File 'lib/models/porcelain.rb', line 7457 def secret_store_id @secret_store_id end |
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
7459 7460 7461 |
# File 'lib/models/porcelain.rb', line 7459 def session_expiry @session_expiry end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7461 7462 7463 |
# File 'lib/models/porcelain.rb', line 7461 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7463 7464 7465 |
# File 'lib/models/porcelain.rb', line 7463 def end |
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
7465 7466 7467 |
# File 'lib/models/porcelain.rb', line 7465 def workforce_pool_id @workforce_pool_id end |
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
7467 7468 7469 |
# File 'lib/models/porcelain.rb', line 7467 def workforce_provider_id @workforce_provider_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7503 7504 7505 7506 7507 7508 7509 |
# File 'lib/models/porcelain.rb', line 7503 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |