Class: SDM::GCPWIF

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, project_id: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPWIF

Returns a new instance of GCPWIF.



7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
7648
7649
7650
7651
7652
7653
7654
7655
# File 'lib/models/porcelain.rb', line 7619

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  project_id: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  session_expiry: nil,
  subdomain: nil,
  tags: nil,
  workforce_pool_id: nil,
  workforce_provider_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @project_id = project_id == nil ? "" : project_id
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @session_expiry = session_expiry == nil ? 0 : session_expiry
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id
  @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7585
7586
7587
# File 'lib/models/porcelain.rb', line 7585

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7587
7588
7589
# File 'lib/models/porcelain.rb', line 7587

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7589
7590
7591
# File 'lib/models/porcelain.rb', line 7589

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7591
7592
7593
# File 'lib/models/porcelain.rb', line 7591

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



7593
7594
7595
# File 'lib/models/porcelain.rb', line 7593

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



7595
7596
7597
# File 'lib/models/porcelain.rb', line 7595

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



7597
7598
7599
# File 'lib/models/porcelain.rb', line 7597

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7599
7600
7601
# File 'lib/models/porcelain.rb', line 7599

def port_override
  @port_override
end

#project_idObject

When specified, all project scoped requests will use this Project ID, overriding the project ID specified by clients



7601
7602
7603
# File 'lib/models/porcelain.rb', line 7601

def project_id
  @project_id
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7603
7604
7605
# File 'lib/models/porcelain.rb', line 7603

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



7605
7606
7607
# File 'lib/models/porcelain.rb', line 7605

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7607
7608
7609
# File 'lib/models/porcelain.rb', line 7607

def secret_store_id
  @secret_store_id
end

#session_expiryObject

The length of time in seconds console sessions will live before needing to reauthenticate.



7609
7610
7611
# File 'lib/models/porcelain.rb', line 7609

def session_expiry
  @session_expiry
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7611
7612
7613
# File 'lib/models/porcelain.rb', line 7611

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7613
7614
7615
# File 'lib/models/porcelain.rb', line 7613

def tags
  @tags
end

#workforce_pool_idObject

The ID of the Workforce Identity Pool in GCP to use for federated authentication.



7615
7616
7617
# File 'lib/models/porcelain.rb', line 7615

def workforce_pool_id
  @workforce_pool_id
end

#workforce_provider_idObject

The ID of the Workforce Identity Provider in GCP to use for federated authentication.



7617
7618
7619
# File 'lib/models/porcelain.rb', line 7617

def workforce_provider_id
  @workforce_provider_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7657
7658
7659
7660
7661
7662
7663
# File 'lib/models/porcelain.rb', line 7657

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end