Class: SDM::GCPWIF
- Inherits:
-
Object
- Object
- SDM::GCPWIF
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#project_id ⇒ Object
When specified, all project scoped requests will use this Project ID, overriding the project ID specified by clients.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
-
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, project_id: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPWIF
constructor
A new instance of GCPWIF.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, project_id: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPWIF
Returns a new instance of GCPWIF.
7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 7251 |
# File 'lib/models/porcelain.rb', line 7215 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, project_id: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @project_id = project_id == nil ? "" : project_id @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @scopes = scopes == nil ? "" : scopes @secret_store_id = secret_store_id == nil ? "" : secret_store_id @session_expiry = session_expiry == nil ? 0 : session_expiry @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7181 7182 7183 |
# File 'lib/models/porcelain.rb', line 7181 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7183 7184 7185 |
# File 'lib/models/porcelain.rb', line 7183 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7185 7186 7187 |
# File 'lib/models/porcelain.rb', line 7185 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7187 7188 7189 |
# File 'lib/models/porcelain.rb', line 7187 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
7189 7190 7191 |
# File 'lib/models/porcelain.rb', line 7189 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
7191 7192 7193 |
# File 'lib/models/porcelain.rb', line 7191 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7193 7194 7195 |
# File 'lib/models/porcelain.rb', line 7193 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
7195 7196 7197 |
# File 'lib/models/porcelain.rb', line 7195 def port_override @port_override end |
#project_id ⇒ Object
When specified, all project scoped requests will use this Project ID, overriding the project ID specified by clients
7197 7198 7199 |
# File 'lib/models/porcelain.rb', line 7197 def project_id @project_id end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7199 7200 7201 |
# File 'lib/models/porcelain.rb', line 7199 def proxy_cluster_id @proxy_cluster_id end |
#scopes ⇒ Object
Space separated scopes that this login should assume into when authenticating.
7201 7202 7203 |
# File 'lib/models/porcelain.rb', line 7201 def scopes @scopes end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7203 7204 7205 |
# File 'lib/models/porcelain.rb', line 7203 def secret_store_id @secret_store_id end |
#session_expiry ⇒ Object
The length of time in seconds console sessions will live before needing to reauthenticate.
7205 7206 7207 |
# File 'lib/models/porcelain.rb', line 7205 def session_expiry @session_expiry end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
7207 7208 7209 |
# File 'lib/models/porcelain.rb', line 7207 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7209 7210 7211 |
# File 'lib/models/porcelain.rb', line 7209 def @tags end |
#workforce_pool_id ⇒ Object
The ID of the Workforce Identity Pool in GCP to use for federated authentication.
7211 7212 7213 |
# File 'lib/models/porcelain.rb', line 7211 def workforce_pool_id @workforce_pool_id end |
#workforce_provider_id ⇒ Object
The ID of the Workforce Identity Provider in GCP to use for federated authentication.
7213 7214 7215 |
# File 'lib/models/porcelain.rb', line 7213 def workforce_provider_id @workforce_provider_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7253 7254 7255 7256 7257 7258 7259 |
# File 'lib/models/porcelain.rb', line 7253 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |