Class: SDM::GCPWIF

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, project_id: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPWIF

Returns a new instance of GCPWIF.



6690
6691
6692
6693
6694
6695
6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
6720
6721
6722
6723
6724
6725
6726
# File 'lib/models/porcelain.rb', line 6690

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  project_id: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  session_expiry: nil,
  subdomain: nil,
  tags: nil,
  workforce_pool_id: nil,
  workforce_provider_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @project_id = project_id == nil ? "" : project_id
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @session_expiry = session_expiry == nil ? 0 : session_expiry
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id
  @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6656
6657
6658
# File 'lib/models/porcelain.rb', line 6656

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6658
6659
6660
# File 'lib/models/porcelain.rb', line 6658

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6660
6661
6662
# File 'lib/models/porcelain.rb', line 6660

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6662
6663
6664
# File 'lib/models/porcelain.rb', line 6662

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



6664
6665
6666
# File 'lib/models/porcelain.rb', line 6664

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



6666
6667
6668
# File 'lib/models/porcelain.rb', line 6666

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



6668
6669
6670
# File 'lib/models/porcelain.rb', line 6668

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6670
6671
6672
# File 'lib/models/porcelain.rb', line 6670

def port_override
  @port_override
end

#project_idObject

When specified, all project scoped requests will use this Project ID, overriding the project ID specified by clients



6672
6673
6674
# File 'lib/models/porcelain.rb', line 6672

def project_id
  @project_id
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6674
6675
6676
# File 'lib/models/porcelain.rb', line 6674

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



6676
6677
6678
# File 'lib/models/porcelain.rb', line 6676

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6678
6679
6680
# File 'lib/models/porcelain.rb', line 6678

def secret_store_id
  @secret_store_id
end

#session_expiryObject

The length of time in seconds console sessions will live before needing to reauthenticate.



6680
6681
6682
# File 'lib/models/porcelain.rb', line 6680

def session_expiry
  @session_expiry
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



6682
6683
6684
# File 'lib/models/porcelain.rb', line 6682

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6684
6685
6686
# File 'lib/models/porcelain.rb', line 6684

def tags
  @tags
end

#workforce_pool_idObject

The ID of the Workforce Identity Pool in GCP to use for federated authentication.



6686
6687
6688
# File 'lib/models/porcelain.rb', line 6686

def workforce_pool_id
  @workforce_pool_id
end

#workforce_provider_idObject

The ID of the Workforce Identity Provider in GCP to use for federated authentication.



6688
6689
6690
# File 'lib/models/porcelain.rb', line 6688

def workforce_provider_id
  @workforce_provider_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6728
6729
6730
6731
6732
6733
6734
# File 'lib/models/porcelain.rb', line 6728

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end