Class: SDM::GCPWIF

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, project_id: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPWIF

Returns a new instance of GCPWIF.



5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
5797
5798
5799
5800
5801
5802
5803
5804
5805
5806
5807
5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
5819
5820
5821
5822
# File 'lib/models/porcelain.rb', line 5786

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  project_id: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  session_expiry: nil,
  subdomain: nil,
  tags: nil,
  workforce_pool_id: nil,
  workforce_provider_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @project_id = project_id == nil ? "" : project_id
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @session_expiry = session_expiry == nil ? 0 : session_expiry
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id
  @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5752
5753
5754
# File 'lib/models/porcelain.rb', line 5752

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5754
5755
5756
# File 'lib/models/porcelain.rb', line 5754

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5756
5757
5758
# File 'lib/models/porcelain.rb', line 5756

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5758
5759
5760
# File 'lib/models/porcelain.rb', line 5758

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5760
5761
5762
# File 'lib/models/porcelain.rb', line 5760

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5762
5763
5764
# File 'lib/models/porcelain.rb', line 5762

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5764
5765
5766
# File 'lib/models/porcelain.rb', line 5764

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5766
5767
5768
# File 'lib/models/porcelain.rb', line 5766

def port_override
  @port_override
end

#project_idObject

When specified, all project scoped requests will use this Project ID, overriding the project ID specified by clients



5768
5769
5770
# File 'lib/models/porcelain.rb', line 5768

def project_id
  @project_id
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5770
5771
5772
# File 'lib/models/porcelain.rb', line 5770

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



5772
5773
5774
# File 'lib/models/porcelain.rb', line 5772

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5774
5775
5776
# File 'lib/models/porcelain.rb', line 5774

def secret_store_id
  @secret_store_id
end

#session_expiryObject

The length of time in seconds console sessions will live before needing to reauthenticate.



5776
5777
5778
# File 'lib/models/porcelain.rb', line 5776

def session_expiry
  @session_expiry
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5778
5779
5780
# File 'lib/models/porcelain.rb', line 5778

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5780
5781
5782
# File 'lib/models/porcelain.rb', line 5780

def tags
  @tags
end

#workforce_pool_idObject

The ID of the Workforce Identity Pool in GCP to use for federated authentication.



5782
5783
5784
# File 'lib/models/porcelain.rb', line 5782

def workforce_pool_id
  @workforce_pool_id
end

#workforce_provider_idObject

The ID of the Workforce Identity Provider in GCP to use for federated authentication.



5784
5785
5786
# File 'lib/models/porcelain.rb', line 5784

def workforce_provider_id
  @workforce_provider_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5824
5825
5826
5827
5828
5829
5830
# File 'lib/models/porcelain.rb', line 5824

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end