Class: SDM::GCPWIF

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, project_id: nil, proxy_cluster_id: nil, scopes: nil, secret_store_id: nil, session_expiry: nil, subdomain: nil, tags: nil, workforce_pool_id: nil, workforce_provider_id: nil) ⇒ GCPWIF

Returns a new instance of GCPWIF.



5715
5716
5717
5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
5745
5746
5747
5748
5749
5750
5751
# File 'lib/models/porcelain.rb', line 5715

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  project_id: nil,
  proxy_cluster_id: nil,
  scopes: nil,
  secret_store_id: nil,
  session_expiry: nil,
  subdomain: nil,
  tags: nil,
  workforce_pool_id: nil,
  workforce_provider_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @project_id = project_id == nil ? "" : project_id
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @scopes = scopes == nil ? "" : scopes
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @session_expiry = session_expiry == nil ? 0 : session_expiry
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workforce_pool_id = workforce_pool_id == nil ? "" : workforce_pool_id
  @workforce_provider_id = workforce_provider_id == nil ? "" : workforce_provider_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5681
5682
5683
# File 'lib/models/porcelain.rb', line 5681

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5683
5684
5685
# File 'lib/models/porcelain.rb', line 5683

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5685
5686
5687
# File 'lib/models/porcelain.rb', line 5685

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5687
5688
5689
# File 'lib/models/porcelain.rb', line 5687

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5689
5690
5691
# File 'lib/models/porcelain.rb', line 5689

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5691
5692
5693
# File 'lib/models/porcelain.rb', line 5691

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5693
5694
5695
# File 'lib/models/porcelain.rb', line 5693

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5695
5696
5697
# File 'lib/models/porcelain.rb', line 5695

def port_override
  @port_override
end

#project_idObject

When specified, all project scoped requests will use this Project ID, overriding the project ID specified by clients



5697
5698
5699
# File 'lib/models/porcelain.rb', line 5697

def project_id
  @project_id
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5699
5700
5701
# File 'lib/models/porcelain.rb', line 5699

def proxy_cluster_id
  @proxy_cluster_id
end

#scopesObject

Space separated scopes that this login should assume into when authenticating.



5701
5702
5703
# File 'lib/models/porcelain.rb', line 5701

def scopes
  @scopes
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5703
5704
5705
# File 'lib/models/porcelain.rb', line 5703

def secret_store_id
  @secret_store_id
end

#session_expiryObject

The length of time in seconds console sessions will live before needing to reauthenticate.



5705
5706
5707
# File 'lib/models/porcelain.rb', line 5705

def session_expiry
  @session_expiry
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5707
5708
5709
# File 'lib/models/porcelain.rb', line 5707

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5709
5710
5711
# File 'lib/models/porcelain.rb', line 5709

def tags
  @tags
end

#workforce_pool_idObject

The ID of the Workforce Identity Pool in GCP to use for federated authentication.



5711
5712
5713
# File 'lib/models/porcelain.rb', line 5711

def workforce_pool_id
  @workforce_pool_id
end

#workforce_provider_idObject

The ID of the Workforce Identity Provider in GCP to use for federated authentication.



5713
5714
5715
# File 'lib/models/porcelain.rb', line 5713

def workforce_provider_id
  @workforce_provider_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5753
5754
5755
5756
5757
5758
5759
# File 'lib/models/porcelain.rb', line 5753

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end