Class: SDM::Gateway

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Gateway represents a StrongDM CLI installation running in gateway mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_address: nil, connects_to: nil, device: nil, gateway_filter: nil, id: nil, listen_address: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Gateway

Returns a new instance of Gateway.



3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
3812
3813
3814
# File 'lib/models/porcelain.rb', line 3788

def initialize(
  bind_address: nil,
  connects_to: nil,
  device: nil,
  gateway_filter: nil,
  id: nil,
  listen_address: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @bind_address = bind_address == nil ? "" : bind_address
  @connects_to = connects_to == nil ? "" : connects_to
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @listen_address = listen_address == nil ? "" : listen_address
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#bind_addressObject

The hostname/port tuple which the gateway daemon will bind to. If not provided on create, set to "0.0.0.0:listen_address_port".



3747
3748
3749
# File 'lib/models/porcelain.rb', line 3747

def bind_address
  @bind_address
end

#connects_toObject

ConnectsTo can be used to restrict the peering between relays and gateways.



3750
3751
3752
# File 'lib/models/porcelain.rb', line 3750

def connects_to
  @connects_to
end

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



3753
3754
3755
# File 'lib/models/porcelain.rb', line 3753

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



3756
3757
3758
# File 'lib/models/porcelain.rb', line 3756

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Gateway.



3758
3759
3760
# File 'lib/models/porcelain.rb', line 3758

def id
  @id
end

#listen_addressObject

The public hostname/port tuple at which the gateway will be accessible to clients.



3760
3761
3762
# File 'lib/models/porcelain.rb', line 3760

def listen_address
  @listen_address
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



3763
3764
3765
# File 'lib/models/porcelain.rb', line 3763

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



3776
3777
3778
# File 'lib/models/porcelain.rb', line 3776

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Gateway. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



3778
3779
3780
# File 'lib/models/porcelain.rb', line 3778

def name
  @name
end

#stateObject

The current state of the gateway. One of: "new", "verifying_restart", "restarting", "started", "stopped", "dead", "unknown"



3781
3782
3783
# File 'lib/models/porcelain.rb', line 3781

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



3783
3784
3785
# File 'lib/models/porcelain.rb', line 3783

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



3786
3787
3788
# File 'lib/models/porcelain.rb', line 3786

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3816
3817
3818
3819
3820
3821
3822
# File 'lib/models/porcelain.rb', line 3816

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end