Class: SDM::Gateway

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Gateway represents a StrongDM CLI installation running in gateway mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_address: nil, device: nil, gateway_filter: nil, id: nil, listen_address: nil, location: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Gateway

Returns a new instance of Gateway.



3367
3368
3369
3370
3371
3372
3373
3374
3375
3376
3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
# File 'lib/models/porcelain.rb', line 3367

def initialize(
  bind_address: nil,
  device: nil,
  gateway_filter: nil,
  id: nil,
  listen_address: nil,
  location: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @bind_address = bind_address == nil ? "" : bind_address
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @listen_address = listen_address == nil ? "" : listen_address
  @location = location == nil ? "" : location
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#bind_addressObject

The hostname/port tuple which the gateway daemon will bind to. If not provided on create, set to "0.0.0.0:listen_address_port".



3342
3343
3344
# File 'lib/models/porcelain.rb', line 3342

def bind_address
  @bind_address
end

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



3345
3346
3347
# File 'lib/models/porcelain.rb', line 3345

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways.



3348
3349
3350
# File 'lib/models/porcelain.rb', line 3348

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Gateway.



3350
3351
3352
# File 'lib/models/porcelain.rb', line 3350

def id
  @id
end

#listen_addressObject

The public hostname/port tuple at which the gateway will be accessible to clients.



3352
3353
3354
# File 'lib/models/porcelain.rb', line 3352

def listen_address
  @listen_address
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



3355
3356
3357
# File 'lib/models/porcelain.rb', line 3355

def location
  @location
end

#nameObject

Unique human-readable name of the Gateway. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



3357
3358
3359
# File 'lib/models/porcelain.rb', line 3357

def name
  @name
end

#stateObject

The current state of the gateway. One of: "new", "verifying_restart", "restarting", "started", "stopped", "dead", "unknown"



3360
3361
3362
# File 'lib/models/porcelain.rb', line 3360

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



3362
3363
3364
# File 'lib/models/porcelain.rb', line 3362

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



3365
3366
3367
# File 'lib/models/porcelain.rb', line 3365

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3391
3392
3393
3394
3395
3396
3397
# File 'lib/models/porcelain.rb', line 3391

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end