Class: SDM::Gateway

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Gateway represents a StrongDM CLI installation running in gateway mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_address: nil, device: nil, gateway_filter: nil, id: nil, listen_address: nil, location: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Gateway

Returns a new instance of Gateway.



2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
# File 'lib/models/porcelain.rb', line 2922

def initialize(
  bind_address: nil,
  device: nil,
  gateway_filter: nil,
  id: nil,
  listen_address: nil,
  location: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @bind_address = bind_address == nil ? "" : bind_address
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @listen_address = listen_address == nil ? "" : listen_address
  @location = location == nil ? "" : location
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#bind_addressObject

The hostname/port tuple which the gateway daemon will bind to. If not provided on create, set to "0.0.0.0:listen_address_port".



2897
2898
2899
# File 'lib/models/porcelain.rb', line 2897

def bind_address
  @bind_address
end

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



2900
2901
2902
# File 'lib/models/porcelain.rb', line 2900

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways.



2903
2904
2905
# File 'lib/models/porcelain.rb', line 2903

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Gateway.



2905
2906
2907
# File 'lib/models/porcelain.rb', line 2905

def id
  @id
end

#listen_addressObject

The public hostname/port tuple at which the gateway will be accessible to clients.



2907
2908
2909
# File 'lib/models/porcelain.rb', line 2907

def listen_address
  @listen_address
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



2910
2911
2912
# File 'lib/models/porcelain.rb', line 2910

def location
  @location
end

#nameObject

Unique human-readable name of the Gateway. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



2912
2913
2914
# File 'lib/models/porcelain.rb', line 2912

def name
  @name
end

#stateObject

The current state of the gateway. One of: "new", "verifying_restart", "restarting", "started", "stopped", "dead", "unknown"



2915
2916
2917
# File 'lib/models/porcelain.rb', line 2915

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



2917
2918
2919
# File 'lib/models/porcelain.rb', line 2917

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



2920
2921
2922
# File 'lib/models/porcelain.rb', line 2920

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2946
2947
2948
2949
2950
2951
2952
# File 'lib/models/porcelain.rb', line 2946

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end