Class: SDM::GoogleGKE
- Inherits:
-
Object
- Object
- SDM::GoogleGKE
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
-
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_key ⇒ Object
The service account key to authenticate with.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE
constructor
A new instance of GoogleGKE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE
Returns a new instance of GoogleGKE.
7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 |
# File 'lib/models/porcelain.rb', line 7448 def initialize( allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil ) @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled @discovery_username = discovery_username == nil ? "" : discovery_username @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_key = service_account_key == nil ? "" : service_account_key @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
7409 7410 7411 |
# File 'lib/models/porcelain.rb', line 7409 def allow_resource_role_bypass @allow_resource_role_bypass end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7411 7412 7413 |
# File 'lib/models/porcelain.rb', line 7411 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
7413 7414 7415 |
# File 'lib/models/porcelain.rb', line 7413 def @certificate_authority end |
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
7415 7416 7417 |
# File 'lib/models/porcelain.rb', line 7415 def discovery_enabled @discovery_enabled end |
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
7418 7419 7420 |
# File 'lib/models/porcelain.rb', line 7418 def discovery_username @discovery_username end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7420 7421 7422 |
# File 'lib/models/porcelain.rb', line 7420 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
7422 7423 7424 |
# File 'lib/models/porcelain.rb', line 7422 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
7424 7425 7426 |
# File 'lib/models/porcelain.rb', line 7424 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7426 7427 7428 |
# File 'lib/models/porcelain.rb', line 7426 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7428 7429 7430 |
# File 'lib/models/porcelain.rb', line 7428 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
7430 7431 7432 |
# File 'lib/models/porcelain.rb', line 7430 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
7432 7433 7434 |
# File 'lib/models/porcelain.rb', line 7432 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7434 7435 7436 |
# File 'lib/models/porcelain.rb', line 7434 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
7436 7437 7438 |
# File 'lib/models/porcelain.rb', line 7436 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7438 7439 7440 |
# File 'lib/models/porcelain.rb', line 7438 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7440 7441 7442 |
# File 'lib/models/porcelain.rb', line 7440 def secret_store_id @secret_store_id end |
#service_account_key ⇒ Object
The service account key to authenticate with.
7442 7443 7444 |
# File 'lib/models/porcelain.rb', line 7442 def service_account_key @service_account_key end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
7444 7445 7446 |
# File 'lib/models/porcelain.rb', line 7444 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7446 7447 7448 |
# File 'lib/models/porcelain.rb', line 7446 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7490 7491 7492 7493 7494 7495 7496 |
# File 'lib/models/porcelain.rb', line 7490 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |