Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
# File 'lib/models/porcelain.rb', line 6338

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



6299
6300
6301
# File 'lib/models/porcelain.rb', line 6299

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6301
6302
6303
# File 'lib/models/porcelain.rb', line 6301

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6303
6304
6305
# File 'lib/models/porcelain.rb', line 6303

def certificate_authority
  @certificate_authority
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



6305
6306
6307
# File 'lib/models/porcelain.rb', line 6305

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



6308
6309
6310
# File 'lib/models/porcelain.rb', line 6308

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6310
6311
6312
# File 'lib/models/porcelain.rb', line 6310

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



6312
6313
6314
# File 'lib/models/porcelain.rb', line 6312

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6314
6315
6316
# File 'lib/models/porcelain.rb', line 6314

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6316
6317
6318
# File 'lib/models/porcelain.rb', line 6316

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6318
6319
6320
# File 'lib/models/porcelain.rb', line 6318

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



6320
6321
6322
# File 'lib/models/porcelain.rb', line 6320

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



6322
6323
6324
# File 'lib/models/porcelain.rb', line 6322

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



6324
6325
6326
# File 'lib/models/porcelain.rb', line 6324

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



6326
6327
6328
# File 'lib/models/porcelain.rb', line 6326

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6328
6329
6330
# File 'lib/models/porcelain.rb', line 6328

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6330
6331
6332
# File 'lib/models/porcelain.rb', line 6330

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



6332
6333
6334
# File 'lib/models/porcelain.rb', line 6332

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6334
6335
6336
# File 'lib/models/porcelain.rb', line 6334

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6336
6337
6338
# File 'lib/models/porcelain.rb', line 6336

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6380
6381
6382
6383
6384
6385
6386
# File 'lib/models/porcelain.rb', line 6380

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end