Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
5951
# File 'lib/models/porcelain.rb', line 5911

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



5872
5873
5874
# File 'lib/models/porcelain.rb', line 5872

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5874
5875
5876
# File 'lib/models/porcelain.rb', line 5874

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5876
5877
5878
# File 'lib/models/porcelain.rb', line 5876

def certificate_authority
  @certificate_authority
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



5878
5879
5880
# File 'lib/models/porcelain.rb', line 5878

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



5881
5882
5883
# File 'lib/models/porcelain.rb', line 5881

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5883
5884
5885
# File 'lib/models/porcelain.rb', line 5883

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



5885
5886
5887
# File 'lib/models/porcelain.rb', line 5885

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5887
5888
5889
# File 'lib/models/porcelain.rb', line 5887

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5889
5890
5891
# File 'lib/models/porcelain.rb', line 5889

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5891
5892
5893
# File 'lib/models/porcelain.rb', line 5891

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5893
5894
5895
# File 'lib/models/porcelain.rb', line 5893

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5895
5896
5897
# File 'lib/models/porcelain.rb', line 5895

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5897
5898
5899
# File 'lib/models/porcelain.rb', line 5897

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5899
5900
5901
# File 'lib/models/porcelain.rb', line 5899

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5901
5902
5903
# File 'lib/models/porcelain.rb', line 5901

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5903
5904
5905
# File 'lib/models/porcelain.rb', line 5903

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



5905
5906
5907
# File 'lib/models/porcelain.rb', line 5905

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5907
5908
5909
# File 'lib/models/porcelain.rb', line 5907

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5909
5910
5911
# File 'lib/models/porcelain.rb', line 5909

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5953
5954
5955
5956
5957
5958
5959
# File 'lib/models/porcelain.rb', line 5953

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end