Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



5300
5301
5302
5303
5304
5305
5306
5307
5308
5309
5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
# File 'lib/models/porcelain.rb', line 5300

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



5261
5262
5263
# File 'lib/models/porcelain.rb', line 5261

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5263
5264
5265
# File 'lib/models/porcelain.rb', line 5263

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5265
5266
5267
# File 'lib/models/porcelain.rb', line 5265

def certificate_authority
  @certificate_authority
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



5267
5268
5269
# File 'lib/models/porcelain.rb', line 5267

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



5270
5271
5272
# File 'lib/models/porcelain.rb', line 5270

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5272
5273
5274
# File 'lib/models/porcelain.rb', line 5272

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



5274
5275
5276
# File 'lib/models/porcelain.rb', line 5274

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5276
5277
5278
# File 'lib/models/porcelain.rb', line 5276

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5278
5279
5280
# File 'lib/models/porcelain.rb', line 5278

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5280
5281
5282
# File 'lib/models/porcelain.rb', line 5280

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5282
5283
5284
# File 'lib/models/porcelain.rb', line 5282

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5284
5285
5286
# File 'lib/models/porcelain.rb', line 5284

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5286
5287
5288
# File 'lib/models/porcelain.rb', line 5286

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5288
5289
5290
# File 'lib/models/porcelain.rb', line 5288

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5290
5291
5292
# File 'lib/models/porcelain.rb', line 5290

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5292
5293
5294
# File 'lib/models/porcelain.rb', line 5292

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



5294
5295
5296
# File 'lib/models/porcelain.rb', line 5294

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5296
5297
5298
# File 'lib/models/porcelain.rb', line 5296

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5298
5299
5300
# File 'lib/models/porcelain.rb', line 5298

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5342
5343
5344
5345
5346
5347
5348
# File 'lib/models/porcelain.rb', line 5342

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end