Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
# File 'lib/models/porcelain.rb', line 5071

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



5034
5035
5036
# File 'lib/models/porcelain.rb', line 5034

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5036
5037
5038
# File 'lib/models/porcelain.rb', line 5036

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5038
5039
5040
# File 'lib/models/porcelain.rb', line 5038

def certificate_authority
  @certificate_authority
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



5040
5041
5042
# File 'lib/models/porcelain.rb', line 5040

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



5043
5044
5045
# File 'lib/models/porcelain.rb', line 5043

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5045
5046
5047
# File 'lib/models/porcelain.rb', line 5045

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



5047
5048
5049
# File 'lib/models/porcelain.rb', line 5047

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5049
5050
5051
# File 'lib/models/porcelain.rb', line 5049

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5051
5052
5053
# File 'lib/models/porcelain.rb', line 5051

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5053
5054
5055
# File 'lib/models/porcelain.rb', line 5053

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5055
5056
5057
# File 'lib/models/porcelain.rb', line 5055

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5057
5058
5059
# File 'lib/models/porcelain.rb', line 5057

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5059
5060
5061
# File 'lib/models/porcelain.rb', line 5059

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5061
5062
5063
# File 'lib/models/porcelain.rb', line 5061

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5063
5064
5065
# File 'lib/models/porcelain.rb', line 5063

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



5065
5066
5067
# File 'lib/models/porcelain.rb', line 5065

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5067
5068
5069
# File 'lib/models/porcelain.rb', line 5067

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5069
5070
5071
# File 'lib/models/porcelain.rb', line 5069

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5111
5112
5113
5114
5115
5116
5117
# File 'lib/models/porcelain.rb', line 5111

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end