Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



4913
4914
4915
4916
4917
4918
4919
4920
4921
4922
4923
4924
4925
4926
4927
4928
4929
4930
4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
# File 'lib/models/porcelain.rb', line 4913

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



4876
4877
4878
# File 'lib/models/porcelain.rb', line 4876

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4878
4879
4880
# File 'lib/models/porcelain.rb', line 4878

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4880
4881
4882
# File 'lib/models/porcelain.rb', line 4880

def certificate_authority
  @certificate_authority
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



4882
4883
4884
# File 'lib/models/porcelain.rb', line 4882

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



4885
4886
4887
# File 'lib/models/porcelain.rb', line 4885

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4887
4888
4889
# File 'lib/models/porcelain.rb', line 4887

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



4889
4890
4891
# File 'lib/models/porcelain.rb', line 4889

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4891
4892
4893
# File 'lib/models/porcelain.rb', line 4891

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4893
4894
4895
# File 'lib/models/porcelain.rb', line 4893

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4895
4896
4897
# File 'lib/models/porcelain.rb', line 4895

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



4897
4898
4899
# File 'lib/models/porcelain.rb', line 4897

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



4899
4900
4901
# File 'lib/models/porcelain.rb', line 4899

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



4901
4902
4903
# File 'lib/models/porcelain.rb', line 4901

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



4903
4904
4905
# File 'lib/models/porcelain.rb', line 4903

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4905
4906
4907
# File 'lib/models/porcelain.rb', line 4905

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



4907
4908
4909
# File 'lib/models/porcelain.rb', line 4907

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4909
4910
4911
# File 'lib/models/porcelain.rb', line 4909

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4911
4912
4913
# File 'lib/models/porcelain.rb', line 4911

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4953
4954
4955
4956
4957
4958
4959
# File 'lib/models/porcelain.rb', line 4953

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end