Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
# File 'lib/models/porcelain.rb', line 4069

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4039
4040
4041
# File 'lib/models/porcelain.rb', line 4039

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4041
4042
4043
# File 'lib/models/porcelain.rb', line 4041

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4043
4044
4045
# File 'lib/models/porcelain.rb', line 4043

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



4045
4046
4047
# File 'lib/models/porcelain.rb', line 4045

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4047
4048
4049
# File 'lib/models/porcelain.rb', line 4047

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4049
4050
4051
# File 'lib/models/porcelain.rb', line 4049

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4051
4052
4053
# File 'lib/models/porcelain.rb', line 4051

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4053
4054
4055
# File 'lib/models/porcelain.rb', line 4053

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



4055
4056
4057
# File 'lib/models/porcelain.rb', line 4055

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



4057
4058
4059
# File 'lib/models/porcelain.rb', line 4057

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



4059
4060
4061
# File 'lib/models/porcelain.rb', line 4059

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4061
4062
4063
# File 'lib/models/porcelain.rb', line 4061

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



4063
4064
4065
# File 'lib/models/porcelain.rb', line 4063

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4065
4066
4067
# File 'lib/models/porcelain.rb', line 4065

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4067
4068
4069
# File 'lib/models/porcelain.rb', line 4067

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4103
4104
4105
4106
4107
4108
4109
# File 'lib/models/porcelain.rb', line 4103

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end