Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
# File 'lib/models/porcelain.rb', line 4030

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4000
4001
4002
# File 'lib/models/porcelain.rb', line 4000

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4002
4003
4004
# File 'lib/models/porcelain.rb', line 4002

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4004
4005
4006
# File 'lib/models/porcelain.rb', line 4004

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



4006
4007
4008
# File 'lib/models/porcelain.rb', line 4006

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4008
4009
4010
# File 'lib/models/porcelain.rb', line 4008

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4010
4011
4012
# File 'lib/models/porcelain.rb', line 4010

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4012
4013
4014
# File 'lib/models/porcelain.rb', line 4012

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4014
4015
4016
# File 'lib/models/porcelain.rb', line 4014

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



4016
4017
4018
# File 'lib/models/porcelain.rb', line 4016

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



4018
4019
4020
# File 'lib/models/porcelain.rb', line 4018

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



4020
4021
4022
# File 'lib/models/porcelain.rb', line 4020

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4022
4023
4024
# File 'lib/models/porcelain.rb', line 4022

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



4024
4025
4026
# File 'lib/models/porcelain.rb', line 4024

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4026
4027
4028
# File 'lib/models/porcelain.rb', line 4026

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4028
4029
4030
# File 'lib/models/porcelain.rb', line 4028

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4064
4065
4066
4067
4068
4069
4070
# File 'lib/models/porcelain.rb', line 4064

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end