Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
3888
3889
3890
3891
3892
3893
3894
# File 'lib/models/porcelain.rb', line 3864

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3836
3837
3838
# File 'lib/models/porcelain.rb', line 3836

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



3838
3839
3840
# File 'lib/models/porcelain.rb', line 3838

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3840
3841
3842
# File 'lib/models/porcelain.rb', line 3840

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



3842
3843
3844
# File 'lib/models/porcelain.rb', line 3842

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3844
3845
3846
# File 'lib/models/porcelain.rb', line 3844

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3846
3847
3848
# File 'lib/models/porcelain.rb', line 3846

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3848
3849
3850
# File 'lib/models/porcelain.rb', line 3848

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3850
3851
3852
# File 'lib/models/porcelain.rb', line 3850

def name
  @name
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



3852
3853
3854
# File 'lib/models/porcelain.rb', line 3852

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



3854
3855
3856
# File 'lib/models/porcelain.rb', line 3854

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3856
3857
3858
# File 'lib/models/porcelain.rb', line 3856

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



3858
3859
3860
# File 'lib/models/porcelain.rb', line 3858

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3860
3861
3862
# File 'lib/models/porcelain.rb', line 3860

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3862
3863
3864
# File 'lib/models/porcelain.rb', line 3862

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3896
3897
3898
3899
3900
3901
3902
# File 'lib/models/porcelain.rb', line 3896

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end