Class: SDM::GoogleGKE
- Inherits:
-
Object
- Object
- SDM::GoogleGKE
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
-
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE
constructor
A new instance of GoogleGKE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE
Returns a new instance of GoogleGKE.
3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 |
# File 'lib/models/porcelain.rb', line 3750 def initialize( bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_key = service_account_key == nil ? "" : service_account_key @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3722 3723 3724 |
# File 'lib/models/porcelain.rb', line 3722 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3724 3725 3726 |
# File 'lib/models/porcelain.rb', line 3724 def @certificate_authority end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3726 3727 3728 |
# File 'lib/models/porcelain.rb', line 3726 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
3728 3729 3730 |
# File 'lib/models/porcelain.rb', line 3728 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3730 3731 3732 |
# File 'lib/models/porcelain.rb', line 3730 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3732 3733 3734 |
# File 'lib/models/porcelain.rb', line 3732 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3734 3735 3736 |
# File 'lib/models/porcelain.rb', line 3734 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3736 3737 3738 |
# File 'lib/models/porcelain.rb', line 3736 def name @name end |
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
3738 3739 3740 |
# File 'lib/models/porcelain.rb', line 3738 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
3740 3741 3742 |
# File 'lib/models/porcelain.rb', line 3740 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3742 3743 3744 |
# File 'lib/models/porcelain.rb', line 3742 def secret_store_id @secret_store_id end |
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
3744 3745 3746 |
# File 'lib/models/porcelain.rb', line 3744 def service_account_key @service_account_key end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3746 3747 3748 |
# File 'lib/models/porcelain.rb', line 3746 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3748 3749 3750 |
# File 'lib/models/porcelain.rb', line 3748 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3782 3783 3784 3785 3786 3787 3788 |
# File 'lib/models/porcelain.rb', line 3782 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |