Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/models/porcelain.rb', line 3726

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3698
3699
3700
# File 'lib/models/porcelain.rb', line 3698

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3700
3701
3702
# File 'lib/models/porcelain.rb', line 3700

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3702
3703
3704
# File 'lib/models/porcelain.rb', line 3702

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3704
3705
3706
# File 'lib/models/porcelain.rb', line 3704

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3706
3707
3708
# File 'lib/models/porcelain.rb', line 3706

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3708
3709
3710
# File 'lib/models/porcelain.rb', line 3708

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3710
3711
3712
# File 'lib/models/porcelain.rb', line 3710

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3712
3713
3714
# File 'lib/models/porcelain.rb', line 3712

def name
  @name
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3714
3715
3716
# File 'lib/models/porcelain.rb', line 3714

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3716
3717
3718
# File 'lib/models/porcelain.rb', line 3716

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3718
3719
3720
# File 'lib/models/porcelain.rb', line 3718

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



3720
3721
3722
# File 'lib/models/porcelain.rb', line 3720

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3722
3723
3724
# File 'lib/models/porcelain.rb', line 3722

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3724
3725
3726
# File 'lib/models/porcelain.rb', line 3724

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3758
3759
3760
3761
3762
3763
3764
# File 'lib/models/porcelain.rb', line 3758

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end