Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



3442
3443
3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/models/porcelain.rb', line 3442

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  service_account_key: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3416
3417
3418
# File 'lib/models/porcelain.rb', line 3416

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3418
3419
3420
# File 'lib/models/porcelain.rb', line 3418

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3420
3421
3422
# File 'lib/models/porcelain.rb', line 3420

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3422
3423
3424
# File 'lib/models/porcelain.rb', line 3422

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3424
3425
3426
# File 'lib/models/porcelain.rb', line 3424

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3426
3427
3428
# File 'lib/models/porcelain.rb', line 3426

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3428
3429
3430
# File 'lib/models/porcelain.rb', line 3428

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3430
3431
3432
# File 'lib/models/porcelain.rb', line 3430

def name
  @name
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3432
3433
3434
# File 'lib/models/porcelain.rb', line 3432

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3434
3435
3436
# File 'lib/models/porcelain.rb', line 3434

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3436
3437
3438
# File 'lib/models/porcelain.rb', line 3436

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



3438
3439
3440
# File 'lib/models/porcelain.rb', line 3438

def 
  @service_account_key
end

#tagsObject

Tags is a map of key, value pairs.



3440
3441
3442
# File 'lib/models/porcelain.rb', line 3440

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3472
3473
3474
3475
3476
3477
3478
# File 'lib/models/porcelain.rb', line 3472

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end