Class: SDM::GoogleGKE
- Inherits:
-
Object
- Object
- SDM::GoogleGKE
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
-
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKE
constructor
A new instance of GoogleGKE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKE
Returns a new instance of GoogleGKE.
3104 3105 3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 |
# File 'lib/models/porcelain.rb', line 3104 def initialize( bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_key = service_account_key == nil ? "" : service_account_key @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3078 3079 3080 |
# File 'lib/models/porcelain.rb', line 3078 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3080 3081 3082 |
# File 'lib/models/porcelain.rb', line 3080 def @certificate_authority end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3082 3083 3084 |
# File 'lib/models/porcelain.rb', line 3082 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
3084 3085 3086 |
# File 'lib/models/porcelain.rb', line 3084 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3086 3087 3088 |
# File 'lib/models/porcelain.rb', line 3086 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3088 3089 3090 |
# File 'lib/models/porcelain.rb', line 3088 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3090 3091 3092 |
# File 'lib/models/porcelain.rb', line 3090 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3092 3093 3094 |
# File 'lib/models/porcelain.rb', line 3092 def name @name end |
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
3094 3095 3096 |
# File 'lib/models/porcelain.rb', line 3094 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
3096 3097 3098 |
# File 'lib/models/porcelain.rb', line 3096 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3098 3099 3100 |
# File 'lib/models/porcelain.rb', line 3098 def secret_store_id @secret_store_id end |
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
3100 3101 3102 |
# File 'lib/models/porcelain.rb', line 3100 def service_account_key @service_account_key end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3102 3103 3104 |
# File 'lib/models/porcelain.rb', line 3102 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3134 3135 3136 3137 3138 3139 3140 |
# File 'lib/models/porcelain.rb', line 3134 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |