Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
# File 'lib/models/porcelain.rb', line 3105

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  service_account_key: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3079
3080
3081
# File 'lib/models/porcelain.rb', line 3079

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3081
3082
3083
# File 'lib/models/porcelain.rb', line 3081

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3083
3084
3085
# File 'lib/models/porcelain.rb', line 3083

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3085
3086
3087
# File 'lib/models/porcelain.rb', line 3085

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3087
3088
3089
# File 'lib/models/porcelain.rb', line 3087

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3089
3090
3091
# File 'lib/models/porcelain.rb', line 3089

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3091
3092
3093
# File 'lib/models/porcelain.rb', line 3091

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3093
3094
3095
# File 'lib/models/porcelain.rb', line 3093

def name
  @name
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3095
3096
3097
# File 'lib/models/porcelain.rb', line 3095

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3097
3098
3099
# File 'lib/models/porcelain.rb', line 3097

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3099
3100
3101
# File 'lib/models/porcelain.rb', line 3099

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



3101
3102
3103
# File 'lib/models/porcelain.rb', line 3101

def 
  @service_account_key
end

#tagsObject

Tags is a map of key, value pairs.



3103
3104
3105
# File 'lib/models/porcelain.rb', line 3103

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3135
3136
3137
3138
3139
3140
3141
# File 'lib/models/porcelain.rb', line 3135

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end