Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
# File 'lib/models/porcelain.rb', line 2993

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  service_account_key: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2967
2968
2969
# File 'lib/models/porcelain.rb', line 2967

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



2969
2970
2971
# File 'lib/models/porcelain.rb', line 2969

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2971
2972
2973
# File 'lib/models/porcelain.rb', line 2971

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



2973
2974
2975
# File 'lib/models/porcelain.rb', line 2973

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



2975
2976
2977
# File 'lib/models/porcelain.rb', line 2975

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2977
2978
2979
# File 'lib/models/porcelain.rb', line 2977

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2979
2980
2981
# File 'lib/models/porcelain.rb', line 2979

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2981
2982
2983
# File 'lib/models/porcelain.rb', line 2981

def name
  @name
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



2983
2984
2985
# File 'lib/models/porcelain.rb', line 2983

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



2985
2986
2987
# File 'lib/models/porcelain.rb', line 2985

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2987
2988
2989
# File 'lib/models/porcelain.rb', line 2987

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



2989
2990
2991
# File 'lib/models/porcelain.rb', line 2989

def 
  @service_account_key
end

#tagsObject

Tags is a map of key, value pairs.



2991
2992
2993
# File 'lib/models/porcelain.rb', line 2991

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3023
3024
3025
3026
3027
3028
3029
# File 'lib/models/porcelain.rb', line 3023

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end