Class: SDM::GoogleGKE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKE

Returns a new instance of GoogleGKE.



2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
2679
# File 'lib/models/porcelain.rb', line 2651

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  service_account_key: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



2625
2626
2627
# File 'lib/models/porcelain.rb', line 2625

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



2627
2628
2629
# File 'lib/models/porcelain.rb', line 2627

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



2629
2630
2631
# File 'lib/models/porcelain.rb', line 2629

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



2631
2632
2633
# File 'lib/models/porcelain.rb', line 2631

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



2633
2634
2635
# File 'lib/models/porcelain.rb', line 2633

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



2635
2636
2637
# File 'lib/models/porcelain.rb', line 2635

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



2637
2638
2639
# File 'lib/models/porcelain.rb', line 2637

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



2639
2640
2641
# File 'lib/models/porcelain.rb', line 2639

def name
  @name
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



2641
2642
2643
# File 'lib/models/porcelain.rb', line 2641

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



2643
2644
2645
# File 'lib/models/porcelain.rb', line 2643

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



2645
2646
2647
# File 'lib/models/porcelain.rb', line 2645

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



2647
2648
2649
# File 'lib/models/porcelain.rb', line 2647

def 
  @service_account_key
end

#tagsObject

Tags is a map of key, value pairs.



2649
2650
2651
# File 'lib/models/porcelain.rb', line 2649

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



2681
2682
2683
2684
2685
2686
2687
# File 'lib/models/porcelain.rb', line 2681

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end