Class: SDM::GoogleGKE
- Inherits:
-
Object
- Object
- SDM::GoogleGKE
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKE
constructor
A new instance of GoogleGKE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKE
Returns a new instance of GoogleGKE.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 |
# File 'lib/models/porcelain.rb', line 3264 def initialize( certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil ) if != nil @certificate_authority = end if egress_filter != nil @egress_filter = egress_filter end if endpoint != nil @endpoint = endpoint end if healthcheck_namespace != nil @healthcheck_namespace = healthcheck_namespace end if healthy != nil @healthy = healthy end if id != nil @id = id end if name != nil @name = name end if secret_store_id != nil @secret_store_id = secret_store_id end if service_account_key != nil @service_account_key = service_account_key end if != nil @tags = end end |
Instance Attribute Details
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3244 3245 3246 |
# File 'lib/models/porcelain.rb', line 3244 def @certificate_authority end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3246 3247 3248 |
# File 'lib/models/porcelain.rb', line 3246 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
3248 3249 3250 |
# File 'lib/models/porcelain.rb', line 3248 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to `default`.
3250 3251 3252 |
# File 'lib/models/porcelain.rb', line 3250 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3252 3253 3254 |
# File 'lib/models/porcelain.rb', line 3252 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3254 3255 3256 |
# File 'lib/models/porcelain.rb', line 3254 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3256 3257 3258 |
# File 'lib/models/porcelain.rb', line 3256 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3258 3259 3260 |
# File 'lib/models/porcelain.rb', line 3258 def secret_store_id @secret_store_id end |
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
3260 3261 3262 |
# File 'lib/models/porcelain.rb', line 3260 def service_account_key @service_account_key end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3262 3263 3264 |
# File 'lib/models/porcelain.rb', line 3262 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3308 3309 3310 3311 3312 3313 3314 |
# File 'lib/models/porcelain.rb', line 3308 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |