Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GoogleGKEUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



7934
7935
7936
7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
# File 'lib/models/porcelain.rb', line 7934

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7906
7907
7908
# File 'lib/models/porcelain.rb', line 7906

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7908
7909
7910
# File 'lib/models/porcelain.rb', line 7908

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7910
7911
7912
# File 'lib/models/porcelain.rb', line 7910

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



7912
7913
7914
# File 'lib/models/porcelain.rb', line 7912

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7914
7915
7916
# File 'lib/models/porcelain.rb', line 7914

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7916
7917
7918
# File 'lib/models/porcelain.rb', line 7916

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7918
7919
7920
# File 'lib/models/porcelain.rb', line 7918

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7920
7921
7922
# File 'lib/models/porcelain.rb', line 7920

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7922
7923
7924
# File 'lib/models/porcelain.rb', line 7922

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7924
7925
7926
# File 'lib/models/porcelain.rb', line 7924

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7926
7927
7928
# File 'lib/models/porcelain.rb', line 7926

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



7928
7929
7930
# File 'lib/models/porcelain.rb', line 7928

def 
  @service_account_key
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7930
7931
7932
# File 'lib/models/porcelain.rb', line 7930

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7932
7933
7934
# File 'lib/models/porcelain.rb', line 7932

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7966
7967
7968
7969
7970
7971
7972
# File 'lib/models/porcelain.rb', line 7966

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end