Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GoogleGKEUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
# File 'lib/models/porcelain.rb', line 7894

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7866
7867
7868
# File 'lib/models/porcelain.rb', line 7866

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7868
7869
7870
# File 'lib/models/porcelain.rb', line 7868

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7870
7871
7872
# File 'lib/models/porcelain.rb', line 7870

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



7872
7873
7874
# File 'lib/models/porcelain.rb', line 7872

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7874
7875
7876
# File 'lib/models/porcelain.rb', line 7874

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7876
7877
7878
# File 'lib/models/porcelain.rb', line 7876

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7878
7879
7880
# File 'lib/models/porcelain.rb', line 7878

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7880
7881
7882
# File 'lib/models/porcelain.rb', line 7880

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7882
7883
7884
# File 'lib/models/porcelain.rb', line 7882

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7884
7885
7886
# File 'lib/models/porcelain.rb', line 7884

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7886
7887
7888
# File 'lib/models/porcelain.rb', line 7886

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



7888
7889
7890
# File 'lib/models/porcelain.rb', line 7888

def 
  @service_account_key
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7890
7891
7892
# File 'lib/models/porcelain.rb', line 7890

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7892
7893
7894
# File 'lib/models/porcelain.rb', line 7892

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7926
7927
7928
7929
7930
7931
7932
# File 'lib/models/porcelain.rb', line 7926

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end