Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GoogleGKEUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



7816
7817
7818
7819
7820
7821
7822
7823
7824
7825
7826
7827
7828
7829
7830
7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
# File 'lib/models/porcelain.rb', line 7816

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7788
7789
7790
# File 'lib/models/porcelain.rb', line 7788

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7790
7791
7792
# File 'lib/models/porcelain.rb', line 7790

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7792
7793
7794
# File 'lib/models/porcelain.rb', line 7792

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



7794
7795
7796
# File 'lib/models/porcelain.rb', line 7794

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7796
7797
7798
# File 'lib/models/porcelain.rb', line 7796

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7798
7799
7800
# File 'lib/models/porcelain.rb', line 7798

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7800
7801
7802
# File 'lib/models/porcelain.rb', line 7800

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7802
7803
7804
# File 'lib/models/porcelain.rb', line 7802

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7804
7805
7806
# File 'lib/models/porcelain.rb', line 7804

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7806
7807
7808
# File 'lib/models/porcelain.rb', line 7806

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7808
7809
7810
# File 'lib/models/porcelain.rb', line 7808

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



7810
7811
7812
# File 'lib/models/porcelain.rb', line 7810

def 
  @service_account_key
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7812
7813
7814
# File 'lib/models/porcelain.rb', line 7812

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7814
7815
7816
# File 'lib/models/porcelain.rb', line 7814

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7848
7849
7850
7851
7852
7853
7854
# File 'lib/models/porcelain.rb', line 7848

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end