Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GoogleGKEUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
# File 'lib/models/porcelain.rb', line 7005

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



6977
6978
6979
# File 'lib/models/porcelain.rb', line 6977

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6979
6980
6981
# File 'lib/models/porcelain.rb', line 6979

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6981
6982
6983
# File 'lib/models/porcelain.rb', line 6981

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



6983
6984
6985
# File 'lib/models/porcelain.rb', line 6983

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6985
6986
6987
# File 'lib/models/porcelain.rb', line 6985

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6987
6988
6989
# File 'lib/models/porcelain.rb', line 6987

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6989
6990
6991
# File 'lib/models/porcelain.rb', line 6989

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6991
6992
6993
# File 'lib/models/porcelain.rb', line 6991

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



6993
6994
6995
# File 'lib/models/porcelain.rb', line 6993

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6995
6996
6997
# File 'lib/models/porcelain.rb', line 6995

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6997
6998
6999
# File 'lib/models/porcelain.rb', line 6997

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



6999
7000
7001
# File 'lib/models/porcelain.rb', line 6999

def 
  @service_account_key
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7001
7002
7003
# File 'lib/models/porcelain.rb', line 7001

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7003
7004
7005
# File 'lib/models/porcelain.rb', line 7003

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7037
7038
7039
7040
7041
7042
7043
# File 'lib/models/porcelain.rb', line 7037

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end