Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GoogleGKEUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



6756
6757
6758
6759
6760
6761
6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
6783
6784
6785
6786
# File 'lib/models/porcelain.rb', line 6756

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6728
6729
6730
# File 'lib/models/porcelain.rb', line 6728

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6730
6731
6732
# File 'lib/models/porcelain.rb', line 6730

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6732
6733
6734
# File 'lib/models/porcelain.rb', line 6732

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



6734
6735
6736
# File 'lib/models/porcelain.rb', line 6734

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6736
6737
6738
# File 'lib/models/porcelain.rb', line 6736

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6738
6739
6740
# File 'lib/models/porcelain.rb', line 6738

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6740
6741
6742
# File 'lib/models/porcelain.rb', line 6740

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6742
6743
6744
# File 'lib/models/porcelain.rb', line 6742

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



6744
6745
6746
# File 'lib/models/porcelain.rb', line 6744

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6746
6747
6748
# File 'lib/models/porcelain.rb', line 6746

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6748
6749
6750
# File 'lib/models/porcelain.rb', line 6748

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



6750
6751
6752
# File 'lib/models/porcelain.rb', line 6750

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6752
6753
6754
# File 'lib/models/porcelain.rb', line 6752

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6754
6755
6756
# File 'lib/models/porcelain.rb', line 6754

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6788
6789
6790
6791
6792
6793
6794
# File 'lib/models/porcelain.rb', line 6788

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end