Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
6600
6601
6602
6603
6604
6605
6606
6607
6608
# File 'lib/models/porcelain.rb', line 6578

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6550
6551
6552
# File 'lib/models/porcelain.rb', line 6550

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6552
6553
6554
# File 'lib/models/porcelain.rb', line 6552

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6554
6555
6556
# File 'lib/models/porcelain.rb', line 6554

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



6556
6557
6558
# File 'lib/models/porcelain.rb', line 6556

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6558
6559
6560
# File 'lib/models/porcelain.rb', line 6558

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6560
6561
6562
# File 'lib/models/porcelain.rb', line 6560

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6562
6563
6564
# File 'lib/models/porcelain.rb', line 6562

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6564
6565
6566
# File 'lib/models/porcelain.rb', line 6564

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



6566
6567
6568
# File 'lib/models/porcelain.rb', line 6566

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6568
6569
6570
# File 'lib/models/porcelain.rb', line 6568

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6570
6571
6572
# File 'lib/models/porcelain.rb', line 6570

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



6572
6573
6574
# File 'lib/models/porcelain.rb', line 6572

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6574
6575
6576
# File 'lib/models/porcelain.rb', line 6574

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6576
6577
6578
# File 'lib/models/porcelain.rb', line 6576

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6610
6611
6612
6613
6614
6615
6616
# File 'lib/models/porcelain.rb', line 6610

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end