Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



6430
6431
6432
6433
6434
6435
6436
6437
6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
# File 'lib/models/porcelain.rb', line 6430

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6402
6403
6404
# File 'lib/models/porcelain.rb', line 6402

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6404
6405
6406
# File 'lib/models/porcelain.rb', line 6404

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6406
6407
6408
# File 'lib/models/porcelain.rb', line 6406

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



6408
6409
6410
# File 'lib/models/porcelain.rb', line 6408

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6410
6411
6412
# File 'lib/models/porcelain.rb', line 6410

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6412
6413
6414
# File 'lib/models/porcelain.rb', line 6412

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6414
6415
6416
# File 'lib/models/porcelain.rb', line 6414

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6416
6417
6418
# File 'lib/models/porcelain.rb', line 6416

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



6418
6419
6420
# File 'lib/models/porcelain.rb', line 6418

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6420
6421
6422
# File 'lib/models/porcelain.rb', line 6420

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6422
6423
6424
# File 'lib/models/porcelain.rb', line 6422

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



6424
6425
6426
# File 'lib/models/porcelain.rb', line 6424

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6426
6427
6428
# File 'lib/models/porcelain.rb', line 6426

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6428
6429
6430
# File 'lib/models/porcelain.rb', line 6428

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6462
6463
6464
6465
6466
6467
6468
# File 'lib/models/porcelain.rb', line 6462

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end