Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
# File 'lib/models/porcelain.rb', line 6283

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6255
6256
6257
# File 'lib/models/porcelain.rb', line 6255

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6257
6258
6259
# File 'lib/models/porcelain.rb', line 6257

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6259
6260
6261
# File 'lib/models/porcelain.rb', line 6259

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



6261
6262
6263
# File 'lib/models/porcelain.rb', line 6261

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6263
6264
6265
# File 'lib/models/porcelain.rb', line 6263

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6265
6266
6267
# File 'lib/models/porcelain.rb', line 6265

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



6267
6268
6269
# File 'lib/models/porcelain.rb', line 6267

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6269
6270
6271
# File 'lib/models/porcelain.rb', line 6269

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



6271
6272
6273
# File 'lib/models/porcelain.rb', line 6271

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6273
6274
6275
# File 'lib/models/porcelain.rb', line 6273

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6275
6276
6277
# File 'lib/models/porcelain.rb', line 6275

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



6277
6278
6279
# File 'lib/models/porcelain.rb', line 6277

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6279
6280
6281
# File 'lib/models/porcelain.rb', line 6279

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6281
6282
6283
# File 'lib/models/porcelain.rb', line 6281

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6315
6316
6317
6318
6319
6320
6321
# File 'lib/models/porcelain.rb', line 6315

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end