Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
# File 'lib/models/porcelain.rb', line 5991

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5963
5964
5965
# File 'lib/models/porcelain.rb', line 5963

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5965
5966
5967
# File 'lib/models/porcelain.rb', line 5965

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5967
5968
5969
# File 'lib/models/porcelain.rb', line 5967

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



5969
5970
5971
# File 'lib/models/porcelain.rb', line 5969

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5971
5972
5973
# File 'lib/models/porcelain.rb', line 5971

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5973
5974
5975
# File 'lib/models/porcelain.rb', line 5973

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5975
5976
5977
# File 'lib/models/porcelain.rb', line 5975

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5977
5978
5979
# File 'lib/models/porcelain.rb', line 5977

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5979
5980
5981
# File 'lib/models/porcelain.rb', line 5979

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5981
5982
5983
# File 'lib/models/porcelain.rb', line 5981

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5983
5984
5985
# File 'lib/models/porcelain.rb', line 5983

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



5985
5986
5987
# File 'lib/models/porcelain.rb', line 5985

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5987
5988
5989
# File 'lib/models/porcelain.rb', line 5987

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5989
5990
5991
# File 'lib/models/porcelain.rb', line 5989

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6023
6024
6025
6026
6027
6028
6029
# File 'lib/models/porcelain.rb', line 6023

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end