Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/models/porcelain.rb', line 5992

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5964
5965
5966
# File 'lib/models/porcelain.rb', line 5964

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5966
5967
5968
# File 'lib/models/porcelain.rb', line 5966

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5968
5969
5970
# File 'lib/models/porcelain.rb', line 5968

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



5970
5971
5972
# File 'lib/models/porcelain.rb', line 5970

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5972
5973
5974
# File 'lib/models/porcelain.rb', line 5972

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5974
5975
5976
# File 'lib/models/porcelain.rb', line 5974

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5976
5977
5978
# File 'lib/models/porcelain.rb', line 5976

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5978
5979
5980
# File 'lib/models/porcelain.rb', line 5978

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5980
5981
5982
# File 'lib/models/porcelain.rb', line 5980

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5982
5983
5984
# File 'lib/models/porcelain.rb', line 5982

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5984
5985
5986
# File 'lib/models/porcelain.rb', line 5984

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



5986
5987
5988
# File 'lib/models/porcelain.rb', line 5986

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5988
5989
5990
# File 'lib/models/porcelain.rb', line 5988

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5990
5991
5992
# File 'lib/models/porcelain.rb', line 5990

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6024
6025
6026
6027
6028
6029
6030
# File 'lib/models/porcelain.rb', line 6024

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end