Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



5628
5629
5630
5631
5632
5633
5634
5635
5636
5637
5638
5639
5640
5641
5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
# File 'lib/models/porcelain.rb', line 5628

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5600
5601
5602
# File 'lib/models/porcelain.rb', line 5600

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5602
5603
5604
# File 'lib/models/porcelain.rb', line 5602

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5604
5605
5606
# File 'lib/models/porcelain.rb', line 5604

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



5606
5607
5608
# File 'lib/models/porcelain.rb', line 5606

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5608
5609
5610
# File 'lib/models/porcelain.rb', line 5608

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5610
5611
5612
# File 'lib/models/porcelain.rb', line 5610

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5612
5613
5614
# File 'lib/models/porcelain.rb', line 5612

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5614
5615
5616
# File 'lib/models/porcelain.rb', line 5614

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5616
5617
5618
# File 'lib/models/porcelain.rb', line 5616

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5618
5619
5620
# File 'lib/models/porcelain.rb', line 5618

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5620
5621
5622
# File 'lib/models/porcelain.rb', line 5620

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



5622
5623
5624
# File 'lib/models/porcelain.rb', line 5622

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5624
5625
5626
# File 'lib/models/porcelain.rb', line 5624

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5626
5627
5628
# File 'lib/models/porcelain.rb', line 5626

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5660
5661
5662
5663
5664
5665
5666
# File 'lib/models/porcelain.rb', line 5660

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end