Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



5148
5149
5150
5151
5152
5153
5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
# File 'lib/models/porcelain.rb', line 5148

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5122
5123
5124
# File 'lib/models/porcelain.rb', line 5122

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5124
5125
5126
# File 'lib/models/porcelain.rb', line 5124

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5126
5127
5128
# File 'lib/models/porcelain.rb', line 5126

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



5128
5129
5130
# File 'lib/models/porcelain.rb', line 5128

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5130
5131
5132
# File 'lib/models/porcelain.rb', line 5130

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5132
5133
5134
# File 'lib/models/porcelain.rb', line 5132

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5134
5135
5136
# File 'lib/models/porcelain.rb', line 5134

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5136
5137
5138
# File 'lib/models/porcelain.rb', line 5136

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



5138
5139
5140
# File 'lib/models/porcelain.rb', line 5138

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5140
5141
5142
# File 'lib/models/porcelain.rb', line 5140

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



5142
5143
5144
# File 'lib/models/porcelain.rb', line 5142

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5144
5145
5146
# File 'lib/models/porcelain.rb', line 5144

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5146
5147
5148
# File 'lib/models/porcelain.rb', line 5146

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5178
5179
5180
5181
5182
5183
5184
# File 'lib/models/porcelain.rb', line 5178

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end