Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
4129
# File 'lib/models/porcelain.rb', line 4101

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port_override: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4075
4076
4077
# File 'lib/models/porcelain.rb', line 4075

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4077
4078
4079
# File 'lib/models/porcelain.rb', line 4077

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4079
4080
4081
# File 'lib/models/porcelain.rb', line 4079

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



4081
4082
4083
# File 'lib/models/porcelain.rb', line 4081

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4083
4084
4085
# File 'lib/models/porcelain.rb', line 4083

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4085
4086
4087
# File 'lib/models/porcelain.rb', line 4085

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4087
4088
4089
# File 'lib/models/porcelain.rb', line 4087

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4089
4090
4091
# File 'lib/models/porcelain.rb', line 4089

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



4091
4092
4093
# File 'lib/models/porcelain.rb', line 4091

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4093
4094
4095
# File 'lib/models/porcelain.rb', line 4093

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



4095
4096
4097
# File 'lib/models/porcelain.rb', line 4095

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4097
4098
4099
# File 'lib/models/porcelain.rb', line 4097

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4099
4100
4101
# File 'lib/models/porcelain.rb', line 4099

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4131
4132
4133
4134
4135
4136
4137
# File 'lib/models/porcelain.rb', line 4131

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end