Class: SDM::GoogleGKEUserImpersonation
- Inherits:
-
Object
- Object
- SDM::GoogleGKEUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_key ⇒ Object
The service account key to authenticate with.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation
constructor
A new instance of GoogleGKEUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation
Returns a new instance of GoogleGKEUserImpersonation.
3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/models/porcelain.rb', line 3937 def initialize( bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, port_override: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_key = service_account_key == nil ? "" : service_account_key @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3911 3912 3913 |
# File 'lib/models/porcelain.rb', line 3911 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
3913 3914 3915 |
# File 'lib/models/porcelain.rb', line 3913 def @certificate_authority end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3915 3916 3917 |
# File 'lib/models/porcelain.rb', line 3915 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial.
3917 3918 3919 |
# File 'lib/models/porcelain.rb', line 3917 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3919 3920 3921 |
# File 'lib/models/porcelain.rb', line 3919 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3921 3922 3923 |
# File 'lib/models/porcelain.rb', line 3921 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3923 3924 3925 |
# File 'lib/models/porcelain.rb', line 3923 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3925 3926 3927 |
# File 'lib/models/porcelain.rb', line 3925 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3927 3928 3929 |
# File 'lib/models/porcelain.rb', line 3927 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3929 3930 3931 |
# File 'lib/models/porcelain.rb', line 3929 def secret_store_id @secret_store_id end |
#service_account_key ⇒ Object
The service account key to authenticate with.
3931 3932 3933 |
# File 'lib/models/porcelain.rb', line 3931 def service_account_key @service_account_key end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3933 3934 3935 |
# File 'lib/models/porcelain.rb', line 3933 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3935 3936 3937 |
# File 'lib/models/porcelain.rb', line 3935 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3967 3968 3969 3970 3971 3972 3973 |
# File 'lib/models/porcelain.rb', line 3967 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |