Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
3957
3958
3959
3960
3961
3962
# File 'lib/models/porcelain.rb', line 3936

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



3912
3913
3914
# File 'lib/models/porcelain.rb', line 3912

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



3914
3915
3916
# File 'lib/models/porcelain.rb', line 3914

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3916
3917
3918
# File 'lib/models/porcelain.rb', line 3916

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial.



3918
3919
3920
# File 'lib/models/porcelain.rb', line 3918

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3920
3921
3922
# File 'lib/models/porcelain.rb', line 3920

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3922
3923
3924
# File 'lib/models/porcelain.rb', line 3922

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3924
3925
3926
# File 'lib/models/porcelain.rb', line 3924

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3926
3927
3928
# File 'lib/models/porcelain.rb', line 3926

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3928
3929
3930
# File 'lib/models/porcelain.rb', line 3928

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

The service account key to authenticate with.



3930
3931
3932
# File 'lib/models/porcelain.rb', line 3930

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3932
3933
3934
# File 'lib/models/porcelain.rb', line 3932

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3934
3935
3936
# File 'lib/models/porcelain.rb', line 3934

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3964
3965
3966
3967
3968
3969
3970
# File 'lib/models/porcelain.rb', line 3964

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end