Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, subdomain: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
# File 'lib/models/porcelain.rb', line 3817

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  service_account_key: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3793
3794
3795
# File 'lib/models/porcelain.rb', line 3793

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3795
3796
3797
# File 'lib/models/porcelain.rb', line 3795

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3797
3798
3799
# File 'lib/models/porcelain.rb', line 3797

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3799
3800
3801
# File 'lib/models/porcelain.rb', line 3799

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3801
3802
3803
# File 'lib/models/porcelain.rb', line 3801

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3803
3804
3805
# File 'lib/models/porcelain.rb', line 3803

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3805
3806
3807
# File 'lib/models/porcelain.rb', line 3805

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3807
3808
3809
# File 'lib/models/porcelain.rb', line 3807

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3809
3810
3811
# File 'lib/models/porcelain.rb', line 3809

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



3811
3812
3813
# File 'lib/models/porcelain.rb', line 3811

def 
  @service_account_key
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3813
3814
3815
# File 'lib/models/porcelain.rb', line 3813

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3815
3816
3817
# File 'lib/models/porcelain.rb', line 3815

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3845
3846
3847
3848
3849
3850
3851
# File 'lib/models/porcelain.rb', line 3845

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end