Class: SDM::GoogleGKEUserImpersonation
- Inherits:
-
Object
- Object
- SDM::GoogleGKEUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKEUserImpersonation
constructor
A new instance of GoogleGKEUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKEUserImpersonation
Returns a new instance of GoogleGKEUserImpersonation.
3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 3524 3525 3526 3527 3528 3529 |
# File 'lib/models/porcelain.rb', line 3505 def initialize( bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_key = service_account_key == nil ? "" : service_account_key @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3483 3484 3485 |
# File 'lib/models/porcelain.rb', line 3483 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3485 3486 3487 |
# File 'lib/models/porcelain.rb', line 3485 def @certificate_authority end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3487 3488 3489 |
# File 'lib/models/porcelain.rb', line 3487 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
3489 3490 3491 |
# File 'lib/models/porcelain.rb', line 3489 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3491 3492 3493 |
# File 'lib/models/porcelain.rb', line 3491 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3493 3494 3495 |
# File 'lib/models/porcelain.rb', line 3493 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3495 3496 3497 |
# File 'lib/models/porcelain.rb', line 3495 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3497 3498 3499 |
# File 'lib/models/porcelain.rb', line 3497 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3499 3500 3501 |
# File 'lib/models/porcelain.rb', line 3499 def secret_store_id @secret_store_id end |
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
3501 3502 3503 |
# File 'lib/models/porcelain.rb', line 3501 def service_account_key @service_account_key end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3503 3504 3505 |
# File 'lib/models/porcelain.rb', line 3503 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/models/porcelain.rb', line 3531 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |