Class: SDM::GoogleGKEUserImpersonation
- Inherits:
-
Object
- Object
- SDM::GoogleGKEUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKEUserImpersonation
constructor
A new instance of GoogleGKEUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKEUserImpersonation
Returns a new instance of GoogleGKEUserImpersonation.
3167 3168 3169 3170 3171 3172 3173 3174 3175 3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 |
# File 'lib/models/porcelain.rb', line 3167 def initialize( bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_key = service_account_key == nil ? "" : service_account_key @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3145 3146 3147 |
# File 'lib/models/porcelain.rb', line 3145 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3147 3148 3149 |
# File 'lib/models/porcelain.rb', line 3147 def @certificate_authority end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3149 3150 3151 |
# File 'lib/models/porcelain.rb', line 3149 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
3151 3152 3153 |
# File 'lib/models/porcelain.rb', line 3151 def endpoint @endpoint end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3153 3154 3155 |
# File 'lib/models/porcelain.rb', line 3153 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3155 3156 3157 |
# File 'lib/models/porcelain.rb', line 3155 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3157 3158 3159 |
# File 'lib/models/porcelain.rb', line 3157 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3159 3160 3161 |
# File 'lib/models/porcelain.rb', line 3159 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3161 3162 3163 |
# File 'lib/models/porcelain.rb', line 3161 def secret_store_id @secret_store_id end |
#service_account_key ⇒ Object
Returns the value of attribute service_account_key.
3163 3164 3165 |
# File 'lib/models/porcelain.rb', line 3163 def service_account_key @service_account_key end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3165 3166 3167 |
# File 'lib/models/porcelain.rb', line 3165 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3193 3194 3195 3196 3197 3198 3199 |
# File 'lib/models/porcelain.rb', line 3193 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |