Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



3168
3169
3170
3171
3172
3173
3174
3175
3176
3177
3178
3179
3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/models/porcelain.rb', line 3168

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  service_account_key: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3146
3147
3148
# File 'lib/models/porcelain.rb', line 3146

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3148
3149
3150
# File 'lib/models/porcelain.rb', line 3148

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3150
3151
3152
# File 'lib/models/porcelain.rb', line 3150

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3152
3153
3154
# File 'lib/models/porcelain.rb', line 3152

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3154
3155
3156
# File 'lib/models/porcelain.rb', line 3154

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3156
3157
3158
# File 'lib/models/porcelain.rb', line 3156

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3158
3159
3160
# File 'lib/models/porcelain.rb', line 3158

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3160
3161
3162
# File 'lib/models/porcelain.rb', line 3160

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3162
3163
3164
# File 'lib/models/porcelain.rb', line 3162

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



3164
3165
3166
# File 'lib/models/porcelain.rb', line 3164

def 
  @service_account_key
end

#tagsObject

Tags is a map of key, value pairs.



3166
3167
3168
# File 'lib/models/porcelain.rb', line 3166

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3194
3195
3196
3197
3198
3199
3200
# File 'lib/models/porcelain.rb', line 3194

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end