Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
# File 'lib/models/porcelain.rb', line 3056

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  service_account_key: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3034
3035
3036
# File 'lib/models/porcelain.rb', line 3034

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3036
3037
3038
# File 'lib/models/porcelain.rb', line 3036

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3038
3039
3040
# File 'lib/models/porcelain.rb', line 3038

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3040
3041
3042
# File 'lib/models/porcelain.rb', line 3040

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3042
3043
3044
# File 'lib/models/porcelain.rb', line 3042

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3044
3045
3046
# File 'lib/models/porcelain.rb', line 3044

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3046
3047
3048
# File 'lib/models/porcelain.rb', line 3046

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3048
3049
3050
# File 'lib/models/porcelain.rb', line 3048

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3050
3051
3052
# File 'lib/models/porcelain.rb', line 3050

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



3052
3053
3054
# File 'lib/models/porcelain.rb', line 3052

def 
  @service_account_key
end

#tagsObject

Tags is a map of key, value pairs.



3054
3055
3056
# File 'lib/models/porcelain.rb', line 3054

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3082
3083
3084
3085
3086
3087
3088
# File 'lib/models/porcelain.rb', line 3082

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end