Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
# File 'lib/models/porcelain.rb', line 3041

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  service_account_key: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_key =  == nil ? "" : 
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3019
3020
3021
# File 'lib/models/porcelain.rb', line 3019

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3021
3022
3023
# File 'lib/models/porcelain.rb', line 3021

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3023
3024
3025
# File 'lib/models/porcelain.rb', line 3023

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3025
3026
3027
# File 'lib/models/porcelain.rb', line 3025

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3027
3028
3029
# File 'lib/models/porcelain.rb', line 3027

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3029
3030
3031
# File 'lib/models/porcelain.rb', line 3029

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3031
3032
3033
# File 'lib/models/porcelain.rb', line 3031

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3033
3034
3035
# File 'lib/models/porcelain.rb', line 3033

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3035
3036
3037
# File 'lib/models/porcelain.rb', line 3035

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



3037
3038
3039
# File 'lib/models/porcelain.rb', line 3037

def 
  @service_account_key
end

#tagsObject

Tags is a map of key, value pairs.



3039
3040
3041
# File 'lib/models/porcelain.rb', line 3039

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3067
3068
3069
3070
3071
3072
3073
# File 'lib/models/porcelain.rb', line 3067

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end