Class: SDM::GoogleGKEUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(certificate_authority: nil, egress_filter: nil, endpoint: nil, healthcheck_namespace: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, service_account_key: nil, tags: nil) ⇒ GoogleGKEUserImpersonation

Returns a new instance of GoogleGKEUserImpersonation.



3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
3374
3375
3376
3377
3378
3379
3380
# File 'lib/models/porcelain.rb', line 3338

def initialize(
  certificate_authority: nil,
  egress_filter: nil,
  endpoint: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  service_account_key: nil,
  tags: nil
)
  if certificate_authority != nil
    @certificate_authority = certificate_authority
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if endpoint != nil
    @endpoint = endpoint
  end
  if healthcheck_namespace != nil
    @healthcheck_namespace = healthcheck_namespace
  end
  if healthy != nil
    @healthy = healthy
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if  != nil
    @service_account_key = 
  end
  if tags != nil
    @tags = tags
  end
end

Instance Attribute Details

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3318
3319
3320
# File 'lib/models/porcelain.rb', line 3318

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3320
3321
3322
# File 'lib/models/porcelain.rb', line 3320

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



3322
3323
3324
# File 'lib/models/porcelain.rb', line 3322

def endpoint
  @endpoint
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to `default`.



3324
3325
3326
# File 'lib/models/porcelain.rb', line 3324

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3326
3327
3328
# File 'lib/models/porcelain.rb', line 3326

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3328
3329
3330
# File 'lib/models/porcelain.rb', line 3328

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3330
3331
3332
# File 'lib/models/porcelain.rb', line 3330

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3332
3333
3334
# File 'lib/models/porcelain.rb', line 3332

def secret_store_id
  @secret_store_id
end

#service_account_keyObject

Returns the value of attribute service_account_key.



3334
3335
3336
# File 'lib/models/porcelain.rb', line 3334

def 
  @service_account_key
end

#tagsObject

Tags is a map of key, value pairs.



3336
3337
3338
# File 'lib/models/porcelain.rb', line 3336

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3382
3383
3384
3385
3386
3387
3388
# File 'lib/models/porcelain.rb', line 3382

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end