Class: SDM::GoogleSpanner
- Inherits:
-
Object
- Object
- SDM::GoogleSpanner
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#instance ⇒ Object
The Spanner instance ID within the GCP project.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#project ⇒ Object
The GCP project ID containing the Spanner database.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_to_impersonate ⇒ Object
Optional service account email to impersonate.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner
constructor
A new instance of GoogleSpanner.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner
Returns a new instance of GoogleSpanner.
8048 8049 8050 8051 8052 8053 8054 8055 8056 8057 8058 8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 |
# File 'lib/models/porcelain.rb', line 8048 def initialize( bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @instance = instance == nil ? "" : instance @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @project = project == nil ? "" : project @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_to_impersonate = service_account_to_impersonate == nil ? "" : service_account_to_impersonate @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
8013 8014 8015 |
# File 'lib/models/porcelain.rb', line 8013 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8015 8016 8017 |
# File 'lib/models/porcelain.rb', line 8015 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8017 8018 8019 |
# File 'lib/models/porcelain.rb', line 8017 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. spanner.googleapis.com
8019 8020 8021 |
# File 'lib/models/porcelain.rb', line 8019 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8021 8022 8023 |
# File 'lib/models/porcelain.rb', line 8021 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
8023 8024 8025 |
# File 'lib/models/porcelain.rb', line 8023 def id @id end |
#instance ⇒ Object
The Spanner instance ID within the GCP project.
8025 8026 8027 |
# File 'lib/models/porcelain.rb', line 8025 def instance @instance end |
#name ⇒ Object
Unique human-readable name of the Resource.
8027 8028 8029 |
# File 'lib/models/porcelain.rb', line 8027 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8029 8030 8031 |
# File 'lib/models/porcelain.rb', line 8029 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
8031 8032 8033 |
# File 'lib/models/porcelain.rb', line 8031 def port_override @port_override end |
#project ⇒ Object
The GCP project ID containing the Spanner database.
8033 8034 8035 |
# File 'lib/models/porcelain.rb', line 8033 def project @project end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8035 8036 8037 |
# File 'lib/models/porcelain.rb', line 8035 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8037 8038 8039 |
# File 'lib/models/porcelain.rb', line 8037 def secret_store_id @secret_store_id end |
#service_account_to_impersonate ⇒ Object
Optional service account email to impersonate. When set, the relay's Application Default Credentials will impersonate this service account to access Spanner. This allows role separation where the relay uses one service account but operates as another.
8042 8043 8044 |
# File 'lib/models/porcelain.rb', line 8042 def service_account_to_impersonate @service_account_to_impersonate end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
8044 8045 8046 |
# File 'lib/models/porcelain.rb', line 8044 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8046 8047 8048 |
# File 'lib/models/porcelain.rb', line 8046 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8084 8085 8086 8087 8088 8089 8090 |
# File 'lib/models/porcelain.rb', line 8084 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |