Class: SDM::GoogleSpanner

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner

Returns a new instance of GoogleSpanner.



8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
8037
8038
8039
8040
8041
8042
8043
8044
8045
8046
# File 'lib/models/porcelain.rb', line 8012

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  instance: nil,
  name: nil,
  port: nil,
  port_override: nil,
  project: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_to_impersonate: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @instance = instance == nil ? "" : instance
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @project = project == nil ? "" : project
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_to_impersonate =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7977
7978
7979
# File 'lib/models/porcelain.rb', line 7977

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7979
7980
7981
# File 'lib/models/porcelain.rb', line 7979

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7981
7982
7983
# File 'lib/models/porcelain.rb', line 7981

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. spanner.googleapis.com



7983
7984
7985
# File 'lib/models/porcelain.rb', line 7983

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7985
7986
7987
# File 'lib/models/porcelain.rb', line 7985

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7987
7988
7989
# File 'lib/models/porcelain.rb', line 7987

def id
  @id
end

#instanceObject

The Spanner instance ID within the GCP project.



7989
7990
7991
# File 'lib/models/porcelain.rb', line 7989

def instance
  @instance
end

#nameObject

Unique human-readable name of the Resource.



7991
7992
7993
# File 'lib/models/porcelain.rb', line 7991

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7993
7994
7995
# File 'lib/models/porcelain.rb', line 7993

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7995
7996
7997
# File 'lib/models/porcelain.rb', line 7995

def port_override
  @port_override
end

#projectObject

The GCP project ID containing the Spanner database.



7997
7998
7999
# File 'lib/models/porcelain.rb', line 7997

def project
  @project
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7999
8000
8001
# File 'lib/models/porcelain.rb', line 7999

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8001
8002
8003
# File 'lib/models/porcelain.rb', line 8001

def secret_store_id
  @secret_store_id
end

#service_account_to_impersonateObject

Optional service account email to impersonate. When set, the relay's Application Default Credentials will impersonate this service account to access Spanner. This allows role separation where the relay uses one service account but operates as another.



8006
8007
8008
# File 'lib/models/porcelain.rb', line 8006

def 
  @service_account_to_impersonate
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



8008
8009
8010
# File 'lib/models/porcelain.rb', line 8008

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8010
8011
8012
# File 'lib/models/porcelain.rb', line 8010

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8048
8049
8050
8051
8052
8053
8054
# File 'lib/models/porcelain.rb', line 8048

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end