Class: SDM::GoogleSpanner

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GoogleSpanner is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner

Returns a new instance of GoogleSpanner.



7973
7974
7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
# File 'lib/models/porcelain.rb', line 7973

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  instance: nil,
  name: nil,
  port: nil,
  port_override: nil,
  project: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_to_impersonate: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @instance = instance == nil ? "" : instance
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @project = project == nil ? "" : project
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_to_impersonate =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7938
7939
7940
# File 'lib/models/porcelain.rb', line 7938

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7940
7941
7942
# File 'lib/models/porcelain.rb', line 7940

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7942
7943
7944
# File 'lib/models/porcelain.rb', line 7942

def egress_filter
  @egress_filter
end

#endpointObject

The endpoint to dial e.g. spanner.googleapis.com



7944
7945
7946
# File 'lib/models/porcelain.rb', line 7944

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7946
7947
7948
# File 'lib/models/porcelain.rb', line 7946

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7948
7949
7950
# File 'lib/models/porcelain.rb', line 7948

def id
  @id
end

#instanceObject

The Spanner instance ID within the GCP project.



7950
7951
7952
# File 'lib/models/porcelain.rb', line 7950

def instance
  @instance
end

#nameObject

Unique human-readable name of the Resource.



7952
7953
7954
# File 'lib/models/porcelain.rb', line 7952

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7954
7955
7956
# File 'lib/models/porcelain.rb', line 7954

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7956
7957
7958
# File 'lib/models/porcelain.rb', line 7956

def port_override
  @port_override
end

#projectObject

The GCP project ID containing the Spanner database.



7958
7959
7960
# File 'lib/models/porcelain.rb', line 7958

def project
  @project
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7960
7961
7962
# File 'lib/models/porcelain.rb', line 7960

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7962
7963
7964
# File 'lib/models/porcelain.rb', line 7962

def secret_store_id
  @secret_store_id
end

#service_account_to_impersonateObject

Optional service account email to impersonate. When set, the relay's Application Default Credentials will impersonate this service account to access Spanner. This allows role separation where the relay uses one service account but operates as another.



7967
7968
7969
# File 'lib/models/porcelain.rb', line 7967

def 
  @service_account_to_impersonate
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



7969
7970
7971
# File 'lib/models/porcelain.rb', line 7969

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7971
7972
7973
# File 'lib/models/porcelain.rb', line 7971

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8009
8010
8011
8012
8013
8014
8015
# File 'lib/models/porcelain.rb', line 8009

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end