Class: SDM::GoogleSpanner
- Inherits:
-
Object
- Object
- SDM::GoogleSpanner
- Defined in:
- lib/models/porcelain.rb
Overview
GoogleSpanner is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#instance ⇒ Object
The Spanner instance ID within the GCP project.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#project ⇒ Object
The GCP project ID containing the Spanner database.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_to_impersonate ⇒ Object
Optional service account email to impersonate.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner
constructor
A new instance of GoogleSpanner.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner
Returns a new instance of GoogleSpanner.
7899 7900 7901 7902 7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 |
# File 'lib/models/porcelain.rb', line 7899 def initialize( bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @instance = instance == nil ? "" : instance @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @project = project == nil ? "" : project @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_to_impersonate = service_account_to_impersonate == nil ? "" : service_account_to_impersonate @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7864 7865 7866 |
# File 'lib/models/porcelain.rb', line 7864 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7866 7867 7868 |
# File 'lib/models/porcelain.rb', line 7866 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7868 7869 7870 |
# File 'lib/models/porcelain.rb', line 7868 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. spanner.googleapis.com
7870 7871 7872 |
# File 'lib/models/porcelain.rb', line 7870 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7872 7873 7874 |
# File 'lib/models/porcelain.rb', line 7872 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7874 7875 7876 |
# File 'lib/models/porcelain.rb', line 7874 def id @id end |
#instance ⇒ Object
The Spanner instance ID within the GCP project.
7876 7877 7878 |
# File 'lib/models/porcelain.rb', line 7876 def instance @instance end |
#name ⇒ Object
Unique human-readable name of the Resource.
7878 7879 7880 |
# File 'lib/models/porcelain.rb', line 7878 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7880 7881 7882 |
# File 'lib/models/porcelain.rb', line 7880 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
7882 7883 7884 |
# File 'lib/models/porcelain.rb', line 7882 def port_override @port_override end |
#project ⇒ Object
The GCP project ID containing the Spanner database.
7884 7885 7886 |
# File 'lib/models/porcelain.rb', line 7884 def project @project end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7886 7887 7888 |
# File 'lib/models/porcelain.rb', line 7886 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7888 7889 7890 |
# File 'lib/models/porcelain.rb', line 7888 def secret_store_id @secret_store_id end |
#service_account_to_impersonate ⇒ Object
Optional service account email to impersonate. When set, the relay's Application Default Credentials will impersonate this service account to access Spanner. This allows role separation where the relay uses one service account but operates as another.
7893 7894 7895 |
# File 'lib/models/porcelain.rb', line 7893 def service_account_to_impersonate @service_account_to_impersonate end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
7895 7896 7897 |
# File 'lib/models/porcelain.rb', line 7895 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7897 7898 7899 |
# File 'lib/models/porcelain.rb', line 7897 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7935 7936 7937 7938 7939 7940 7941 |
# File 'lib/models/porcelain.rb', line 7935 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |