Class: SDM::GoogleSpanner
- Inherits:
-
Object
- Object
- SDM::GoogleSpanner
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The endpoint to dial e.g.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#instance ⇒ Object
The Spanner instance ID within the GCP project.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#project ⇒ Object
The GCP project ID containing the Spanner database.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#service_account_to_impersonate ⇒ Object
Optional service account email to impersonate.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner
constructor
A new instance of GoogleSpanner.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner
Returns a new instance of GoogleSpanner.
7972 7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 |
# File 'lib/models/porcelain.rb', line 7972 def initialize( bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @instance = instance == nil ? "" : instance @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @project = project == nil ? "" : project @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @service_account_to_impersonate = service_account_to_impersonate == nil ? "" : service_account_to_impersonate @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
7937 7938 7939 |
# File 'lib/models/porcelain.rb', line 7937 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7939 7940 7941 |
# File 'lib/models/porcelain.rb', line 7939 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7941 7942 7943 |
# File 'lib/models/porcelain.rb', line 7941 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The endpoint to dial e.g. spanner.googleapis.com
7943 7944 7945 |
# File 'lib/models/porcelain.rb', line 7943 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7945 7946 7947 |
# File 'lib/models/porcelain.rb', line 7945 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
7947 7948 7949 |
# File 'lib/models/porcelain.rb', line 7947 def id @id end |
#instance ⇒ Object
The Spanner instance ID within the GCP project.
7949 7950 7951 |
# File 'lib/models/porcelain.rb', line 7949 def instance @instance end |
#name ⇒ Object
Unique human-readable name of the Resource.
7951 7952 7953 |
# File 'lib/models/porcelain.rb', line 7951 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7953 7954 7955 |
# File 'lib/models/porcelain.rb', line 7953 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
7955 7956 7957 |
# File 'lib/models/porcelain.rb', line 7955 def port_override @port_override end |
#project ⇒ Object
The GCP project ID containing the Spanner database.
7957 7958 7959 |
# File 'lib/models/porcelain.rb', line 7957 def project @project end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7959 7960 7961 |
# File 'lib/models/porcelain.rb', line 7959 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7961 7962 7963 |
# File 'lib/models/porcelain.rb', line 7961 def secret_store_id @secret_store_id end |
#service_account_to_impersonate ⇒ Object
Optional service account email to impersonate. When set, the relay's Application Default Credentials will impersonate this service account to access Spanner. This allows role separation where the relay uses one service account but operates as another.
7966 7967 7968 |
# File 'lib/models/porcelain.rb', line 7966 def service_account_to_impersonate @service_account_to_impersonate end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
7968 7969 7970 |
# File 'lib/models/porcelain.rb', line 7968 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7970 7971 7972 |
# File 'lib/models/porcelain.rb', line 7970 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8008 8009 8010 8011 8012 8013 8014 |
# File 'lib/models/porcelain.rb', line 8008 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |