Class: SDM::GoogleSpanner

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, instance: nil, name: nil, port: nil, port_override: nil, project: nil, proxy_cluster_id: nil, secret_store_id: nil, service_account_to_impersonate: nil, subdomain: nil, tags: nil) ⇒ GoogleSpanner

Returns a new instance of GoogleSpanner.



8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
8153
8154
8155
8156
8157
8158
# File 'lib/models/porcelain.rb', line 8124

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  instance: nil,
  name: nil,
  port: nil,
  port_override: nil,
  project: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  service_account_to_impersonate: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @instance = instance == nil ? "" : instance
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @project = project == nil ? "" : project
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @service_account_to_impersonate =  == nil ? "" : 
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8089
8090
8091
# File 'lib/models/porcelain.rb', line 8089

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8091
8092
8093
# File 'lib/models/porcelain.rb', line 8091

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



8093
8094
8095
# File 'lib/models/porcelain.rb', line 8093

def egress_filter
  @egress_filter
end

#endpoint ⇒ Object

The endpoint to dial e.g. spanner.googleapis.com



8095
8096
8097
# File 'lib/models/porcelain.rb', line 8095

def endpoint
  @endpoint
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



8097
8098
8099
# File 'lib/models/porcelain.rb', line 8097

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



8099
8100
8101
# File 'lib/models/porcelain.rb', line 8099

def id
  @id
end

#instance ⇒ Object

The Spanner instance ID within the GCP project.



8101
8102
8103
# File 'lib/models/porcelain.rb', line 8101

def instance
  @instance
end

#name ⇒ Object

Unique human-readable name of the Resource.



8103
8104
8105
# File 'lib/models/porcelain.rb', line 8103

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



8105
8106
8107
# File 'lib/models/porcelain.rb', line 8105

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8107
8108
8109
# File 'lib/models/porcelain.rb', line 8107

def port_override
  @port_override
end

#project ⇒ Object

The GCP project ID containing the Spanner database.



8109
8110
8111
# File 'lib/models/porcelain.rb', line 8109

def project
  @project
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



8111
8112
8113
# File 'lib/models/porcelain.rb', line 8111

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



8113
8114
8115
# File 'lib/models/porcelain.rb', line 8113

def secret_store_id
  @secret_store_id
end

#service_account_to_impersonate ⇒ Object

Optional service account email to impersonate. When set, the relay's Application Default Credentials will impersonate this service account to access Spanner. This allows role separation where the relay uses one service account but operates as another.



8118
8119
8120
# File 'lib/models/porcelain.rb', line 8118

def 
  @service_account_to_impersonate
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



8120
8121
8122
# File 'lib/models/porcelain.rb', line 8120

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



8122
8123
8124
# File 'lib/models/porcelain.rb', line 8122

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8160
8161
8162
8163
8164
8165
8166
# File 'lib/models/porcelain.rb', line 8160

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end