Class: SDM::GrantedAccountEntitlement
- Inherits:
-
Object
- Object
- SDM::GrantedAccountEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
GrantedAccountEntitlement represents an individual entitlement of an Account to a Resource that has been granted.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#last_accessed ⇒ Object
The most recent time at which the account accessed this resource.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., a Role or AccountGrant ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
Instance Method Summary collapse
-
#initialize(group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ GrantedAccountEntitlement
constructor
A new instance of GrantedAccountEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ GrantedAccountEntitlement
Returns a new instance of GrantedAccountEntitlement.
8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 8082 |
# File 'lib/models/porcelain.rb', line 8070 def initialize( group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @last_accessed = last_accessed == nil ? nil : last_accessed @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
8060 8061 8062 |
# File 'lib/models/porcelain.rb', line 8060 def group_id @group_id end |
#last_accessed ⇒ Object
The most recent time at which the account accessed this resource. Empty if the resource has never been accessed.
8062 8063 8064 |
# File 'lib/models/porcelain.rb', line 8062 def last_accessed @last_accessed end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
8064 8065 8066 |
# File 'lib/models/porcelain.rb', line 8064 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., a Role or AccountGrant ID).
8066 8067 8068 |
# File 'lib/models/porcelain.rb', line 8066 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
8068 8069 8070 |
# File 'lib/models/porcelain.rb', line 8068 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8084 8085 8086 8087 8088 8089 8090 |
# File 'lib/models/porcelain.rb', line 8084 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |