Class: SDM::GrantedAccountEntitlement
- Inherits:
-
Object
- Object
- SDM::GrantedAccountEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
GrantedAccountEntitlement represents an individual entitlement of an Account to a Resource that has been granted.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#last_accessed ⇒ Object
The most recent time at which the account accessed this resource.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., a Role or AccountGrant ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
Instance Method Summary collapse
-
#initialize(group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ GrantedAccountEntitlement
constructor
A new instance of GrantedAccountEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ GrantedAccountEntitlement
Returns a new instance of GrantedAccountEntitlement.
8044 8045 8046 8047 8048 8049 8050 8051 8052 8053 8054 8055 8056 |
# File 'lib/models/porcelain.rb', line 8044 def initialize( group_id: nil, last_accessed: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @last_accessed = last_accessed == nil ? nil : last_accessed @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
8034 8035 8036 |
# File 'lib/models/porcelain.rb', line 8034 def group_id @group_id end |
#last_accessed ⇒ Object
The most recent time at which the account accessed this resource. Empty if the resource has never been accessed.
8036 8037 8038 |
# File 'lib/models/porcelain.rb', line 8036 def last_accessed @last_accessed end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
8038 8039 8040 |
# File 'lib/models/porcelain.rb', line 8038 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., a Role or AccountGrant ID).
8040 8041 8042 |
# File 'lib/models/porcelain.rb', line 8040 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
8042 8043 8044 |
# File 'lib/models/porcelain.rb', line 8042 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8058 8059 8060 8061 8062 8063 8064 |
# File 'lib/models/porcelain.rb', line 8058 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |