Class: SDM::GrantedRoleEntitlement
- Inherits:
-
Object
- Object
- SDM::GrantedRoleEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
GrantedRoleEntitlement represents an individual resource entitlement granted through a Role.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#last_accessed ⇒ Object
The most recent time at which any account in the organization accessed this resource.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#resource_id ⇒ Object
The unique identifier of the Resource to which the role grants access.
Instance Method Summary collapse
-
#initialize(group_id: nil, last_accessed: nil, mapped_identities: nil, resource_id: nil) ⇒ GrantedRoleEntitlement
constructor
A new instance of GrantedRoleEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, last_accessed: nil, mapped_identities: nil, resource_id: nil) ⇒ GrantedRoleEntitlement
Returns a new instance of GrantedRoleEntitlement.
8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 |
# File 'lib/models/porcelain.rb', line 8162 def initialize( group_id: nil, last_accessed: nil, mapped_identities: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @last_accessed = last_accessed == nil ? nil : last_accessed @mapped_identities = mapped_identities == nil ? nil : mapped_identities @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
8153 8154 8155 |
# File 'lib/models/porcelain.rb', line 8153 def group_id @group_id end |
#last_accessed ⇒ Object
The most recent time at which any account in the organization accessed this resource. Empty if the resource has never been accessed.
8156 8157 8158 |
# File 'lib/models/porcelain.rb', line 8156 def last_accessed @last_accessed end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
8158 8159 8160 |
# File 'lib/models/porcelain.rb', line 8158 def mapped_identities @mapped_identities end |
#resource_id ⇒ Object
The unique identifier of the Resource to which the role grants access.
8160 8161 8162 |
# File 'lib/models/porcelain.rb', line 8160 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8174 8175 8176 8177 8178 8179 8180 |
# File 'lib/models/porcelain.rb', line 8174 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |