Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



8051
8052
8053
8054
8055
8056
8057
8058
8059
8060
8061
8062
8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
# File 'lib/models/porcelain.rb', line 8051

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8019
8020
8021
# File 'lib/models/porcelain.rb', line 8019

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8021
8022
8023
# File 'lib/models/porcelain.rb', line 8021

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8023
8024
8025
# File 'lib/models/porcelain.rb', line 8023

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8025
8026
8027
# File 'lib/models/porcelain.rb', line 8025

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8027
8028
8029
# File 'lib/models/porcelain.rb', line 8027

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8029
8030
8031
# File 'lib/models/porcelain.rb', line 8029

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8031
8032
8033
# File 'lib/models/porcelain.rb', line 8031

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8033
8034
8035
# File 'lib/models/porcelain.rb', line 8033

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



8035
8036
8037
# File 'lib/models/porcelain.rb', line 8035

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8037
8038
8039
# File 'lib/models/porcelain.rb', line 8037

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8039
8040
8041
# File 'lib/models/porcelain.rb', line 8039

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8041
8042
8043
# File 'lib/models/porcelain.rb', line 8041

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8043
8044
8045
# File 'lib/models/porcelain.rb', line 8043

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



8045
8046
8047
# File 'lib/models/porcelain.rb', line 8045

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8047
8048
8049
# File 'lib/models/porcelain.rb', line 8047

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8049
8050
8051
# File 'lib/models/porcelain.rb', line 8049

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8087
8088
8089
8090
8091
8092
8093
# File 'lib/models/porcelain.rb', line 8087

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end