Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
# File 'lib/models/porcelain.rb', line 6831

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6799
6800
6801
# File 'lib/models/porcelain.rb', line 6799

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6801
6802
6803
# File 'lib/models/porcelain.rb', line 6801

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6803
6804
6805
# File 'lib/models/porcelain.rb', line 6803

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6805
6806
6807
# File 'lib/models/porcelain.rb', line 6805

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6807
6808
6809
# File 'lib/models/porcelain.rb', line 6807

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6809
6810
6811
# File 'lib/models/porcelain.rb', line 6809

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6811
6812
6813
# File 'lib/models/porcelain.rb', line 6811

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



6813
6814
6815
# File 'lib/models/porcelain.rb', line 6813

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



6815
6816
6817
# File 'lib/models/porcelain.rb', line 6815

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6817
6818
6819
# File 'lib/models/porcelain.rb', line 6817

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6819
6820
6821
# File 'lib/models/porcelain.rb', line 6819

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6821
6822
6823
# File 'lib/models/porcelain.rb', line 6821

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6823
6824
6825
# File 'lib/models/porcelain.rb', line 6823

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6825
6826
6827
# File 'lib/models/porcelain.rb', line 6825

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6827
6828
6829
# File 'lib/models/porcelain.rb', line 6827

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6829
6830
6831
# File 'lib/models/porcelain.rb', line 6829

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6867
6868
6869
6870
6871
6872
6873
# File 'lib/models/porcelain.rb', line 6867

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end