Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
6673
6674
6675
6676
6677
6678
6679
6680
6681
6682
6683
6684
6685
6686
6687
# File 'lib/models/porcelain.rb', line 6653

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6621
6622
6623
# File 'lib/models/porcelain.rb', line 6621

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6623
6624
6625
# File 'lib/models/porcelain.rb', line 6623

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6625
6626
6627
# File 'lib/models/porcelain.rb', line 6625

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6627
6628
6629
# File 'lib/models/porcelain.rb', line 6627

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6629
6630
6631
# File 'lib/models/porcelain.rb', line 6629

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6631
6632
6633
# File 'lib/models/porcelain.rb', line 6631

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6633
6634
6635
# File 'lib/models/porcelain.rb', line 6633

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



6635
6636
6637
# File 'lib/models/porcelain.rb', line 6635

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



6637
6638
6639
# File 'lib/models/porcelain.rb', line 6637

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6639
6640
6641
# File 'lib/models/porcelain.rb', line 6639

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6641
6642
6643
# File 'lib/models/porcelain.rb', line 6641

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6643
6644
6645
# File 'lib/models/porcelain.rb', line 6643

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6645
6646
6647
# File 'lib/models/porcelain.rb', line 6645

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6647
6648
6649
# File 'lib/models/porcelain.rb', line 6647

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6649
6650
6651
# File 'lib/models/porcelain.rb', line 6649

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6651
6652
6653
# File 'lib/models/porcelain.rb', line 6651

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6689
6690
6691
6692
6693
6694
6695
# File 'lib/models/porcelain.rb', line 6689

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end