Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



6426
6427
6428
6429
6430
6431
6432
6433
6434
6435
6436
6437
6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
# File 'lib/models/porcelain.rb', line 6426

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6394
6395
6396
# File 'lib/models/porcelain.rb', line 6394

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6396
6397
6398
# File 'lib/models/porcelain.rb', line 6396

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6398
6399
6400
# File 'lib/models/porcelain.rb', line 6398

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6400
6401
6402
# File 'lib/models/porcelain.rb', line 6400

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6402
6403
6404
# File 'lib/models/porcelain.rb', line 6402

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6404
6405
6406
# File 'lib/models/porcelain.rb', line 6404

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6406
6407
6408
# File 'lib/models/porcelain.rb', line 6406

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



6408
6409
6410
# File 'lib/models/porcelain.rb', line 6408

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



6410
6411
6412
# File 'lib/models/porcelain.rb', line 6410

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6412
6413
6414
# File 'lib/models/porcelain.rb', line 6412

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6414
6415
6416
# File 'lib/models/porcelain.rb', line 6414

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6416
6417
6418
# File 'lib/models/porcelain.rb', line 6416

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6418
6419
6420
# File 'lib/models/porcelain.rb', line 6418

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6420
6421
6422
# File 'lib/models/porcelain.rb', line 6420

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6422
6423
6424
# File 'lib/models/porcelain.rb', line 6422

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6424
6425
6426
# File 'lib/models/porcelain.rb', line 6424

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6462
6463
6464
6465
6466
6467
6468
# File 'lib/models/porcelain.rb', line 6462

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end