Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



6358
6359
6360
6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
6387
6388
6389
6390
6391
6392
# File 'lib/models/porcelain.rb', line 6358

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6326
6327
6328
# File 'lib/models/porcelain.rb', line 6326

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6328
6329
6330
# File 'lib/models/porcelain.rb', line 6328

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6330
6331
6332
# File 'lib/models/porcelain.rb', line 6330

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6332
6333
6334
# File 'lib/models/porcelain.rb', line 6332

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6334
6335
6336
# File 'lib/models/porcelain.rb', line 6334

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6336
6337
6338
# File 'lib/models/porcelain.rb', line 6336

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6338
6339
6340
# File 'lib/models/porcelain.rb', line 6338

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



6340
6341
6342
# File 'lib/models/porcelain.rb', line 6340

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



6342
6343
6344
# File 'lib/models/porcelain.rb', line 6342

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6344
6345
6346
# File 'lib/models/porcelain.rb', line 6344

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6346
6347
6348
# File 'lib/models/porcelain.rb', line 6346

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6348
6349
6350
# File 'lib/models/porcelain.rb', line 6348

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6350
6351
6352
# File 'lib/models/porcelain.rb', line 6350

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6352
6353
6354
# File 'lib/models/porcelain.rb', line 6352

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6354
6355
6356
# File 'lib/models/porcelain.rb', line 6354

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6356
6357
6358
# File 'lib/models/porcelain.rb', line 6356

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6394
6395
6396
6397
6398
6399
6400
# File 'lib/models/porcelain.rb', line 6394

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end