Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 |
# File 'lib/models/porcelain.rb', line 6137 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6105 6106 6107 |
# File 'lib/models/porcelain.rb', line 6105 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
6107 6108 6109 |
# File 'lib/models/porcelain.rb', line 6107 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6109 6110 6111 |
# File 'lib/models/porcelain.rb', line 6109 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6111 6112 6113 |
# File 'lib/models/porcelain.rb', line 6111 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6113 6114 6115 |
# File 'lib/models/porcelain.rb', line 6113 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6115 6116 6117 |
# File 'lib/models/porcelain.rb', line 6115 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6117 6118 6119 |
# File 'lib/models/porcelain.rb', line 6117 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
6119 6120 6121 |
# File 'lib/models/porcelain.rb', line 6119 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
6121 6122 6123 |
# File 'lib/models/porcelain.rb', line 6121 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6123 6124 6125 |
# File 'lib/models/porcelain.rb', line 6123 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6125 6126 6127 |
# File 'lib/models/porcelain.rb', line 6125 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
6127 6128 6129 |
# File 'lib/models/porcelain.rb', line 6127 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6129 6130 6131 |
# File 'lib/models/porcelain.rb', line 6129 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6131 6132 6133 |
# File 'lib/models/porcelain.rb', line 6131 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6133 6134 6135 |
# File 'lib/models/porcelain.rb', line 6133 def @tags end |
#username ⇒ Object
The username to authenticate with.
6135 6136 6137 |
# File 'lib/models/porcelain.rb', line 6135 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6173 6174 6175 6176 6177 6178 6179 |
# File 'lib/models/porcelain.rb', line 6173 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |