Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
# File 'lib/models/porcelain.rb', line 5705

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5673
5674
5675
# File 'lib/models/porcelain.rb', line 5673

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



5675
5676
5677
# File 'lib/models/porcelain.rb', line 5675

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5677
5678
5679
# File 'lib/models/porcelain.rb', line 5677

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5679
5680
5681
# File 'lib/models/porcelain.rb', line 5679

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5681
5682
5683
# File 'lib/models/porcelain.rb', line 5681

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5683
5684
5685
# File 'lib/models/porcelain.rb', line 5683

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5685
5686
5687
# File 'lib/models/porcelain.rb', line 5685

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



5687
5688
5689
# File 'lib/models/porcelain.rb', line 5687

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



5689
5690
5691
# File 'lib/models/porcelain.rb', line 5689

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5691
5692
5693
# File 'lib/models/porcelain.rb', line 5691

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5693
5694
5695
# File 'lib/models/porcelain.rb', line 5693

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5695
5696
5697
# File 'lib/models/porcelain.rb', line 5695

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5697
5698
5699
# File 'lib/models/porcelain.rb', line 5697

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5699
5700
5701
# File 'lib/models/porcelain.rb', line 5699

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5701
5702
5703
# File 'lib/models/porcelain.rb', line 5701

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5703
5704
5705
# File 'lib/models/porcelain.rb', line 5703

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5741
5742
5743
5744
5745
5746
5747
# File 'lib/models/porcelain.rb', line 5741

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end