Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
# File 'lib/models/porcelain.rb', line 5219

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5189
5190
5191
# File 'lib/models/porcelain.rb', line 5189

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



5191
5192
5193
# File 'lib/models/porcelain.rb', line 5191

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5193
5194
5195
# File 'lib/models/porcelain.rb', line 5193

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5195
5196
5197
# File 'lib/models/porcelain.rb', line 5195

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5197
5198
5199
# File 'lib/models/porcelain.rb', line 5197

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5199
5200
5201
# File 'lib/models/porcelain.rb', line 5199

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5201
5202
5203
# File 'lib/models/porcelain.rb', line 5201

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



5203
5204
5205
# File 'lib/models/porcelain.rb', line 5203

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



5205
5206
5207
# File 'lib/models/porcelain.rb', line 5205

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5207
5208
5209
# File 'lib/models/porcelain.rb', line 5207

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5209
5210
5211
# File 'lib/models/porcelain.rb', line 5209

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5211
5212
5213
# File 'lib/models/porcelain.rb', line 5211

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5213
5214
5215
# File 'lib/models/porcelain.rb', line 5213

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5215
5216
5217
# File 'lib/models/porcelain.rb', line 5215

def tags
  @tags
end

#usernameObject

The username to authenticate with.



5217
5218
5219
# File 'lib/models/porcelain.rb', line 5217

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5253
5254
5255
5256
5257
5258
5259
# File 'lib/models/porcelain.rb', line 5253

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end