Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/models/porcelain.rb', line 5061 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5031 5032 5033 |
# File 'lib/models/porcelain.rb', line 5031 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
5033 5034 5035 |
# File 'lib/models/porcelain.rb', line 5033 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5035 5036 5037 |
# File 'lib/models/porcelain.rb', line 5035 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5037 5038 5039 |
# File 'lib/models/porcelain.rb', line 5037 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5039 5040 5041 |
# File 'lib/models/porcelain.rb', line 5039 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5041 5042 5043 |
# File 'lib/models/porcelain.rb', line 5041 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5043 5044 5045 |
# File 'lib/models/porcelain.rb', line 5043 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
5045 5046 5047 |
# File 'lib/models/porcelain.rb', line 5045 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
5047 5048 5049 |
# File 'lib/models/porcelain.rb', line 5047 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5049 5050 5051 |
# File 'lib/models/porcelain.rb', line 5049 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5051 5052 5053 |
# File 'lib/models/porcelain.rb', line 5051 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5053 5054 5055 |
# File 'lib/models/porcelain.rb', line 5053 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5055 5056 5057 |
# File 'lib/models/porcelain.rb', line 5055 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5057 5058 5059 |
# File 'lib/models/porcelain.rb', line 5057 def @tags end |
#username ⇒ Object
The username to authenticate with.
5059 5060 5061 |
# File 'lib/models/porcelain.rb', line 5059 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5095 5096 5097 5098 5099 5100 5101 |
# File 'lib/models/porcelain.rb', line 5095 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |