Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 |
# File 'lib/models/porcelain.rb', line 4323 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4293 4294 4295 |
# File 'lib/models/porcelain.rb', line 4293 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4295 4296 4297 |
# File 'lib/models/porcelain.rb', line 4295 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4297 4298 4299 |
# File 'lib/models/porcelain.rb', line 4297 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4299 4300 4301 |
# File 'lib/models/porcelain.rb', line 4299 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4301 4302 4303 |
# File 'lib/models/porcelain.rb', line 4301 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4303 4304 4305 |
# File 'lib/models/porcelain.rb', line 4303 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4305 4306 4307 |
# File 'lib/models/porcelain.rb', line 4305 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
4307 4308 4309 |
# File 'lib/models/porcelain.rb', line 4307 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
4309 4310 4311 |
# File 'lib/models/porcelain.rb', line 4309 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4311 4312 4313 |
# File 'lib/models/porcelain.rb', line 4311 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4313 4314 4315 |
# File 'lib/models/porcelain.rb', line 4313 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4315 4316 4317 |
# File 'lib/models/porcelain.rb', line 4315 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4317 4318 4319 |
# File 'lib/models/porcelain.rb', line 4317 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4319 4320 4321 |
# File 'lib/models/porcelain.rb', line 4319 def @tags end |
#username ⇒ Object
The username to authenticate with.
4321 4322 4323 |
# File 'lib/models/porcelain.rb', line 4321 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4357 4358 4359 4360 4361 4362 4363 |
# File 'lib/models/porcelain.rb', line 4357 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |