Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
4172 4173 4174 4175 4176 4177 4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 |
# File 'lib/models/porcelain.rb', line 4172 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4142 4143 4144 |
# File 'lib/models/porcelain.rb', line 4142 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4144 4145 4146 |
# File 'lib/models/porcelain.rb', line 4144 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4146 4147 4148 |
# File 'lib/models/porcelain.rb', line 4146 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4148 4149 4150 |
# File 'lib/models/porcelain.rb', line 4148 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4150 4151 4152 |
# File 'lib/models/porcelain.rb', line 4150 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4152 4153 4154 |
# File 'lib/models/porcelain.rb', line 4152 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4154 4155 4156 |
# File 'lib/models/porcelain.rb', line 4154 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
4156 4157 4158 |
# File 'lib/models/porcelain.rb', line 4156 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
4158 4159 4160 |
# File 'lib/models/porcelain.rb', line 4158 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4160 4161 4162 |
# File 'lib/models/porcelain.rb', line 4160 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4162 4163 4164 |
# File 'lib/models/porcelain.rb', line 4162 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4164 4165 4166 |
# File 'lib/models/porcelain.rb', line 4164 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4166 4167 4168 |
# File 'lib/models/porcelain.rb', line 4166 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4168 4169 4170 |
# File 'lib/models/porcelain.rb', line 4168 def @tags end |
#username ⇒ Object
The username to authenticate with.
4170 4171 4172 |
# File 'lib/models/porcelain.rb', line 4170 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4206 4207 4208 4209 4210 4211 4212 |
# File 'lib/models/porcelain.rb', line 4206 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |