Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 |
# File 'lib/models/porcelain.rb', line 4000 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
3970 3971 3972 |
# File 'lib/models/porcelain.rb', line 3970 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
3972 3973 3974 |
# File 'lib/models/porcelain.rb', line 3972 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3974 3975 3976 |
# File 'lib/models/porcelain.rb', line 3974 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3976 3977 3978 |
# File 'lib/models/porcelain.rb', line 3976 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
3978 3979 3980 |
# File 'lib/models/porcelain.rb', line 3978 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3980 3981 3982 |
# File 'lib/models/porcelain.rb', line 3980 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3982 3983 3984 |
# File 'lib/models/porcelain.rb', line 3982 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
3984 3985 3986 |
# File 'lib/models/porcelain.rb', line 3984 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
3986 3987 3988 |
# File 'lib/models/porcelain.rb', line 3986 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
3988 3989 3990 |
# File 'lib/models/porcelain.rb', line 3988 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
3990 3991 3992 |
# File 'lib/models/porcelain.rb', line 3990 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3992 3993 3994 |
# File 'lib/models/porcelain.rb', line 3992 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3994 3995 3996 |
# File 'lib/models/porcelain.rb', line 3994 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3996 3997 3998 |
# File 'lib/models/porcelain.rb', line 3996 def @tags end |
#username ⇒ Object
The username to authenticate with.
3998 3999 4000 |
# File 'lib/models/porcelain.rb', line 3998 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4034 4035 4036 4037 4038 4039 4040 |
# File 'lib/models/porcelain.rb', line 4034 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |