Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 |
# File 'lib/models/porcelain.rb', line 3862 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3832 3833 3834 |
# File 'lib/models/porcelain.rb', line 3832 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
3834 3835 3836 |
# File 'lib/models/porcelain.rb', line 3834 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3836 3837 3838 |
# File 'lib/models/porcelain.rb', line 3836 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3838 3839 3840 |
# File 'lib/models/porcelain.rb', line 3838 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3840 3841 3842 |
# File 'lib/models/porcelain.rb', line 3840 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3842 3843 3844 |
# File 'lib/models/porcelain.rb', line 3842 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3844 3845 3846 |
# File 'lib/models/porcelain.rb', line 3844 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3846 3847 3848 |
# File 'lib/models/porcelain.rb', line 3846 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3848 3849 3850 |
# File 'lib/models/porcelain.rb', line 3848 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3850 3851 3852 |
# File 'lib/models/porcelain.rb', line 3850 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3852 3853 3854 |
# File 'lib/models/porcelain.rb', line 3852 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3854 3855 3856 |
# File 'lib/models/porcelain.rb', line 3854 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3856 3857 3858 |
# File 'lib/models/porcelain.rb', line 3856 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3858 3859 3860 |
# File 'lib/models/porcelain.rb', line 3858 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3860 3861 3862 |
# File 'lib/models/porcelain.rb', line 3860 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3896 3897 3898 3899 3900 3901 3902 |
# File 'lib/models/porcelain.rb', line 3896 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |