Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



3846
3847
3848
3849
3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
3878
# File 'lib/models/porcelain.rb', line 3846

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3816
3817
3818
# File 'lib/models/porcelain.rb', line 3816

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



3818
3819
3820
# File 'lib/models/porcelain.rb', line 3818

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3820
3821
3822
# File 'lib/models/porcelain.rb', line 3820

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3822
3823
3824
# File 'lib/models/porcelain.rb', line 3822

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3824
3825
3826
# File 'lib/models/porcelain.rb', line 3824

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3826
3827
3828
# File 'lib/models/porcelain.rb', line 3826

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3828
3829
3830
# File 'lib/models/porcelain.rb', line 3828

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



3830
3831
3832
# File 'lib/models/porcelain.rb', line 3830

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



3832
3833
3834
# File 'lib/models/porcelain.rb', line 3832

def password
  @password
end

#portObject

Returns the value of attribute port.



3834
3835
3836
# File 'lib/models/porcelain.rb', line 3834

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3836
3837
3838
# File 'lib/models/porcelain.rb', line 3836

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3838
3839
3840
# File 'lib/models/porcelain.rb', line 3838

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



3840
3841
3842
# File 'lib/models/porcelain.rb', line 3840

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3842
3843
3844
# File 'lib/models/porcelain.rb', line 3842

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3844
3845
3846
# File 'lib/models/porcelain.rb', line 3844

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3880
3881
3882
3883
3884
3885
3886
# File 'lib/models/porcelain.rb', line 3880

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end