Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 |
# File 'lib/models/porcelain.rb', line 3692 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3662 3663 3664 |
# File 'lib/models/porcelain.rb', line 3662 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
3664 3665 3666 |
# File 'lib/models/porcelain.rb', line 3664 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3666 3667 3668 |
# File 'lib/models/porcelain.rb', line 3666 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3668 3669 3670 |
# File 'lib/models/porcelain.rb', line 3668 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3670 3671 3672 |
# File 'lib/models/porcelain.rb', line 3670 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3672 3673 3674 |
# File 'lib/models/porcelain.rb', line 3672 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3674 3675 3676 |
# File 'lib/models/porcelain.rb', line 3674 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3676 3677 3678 |
# File 'lib/models/porcelain.rb', line 3676 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3678 3679 3680 |
# File 'lib/models/porcelain.rb', line 3678 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3680 3681 3682 |
# File 'lib/models/porcelain.rb', line 3680 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3682 3683 3684 |
# File 'lib/models/porcelain.rb', line 3682 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3684 3685 3686 |
# File 'lib/models/porcelain.rb', line 3684 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
3686 3687 3688 |
# File 'lib/models/porcelain.rb', line 3686 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3688 3689 3690 |
# File 'lib/models/porcelain.rb', line 3688 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3690 3691 3692 |
# File 'lib/models/porcelain.rb', line 3690 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3726 3727 3728 3729 3730 3731 3732 |
# File 'lib/models/porcelain.rb', line 3726 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |