Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 3597 3598 3599 3600 |
# File 'lib/models/porcelain.rb', line 3570 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3542 3543 3544 |
# File 'lib/models/porcelain.rb', line 3542 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
3544 3545 3546 |
# File 'lib/models/porcelain.rb', line 3544 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3546 3547 3548 |
# File 'lib/models/porcelain.rb', line 3546 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3548 3549 3550 |
# File 'lib/models/porcelain.rb', line 3548 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3550 3551 3552 |
# File 'lib/models/porcelain.rb', line 3550 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3552 3553 3554 |
# File 'lib/models/porcelain.rb', line 3552 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3554 3555 3556 |
# File 'lib/models/porcelain.rb', line 3554 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3556 3557 3558 |
# File 'lib/models/porcelain.rb', line 3556 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3558 3559 3560 |
# File 'lib/models/porcelain.rb', line 3558 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3560 3561 3562 |
# File 'lib/models/porcelain.rb', line 3560 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3562 3563 3564 |
# File 'lib/models/porcelain.rb', line 3562 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3564 3565 3566 |
# File 'lib/models/porcelain.rb', line 3564 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3566 3567 3568 |
# File 'lib/models/porcelain.rb', line 3566 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3568 3569 3570 |
# File 'lib/models/porcelain.rb', line 3568 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3602 3603 3604 3605 3606 3607 3608 |
# File 'lib/models/porcelain.rb', line 3602 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |