Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
3232 3233 3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 |
# File 'lib/models/porcelain.rb', line 3232 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3204 3205 3206 |
# File 'lib/models/porcelain.rb', line 3204 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
3206 3207 3208 |
# File 'lib/models/porcelain.rb', line 3206 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3208 3209 3210 |
# File 'lib/models/porcelain.rb', line 3208 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3210 3211 3212 |
# File 'lib/models/porcelain.rb', line 3210 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3212 3213 3214 |
# File 'lib/models/porcelain.rb', line 3212 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3214 3215 3216 |
# File 'lib/models/porcelain.rb', line 3214 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3216 3217 3218 |
# File 'lib/models/porcelain.rb', line 3216 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3218 3219 3220 |
# File 'lib/models/porcelain.rb', line 3218 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3220 3221 3222 |
# File 'lib/models/porcelain.rb', line 3220 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3222 3223 3224 |
# File 'lib/models/porcelain.rb', line 3222 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3224 3225 3226 |
# File 'lib/models/porcelain.rb', line 3224 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3226 3227 3228 |
# File 'lib/models/porcelain.rb', line 3226 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3228 3229 3230 |
# File 'lib/models/porcelain.rb', line 3228 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3230 3231 3232 |
# File 'lib/models/porcelain.rb', line 3230 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3264 3265 3266 3267 3268 3269 3270 |
# File 'lib/models/porcelain.rb', line 3264 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |