Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/models/porcelain.rb', line 3233

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3205
3206
3207
# File 'lib/models/porcelain.rb', line 3205

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



3207
3208
3209
# File 'lib/models/porcelain.rb', line 3207

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3209
3210
3211
# File 'lib/models/porcelain.rb', line 3209

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3211
3212
3213
# File 'lib/models/porcelain.rb', line 3211

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3213
3214
3215
# File 'lib/models/porcelain.rb', line 3213

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3215
3216
3217
# File 'lib/models/porcelain.rb', line 3215

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3217
3218
3219
# File 'lib/models/porcelain.rb', line 3217

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



3219
3220
3221
# File 'lib/models/porcelain.rb', line 3219

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



3221
3222
3223
# File 'lib/models/porcelain.rb', line 3221

def password
  @password
end

#portObject

Returns the value of attribute port.



3223
3224
3225
# File 'lib/models/porcelain.rb', line 3223

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3225
3226
3227
# File 'lib/models/porcelain.rb', line 3225

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3227
3228
3229
# File 'lib/models/porcelain.rb', line 3227

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3229
3230
3231
# File 'lib/models/porcelain.rb', line 3229

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3231
3232
3233
# File 'lib/models/porcelain.rb', line 3231

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3265
3266
3267
3268
3269
3270
3271
# File 'lib/models/porcelain.rb', line 3265

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end