Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 3145 3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 |
# File 'lib/models/porcelain.rb', line 3125 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3097 3098 3099 |
# File 'lib/models/porcelain.rb', line 3097 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
3099 3100 3101 |
# File 'lib/models/porcelain.rb', line 3099 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3101 3102 3103 |
# File 'lib/models/porcelain.rb', line 3101 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3103 3104 3105 |
# File 'lib/models/porcelain.rb', line 3103 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3105 3106 3107 |
# File 'lib/models/porcelain.rb', line 3105 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3107 3108 3109 |
# File 'lib/models/porcelain.rb', line 3107 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3109 3110 3111 |
# File 'lib/models/porcelain.rb', line 3109 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3111 3112 3113 |
# File 'lib/models/porcelain.rb', line 3111 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3113 3114 3115 |
# File 'lib/models/porcelain.rb', line 3113 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3115 3116 3117 |
# File 'lib/models/porcelain.rb', line 3115 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3117 3118 3119 |
# File 'lib/models/porcelain.rb', line 3117 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3119 3120 3121 |
# File 'lib/models/porcelain.rb', line 3119 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3121 3122 3123 |
# File 'lib/models/porcelain.rb', line 3121 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3123 3124 3125 |
# File 'lib/models/porcelain.rb', line 3123 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3157 3158 3159 3160 3161 3162 3163 |
# File 'lib/models/porcelain.rb', line 3157 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |