Class: SDM::Greenplum

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum

Returns a new instance of Greenplum.



3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
3148
3149
3150
3151
# File 'lib/models/porcelain.rb', line 3121

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3093
3094
3095
# File 'lib/models/porcelain.rb', line 3093

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



3095
3096
3097
# File 'lib/models/porcelain.rb', line 3095

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3097
3098
3099
# File 'lib/models/porcelain.rb', line 3097

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3099
3100
3101
# File 'lib/models/porcelain.rb', line 3099

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3101
3102
3103
# File 'lib/models/porcelain.rb', line 3101

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3103
3104
3105
# File 'lib/models/porcelain.rb', line 3103

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3105
3106
3107
# File 'lib/models/porcelain.rb', line 3105

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



3107
3108
3109
# File 'lib/models/porcelain.rb', line 3107

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



3109
3110
3111
# File 'lib/models/porcelain.rb', line 3109

def password
  @password
end

#portObject

Returns the value of attribute port.



3111
3112
3113
# File 'lib/models/porcelain.rb', line 3111

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3113
3114
3115
# File 'lib/models/porcelain.rb', line 3113

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3115
3116
3117
# File 'lib/models/porcelain.rb', line 3115

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3117
3118
3119
# File 'lib/models/porcelain.rb', line 3117

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3119
3120
3121
# File 'lib/models/porcelain.rb', line 3119

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3153
3154
3155
3156
3157
3158
3159
# File 'lib/models/porcelain.rb', line 3153

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end