Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
3106 3107 3108 3109 3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 |
# File 'lib/models/porcelain.rb', line 3106 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3078 3079 3080 |
# File 'lib/models/porcelain.rb', line 3078 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
3080 3081 3082 |
# File 'lib/models/porcelain.rb', line 3080 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3082 3083 3084 |
# File 'lib/models/porcelain.rb', line 3082 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3084 3085 3086 |
# File 'lib/models/porcelain.rb', line 3084 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3086 3087 3088 |
# File 'lib/models/porcelain.rb', line 3086 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3088 3089 3090 |
# File 'lib/models/porcelain.rb', line 3088 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3090 3091 3092 |
# File 'lib/models/porcelain.rb', line 3090 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3092 3093 3094 |
# File 'lib/models/porcelain.rb', line 3092 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3094 3095 3096 |
# File 'lib/models/porcelain.rb', line 3094 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3096 3097 3098 |
# File 'lib/models/porcelain.rb', line 3096 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3098 3099 3100 |
# File 'lib/models/porcelain.rb', line 3098 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3100 3101 3102 |
# File 'lib/models/porcelain.rb', line 3100 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3102 3103 3104 |
# File 'lib/models/porcelain.rb', line 3102 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3104 3105 3106 |
# File 'lib/models/porcelain.rb', line 3104 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3138 3139 3140 3141 3142 3143 3144 |
# File 'lib/models/porcelain.rb', line 3138 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |