Class: SDM::Greenplum
- Inherits:
-
Object
- Object
- SDM::Greenplum
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
constructor
A new instance of Greenplum.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Greenplum
Returns a new instance of Greenplum.
3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/models/porcelain.rb', line 3418 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if override_database != nil @override_database = override_database end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
3392 3393 3394 |
# File 'lib/models/porcelain.rb', line 3392 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3394 3395 3396 |
# File 'lib/models/porcelain.rb', line 3394 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3396 3397 3398 |
# File 'lib/models/porcelain.rb', line 3396 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3398 3399 3400 |
# File 'lib/models/porcelain.rb', line 3398 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3400 3401 3402 |
# File 'lib/models/porcelain.rb', line 3400 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3402 3403 3404 |
# File 'lib/models/porcelain.rb', line 3402 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3404 3405 3406 |
# File 'lib/models/porcelain.rb', line 3404 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3406 3407 3408 |
# File 'lib/models/porcelain.rb', line 3406 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3408 3409 3410 |
# File 'lib/models/porcelain.rb', line 3408 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3410 3411 3412 |
# File 'lib/models/porcelain.rb', line 3410 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3412 3413 3414 |
# File 'lib/models/porcelain.rb', line 3412 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3414 3415 3416 |
# File 'lib/models/porcelain.rb', line 3414 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3416 3417 3418 |
# File 'lib/models/porcelain.rb', line 3416 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3474 3475 3476 3477 3478 3479 3480 |
# File 'lib/models/porcelain.rb', line 3474 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |