Class: SDM::Group
- Inherits:
-
Object
- Object
- SDM::Group
- Defined in:
- lib/models/porcelain.rb
Overview
A Group is a named set of principals.
Instance Attribute Summary collapse
-
#description ⇒ Object
Description of the Group.
-
#id ⇒ Object
Unique identifier of the Group.
-
#name ⇒ Object
Unique human-readable name of the Group.
-
#source ⇒ Object
Source is a read only field for what service manages this group, e.g.
-
#tags ⇒ Object
Tags is a map of key/value pairs that can be attached to a Group.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, source: nil, tags: nil) ⇒ Group
constructor
A new instance of Group.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, source: nil, tags: nil) ⇒ Group
Returns a new instance of Group.
8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 |
# File 'lib/models/porcelain.rb', line 8311 def initialize( description: nil, id: nil, name: nil, source: nil, tags: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @source = source == nil ? "" : source @tags = == nil ? SDM::() : end |
Instance Attribute Details
#description ⇒ Object
Description of the Group.
8301 8302 8303 |
# File 'lib/models/porcelain.rb', line 8301 def description @description end |
#id ⇒ Object
Unique identifier of the Group.
8303 8304 8305 |
# File 'lib/models/porcelain.rb', line 8303 def id @id end |
#name ⇒ Object
Unique human-readable name of the Group.
8305 8306 8307 |
# File 'lib/models/porcelain.rb', line 8305 def name @name end |
#source ⇒ Object
Source is a read only field for what service manages this group, e.g. StrongDM, Okta, Azure.
8307 8308 8309 |
# File 'lib/models/porcelain.rb', line 8307 def source @source end |
#tags ⇒ Object
Tags is a map of key/value pairs that can be attached to a Group.
8309 8310 8311 |
# File 'lib/models/porcelain.rb', line 8309 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8325 8326 8327 8328 8329 8330 8331 |
# File 'lib/models/porcelain.rb', line 8325 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |