Class: SDM::Group

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Group is a named set of principals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, source: nil, tags: nil) ⇒ Group

Returns a new instance of Group.



7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
# File 'lib/models/porcelain.rb', line 7138

def initialize(
  description: nil,
  id: nil,
  name: nil,
  source: nil,
  tags: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @source = source == nil ? "" : source
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#descriptionObject

Description of the Group.



7128
7129
7130
# File 'lib/models/porcelain.rb', line 7128

def description
  @description
end

#idObject

Unique identifier of the Group.



7130
7131
7132
# File 'lib/models/porcelain.rb', line 7130

def id
  @id
end

#nameObject

Unique human-readable name of the Group.



7132
7133
7134
# File 'lib/models/porcelain.rb', line 7132

def name
  @name
end

#sourceObject

Source is a read only field for what service manages this group, e.g. StrongDM, Okta, Azure.



7134
7135
7136
# File 'lib/models/porcelain.rb', line 7134

def source
  @source
end

#tagsObject

Tags is a map of key/value pairs that can be attached to a Group.



7136
7137
7138
# File 'lib/models/porcelain.rb', line 7136

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7152
7153
7154
7155
7156
7157
7158
# File 'lib/models/porcelain.rb', line 7152

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end