Class: SDM::GroupCreateFromRolesRequest
- Inherits:
-
Object
- Object
- SDM::GroupCreateFromRolesRequest
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#commit ⇒ Object
Commit.
-
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
Instance Method Summary collapse
-
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
constructor
A new instance of GroupCreateFromRolesRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
Returns a new instance of GroupCreateFromRolesRequest.
8304 8305 8306 8307 8308 8309 8310 |
# File 'lib/models/porcelain.rb', line 8304 def initialize( commit: nil, role_ids: nil ) @commit = commit == nil ? false : commit @role_ids = role_ids == nil ? [] : role_ids end |
Instance Attribute Details
#commit ⇒ Object
Commit
8300 8301 8302 |
# File 'lib/models/porcelain.rb', line 8300 def commit @commit end |
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
8302 8303 8304 |
# File 'lib/models/porcelain.rb', line 8302 def role_ids @role_ids end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8312 8313 8314 8315 8316 8317 8318 |
# File 'lib/models/porcelain.rb', line 8312 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |