Class: SDM::GroupCreateFromRolesRequest
- Inherits:
-
Object
- Object
- SDM::GroupCreateFromRolesRequest
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#commit ⇒ Object
Commit.
-
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
Instance Method Summary collapse
-
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
constructor
A new instance of GroupCreateFromRolesRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
Returns a new instance of GroupCreateFromRolesRequest.
8061 8062 8063 8064 8065 8066 8067 |
# File 'lib/models/porcelain.rb', line 8061 def initialize( commit: nil, role_ids: nil ) @commit = commit == nil ? false : commit @role_ids = role_ids == nil ? [] : role_ids end |
Instance Attribute Details
#commit ⇒ Object
Commit
8057 8058 8059 |
# File 'lib/models/porcelain.rb', line 8057 def commit @commit end |
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
8059 8060 8061 |
# File 'lib/models/porcelain.rb', line 8059 def role_ids @role_ids end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8069 8070 8071 8072 8073 8074 8075 |
# File 'lib/models/porcelain.rb', line 8069 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |