Class: SDM::GroupCreateFromRolesRequest
- Inherits:
-
Object
- Object
- SDM::GroupCreateFromRolesRequest
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#commit ⇒ Object
Commit.
-
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
Instance Method Summary collapse
-
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
constructor
A new instance of GroupCreateFromRolesRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
Returns a new instance of GroupCreateFromRolesRequest.
7167 7168 7169 7170 7171 7172 7173 |
# File 'lib/models/porcelain.rb', line 7167 def initialize( commit: nil, role_ids: nil ) @commit = commit == nil ? false : commit @role_ids = role_ids == nil ? [] : role_ids end |
Instance Attribute Details
#commit ⇒ Object
Commit
7163 7164 7165 |
# File 'lib/models/porcelain.rb', line 7163 def commit @commit end |
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
7165 7166 7167 |
# File 'lib/models/porcelain.rb', line 7165 def role_ids @role_ids end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7175 7176 7177 7178 7179 7180 7181 |
# File 'lib/models/porcelain.rb', line 7175 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |