Class: SDM::GroupCreateFromRolesRequest
- Inherits:
-
Object
- Object
- SDM::GroupCreateFromRolesRequest
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#commit ⇒ Object
Commit.
-
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
Instance Method Summary collapse
-
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
constructor
A new instance of GroupCreateFromRolesRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(commit: nil, role_ids: nil) ⇒ GroupCreateFromRolesRequest
Returns a new instance of GroupCreateFromRolesRequest.
8416 8417 8418 8419 8420 8421 8422 |
# File 'lib/models/porcelain.rb', line 8416 def initialize( commit: nil, role_ids: nil ) @commit = commit == nil ? false : commit @role_ids = role_ids == nil ? [] : role_ids end |
Instance Attribute Details
#commit ⇒ Object
Commit
8412 8413 8414 |
# File 'lib/models/porcelain.rb', line 8412 def commit @commit end |
#role_ids ⇒ Object
The unique identifiers of the roles create groups from.
8414 8415 8416 |
# File 'lib/models/porcelain.rb', line 8414 def role_ids @role_ids end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8424 8425 8426 8427 8428 8429 8430 |
# File 'lib/models/porcelain.rb', line 8424 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |