Class: SDM::GroupHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GroupHistory records the state of a Group at a given point in time, where every change (create, update and delete) to a Group produces a GroupHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, group: nil, timestamp: nil) ⇒ GroupHistory

Returns a new instance of GroupHistory.



8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
# File 'lib/models/porcelain.rb', line 8565

def initialize(
  activity_id: nil,
  deleted_at: nil,
  group: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @group = group == nil ? nil : group
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Group. May be empty for some system-initiated updates.



8557
8558
8559
# File 'lib/models/porcelain.rb', line 8557

def activity_id
  @activity_id
end

#deleted_atObject

If this Group was deleted, the time it was deleted.



8559
8560
8561
# File 'lib/models/porcelain.rb', line 8559

def deleted_at
  @deleted_at
end

#groupObject

The complete Group state at this time.



8561
8562
8563
# File 'lib/models/porcelain.rb', line 8561

def group
  @group
end

#timestampObject

The time at which the Group state was recorded.



8563
8564
8565
# File 'lib/models/porcelain.rb', line 8563

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8577
8578
8579
8580
8581
8582
8583
# File 'lib/models/porcelain.rb', line 8577

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end