Class: SDM::GroupHistory
- Inherits:
-
Object
- Object
- SDM::GroupHistory
- Defined in:
- lib/models/porcelain.rb
Overview
GroupHistory records the state of a Group at a given point in time, where every change (create, update and delete) to a Group produces a GroupHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Group.
-
#deleted_at ⇒ Object
If this Group was deleted, the time it was deleted.
-
#group ⇒ Object
The complete Group state at this time.
-
#timestamp ⇒ Object
The time at which the Group state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, group: nil, timestamp: nil) ⇒ GroupHistory
constructor
A new instance of GroupHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, group: nil, timestamp: nil) ⇒ GroupHistory
Returns a new instance of GroupHistory.
8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 |
# File 'lib/models/porcelain.rb', line 8529 def initialize( activity_id: nil, deleted_at: nil, group: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @group = group == nil ? nil : group @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Group. May be empty for some system-initiated updates.
8521 8522 8523 |
# File 'lib/models/porcelain.rb', line 8521 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Group was deleted, the time it was deleted.
8523 8524 8525 |
# File 'lib/models/porcelain.rb', line 8523 def deleted_at @deleted_at end |
#group ⇒ Object
The complete Group state at this time.
8525 8526 8527 |
# File 'lib/models/porcelain.rb', line 8525 def group @group end |
#timestamp ⇒ Object
The time at which the Group state was recorded.
8527 8528 8529 |
# File 'lib/models/porcelain.rb', line 8527 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8541 8542 8543 8544 8545 8546 8547 |
# File 'lib/models/porcelain.rb', line 8541 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |