Class: SDM::GroupHistory
- Inherits:
-
Object
- Object
- SDM::GroupHistory
- Defined in:
- lib/models/porcelain.rb
Overview
GroupHistory records the state of a Group at a given point in time, where every change (create, update and delete) to a Group produces a GroupHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Group.
-
#deleted_at ⇒ Object
If this Group was deleted, the time it was deleted.
-
#group ⇒ Object
The complete Group state at this time.
-
#timestamp ⇒ Object
The time at which the Group state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, group: nil, timestamp: nil) ⇒ GroupHistory
constructor
A new instance of GroupHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, group: nil, timestamp: nil) ⇒ GroupHistory
Returns a new instance of GroupHistory.
8000 8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 |
# File 'lib/models/porcelain.rb', line 8000 def initialize( activity_id: nil, deleted_at: nil, group: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @group = group == nil ? nil : group @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Group. May be empty for some system-initiated updates.
7992 7993 7994 |
# File 'lib/models/porcelain.rb', line 7992 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Group was deleted, the time it was deleted.
7994 7995 7996 |
# File 'lib/models/porcelain.rb', line 7994 def deleted_at @deleted_at end |
#group ⇒ Object
The complete Group state at this time.
7996 7997 7998 |
# File 'lib/models/porcelain.rb', line 7996 def group @group end |
#timestamp ⇒ Object
The time at which the Group state was recorded.
7998 7999 8000 |
# File 'lib/models/porcelain.rb', line 7998 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8012 8013 8014 8015 8016 8017 8018 |
# File 'lib/models/porcelain.rb', line 8012 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |