Class: SDM::GroupRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GroupRoleHistory records the state of a GroupRole at a given point in time, where every change (create, update and delete) to a GroupRole produces a GroupRoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, group_role: nil, timestamp: nil) ⇒ GroupRoleHistory

Returns a new instance of GroupRoleHistory.



8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
# File 'lib/models/porcelain.rb', line 8534

def initialize(
  activity_id: nil,
  deleted_at: nil,
  group_role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @group_role = group_role == nil ? nil : group_role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the GroupRole. May be empty for some system-initiated updates.



8526
8527
8528
# File 'lib/models/porcelain.rb', line 8526

def activity_id
  @activity_id
end

#deleted_atObject

If this GroupRole was deleted, the time it was deleted.



8528
8529
8530
# File 'lib/models/porcelain.rb', line 8528

def deleted_at
  @deleted_at
end

#group_roleObject

The complete GroupRole state at this time.



8530
8531
8532
# File 'lib/models/porcelain.rb', line 8530

def group_role
  @group_role
end

#timestampObject

The time at which the GroupRole state was recorded.



8532
8533
8534
# File 'lib/models/porcelain.rb', line 8532

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8546
8547
8548
8549
8550
8551
8552
# File 'lib/models/porcelain.rb', line 8546

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end