Class: SDM::GroupRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GroupRoleHistory records the state of a GroupRole at a given point in time, where every change (create, update and delete) to a GroupRole produces a GroupRoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, group_role: nil, timestamp: nil) ⇒ GroupRoleHistory

Returns a new instance of GroupRoleHistory.



8244
8245
8246
8247
8248
8249
8250
8251
8252
8253
8254
# File 'lib/models/porcelain.rb', line 8244

def initialize(
  activity_id: nil,
  deleted_at: nil,
  group_role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @group_role = group_role == nil ? nil : group_role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the GroupRole. May be empty for some system-initiated updates.



8236
8237
8238
# File 'lib/models/porcelain.rb', line 8236

def activity_id
  @activity_id
end

#deleted_atObject

If this GroupRole was deleted, the time it was deleted.



8238
8239
8240
# File 'lib/models/porcelain.rb', line 8238

def deleted_at
  @deleted_at
end

#group_roleObject

The complete GroupRole state at this time.



8240
8241
8242
# File 'lib/models/porcelain.rb', line 8240

def group_role
  @group_role
end

#timestampObject

The time at which the GroupRole state was recorded.



8242
8243
8244
# File 'lib/models/porcelain.rb', line 8242

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8256
8257
8258
8259
8260
8261
8262
# File 'lib/models/porcelain.rb', line 8256

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end