Class: SDM::GroupRoleHistory
- Inherits:
-
Object
- Object
- SDM::GroupRoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
GroupRoleHistory records the state of a GroupRole at a given point in time, where every change (create, update and delete) to a GroupRole produces a GroupRoleHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the GroupRole.
-
#deleted_at ⇒ Object
If this GroupRole was deleted, the time it was deleted.
-
#group_role ⇒ Object
The complete GroupRole state at this time.
-
#timestamp ⇒ Object
The time at which the GroupRole state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, group_role: nil, timestamp: nil) ⇒ GroupRoleHistory
constructor
A new instance of GroupRoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, group_role: nil, timestamp: nil) ⇒ GroupRoleHistory
Returns a new instance of GroupRoleHistory.
8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 |
# File 'lib/models/porcelain.rb', line 8747 def initialize( activity_id: nil, deleted_at: nil, group_role: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @group_role = group_role == nil ? nil : group_role @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the GroupRole. May be empty for some system-initiated updates.
8739 8740 8741 |
# File 'lib/models/porcelain.rb', line 8739 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this GroupRole was deleted, the time it was deleted.
8741 8742 8743 |
# File 'lib/models/porcelain.rb', line 8741 def deleted_at @deleted_at end |
#group_role ⇒ Object
The complete GroupRole state at this time.
8743 8744 8745 |
# File 'lib/models/porcelain.rb', line 8743 def group_role @group_role end |
#timestamp ⇒ Object
The time at which the GroupRole state was recorded.
8745 8746 8747 |
# File 'lib/models/porcelain.rb', line 8745 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8759 8760 8761 8762 8763 8764 8765 |
# File 'lib/models/porcelain.rb', line 8759 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |