Class: SDM::GroupRoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

GroupRoleHistory records the state of a GroupRole at a given point in time, where every change (create, update and delete) to a GroupRole produces a GroupRoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, group_role: nil, timestamp: nil) ⇒ GroupRoleHistory



8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
# File 'lib/models/porcelain.rb', line 8607

def initialize(
  activity_id: nil,
  deleted_at: nil,
  group_role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @group_role = group_role == nil ? nil : group_role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the GroupRole. May be empty for some system-initiated updates.



8599
8600
8601
# File 'lib/models/porcelain.rb', line 8599

def activity_id
  @activity_id
end

#deleted_atObject

If this GroupRole was deleted, the time it was deleted.



8601
8602
8603
# File 'lib/models/porcelain.rb', line 8601

def deleted_at
  @deleted_at
end

#group_roleObject

The complete GroupRole state at this time.



8603
8604
8605
# File 'lib/models/porcelain.rb', line 8603

def group_role
  @group_role
end

#timestampObject

The time at which the GroupRole state was recorded.



8605
8606
8607
# File 'lib/models/porcelain.rb', line 8605

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8619
8620
8621
8622
8623
8624
8625
# File 'lib/models/porcelain.rb', line 8619

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end