Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
8708
8709
8710
8711
8712
8713
# File 'lib/models/porcelain.rb', line 8677

def initialize(
  auth_header: nil,
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



8643
8644
8645
# File 'lib/models/porcelain.rb', line 8643

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8645
8646
8647
# File 'lib/models/porcelain.rb', line 8645

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8647
8648
8649
# File 'lib/models/porcelain.rb', line 8647

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8649
8650
8651
# File 'lib/models/porcelain.rb', line 8649

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8651
8652
8653
# File 'lib/models/porcelain.rb', line 8651

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8653
8654
8655
# File 'lib/models/porcelain.rb', line 8653

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8655
8656
8657
# File 'lib/models/porcelain.rb', line 8655

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8657
8658
8659
# File 'lib/models/porcelain.rb', line 8657

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8659
8660
8661
# File 'lib/models/porcelain.rb', line 8659

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8661
8662
8663
# File 'lib/models/porcelain.rb', line 8661

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8663
8664
8665
# File 'lib/models/porcelain.rb', line 8663

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8665
8666
8667
# File 'lib/models/porcelain.rb', line 8665

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8667
8668
8669
# File 'lib/models/porcelain.rb', line 8667

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8669
8670
8671
# File 'lib/models/porcelain.rb', line 8669

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8671
8672
8673
# File 'lib/models/porcelain.rb', line 8671

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8673
8674
8675
# File 'lib/models/porcelain.rb', line 8673

def tags
  @tags
end

#urlObject

The base address of your website without the path.



8675
8676
8677
# File 'lib/models/porcelain.rb', line 8675

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8715
8716
8717
8718
8719
8720
8721
# File 'lib/models/porcelain.rb', line 8715

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end