Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
# File 'lib/models/porcelain.rb', line 6730

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



6700
6701
6702
# File 'lib/models/porcelain.rb', line 6700

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6702
6703
6704
# File 'lib/models/porcelain.rb', line 6702

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6704
6705
6706
# File 'lib/models/porcelain.rb', line 6704

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6706
6707
6708
# File 'lib/models/porcelain.rb', line 6706

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6708
6709
6710
# File 'lib/models/porcelain.rb', line 6708

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6710
6711
6712
# File 'lib/models/porcelain.rb', line 6710

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6712
6713
6714
# File 'lib/models/porcelain.rb', line 6712

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6714
6715
6716
# File 'lib/models/porcelain.rb', line 6714

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6716
6717
6718
# File 'lib/models/porcelain.rb', line 6716

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6718
6719
6720
# File 'lib/models/porcelain.rb', line 6718

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6720
6721
6722
# File 'lib/models/porcelain.rb', line 6720

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6722
6723
6724
# File 'lib/models/porcelain.rb', line 6722

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6724
6725
6726
# File 'lib/models/porcelain.rb', line 6724

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6726
6727
6728
# File 'lib/models/porcelain.rb', line 6726

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6728
6729
6730
# File 'lib/models/porcelain.rb', line 6728

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6764
6765
6766
6767
6768
6769
6770
# File 'lib/models/porcelain.rb', line 6764

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end