Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
6600
6601
6602
6603
6604
6605
6606
6607
6608
6609
6610
6611
6612
6613
6614
# File 'lib/models/porcelain.rb', line 6582

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



6552
6553
6554
# File 'lib/models/porcelain.rb', line 6552

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6554
6555
6556
# File 'lib/models/porcelain.rb', line 6554

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6556
6557
6558
# File 'lib/models/porcelain.rb', line 6556

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6558
6559
6560
# File 'lib/models/porcelain.rb', line 6558

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6560
6561
6562
# File 'lib/models/porcelain.rb', line 6560

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6562
6563
6564
# File 'lib/models/porcelain.rb', line 6562

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6564
6565
6566
# File 'lib/models/porcelain.rb', line 6564

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6566
6567
6568
# File 'lib/models/porcelain.rb', line 6566

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6568
6569
6570
# File 'lib/models/porcelain.rb', line 6568

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6570
6571
6572
# File 'lib/models/porcelain.rb', line 6570

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6572
6573
6574
# File 'lib/models/porcelain.rb', line 6572

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6574
6575
6576
# File 'lib/models/porcelain.rb', line 6574

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6576
6577
6578
# File 'lib/models/porcelain.rb', line 6576

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6578
6579
6580
# File 'lib/models/porcelain.rb', line 6578

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6580
6581
6582
# File 'lib/models/porcelain.rb', line 6580

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6616
6617
6618
6619
6620
6621
6622
# File 'lib/models/porcelain.rb', line 6616

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end