Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
# File 'lib/models/porcelain.rb', line 6292

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



6262
6263
6264
# File 'lib/models/porcelain.rb', line 6262

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6264
6265
6266
# File 'lib/models/porcelain.rb', line 6264

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6266
6267
6268
# File 'lib/models/porcelain.rb', line 6266

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6268
6269
6270
# File 'lib/models/porcelain.rb', line 6268

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6270
6271
6272
# File 'lib/models/porcelain.rb', line 6270

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6272
6273
6274
# File 'lib/models/porcelain.rb', line 6272

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6274
6275
6276
# File 'lib/models/porcelain.rb', line 6274

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6276
6277
6278
# File 'lib/models/porcelain.rb', line 6276

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6278
6279
6280
# File 'lib/models/porcelain.rb', line 6278

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6280
6281
6282
# File 'lib/models/porcelain.rb', line 6280

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6282
6283
6284
# File 'lib/models/porcelain.rb', line 6282

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6284
6285
6286
# File 'lib/models/porcelain.rb', line 6284

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6286
6287
6288
# File 'lib/models/porcelain.rb', line 6286

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6288
6289
6290
# File 'lib/models/porcelain.rb', line 6288

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6290
6291
6292
# File 'lib/models/porcelain.rb', line 6290

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6326
6327
6328
6329
6330
6331
6332
# File 'lib/models/porcelain.rb', line 6326

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end