Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



6214
6215
6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
6243
6244
6245
6246
# File 'lib/models/porcelain.rb', line 6214

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



6184
6185
6186
# File 'lib/models/porcelain.rb', line 6184

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6186
6187
6188
# File 'lib/models/porcelain.rb', line 6186

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6188
6189
6190
# File 'lib/models/porcelain.rb', line 6188

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6190
6191
6192
# File 'lib/models/porcelain.rb', line 6190

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6192
6193
6194
# File 'lib/models/porcelain.rb', line 6192

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6194
6195
6196
# File 'lib/models/porcelain.rb', line 6194

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6196
6197
6198
# File 'lib/models/porcelain.rb', line 6196

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6198
6199
6200
# File 'lib/models/porcelain.rb', line 6198

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6200
6201
6202
# File 'lib/models/porcelain.rb', line 6200

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6202
6203
6204
# File 'lib/models/porcelain.rb', line 6202

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6204
6205
6206
# File 'lib/models/porcelain.rb', line 6204

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6206
6207
6208
# File 'lib/models/porcelain.rb', line 6206

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6208
6209
6210
# File 'lib/models/porcelain.rb', line 6208

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6210
6211
6212
# File 'lib/models/porcelain.rb', line 6210

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6212
6213
6214
# File 'lib/models/porcelain.rb', line 6212

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6248
6249
6250
6251
6252
6253
6254
# File 'lib/models/porcelain.rb', line 6248

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end