Class: SDM::HTTPAuth
- Inherits:
-
Object
- Object
- SDM::HTTPAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_header ⇒ Object
The content to set as the authorization header.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
-
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
Instance Method Summary collapse
-
#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth
constructor
A new instance of HTTPAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth
Returns a new instance of HTTPAuth.
6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 |
# File 'lib/models/porcelain.rb', line 6143 def initialize( auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @auth_header = auth_header == nil ? "" : auth_header @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#auth_header ⇒ Object
The content to set as the authorization header.
6113 6114 6115 |
# File 'lib/models/porcelain.rb', line 6113 def auth_header @auth_header end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6115 6116 6117 |
# File 'lib/models/porcelain.rb', line 6115 def bind_interface @bind_interface end |
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
6117 6118 6119 |
# File 'lib/models/porcelain.rb', line 6117 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6119 6120 6121 |
# File 'lib/models/porcelain.rb', line 6119 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
6121 6122 6123 |
# File 'lib/models/porcelain.rb', line 6121 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
6123 6124 6125 |
# File 'lib/models/porcelain.rb', line 6123 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6125 6126 6127 |
# File 'lib/models/porcelain.rb', line 6125 def healthy @healthy end |
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
6127 6128 6129 |
# File 'lib/models/porcelain.rb', line 6127 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
6129 6130 6131 |
# File 'lib/models/porcelain.rb', line 6129 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6131 6132 6133 |
# File 'lib/models/porcelain.rb', line 6131 def name @name end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
6133 6134 6135 |
# File 'lib/models/porcelain.rb', line 6133 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6135 6136 6137 |
# File 'lib/models/porcelain.rb', line 6135 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6137 6138 6139 |
# File 'lib/models/porcelain.rb', line 6137 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6139 6140 6141 |
# File 'lib/models/porcelain.rb', line 6139 def @tags end |
#url ⇒ Object
The base address of your website without the path.
6141 6142 6143 |
# File 'lib/models/porcelain.rb', line 6141 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6177 6178 6179 6180 6181 6182 6183 |
# File 'lib/models/porcelain.rb', line 6177 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |