Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
# File 'lib/models/porcelain.rb', line 6144

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



6114
6115
6116
# File 'lib/models/porcelain.rb', line 6114

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6116
6117
6118
# File 'lib/models/porcelain.rb', line 6116

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6118
6119
6120
# File 'lib/models/porcelain.rb', line 6118

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6120
6121
6122
# File 'lib/models/porcelain.rb', line 6120

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6122
6123
6124
# File 'lib/models/porcelain.rb', line 6122

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6124
6125
6126
# File 'lib/models/porcelain.rb', line 6124

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6126
6127
6128
# File 'lib/models/porcelain.rb', line 6126

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6128
6129
6130
# File 'lib/models/porcelain.rb', line 6128

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6130
6131
6132
# File 'lib/models/porcelain.rb', line 6130

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6132
6133
6134
# File 'lib/models/porcelain.rb', line 6132

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6134
6135
6136
# File 'lib/models/porcelain.rb', line 6134

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6136
6137
6138
# File 'lib/models/porcelain.rb', line 6136

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6138
6139
6140
# File 'lib/models/porcelain.rb', line 6138

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6140
6141
6142
# File 'lib/models/porcelain.rb', line 6140

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6142
6143
6144
# File 'lib/models/porcelain.rb', line 6142

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6178
6179
6180
6181
6182
6183
6184
# File 'lib/models/porcelain.rb', line 6178

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end