Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



5780
5781
5782
5783
5784
5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
5797
5798
5799
5800
5801
5802
5803
5804
5805
5806
5807
5808
5809
5810
5811
5812
# File 'lib/models/porcelain.rb', line 5780

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



5750
5751
5752
# File 'lib/models/porcelain.rb', line 5750

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5752
5753
5754
# File 'lib/models/porcelain.rb', line 5752

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



5754
5755
5756
# File 'lib/models/porcelain.rb', line 5754

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5756
5757
5758
# File 'lib/models/porcelain.rb', line 5756

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



5758
5759
5760
# File 'lib/models/porcelain.rb', line 5758

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



5760
5761
5762
# File 'lib/models/porcelain.rb', line 5760

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5762
5763
5764
# File 'lib/models/porcelain.rb', line 5762

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



5764
5765
5766
# File 'lib/models/porcelain.rb', line 5764

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



5766
5767
5768
# File 'lib/models/porcelain.rb', line 5766

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5768
5769
5770
# File 'lib/models/porcelain.rb', line 5768

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5770
5771
5772
# File 'lib/models/porcelain.rb', line 5770

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5772
5773
5774
# File 'lib/models/porcelain.rb', line 5772

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5774
5775
5776
# File 'lib/models/porcelain.rb', line 5774

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5776
5777
5778
# File 'lib/models/porcelain.rb', line 5776

def tags
  @tags
end

#urlObject

The base address of your website without the path.



5778
5779
5780
# File 'lib/models/porcelain.rb', line 5778

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5814
5815
5816
5817
5818
5819
5820
# File 'lib/models/porcelain.rb', line 5814

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end