Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



5533
5534
5535
5536
5537
5538
5539
5540
5541
5542
5543
5544
5545
5546
5547
5548
5549
5550
5551
5552
5553
5554
5555
5556
5557
5558
5559
5560
5561
5562
5563
5564
5565
# File 'lib/models/porcelain.rb', line 5533

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



5503
5504
5505
# File 'lib/models/porcelain.rb', line 5503

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5505
5506
5507
# File 'lib/models/porcelain.rb', line 5505

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



5507
5508
5509
# File 'lib/models/porcelain.rb', line 5507

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5509
5510
5511
# File 'lib/models/porcelain.rb', line 5509

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



5511
5512
5513
# File 'lib/models/porcelain.rb', line 5511

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



5513
5514
5515
# File 'lib/models/porcelain.rb', line 5513

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5515
5516
5517
# File 'lib/models/porcelain.rb', line 5515

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



5517
5518
5519
# File 'lib/models/porcelain.rb', line 5517

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



5519
5520
5521
# File 'lib/models/porcelain.rb', line 5519

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5521
5522
5523
# File 'lib/models/porcelain.rb', line 5521

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5523
5524
5525
# File 'lib/models/porcelain.rb', line 5523

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5525
5526
5527
# File 'lib/models/porcelain.rb', line 5525

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5527
5528
5529
# File 'lib/models/porcelain.rb', line 5527

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5529
5530
5531
# File 'lib/models/porcelain.rb', line 5529

def tags
  @tags
end

#urlObject

The base address of your website without the path.



5531
5532
5533
# File 'lib/models/porcelain.rb', line 5531

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5567
5568
5569
5570
5571
5572
5573
# File 'lib/models/porcelain.rb', line 5567

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end