Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
# File 'lib/models/porcelain.rb', line 4392

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



4364
4365
4366
# File 'lib/models/porcelain.rb', line 4364

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4366
4367
4368
# File 'lib/models/porcelain.rb', line 4366

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



4368
4369
4370
# File 'lib/models/porcelain.rb', line 4368

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4370
4371
4372
# File 'lib/models/porcelain.rb', line 4370

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



4372
4373
4374
# File 'lib/models/porcelain.rb', line 4372

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



4374
4375
4376
# File 'lib/models/porcelain.rb', line 4374

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4376
4377
4378
# File 'lib/models/porcelain.rb', line 4376

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



4378
4379
4380
# File 'lib/models/porcelain.rb', line 4378

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



4380
4381
4382
# File 'lib/models/porcelain.rb', line 4380

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4382
4383
4384
# File 'lib/models/porcelain.rb', line 4382

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4384
4385
4386
# File 'lib/models/porcelain.rb', line 4384

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4386
4387
4388
# File 'lib/models/porcelain.rb', line 4386

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4388
4389
4390
# File 'lib/models/porcelain.rb', line 4388

def tags
  @tags
end

#urlObject

The base address of your website without the path.



4390
4391
4392
# File 'lib/models/porcelain.rb', line 4390

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4424
4425
4426
4427
4428
4429
4430
# File 'lib/models/porcelain.rb', line 4424

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end