Class: SDM::HTTPAuth
- Inherits:
-
Object
- Object
- SDM::HTTPAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_header ⇒ Object
The content to set as the authorization header.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
-
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
Instance Method Summary collapse
-
#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth
constructor
A new instance of HTTPAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth
Returns a new instance of HTTPAuth.
4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 4273 4274 4275 |
# File 'lib/models/porcelain.rb', line 4245 def initialize( auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @auth_header = auth_header == nil ? "" : auth_header @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#auth_header ⇒ Object
The content to set as the authorization header.
4217 4218 4219 |
# File 'lib/models/porcelain.rb', line 4217 def auth_header @auth_header end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4219 4220 4221 |
# File 'lib/models/porcelain.rb', line 4219 def bind_interface @bind_interface end |
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
4221 4222 4223 |
# File 'lib/models/porcelain.rb', line 4221 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4223 4224 4225 |
# File 'lib/models/porcelain.rb', line 4223 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
4225 4226 4227 |
# File 'lib/models/porcelain.rb', line 4225 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
4227 4228 4229 |
# File 'lib/models/porcelain.rb', line 4227 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4229 4230 4231 |
# File 'lib/models/porcelain.rb', line 4229 def healthy @healthy end |
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
4231 4232 4233 |
# File 'lib/models/porcelain.rb', line 4231 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
4233 4234 4235 |
# File 'lib/models/porcelain.rb', line 4233 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4235 4236 4237 |
# File 'lib/models/porcelain.rb', line 4235 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4237 4238 4239 |
# File 'lib/models/porcelain.rb', line 4237 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4239 4240 4241 |
# File 'lib/models/porcelain.rb', line 4239 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4241 4242 4243 |
# File 'lib/models/porcelain.rb', line 4241 def @tags end |
#url ⇒ Object
The base address of your website without the path.
4243 4244 4245 |
# File 'lib/models/porcelain.rb', line 4243 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4277 4278 4279 4280 4281 4282 4283 |
# File 'lib/models/porcelain.rb', line 4277 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |