Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
4102
4103
# File 'lib/models/porcelain.rb', line 4073

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



4045
4046
4047
# File 'lib/models/porcelain.rb', line 4045

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4047
4048
4049
# File 'lib/models/porcelain.rb', line 4047

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



4049
4050
4051
# File 'lib/models/porcelain.rb', line 4049

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4051
4052
4053
# File 'lib/models/porcelain.rb', line 4051

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



4053
4054
4055
# File 'lib/models/porcelain.rb', line 4053

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



4055
4056
4057
# File 'lib/models/porcelain.rb', line 4055

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4057
4058
4059
# File 'lib/models/porcelain.rb', line 4057

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



4059
4060
4061
# File 'lib/models/porcelain.rb', line 4059

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



4061
4062
4063
# File 'lib/models/porcelain.rb', line 4061

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4063
4064
4065
# File 'lib/models/porcelain.rb', line 4063

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4065
4066
4067
# File 'lib/models/porcelain.rb', line 4065

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4067
4068
4069
# File 'lib/models/porcelain.rb', line 4067

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4069
4070
4071
# File 'lib/models/porcelain.rb', line 4069

def tags
  @tags
end

#urlObject

The base address of your website without the path.



4071
4072
4073
# File 'lib/models/porcelain.rb', line 4071

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4105
4106
4107
4108
4109
4110
4111
# File 'lib/models/porcelain.rb', line 4105

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end