Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
# File 'lib/models/porcelain.rb', line 3934

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

Returns the value of attribute auth_header.



3906
3907
3908
# File 'lib/models/porcelain.rb', line 3906

def auth_header
  @auth_header
end

#bind_interfaceObject

Bind interface



3908
3909
3910
# File 'lib/models/porcelain.rb', line 3908

def bind_interface
  @bind_interface
end

#default_pathObject

Returns the value of attribute default_path.



3910
3911
3912
# File 'lib/models/porcelain.rb', line 3910

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3912
3913
3914
# File 'lib/models/porcelain.rb', line 3912

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Returns the value of attribute headers_blacklist.



3914
3915
3916
# File 'lib/models/porcelain.rb', line 3914

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

Returns the value of attribute healthcheck_path.



3916
3917
3918
# File 'lib/models/porcelain.rb', line 3916

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3918
3919
3920
# File 'lib/models/porcelain.rb', line 3918

def healthy
  @healthy
end

#host_overrideObject

Returns the value of attribute host_override.



3920
3921
3922
# File 'lib/models/porcelain.rb', line 3920

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



3922
3923
3924
# File 'lib/models/porcelain.rb', line 3922

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3924
3925
3926
# File 'lib/models/porcelain.rb', line 3924

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3926
3927
3928
# File 'lib/models/porcelain.rb', line 3926

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



3928
3929
3930
# File 'lib/models/porcelain.rb', line 3928

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3930
3931
3932
# File 'lib/models/porcelain.rb', line 3930

def tags
  @tags
end

#urlObject

Returns the value of attribute url.



3932
3933
3934
# File 'lib/models/porcelain.rb', line 3932

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3966
3967
3968
3969
3970
3971
3972
# File 'lib/models/porcelain.rb', line 3966

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end