Class: SDM::HTTPAuth
- Inherits:
-
Object
- Object
- SDM::HTTPAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_header ⇒ Object
Returns the value of attribute auth_header.
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
Instance Method Summary collapse
-
#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth
constructor
A new instance of HTTPAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth
Returns a new instance of HTTPAuth.
3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 3827 3828 3829 |
# File 'lib/models/porcelain.rb', line 3799 def initialize( auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @auth_header = auth_header == nil ? "" : auth_header @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#auth_header ⇒ Object
Returns the value of attribute auth_header.
3771 3772 3773 |
# File 'lib/models/porcelain.rb', line 3771 def auth_header @auth_header end |
#bind_interface ⇒ Object
Bind interface
3773 3774 3775 |
# File 'lib/models/porcelain.rb', line 3773 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3775 3776 3777 |
# File 'lib/models/porcelain.rb', line 3775 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3777 3778 3779 |
# File 'lib/models/porcelain.rb', line 3777 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3779 3780 3781 |
# File 'lib/models/porcelain.rb', line 3779 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3781 3782 3783 |
# File 'lib/models/porcelain.rb', line 3781 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3783 3784 3785 |
# File 'lib/models/porcelain.rb', line 3783 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3785 3786 3787 |
# File 'lib/models/porcelain.rb', line 3785 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3787 3788 3789 |
# File 'lib/models/porcelain.rb', line 3787 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3789 3790 3791 |
# File 'lib/models/porcelain.rb', line 3789 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3791 3792 3793 |
# File 'lib/models/porcelain.rb', line 3791 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3793 3794 3795 |
# File 'lib/models/porcelain.rb', line 3793 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3795 3796 3797 |
# File 'lib/models/porcelain.rb', line 3795 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3797 3798 3799 |
# File 'lib/models/porcelain.rb', line 3797 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3831 3832 3833 3834 3835 3836 3837 |
# File 'lib/models/porcelain.rb', line 3831 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |