Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



3640
3641
3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
3669
3670
# File 'lib/models/porcelain.rb', line 3640

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

Returns the value of attribute auth_header.



3612
3613
3614
# File 'lib/models/porcelain.rb', line 3612

def auth_header
  @auth_header
end

#bind_interfaceObject

Bind interface



3614
3615
3616
# File 'lib/models/porcelain.rb', line 3614

def bind_interface
  @bind_interface
end

#default_pathObject

Returns the value of attribute default_path.



3616
3617
3618
# File 'lib/models/porcelain.rb', line 3616

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3618
3619
3620
# File 'lib/models/porcelain.rb', line 3618

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Returns the value of attribute headers_blacklist.



3620
3621
3622
# File 'lib/models/porcelain.rb', line 3620

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

Returns the value of attribute healthcheck_path.



3622
3623
3624
# File 'lib/models/porcelain.rb', line 3622

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3624
3625
3626
# File 'lib/models/porcelain.rb', line 3624

def healthy
  @healthy
end

#host_overrideObject

Returns the value of attribute host_override.



3626
3627
3628
# File 'lib/models/porcelain.rb', line 3626

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



3628
3629
3630
# File 'lib/models/porcelain.rb', line 3628

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3630
3631
3632
# File 'lib/models/porcelain.rb', line 3630

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3632
3633
3634
# File 'lib/models/porcelain.rb', line 3632

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



3634
3635
3636
# File 'lib/models/porcelain.rb', line 3634

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3636
3637
3638
# File 'lib/models/porcelain.rb', line 3636

def tags
  @tags
end

#urlObject

Returns the value of attribute url.



3638
3639
3640
# File 'lib/models/porcelain.rb', line 3638

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3672
3673
3674
3675
3676
3677
3678
# File 'lib/models/porcelain.rb', line 3672

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end