Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
# File 'lib/models/porcelain.rb', line 3302

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

Returns the value of attribute auth_header.



3274
3275
3276
# File 'lib/models/porcelain.rb', line 3274

def auth_header
  @auth_header
end

#bind_interfaceObject

Bind interface



3276
3277
3278
# File 'lib/models/porcelain.rb', line 3276

def bind_interface
  @bind_interface
end

#default_pathObject

Returns the value of attribute default_path.



3278
3279
3280
# File 'lib/models/porcelain.rb', line 3278

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3280
3281
3282
# File 'lib/models/porcelain.rb', line 3280

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Returns the value of attribute headers_blacklist.



3282
3283
3284
# File 'lib/models/porcelain.rb', line 3282

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

Returns the value of attribute healthcheck_path.



3284
3285
3286
# File 'lib/models/porcelain.rb', line 3284

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3286
3287
3288
# File 'lib/models/porcelain.rb', line 3286

def healthy
  @healthy
end

#host_overrideObject

Returns the value of attribute host_override.



3288
3289
3290
# File 'lib/models/porcelain.rb', line 3288

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



3290
3291
3292
# File 'lib/models/porcelain.rb', line 3290

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3292
3293
3294
# File 'lib/models/porcelain.rb', line 3292

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3294
3295
3296
# File 'lib/models/porcelain.rb', line 3294

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



3296
3297
3298
# File 'lib/models/porcelain.rb', line 3296

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3298
3299
3300
# File 'lib/models/porcelain.rb', line 3298

def tags
  @tags
end

#urlObject

Returns the value of attribute url.



3300
3301
3302
# File 'lib/models/porcelain.rb', line 3300

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3334
3335
3336
3337
3338
3339
3340
# File 'lib/models/porcelain.rb', line 3334

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end