Class: SDM::HTTPAuth
- Inherits:
-
Object
- Object
- SDM::HTTPAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_header ⇒ Object
Returns the value of attribute auth_header.
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
Instance Method Summary collapse
-
#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth
constructor
A new instance of HTTPAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth
Returns a new instance of HTTPAuth.
3195 3196 3197 3198 3199 3200 3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 |
# File 'lib/models/porcelain.rb', line 3195 def initialize( auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @auth_header = auth_header == nil ? "" : auth_header @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#auth_header ⇒ Object
Returns the value of attribute auth_header.
3167 3168 3169 |
# File 'lib/models/porcelain.rb', line 3167 def auth_header @auth_header end |
#bind_interface ⇒ Object
Bind interface
3169 3170 3171 |
# File 'lib/models/porcelain.rb', line 3169 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3171 3172 3173 |
# File 'lib/models/porcelain.rb', line 3171 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3173 3174 3175 |
# File 'lib/models/porcelain.rb', line 3173 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3175 3176 3177 |
# File 'lib/models/porcelain.rb', line 3175 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3177 3178 3179 |
# File 'lib/models/porcelain.rb', line 3177 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3179 3180 3181 |
# File 'lib/models/porcelain.rb', line 3179 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3181 3182 3183 |
# File 'lib/models/porcelain.rb', line 3181 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3183 3184 3185 |
# File 'lib/models/porcelain.rb', line 3183 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3185 3186 3187 |
# File 'lib/models/porcelain.rb', line 3185 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3187 3188 3189 |
# File 'lib/models/porcelain.rb', line 3187 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3189 3190 3191 |
# File 'lib/models/porcelain.rb', line 3189 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3191 3192 3193 |
# File 'lib/models/porcelain.rb', line 3191 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3193 3194 3195 |
# File 'lib/models/porcelain.rb', line 3193 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3227 3228 3229 3230 3231 3232 3233 |
# File 'lib/models/porcelain.rb', line 3227 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |