Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
3219
3220
3221
# File 'lib/models/porcelain.rb', line 3191

def initialize(
  auth_header: nil,
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

Returns the value of attribute auth_header.



3163
3164
3165
# File 'lib/models/porcelain.rb', line 3163

def auth_header
  @auth_header
end

#bind_interfaceObject

Bind interface



3165
3166
3167
# File 'lib/models/porcelain.rb', line 3165

def bind_interface
  @bind_interface
end

#default_pathObject

Returns the value of attribute default_path.



3167
3168
3169
# File 'lib/models/porcelain.rb', line 3167

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3169
3170
3171
# File 'lib/models/porcelain.rb', line 3169

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Returns the value of attribute headers_blacklist.



3171
3172
3173
# File 'lib/models/porcelain.rb', line 3171

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

Returns the value of attribute healthcheck_path.



3173
3174
3175
# File 'lib/models/porcelain.rb', line 3173

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3175
3176
3177
# File 'lib/models/porcelain.rb', line 3175

def healthy
  @healthy
end

#host_overrideObject

Returns the value of attribute host_override.



3177
3178
3179
# File 'lib/models/porcelain.rb', line 3177

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



3179
3180
3181
# File 'lib/models/porcelain.rb', line 3179

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3181
3182
3183
# File 'lib/models/porcelain.rb', line 3181

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3183
3184
3185
# File 'lib/models/porcelain.rb', line 3183

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



3185
3186
3187
# File 'lib/models/porcelain.rb', line 3185

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3187
3188
3189
# File 'lib/models/porcelain.rb', line 3187

def tags
  @tags
end

#urlObject

Returns the value of attribute url.



3189
3190
3191
# File 'lib/models/porcelain.rb', line 3189

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3223
3224
3225
3226
3227
3228
3229
# File 'lib/models/porcelain.rb', line 3223

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end