Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



8750
8751
8752
8753
8754
8755
8756
8757
8758
8759
8760
8761
8762
8763
8764
8765
8766
8767
8768
8769
8770
8771
8772
8773
8774
8775
8776
8777
8778
8779
8780
8781
8782
8783
8784
8785
8786
# File 'lib/models/porcelain.rb', line 8750

def initialize(
  auth_header: nil,
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_headerObject

The content to set as the authorization header.



8716
8717
8718
# File 'lib/models/porcelain.rb', line 8716

def auth_header
  @auth_header
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8718
8719
8720
# File 'lib/models/porcelain.rb', line 8718

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8720
8721
8722
# File 'lib/models/porcelain.rb', line 8720

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8722
8723
8724
# File 'lib/models/porcelain.rb', line 8722

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8724
8725
8726
# File 'lib/models/porcelain.rb', line 8724

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8726
8727
8728
# File 'lib/models/porcelain.rb', line 8726

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8728
8729
8730
# File 'lib/models/porcelain.rb', line 8728

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8730
8731
8732
# File 'lib/models/porcelain.rb', line 8730

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8732
8733
8734
# File 'lib/models/porcelain.rb', line 8732

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8734
8735
8736
# File 'lib/models/porcelain.rb', line 8734

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8736
8737
8738
# File 'lib/models/porcelain.rb', line 8736

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8738
8739
8740
# File 'lib/models/porcelain.rb', line 8738

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8740
8741
8742
# File 'lib/models/porcelain.rb', line 8740

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8742
8743
8744
# File 'lib/models/porcelain.rb', line 8742

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8744
8745
8746
# File 'lib/models/porcelain.rb', line 8744

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8746
8747
8748
# File 'lib/models/porcelain.rb', line 8746

def tags
  @tags
end

#urlObject

The base address of your website without the path.



8748
8749
8750
# File 'lib/models/porcelain.rb', line 8748

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8788
8789
8790
8791
8792
8793
8794
# File 'lib/models/porcelain.rb', line 8788

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end