Class: SDM::HTTPAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_header: nil, bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, tls_required: nil, url: nil) ⇒ HTTPAuth

Returns a new instance of HTTPAuth.



9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
# File 'lib/models/porcelain.rb', line 9034

def initialize(
  auth_header: nil,
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  tls_required: nil,
  url: nil
)
  @auth_header = auth_header == nil ? "" : auth_header
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
end

Instance Attribute Details

#auth_header ⇒ Object

The content to set as the authorization header.



8994
8995
8996
# File 'lib/models/porcelain.rb', line 8994

def auth_header
  @auth_header
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8996
8997
8998
# File 'lib/models/porcelain.rb', line 8996

def bind_interface
  @bind_interface
end

#custom_headers ⇒ Object

Additional HTTP headers to include in requests.



8998
8999
9000
# File 'lib/models/porcelain.rb', line 8998

def custom_headers
  @custom_headers
end

#default_path ⇒ Object

Automatically redirect to this path upon connecting.



9000
9001
9002
# File 'lib/models/porcelain.rb', line 9000

def default_path
  @default_path
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



9002
9003
9004
# File 'lib/models/porcelain.rb', line 9002

def egress_filter
  @egress_filter
end

#headers_blacklist ⇒ Object

Header names (e.g. Authorization), to omit from logs.



9004
9005
9006
# File 'lib/models/porcelain.rb', line 9004

def headers_blacklist
  @headers_blacklist
end

#healthcheck_path ⇒ Object

This path will be used to check the health of your site.



9006
9007
9008
# File 'lib/models/porcelain.rb', line 9006

def healthcheck_path
  @healthcheck_path
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



9008
9009
9010
# File 'lib/models/porcelain.rb', line 9008

def healthy
  @healthy
end

#host_override ⇒ Object

The host header will be overwritten with this field if provided.



9010
9011
9012
# File 'lib/models/porcelain.rb', line 9010

def host_override
  @host_override
end

#id ⇒ Object

Unique identifier of the Resource.



9012
9013
9014
# File 'lib/models/porcelain.rb', line 9012

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



9014
9015
9016
# File 'lib/models/porcelain.rb', line 9014

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9016
9017
9018
# File 'lib/models/porcelain.rb', line 9016

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



9018
9019
9020
# File 'lib/models/porcelain.rb', line 9018

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



9020
9021
9022
# File 'lib/models/porcelain.rb', line 9020

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9022
9023
9024
# File 'lib/models/porcelain.rb', line 9022

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



9024
9025
9026
# File 'lib/models/porcelain.rb', line 9024

def tags
  @tags
end

#tls_cert ⇒ Object

Custom TLS certificate for upstream connection.



9026
9027
9028
# File 'lib/models/porcelain.rb', line 9026

def tls_cert
  @tls_cert
end

#tls_insecure ⇒ Object

Skip TLS certificate verification for the upstream connection.



9028
9029
9030
# File 'lib/models/porcelain.rb', line 9028

def tls_insecure
  @tls_insecure
end

#tls_required ⇒ Object

This option enforces HTTPS on the client, not resource connection.



9030
9031
9032
# File 'lib/models/porcelain.rb', line 9030

def tls_required
  @tls_required
end

#url ⇒ Object

The base address of your website without the path.



9032
9033
9034
# File 'lib/models/porcelain.rb', line 9032

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9078
9079
9080
9081
9082
9083
9084
# File 'lib/models/porcelain.rb', line 9078

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end