Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, tls_required: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



9019
9020
9021
9022
9023
9024
9025
9026
9027
9028
9029
9030
9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
# File 'lib/models/porcelain.rb', line 9019

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  tls_required: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8977
8978
8979
# File 'lib/models/porcelain.rb', line 8977

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8979
8980
8981
# File 'lib/models/porcelain.rb', line 8979

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8981
8982
8983
# File 'lib/models/porcelain.rb', line 8981

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8983
8984
8985
# File 'lib/models/porcelain.rb', line 8983

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8985
8986
8987
# File 'lib/models/porcelain.rb', line 8985

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8987
8988
8989
# File 'lib/models/porcelain.rb', line 8987

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8989
8990
8991
# File 'lib/models/porcelain.rb', line 8989

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8991
8992
8993
# File 'lib/models/porcelain.rb', line 8991

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8993
8994
8995
# File 'lib/models/porcelain.rb', line 8993

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8995
8996
8997
# File 'lib/models/porcelain.rb', line 8995

def name
  @name
end

#passwordObject

The password to authenticate with.



8997
8998
8999
# File 'lib/models/porcelain.rb', line 8997

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8999
9000
9001
# File 'lib/models/porcelain.rb', line 8999

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9001
9002
9003
# File 'lib/models/porcelain.rb', line 9001

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9003
9004
9005
# File 'lib/models/porcelain.rb', line 9003

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9005
9006
9007
# File 'lib/models/porcelain.rb', line 9005

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9007
9008
9009
# File 'lib/models/porcelain.rb', line 9007

def tags
  @tags
end

#tls_certObject

Custom TLS certificate for upstream connection.



9009
9010
9011
# File 'lib/models/porcelain.rb', line 9009

def tls_cert
  @tls_cert
end

#tls_insecureObject

Skip TLS certificate verification for the upstream connection.



9011
9012
9013
# File 'lib/models/porcelain.rb', line 9011

def tls_insecure
  @tls_insecure
end

#tls_requiredObject

This option enforces HTTPS on the client, not resource connection.



9013
9014
9015
# File 'lib/models/porcelain.rb', line 9013

def tls_required
  @tls_required
end

#urlObject

The base address of your website without the path.



9015
9016
9017
# File 'lib/models/porcelain.rb', line 9015

def url
  @url
end

#usernameObject

The username to authenticate with.



9017
9018
9019
# File 'lib/models/porcelain.rb', line 9017

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9065
9066
9067
9068
9069
9070
9071
# File 'lib/models/porcelain.rb', line 9065

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end