Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
8864
8865
8866
8867
8868
8869
8870
8871
8872
8873
8874
# File 'lib/models/porcelain.rb', line 8836

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8800
8801
8802
# File 'lib/models/porcelain.rb', line 8800

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8802
8803
8804
# File 'lib/models/porcelain.rb', line 8802

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8804
8805
8806
# File 'lib/models/porcelain.rb', line 8804

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8806
8807
8808
# File 'lib/models/porcelain.rb', line 8806

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8808
8809
8810
# File 'lib/models/porcelain.rb', line 8808

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8810
8811
8812
# File 'lib/models/porcelain.rb', line 8810

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8812
8813
8814
# File 'lib/models/porcelain.rb', line 8812

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8814
8815
8816
# File 'lib/models/porcelain.rb', line 8814

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8816
8817
8818
# File 'lib/models/porcelain.rb', line 8816

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8818
8819
8820
# File 'lib/models/porcelain.rb', line 8818

def name
  @name
end

#passwordObject

The password to authenticate with.



8820
8821
8822
# File 'lib/models/porcelain.rb', line 8820

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8822
8823
8824
# File 'lib/models/porcelain.rb', line 8822

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8824
8825
8826
# File 'lib/models/porcelain.rb', line 8824

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8826
8827
8828
# File 'lib/models/porcelain.rb', line 8826

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8828
8829
8830
# File 'lib/models/porcelain.rb', line 8828

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8830
8831
8832
# File 'lib/models/porcelain.rb', line 8830

def tags
  @tags
end

#urlObject

The base address of your website without the path.



8832
8833
8834
# File 'lib/models/porcelain.rb', line 8832

def url
  @url
end

#usernameObject

The username to authenticate with.



8834
8835
8836
# File 'lib/models/porcelain.rb', line 8834

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8876
8877
8878
8879
8880
8881
8882
# File 'lib/models/porcelain.rb', line 8876

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end