Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
7888
7889
7890
7891
7892
7893
7894
# File 'lib/models/porcelain.rb', line 7858

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7824
7825
7826
# File 'lib/models/porcelain.rb', line 7824

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



7826
7827
7828
# File 'lib/models/porcelain.rb', line 7826

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7828
7829
7830
# File 'lib/models/porcelain.rb', line 7828

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



7830
7831
7832
# File 'lib/models/porcelain.rb', line 7830

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



7832
7833
7834
# File 'lib/models/porcelain.rb', line 7832

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7834
7835
7836
# File 'lib/models/porcelain.rb', line 7834

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



7836
7837
7838
# File 'lib/models/porcelain.rb', line 7836

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



7838
7839
7840
# File 'lib/models/porcelain.rb', line 7838

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7840
7841
7842
# File 'lib/models/porcelain.rb', line 7840

def name
  @name
end

#passwordObject

The password to authenticate with.



7842
7843
7844
# File 'lib/models/porcelain.rb', line 7842

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7844
7845
7846
# File 'lib/models/porcelain.rb', line 7844

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7846
7847
7848
# File 'lib/models/porcelain.rb', line 7846

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7848
7849
7850
# File 'lib/models/porcelain.rb', line 7848

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7850
7851
7852
# File 'lib/models/porcelain.rb', line 7850

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7852
7853
7854
# File 'lib/models/porcelain.rb', line 7852

def tags
  @tags
end

#urlObject

The base address of your website without the path.



7854
7855
7856
# File 'lib/models/porcelain.rb', line 7854

def url
  @url
end

#usernameObject

The username to authenticate with.



7856
7857
7858
# File 'lib/models/porcelain.rb', line 7856

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7896
7897
7898
7899
7900
7901
7902
# File 'lib/models/porcelain.rb', line 7896

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end