Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



6979
6980
6981
6982
6983
6984
6985
6986
6987
6988
6989
6990
6991
6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/models/porcelain.rb', line 6979

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6945
6946
6947
# File 'lib/models/porcelain.rb', line 6945

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6947
6948
6949
# File 'lib/models/porcelain.rb', line 6947

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6949
6950
6951
# File 'lib/models/porcelain.rb', line 6949

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6951
6952
6953
# File 'lib/models/porcelain.rb', line 6951

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6953
6954
6955
# File 'lib/models/porcelain.rb', line 6953

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6955
6956
6957
# File 'lib/models/porcelain.rb', line 6955

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6957
6958
6959
# File 'lib/models/porcelain.rb', line 6957

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6959
6960
6961
# File 'lib/models/porcelain.rb', line 6959

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6961
6962
6963
# File 'lib/models/porcelain.rb', line 6961

def name
  @name
end

#passwordObject

The password to authenticate with.



6963
6964
6965
# File 'lib/models/porcelain.rb', line 6963

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



6965
6966
6967
# File 'lib/models/porcelain.rb', line 6965

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6967
6968
6969
# File 'lib/models/porcelain.rb', line 6967

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6969
6970
6971
# File 'lib/models/porcelain.rb', line 6969

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6971
6972
6973
# File 'lib/models/porcelain.rb', line 6971

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6973
6974
6975
# File 'lib/models/porcelain.rb', line 6973

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6975
6976
6977
# File 'lib/models/porcelain.rb', line 6975

def url
  @url
end

#usernameObject

The username to authenticate with.



6977
6978
6979
# File 'lib/models/porcelain.rb', line 6977

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7017
7018
7019
7020
7021
7022
7023
# File 'lib/models/porcelain.rb', line 7017

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end