Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



6512
6513
6514
6515
6516
6517
6518
6519
6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
6533
6534
6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
# File 'lib/models/porcelain.rb', line 6512

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6480
6481
6482
# File 'lib/models/porcelain.rb', line 6480

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6482
6483
6484
# File 'lib/models/porcelain.rb', line 6482

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6484
6485
6486
# File 'lib/models/porcelain.rb', line 6484

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6486
6487
6488
# File 'lib/models/porcelain.rb', line 6486

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6488
6489
6490
# File 'lib/models/porcelain.rb', line 6488

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6490
6491
6492
# File 'lib/models/porcelain.rb', line 6490

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6492
6493
6494
# File 'lib/models/porcelain.rb', line 6492

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6494
6495
6496
# File 'lib/models/porcelain.rb', line 6494

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6496
6497
6498
# File 'lib/models/porcelain.rb', line 6496

def name
  @name
end

#passwordObject

The password to authenticate with.



6498
6499
6500
# File 'lib/models/porcelain.rb', line 6498

def password
  @password
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6500
6501
6502
# File 'lib/models/porcelain.rb', line 6500

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6502
6503
6504
# File 'lib/models/porcelain.rb', line 6502

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6504
6505
6506
# File 'lib/models/porcelain.rb', line 6504

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6506
6507
6508
# File 'lib/models/porcelain.rb', line 6506

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6508
6509
6510
# File 'lib/models/porcelain.rb', line 6508

def url
  @url
end

#usernameObject

The username to authenticate with.



6510
6511
6512
# File 'lib/models/porcelain.rb', line 6510

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6548
6549
6550
6551
6552
6553
6554
# File 'lib/models/porcelain.rb', line 6548

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end