Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
6387
6388
6389
6390
6391
6392
6393
6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
# File 'lib/models/porcelain.rb', line 6371

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6339
6340
6341
# File 'lib/models/porcelain.rb', line 6339

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6341
6342
6343
# File 'lib/models/porcelain.rb', line 6341

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6343
6344
6345
# File 'lib/models/porcelain.rb', line 6343

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6345
6346
6347
# File 'lib/models/porcelain.rb', line 6345

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6347
6348
6349
# File 'lib/models/porcelain.rb', line 6347

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6349
6350
6351
# File 'lib/models/porcelain.rb', line 6349

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6351
6352
6353
# File 'lib/models/porcelain.rb', line 6351

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6353
6354
6355
# File 'lib/models/porcelain.rb', line 6353

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6355
6356
6357
# File 'lib/models/porcelain.rb', line 6355

def name
  @name
end

#passwordObject

The password to authenticate with.



6357
6358
6359
# File 'lib/models/porcelain.rb', line 6357

def password
  @password
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6359
6360
6361
# File 'lib/models/porcelain.rb', line 6359

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6361
6362
6363
# File 'lib/models/porcelain.rb', line 6361

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6363
6364
6365
# File 'lib/models/porcelain.rb', line 6363

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6365
6366
6367
# File 'lib/models/porcelain.rb', line 6365

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6367
6368
6369
# File 'lib/models/porcelain.rb', line 6367

def url
  @url
end

#usernameObject

The username to authenticate with.



6369
6370
6371
# File 'lib/models/porcelain.rb', line 6369

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6407
6408
6409
6410
6411
6412
6413
# File 'lib/models/porcelain.rb', line 6407

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end