Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
# File 'lib/models/porcelain.rb', line 6221

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6189
6190
6191
# File 'lib/models/porcelain.rb', line 6189

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6191
6192
6193
# File 'lib/models/porcelain.rb', line 6191

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6193
6194
6195
# File 'lib/models/porcelain.rb', line 6193

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6195
6196
6197
# File 'lib/models/porcelain.rb', line 6195

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6197
6198
6199
# File 'lib/models/porcelain.rb', line 6197

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6199
6200
6201
# File 'lib/models/porcelain.rb', line 6199

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6201
6202
6203
# File 'lib/models/porcelain.rb', line 6201

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6203
6204
6205
# File 'lib/models/porcelain.rb', line 6203

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6205
6206
6207
# File 'lib/models/porcelain.rb', line 6205

def name
  @name
end

#passwordObject

The password to authenticate with.



6207
6208
6209
# File 'lib/models/porcelain.rb', line 6207

def password
  @password
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6209
6210
6211
# File 'lib/models/porcelain.rb', line 6209

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6211
6212
6213
# File 'lib/models/porcelain.rb', line 6211

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6213
6214
6215
# File 'lib/models/porcelain.rb', line 6213

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6215
6216
6217
# File 'lib/models/porcelain.rb', line 6215

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6217
6218
6219
# File 'lib/models/porcelain.rb', line 6217

def url
  @url
end

#usernameObject

The username to authenticate with.



6219
6220
6221
# File 'lib/models/porcelain.rb', line 6219

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6257
6258
6259
6260
6261
6262
6263
# File 'lib/models/porcelain.rb', line 6257

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end