Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



5859
5860
5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
# File 'lib/models/porcelain.rb', line 5859

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5827
5828
5829
# File 'lib/models/porcelain.rb', line 5827

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



5829
5830
5831
# File 'lib/models/porcelain.rb', line 5829

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5831
5832
5833
# File 'lib/models/porcelain.rb', line 5831

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



5833
5834
5835
# File 'lib/models/porcelain.rb', line 5833

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



5835
5836
5837
# File 'lib/models/porcelain.rb', line 5835

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5837
5838
5839
# File 'lib/models/porcelain.rb', line 5837

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



5839
5840
5841
# File 'lib/models/porcelain.rb', line 5839

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



5841
5842
5843
# File 'lib/models/porcelain.rb', line 5841

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5843
5844
5845
# File 'lib/models/porcelain.rb', line 5843

def name
  @name
end

#passwordObject

The password to authenticate with.



5845
5846
5847
# File 'lib/models/porcelain.rb', line 5845

def password
  @password
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5847
5848
5849
# File 'lib/models/porcelain.rb', line 5847

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5849
5850
5851
# File 'lib/models/porcelain.rb', line 5849

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5851
5852
5853
# File 'lib/models/porcelain.rb', line 5851

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5853
5854
5855
# File 'lib/models/porcelain.rb', line 5853

def tags
  @tags
end

#urlObject

The base address of your website without the path.



5855
5856
5857
# File 'lib/models/porcelain.rb', line 5855

def url
  @url
end

#usernameObject

The username to authenticate with.



5857
5858
5859
# File 'lib/models/porcelain.rb', line 5857

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5895
5896
5897
5898
5899
5900
5901
# File 'lib/models/porcelain.rb', line 5895

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end