Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
5636
5637
5638
5639
5640
5641
5642
5643
5644
# File 'lib/models/porcelain.rb', line 5610

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5578
5579
5580
# File 'lib/models/porcelain.rb', line 5578

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



5580
5581
5582
# File 'lib/models/porcelain.rb', line 5580

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5582
5583
5584
# File 'lib/models/porcelain.rb', line 5582

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



5584
5585
5586
# File 'lib/models/porcelain.rb', line 5584

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



5586
5587
5588
# File 'lib/models/porcelain.rb', line 5586

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5588
5589
5590
# File 'lib/models/porcelain.rb', line 5588

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



5590
5591
5592
# File 'lib/models/porcelain.rb', line 5590

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



5592
5593
5594
# File 'lib/models/porcelain.rb', line 5592

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5594
5595
5596
# File 'lib/models/porcelain.rb', line 5594

def name
  @name
end

#passwordObject

The password to authenticate with.



5596
5597
5598
# File 'lib/models/porcelain.rb', line 5596

def password
  @password
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5598
5599
5600
# File 'lib/models/porcelain.rb', line 5598

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5600
5601
5602
# File 'lib/models/porcelain.rb', line 5600

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5602
5603
5604
# File 'lib/models/porcelain.rb', line 5602

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5604
5605
5606
# File 'lib/models/porcelain.rb', line 5604

def tags
  @tags
end

#urlObject

The base address of your website without the path.



5606
5607
5608
# File 'lib/models/porcelain.rb', line 5606

def url
  @url
end

#usernameObject

The username to authenticate with.



5608
5609
5610
# File 'lib/models/porcelain.rb', line 5608

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5646
5647
5648
5649
5650
5651
5652
# File 'lib/models/porcelain.rb', line 5646

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end