Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
5376
5377
5378
5379
5380
5381
5382
5383
5384
5385
5386
5387
5388
5389
5390
5391
5392
5393
5394
5395
5396
5397
# File 'lib/models/porcelain.rb', line 5365

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5335
5336
5337
# File 'lib/models/porcelain.rb', line 5335

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



5337
5338
5339
# File 'lib/models/porcelain.rb', line 5337

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5339
5340
5341
# File 'lib/models/porcelain.rb', line 5339

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



5341
5342
5343
# File 'lib/models/porcelain.rb', line 5341

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



5343
5344
5345
# File 'lib/models/porcelain.rb', line 5343

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5345
5346
5347
# File 'lib/models/porcelain.rb', line 5345

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



5347
5348
5349
# File 'lib/models/porcelain.rb', line 5347

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



5349
5350
5351
# File 'lib/models/porcelain.rb', line 5349

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5351
5352
5353
# File 'lib/models/porcelain.rb', line 5351

def name
  @name
end

#passwordObject

The password to authenticate with.



5353
5354
5355
# File 'lib/models/porcelain.rb', line 5353

def password
  @password
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5355
5356
5357
# File 'lib/models/porcelain.rb', line 5355

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5357
5358
5359
# File 'lib/models/porcelain.rb', line 5357

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5359
5360
5361
# File 'lib/models/porcelain.rb', line 5359

def tags
  @tags
end

#urlObject

The base address of your website without the path.



5361
5362
5363
# File 'lib/models/porcelain.rb', line 5361

def url
  @url
end

#usernameObject

The username to authenticate with.



5363
5364
5365
# File 'lib/models/porcelain.rb', line 5363

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5399
5400
5401
5402
5403
5404
5405
# File 'lib/models/porcelain.rb', line 5399

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end