Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
-
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 |
# File 'lib/models/porcelain.rb', line 4469 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4439 4440 4441 |
# File 'lib/models/porcelain.rb', line 4439 def bind_interface @bind_interface end |
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
4441 4442 4443 |
# File 'lib/models/porcelain.rb', line 4441 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4443 4444 4445 |
# File 'lib/models/porcelain.rb', line 4443 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
4445 4446 4447 |
# File 'lib/models/porcelain.rb', line 4445 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
4447 4448 4449 |
# File 'lib/models/porcelain.rb', line 4447 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4449 4450 4451 |
# File 'lib/models/porcelain.rb', line 4449 def healthy @healthy end |
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
4451 4452 4453 |
# File 'lib/models/porcelain.rb', line 4451 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
4453 4454 4455 |
# File 'lib/models/porcelain.rb', line 4453 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4455 4456 4457 |
# File 'lib/models/porcelain.rb', line 4455 def name @name end |
#password ⇒ Object
The password to authenticate with.
4457 4458 4459 |
# File 'lib/models/porcelain.rb', line 4457 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4459 4460 4461 |
# File 'lib/models/porcelain.rb', line 4459 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4461 4462 4463 |
# File 'lib/models/porcelain.rb', line 4461 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4463 4464 4465 |
# File 'lib/models/porcelain.rb', line 4463 def @tags end |
#url ⇒ Object
The base address of your website without the path.
4465 4466 4467 |
# File 'lib/models/porcelain.rb', line 4465 def url @url end |
#username ⇒ Object
The username to authenticate with.
4467 4468 4469 |
# File 'lib/models/porcelain.rb', line 4467 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4503 4504 4505 4506 4507 4508 4509 |
# File 'lib/models/porcelain.rb', line 4503 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |