Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
-
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 4350 |
# File 'lib/models/porcelain.rb', line 4318 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4288 4289 4290 |
# File 'lib/models/porcelain.rb', line 4288 def bind_interface @bind_interface end |
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
4290 4291 4292 |
# File 'lib/models/porcelain.rb', line 4290 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4292 4293 4294 |
# File 'lib/models/porcelain.rb', line 4292 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
4294 4295 4296 |
# File 'lib/models/porcelain.rb', line 4294 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
4296 4297 4298 |
# File 'lib/models/porcelain.rb', line 4296 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4298 4299 4300 |
# File 'lib/models/porcelain.rb', line 4298 def healthy @healthy end |
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
4300 4301 4302 |
# File 'lib/models/porcelain.rb', line 4300 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
4302 4303 4304 |
# File 'lib/models/porcelain.rb', line 4302 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4304 4305 4306 |
# File 'lib/models/porcelain.rb', line 4304 def name @name end |
#password ⇒ Object
The password to authenticate with.
4306 4307 4308 |
# File 'lib/models/porcelain.rb', line 4306 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4308 4309 4310 |
# File 'lib/models/porcelain.rb', line 4308 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4310 4311 4312 |
# File 'lib/models/porcelain.rb', line 4310 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4312 4313 4314 |
# File 'lib/models/porcelain.rb', line 4312 def @tags end |
#url ⇒ Object
The base address of your website without the path.
4314 4315 4316 |
# File 'lib/models/porcelain.rb', line 4314 def url @url end |
#username ⇒ Object
The username to authenticate with.
4316 4317 4318 |
# File 'lib/models/porcelain.rb', line 4316 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4352 4353 4354 4355 4356 4357 4358 |
# File 'lib/models/porcelain.rb', line 4352 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |