Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
-
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
4146 4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 4168 4169 4170 4171 4172 4173 4174 4175 4176 4177 4178 |
# File 'lib/models/porcelain.rb', line 4146 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4116 4117 4118 |
# File 'lib/models/porcelain.rb', line 4116 def bind_interface @bind_interface end |
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
4118 4119 4120 |
# File 'lib/models/porcelain.rb', line 4118 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4120 4121 4122 |
# File 'lib/models/porcelain.rb', line 4120 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
4122 4123 4124 |
# File 'lib/models/porcelain.rb', line 4122 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
4124 4125 4126 |
# File 'lib/models/porcelain.rb', line 4124 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4126 4127 4128 |
# File 'lib/models/porcelain.rb', line 4126 def healthy @healthy end |
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
4128 4129 4130 |
# File 'lib/models/porcelain.rb', line 4128 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
4130 4131 4132 |
# File 'lib/models/porcelain.rb', line 4130 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4132 4133 4134 |
# File 'lib/models/porcelain.rb', line 4132 def name @name end |
#password ⇒ Object
The password to authenticate with.
4134 4135 4136 |
# File 'lib/models/porcelain.rb', line 4134 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4136 4137 4138 |
# File 'lib/models/porcelain.rb', line 4136 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4138 4139 4140 |
# File 'lib/models/porcelain.rb', line 4138 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4140 4141 4142 |
# File 'lib/models/porcelain.rb', line 4140 def @tags end |
#url ⇒ Object
The base address of your website without the path.
4142 4143 4144 |
# File 'lib/models/porcelain.rb', line 4142 def url @url end |
#username ⇒ Object
The username to authenticate with.
4144 4145 4146 |
# File 'lib/models/porcelain.rb', line 4144 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4180 4181 4182 4183 4184 4185 4186 |
# File 'lib/models/porcelain.rb', line 4180 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |