Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
# File 'lib/models/porcelain.rb', line 4151

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4121
4122
4123
# File 'lib/models/porcelain.rb', line 4121

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



4123
4124
4125
# File 'lib/models/porcelain.rb', line 4123

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4125
4126
4127
# File 'lib/models/porcelain.rb', line 4125

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



4127
4128
4129
# File 'lib/models/porcelain.rb', line 4127

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



4129
4130
4131
# File 'lib/models/porcelain.rb', line 4129

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4131
4132
4133
# File 'lib/models/porcelain.rb', line 4131

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



4133
4134
4135
# File 'lib/models/porcelain.rb', line 4133

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



4135
4136
4137
# File 'lib/models/porcelain.rb', line 4135

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4137
4138
4139
# File 'lib/models/porcelain.rb', line 4137

def name
  @name
end

#passwordObject

The password to authenticate with.



4139
4140
4141
# File 'lib/models/porcelain.rb', line 4139

def password
  @password
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4141
4142
4143
# File 'lib/models/porcelain.rb', line 4141

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4143
4144
4145
# File 'lib/models/porcelain.rb', line 4143

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4145
4146
4147
# File 'lib/models/porcelain.rb', line 4145

def tags
  @tags
end

#urlObject

The base address of your website without the path.



4147
4148
4149
# File 'lib/models/porcelain.rb', line 4147

def url
  @url
end

#usernameObject

The username to authenticate with.



4149
4150
4151
# File 'lib/models/porcelain.rb', line 4149

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4185
4186
4187
4188
4189
4190
4191
# File 'lib/models/porcelain.rb', line 4185

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end