Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
# File 'lib/models/porcelain.rb', line 4031

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4001
4002
4003
# File 'lib/models/porcelain.rb', line 4001

def bind_interface
  @bind_interface
end

#default_pathObject

Returns the value of attribute default_path.



4003
4004
4005
# File 'lib/models/porcelain.rb', line 4003

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4005
4006
4007
# File 'lib/models/porcelain.rb', line 4005

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Returns the value of attribute headers_blacklist.



4007
4008
4009
# File 'lib/models/porcelain.rb', line 4007

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

Returns the value of attribute healthcheck_path.



4009
4010
4011
# File 'lib/models/porcelain.rb', line 4009

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4011
4012
4013
# File 'lib/models/porcelain.rb', line 4011

def healthy
  @healthy
end

#host_overrideObject

Returns the value of attribute host_override.



4013
4014
4015
# File 'lib/models/porcelain.rb', line 4013

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



4015
4016
4017
# File 'lib/models/porcelain.rb', line 4015

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4017
4018
4019
# File 'lib/models/porcelain.rb', line 4017

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4019
4020
4021
# File 'lib/models/porcelain.rb', line 4019

def password
  @password
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4021
4022
4023
# File 'lib/models/porcelain.rb', line 4021

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



4023
4024
4025
# File 'lib/models/porcelain.rb', line 4023

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4025
4026
4027
# File 'lib/models/porcelain.rb', line 4025

def tags
  @tags
end

#urlObject

Returns the value of attribute url.



4027
4028
4029
# File 'lib/models/porcelain.rb', line 4027

def url
  @url
end

#usernameObject

Returns the value of attribute username.



4029
4030
4031
# File 'lib/models/porcelain.rb', line 4029

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4065
4066
4067
4068
4069
4070
4071
# File 'lib/models/porcelain.rb', line 4065

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end