Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 |
# File 'lib/models/porcelain.rb', line 4007 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3977 3978 3979 |
# File 'lib/models/porcelain.rb', line 3977 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3979 3980 3981 |
# File 'lib/models/porcelain.rb', line 3979 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3981 3982 3983 |
# File 'lib/models/porcelain.rb', line 3981 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3983 3984 3985 |
# File 'lib/models/porcelain.rb', line 3983 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3985 3986 3987 |
# File 'lib/models/porcelain.rb', line 3985 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3987 3988 3989 |
# File 'lib/models/porcelain.rb', line 3987 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3989 3990 3991 |
# File 'lib/models/porcelain.rb', line 3989 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3991 3992 3993 |
# File 'lib/models/porcelain.rb', line 3991 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3993 3994 3995 |
# File 'lib/models/porcelain.rb', line 3993 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3995 3996 3997 |
# File 'lib/models/porcelain.rb', line 3995 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3997 3998 3999 |
# File 'lib/models/porcelain.rb', line 3997 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3999 4000 4001 |
# File 'lib/models/porcelain.rb', line 3999 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4001 4002 4003 |
# File 'lib/models/porcelain.rb', line 4001 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
4003 4004 4005 |
# File 'lib/models/porcelain.rb', line 4003 def url @url end |
#username ⇒ Object
Returns the value of attribute username.
4005 4006 4007 |
# File 'lib/models/porcelain.rb', line 4005 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4041 4042 4043 4044 4045 4046 4047 |
# File 'lib/models/porcelain.rb', line 4041 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |