Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
3713 3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/models/porcelain.rb', line 3713 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3683 3684 3685 |
# File 'lib/models/porcelain.rb', line 3683 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3685 3686 3687 |
# File 'lib/models/porcelain.rb', line 3685 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3687 3688 3689 |
# File 'lib/models/porcelain.rb', line 3687 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3689 3690 3691 |
# File 'lib/models/porcelain.rb', line 3689 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3691 3692 3693 |
# File 'lib/models/porcelain.rb', line 3691 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3693 3694 3695 |
# File 'lib/models/porcelain.rb', line 3693 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3695 3696 3697 |
# File 'lib/models/porcelain.rb', line 3695 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3697 3698 3699 |
# File 'lib/models/porcelain.rb', line 3697 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3699 3700 3701 |
# File 'lib/models/porcelain.rb', line 3699 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3701 3702 3703 |
# File 'lib/models/porcelain.rb', line 3701 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3703 3704 3705 |
# File 'lib/models/porcelain.rb', line 3703 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3705 3706 3707 |
# File 'lib/models/porcelain.rb', line 3705 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3707 3708 3709 |
# File 'lib/models/porcelain.rb', line 3707 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3709 3710 3711 |
# File 'lib/models/porcelain.rb', line 3709 def url @url end |
#username ⇒ Object
Returns the value of attribute username.
3711 3712 3713 |
# File 'lib/models/porcelain.rb', line 3711 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3747 3748 3749 3750 3751 3752 3753 |
# File 'lib/models/porcelain.rb', line 3747 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |