Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 |
# File 'lib/models/porcelain.rb', line 3376 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3346 3347 3348 |
# File 'lib/models/porcelain.rb', line 3346 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3348 3349 3350 |
# File 'lib/models/porcelain.rb', line 3348 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3350 3351 3352 |
# File 'lib/models/porcelain.rb', line 3350 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3352 3353 3354 |
# File 'lib/models/porcelain.rb', line 3352 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3354 3355 3356 |
# File 'lib/models/porcelain.rb', line 3354 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3356 3357 3358 |
# File 'lib/models/porcelain.rb', line 3356 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3358 3359 3360 |
# File 'lib/models/porcelain.rb', line 3358 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3360 3361 3362 |
# File 'lib/models/porcelain.rb', line 3360 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3362 3363 3364 |
# File 'lib/models/porcelain.rb', line 3362 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3364 3365 3366 |
# File 'lib/models/porcelain.rb', line 3364 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3366 3367 3368 |
# File 'lib/models/porcelain.rb', line 3366 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3368 3369 3370 |
# File 'lib/models/porcelain.rb', line 3368 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3370 3371 3372 |
# File 'lib/models/porcelain.rb', line 3370 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3372 3373 3374 |
# File 'lib/models/porcelain.rb', line 3372 def url @url end |
#username ⇒ Object
Returns the value of attribute username.
3374 3375 3376 |
# File 'lib/models/porcelain.rb', line 3374 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3410 3411 3412 3413 3414 3415 3416 |
# File 'lib/models/porcelain.rb', line 3410 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |