Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
3299 3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/models/porcelain.rb', line 3299 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3269 3270 3271 |
# File 'lib/models/porcelain.rb', line 3269 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3271 3272 3273 |
# File 'lib/models/porcelain.rb', line 3271 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3273 3274 3275 |
# File 'lib/models/porcelain.rb', line 3273 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3275 3276 3277 |
# File 'lib/models/porcelain.rb', line 3275 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3277 3278 3279 |
# File 'lib/models/porcelain.rb', line 3277 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3279 3280 3281 |
# File 'lib/models/porcelain.rb', line 3279 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3281 3282 3283 |
# File 'lib/models/porcelain.rb', line 3281 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3283 3284 3285 |
# File 'lib/models/porcelain.rb', line 3283 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3285 3286 3287 |
# File 'lib/models/porcelain.rb', line 3285 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3287 3288 3289 |
# File 'lib/models/porcelain.rb', line 3287 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3289 3290 3291 |
# File 'lib/models/porcelain.rb', line 3289 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3291 3292 3293 |
# File 'lib/models/porcelain.rb', line 3291 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3293 3294 3295 |
# File 'lib/models/porcelain.rb', line 3293 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3295 3296 3297 |
# File 'lib/models/porcelain.rb', line 3295 def url @url end |
#username ⇒ Object
Returns the value of attribute username.
3297 3298 3299 |
# File 'lib/models/porcelain.rb', line 3297 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/models/porcelain.rb', line 3333 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |