Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 |
# File 'lib/models/porcelain.rb', line 3264 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3234 3235 3236 |
# File 'lib/models/porcelain.rb', line 3234 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3236 3237 3238 |
# File 'lib/models/porcelain.rb', line 3236 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3238 3239 3240 |
# File 'lib/models/porcelain.rb', line 3238 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3240 3241 3242 |
# File 'lib/models/porcelain.rb', line 3240 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3242 3243 3244 |
# File 'lib/models/porcelain.rb', line 3242 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3244 3245 3246 |
# File 'lib/models/porcelain.rb', line 3244 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3246 3247 3248 |
# File 'lib/models/porcelain.rb', line 3246 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3248 3249 3250 |
# File 'lib/models/porcelain.rb', line 3248 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3250 3251 3252 |
# File 'lib/models/porcelain.rb', line 3250 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3252 3253 3254 |
# File 'lib/models/porcelain.rb', line 3252 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3254 3255 3256 |
# File 'lib/models/porcelain.rb', line 3254 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3256 3257 3258 |
# File 'lib/models/porcelain.rb', line 3256 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3258 3259 3260 |
# File 'lib/models/porcelain.rb', line 3258 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3260 3261 3262 |
# File 'lib/models/porcelain.rb', line 3260 def url @url end |
#username ⇒ Object
Returns the value of attribute username.
3262 3263 3264 |
# File 'lib/models/porcelain.rb', line 3262 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3298 3299 3300 3301 3302 3303 3304 |
# File 'lib/models/porcelain.rb', line 3298 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |