Class: SDM::HTTPBasicAuth
- Inherits:
-
Object
- Object
- SDM::HTTPBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
constructor
A new instance of HTTPBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth
Returns a new instance of HTTPBasicAuth.
3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 |
# File 'lib/models/porcelain.rb', line 3596 def initialize( default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, id: nil, name: nil, password: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil ) if default_path != nil @default_path = default_path end if egress_filter != nil @egress_filter = egress_filter end if headers_blacklist != nil @headers_blacklist = headers_blacklist end if healthcheck_path != nil @healthcheck_path = healthcheck_path end if healthy != nil @healthy = healthy end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if secret_store_id != nil @secret_store_id = secret_store_id end if subdomain != nil @subdomain = subdomain end if != nil @tags = end if url != nil @url = url end if username != nil @username = username end end |
Instance Attribute Details
#default_path ⇒ Object
Returns the value of attribute default_path.
3570 3571 3572 |
# File 'lib/models/porcelain.rb', line 3570 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3572 3573 3574 |
# File 'lib/models/porcelain.rb', line 3572 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3574 3575 3576 |
# File 'lib/models/porcelain.rb', line 3574 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3576 3577 3578 |
# File 'lib/models/porcelain.rb', line 3576 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3578 3579 3580 |
# File 'lib/models/porcelain.rb', line 3578 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
3580 3581 3582 |
# File 'lib/models/porcelain.rb', line 3580 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3582 3583 3584 |
# File 'lib/models/porcelain.rb', line 3582 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3584 3585 3586 |
# File 'lib/models/porcelain.rb', line 3584 def password @password end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3586 3587 3588 |
# File 'lib/models/porcelain.rb', line 3586 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3588 3589 3590 |
# File 'lib/models/porcelain.rb', line 3588 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3590 3591 3592 |
# File 'lib/models/porcelain.rb', line 3590 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3592 3593 3594 |
# File 'lib/models/porcelain.rb', line 3592 def url @url end |
#username ⇒ Object
Returns the value of attribute username.
3594 3595 3596 |
# File 'lib/models/porcelain.rb', line 3594 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3652 3653 3654 3655 3656 3657 3658 |
# File 'lib/models/porcelain.rb', line 3652 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |