Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



8960
8961
8962
8963
8964
8965
8966
8967
8968
8969
8970
8971
8972
8973
8974
8975
8976
8977
8978
8979
8980
8981
8982
8983
8984
8985
8986
8987
8988
8989
8990
8991
8992
8993
8994
8995
8996
8997
8998
# File 'lib/models/porcelain.rb', line 8960

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8924
8925
8926
# File 'lib/models/porcelain.rb', line 8924

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8926
8927
8928
# File 'lib/models/porcelain.rb', line 8926

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8928
8929
8930
# File 'lib/models/porcelain.rb', line 8928

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8930
8931
8932
# File 'lib/models/porcelain.rb', line 8930

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8932
8933
8934
# File 'lib/models/porcelain.rb', line 8932

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8934
8935
8936
# File 'lib/models/porcelain.rb', line 8934

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8936
8937
8938
# File 'lib/models/porcelain.rb', line 8936

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8938
8939
8940
# File 'lib/models/porcelain.rb', line 8938

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8940
8941
8942
# File 'lib/models/porcelain.rb', line 8940

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8942
8943
8944
# File 'lib/models/porcelain.rb', line 8942

def name
  @name
end

#passwordObject

The password to authenticate with.



8944
8945
8946
# File 'lib/models/porcelain.rb', line 8944

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8946
8947
8948
# File 'lib/models/porcelain.rb', line 8946

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8948
8949
8950
# File 'lib/models/porcelain.rb', line 8948

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8950
8951
8952
# File 'lib/models/porcelain.rb', line 8950

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8952
8953
8954
# File 'lib/models/porcelain.rb', line 8952

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8954
8955
8956
# File 'lib/models/porcelain.rb', line 8954

def tags
  @tags
end

#urlObject

The base address of your website without the path.



8956
8957
8958
# File 'lib/models/porcelain.rb', line 8956

def url
  @url
end

#usernameObject

The username to authenticate with.



8958
8959
8960
# File 'lib/models/porcelain.rb', line 8958

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9000
9001
9002
9003
9004
9005
9006
# File 'lib/models/porcelain.rb', line 9000

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end