Class: SDM::HTTPBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, tls_required: nil, url: nil, username: nil) ⇒ HTTPBasicAuth

Returns a new instance of HTTPBasicAuth.



9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
9141
9142
9143
9144
9145
9146
9147
9148
9149
9150
9151
9152
9153
9154
9155
9156
9157
9158
9159
9160
9161
9162
9163
9164
9165
9166
9167
9168
9169
9170
9171
9172
9173
9174
9175
# File 'lib/models/porcelain.rb', line 9131

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  tls_required: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9089
9090
9091
# File 'lib/models/porcelain.rb', line 9089

def bind_interface
  @bind_interface
end

#custom_headers ⇒ Object

Additional HTTP headers to include in requests.



9091
9092
9093
# File 'lib/models/porcelain.rb', line 9091

def custom_headers
  @custom_headers
end

#default_path ⇒ Object

Automatically redirect to this path upon connecting.



9093
9094
9095
# File 'lib/models/porcelain.rb', line 9093

def default_path
  @default_path
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



9095
9096
9097
# File 'lib/models/porcelain.rb', line 9095

def egress_filter
  @egress_filter
end

#headers_blacklist ⇒ Object

Header names (e.g. Authorization), to omit from logs.



9097
9098
9099
# File 'lib/models/porcelain.rb', line 9097

def headers_blacklist
  @headers_blacklist
end

#healthcheck_path ⇒ Object

This path will be used to check the health of your site.



9099
9100
9101
# File 'lib/models/porcelain.rb', line 9099

def healthcheck_path
  @healthcheck_path
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



9101
9102
9103
# File 'lib/models/porcelain.rb', line 9101

def healthy
  @healthy
end

#host_override ⇒ Object

The host header will be overwritten with this field if provided.



9103
9104
9105
# File 'lib/models/porcelain.rb', line 9103

def host_override
  @host_override
end

#id ⇒ Object

Unique identifier of the Resource.



9105
9106
9107
# File 'lib/models/porcelain.rb', line 9105

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



9107
9108
9109
# File 'lib/models/porcelain.rb', line 9107

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



9109
9110
9111
# File 'lib/models/porcelain.rb', line 9109

def password
  @password
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9111
9112
9113
# File 'lib/models/porcelain.rb', line 9111

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



9113
9114
9115
# File 'lib/models/porcelain.rb', line 9113

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



9115
9116
9117
# File 'lib/models/porcelain.rb', line 9115

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9117
9118
9119
# File 'lib/models/porcelain.rb', line 9117

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



9119
9120
9121
# File 'lib/models/porcelain.rb', line 9119

def tags
  @tags
end

#tls_cert ⇒ Object

Custom TLS certificate for upstream connection.



9121
9122
9123
# File 'lib/models/porcelain.rb', line 9121

def tls_cert
  @tls_cert
end

#tls_insecure ⇒ Object

Skip TLS certificate verification for the upstream connection.



9123
9124
9125
# File 'lib/models/porcelain.rb', line 9123

def tls_insecure
  @tls_insecure
end

#tls_required ⇒ Object

This option enforces HTTPS on the client, not resource connection.



9125
9126
9127
# File 'lib/models/porcelain.rb', line 9125

def tls_required
  @tls_required
end

#url ⇒ Object

The base address of your website without the path.



9127
9128
9129
# File 'lib/models/porcelain.rb', line 9127

def url
  @url
end

#username ⇒ Object

The username to authenticate with.



9129
9130
9131
# File 'lib/models/porcelain.rb', line 9129

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9177
9178
9179
9180
9181
9182
9183
# File 'lib/models/porcelain.rb', line 9177

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end