Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, tls_required: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



9150
9151
9152
9153
9154
9155
9156
9157
9158
9159
9160
9161
9162
9163
9164
9165
9166
9167
9168
9169
9170
9171
9172
9173
9174
9175
9176
9177
9178
9179
9180
9181
9182
9183
9184
9185
9186
9187
9188
9189
9190
# File 'lib/models/porcelain.rb', line 9150

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  tls_required: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9112
9113
9114
# File 'lib/models/porcelain.rb', line 9112

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



9114
9115
9116
# File 'lib/models/porcelain.rb', line 9114

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



9116
9117
9118
# File 'lib/models/porcelain.rb', line 9116

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9118
9119
9120
# File 'lib/models/porcelain.rb', line 9118

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



9120
9121
9122
# File 'lib/models/porcelain.rb', line 9120

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



9122
9123
9124
# File 'lib/models/porcelain.rb', line 9122

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9124
9125
9126
# File 'lib/models/porcelain.rb', line 9124

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



9126
9127
9128
# File 'lib/models/porcelain.rb', line 9126

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



9128
9129
9130
# File 'lib/models/porcelain.rb', line 9128

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9130
9131
9132
# File 'lib/models/porcelain.rb', line 9130

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9132
9133
9134
# File 'lib/models/porcelain.rb', line 9132

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9134
9135
9136
# File 'lib/models/porcelain.rb', line 9134

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9136
9137
9138
# File 'lib/models/porcelain.rb', line 9136

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9138
9139
9140
# File 'lib/models/porcelain.rb', line 9138

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9140
9141
9142
# File 'lib/models/porcelain.rb', line 9140

def tags
  @tags
end

#tls_certObject

Custom TLS certificate for upstream connection.



9142
9143
9144
# File 'lib/models/porcelain.rb', line 9142

def tls_cert
  @tls_cert
end

#tls_insecureObject

Skip TLS certificate verification for the upstream connection.



9144
9145
9146
# File 'lib/models/porcelain.rb', line 9144

def tls_insecure
  @tls_insecure
end

#tls_requiredObject

This option enforces HTTPS on the client, not resource connection.



9146
9147
9148
# File 'lib/models/porcelain.rb', line 9146

def tls_required
  @tls_required
end

#urlObject

The base address of your website without the path.



9148
9149
9150
# File 'lib/models/porcelain.rb', line 9148

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9192
9193
9194
9195
9196
9197
9198
# File 'lib/models/porcelain.rb', line 9192

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end