Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, tls_required: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
9124
9125
9126
9127
9128
9129
9130
9131
9132
9133
9134
9135
9136
9137
9138
9139
9140
9141
9142
9143
9144
9145
9146
9147
9148
9149
9150
9151
9152
9153
9154
# File 'lib/models/porcelain.rb', line 9114

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  tls_required: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9076
9077
9078
# File 'lib/models/porcelain.rb', line 9076

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



9078
9079
9080
# File 'lib/models/porcelain.rb', line 9078

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



9080
9081
9082
# File 'lib/models/porcelain.rb', line 9080

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9082
9083
9084
# File 'lib/models/porcelain.rb', line 9082

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



9084
9085
9086
# File 'lib/models/porcelain.rb', line 9084

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



9086
9087
9088
# File 'lib/models/porcelain.rb', line 9086

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9088
9089
9090
# File 'lib/models/porcelain.rb', line 9088

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



9090
9091
9092
# File 'lib/models/porcelain.rb', line 9090

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



9092
9093
9094
# File 'lib/models/porcelain.rb', line 9092

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9094
9095
9096
# File 'lib/models/porcelain.rb', line 9094

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9096
9097
9098
# File 'lib/models/porcelain.rb', line 9096

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9098
9099
9100
# File 'lib/models/porcelain.rb', line 9098

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9100
9101
9102
# File 'lib/models/porcelain.rb', line 9100

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9102
9103
9104
# File 'lib/models/porcelain.rb', line 9102

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9104
9105
9106
# File 'lib/models/porcelain.rb', line 9104

def tags
  @tags
end

#tls_certObject

Custom TLS certificate for upstream connection.



9106
9107
9108
# File 'lib/models/porcelain.rb', line 9106

def tls_cert
  @tls_cert
end

#tls_insecureObject

Skip TLS certificate verification for the upstream connection.



9108
9109
9110
# File 'lib/models/porcelain.rb', line 9108

def tls_insecure
  @tls_insecure
end

#tls_requiredObject

This option enforces HTTPS on the client, not resource connection.



9110
9111
9112
# File 'lib/models/porcelain.rb', line 9110

def tls_required
  @tls_required
end

#urlObject

The base address of your website without the path.



9112
9113
9114
# File 'lib/models/porcelain.rb', line 9112

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9156
9157
9158
9159
9160
9161
9162
# File 'lib/models/porcelain.rb', line 9156

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end