Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
8938
8939
8940
8941
8942
8943
8944
8945
8946
8947
8948
8949
8950
8951
8952
8953
# File 'lib/models/porcelain.rb', line 8919

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8887
8888
8889
# File 'lib/models/porcelain.rb', line 8887

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8889
8890
8891
# File 'lib/models/porcelain.rb', line 8889

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8891
8892
8893
# File 'lib/models/porcelain.rb', line 8891

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8893
8894
8895
# File 'lib/models/porcelain.rb', line 8893

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8895
8896
8897
# File 'lib/models/porcelain.rb', line 8895

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8897
8898
8899
# File 'lib/models/porcelain.rb', line 8897

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8899
8900
8901
# File 'lib/models/porcelain.rb', line 8899

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8901
8902
8903
# File 'lib/models/porcelain.rb', line 8901

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8903
8904
8905
# File 'lib/models/porcelain.rb', line 8903

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8905
8906
8907
# File 'lib/models/porcelain.rb', line 8905

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8907
8908
8909
# File 'lib/models/porcelain.rb', line 8907

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8909
8910
8911
# File 'lib/models/porcelain.rb', line 8909

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8911
8912
8913
# File 'lib/models/porcelain.rb', line 8911

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8913
8914
8915
# File 'lib/models/porcelain.rb', line 8913

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8915
8916
8917
# File 'lib/models/porcelain.rb', line 8915

def tags
  @tags
end

#urlObject

The base address of your website without the path.



8917
8918
8919
# File 'lib/models/porcelain.rb', line 8917

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8955
8956
8957
8958
8959
8960
8961
# File 'lib/models/porcelain.rb', line 8955

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end