Class: SDM::HTTPNoAuth
- Inherits:
-
Object
- Object
- SDM::HTTPNoAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#custom_headers ⇒ Object
Additional HTTP headers to include in requests.
-
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
-
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
constructor
A new instance of HTTPNoAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
Returns a new instance of HTTPNoAuth.
8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'lib/models/porcelain.rb', line 8845 def initialize( bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @custom_headers = custom_headers == nil ? nil : custom_headers @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
8813 8814 8815 |
# File 'lib/models/porcelain.rb', line 8813 def bind_interface @bind_interface end |
#custom_headers ⇒ Object
Additional HTTP headers to include in requests.
8815 8816 8817 |
# File 'lib/models/porcelain.rb', line 8815 def custom_headers @custom_headers end |
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
8817 8818 8819 |
# File 'lib/models/porcelain.rb', line 8817 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8819 8820 8821 |
# File 'lib/models/porcelain.rb', line 8819 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
8821 8822 8823 |
# File 'lib/models/porcelain.rb', line 8821 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
8823 8824 8825 |
# File 'lib/models/porcelain.rb', line 8823 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8825 8826 8827 |
# File 'lib/models/porcelain.rb', line 8825 def healthy @healthy end |
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
8827 8828 8829 |
# File 'lib/models/porcelain.rb', line 8827 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
8829 8830 8831 |
# File 'lib/models/porcelain.rb', line 8829 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8831 8832 8833 |
# File 'lib/models/porcelain.rb', line 8831 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
8833 8834 8835 |
# File 'lib/models/porcelain.rb', line 8833 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8835 8836 8837 |
# File 'lib/models/porcelain.rb', line 8835 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8837 8838 8839 |
# File 'lib/models/porcelain.rb', line 8837 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8839 8840 8841 |
# File 'lib/models/porcelain.rb', line 8839 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8841 8842 8843 |
# File 'lib/models/porcelain.rb', line 8841 def @tags end |
#url ⇒ Object
The base address of your website without the path.
8843 8844 8845 |
# File 'lib/models/porcelain.rb', line 8843 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8881 8882 8883 8884 8885 8886 8887 |
# File 'lib/models/porcelain.rb', line 8881 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |