Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
8864
8865
8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
# File 'lib/models/porcelain.rb', line 8841

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



8809
8810
8811
# File 'lib/models/porcelain.rb', line 8809

def bind_interface
  @bind_interface
end

#custom_headersObject

Additional HTTP headers to include in requests.



8811
8812
8813
# File 'lib/models/porcelain.rb', line 8811

def custom_headers
  @custom_headers
end

#default_pathObject

Automatically redirect to this path upon connecting.



8813
8814
8815
# File 'lib/models/porcelain.rb', line 8813

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8815
8816
8817
# File 'lib/models/porcelain.rb', line 8815

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



8817
8818
8819
# File 'lib/models/porcelain.rb', line 8817

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



8819
8820
8821
# File 'lib/models/porcelain.rb', line 8819

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8821
8822
8823
# File 'lib/models/porcelain.rb', line 8821

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



8823
8824
8825
# File 'lib/models/porcelain.rb', line 8823

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



8825
8826
8827
# File 'lib/models/porcelain.rb', line 8825

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8827
8828
8829
# File 'lib/models/porcelain.rb', line 8827

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



8829
8830
8831
# File 'lib/models/porcelain.rb', line 8829

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8831
8832
8833
# File 'lib/models/porcelain.rb', line 8831

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8833
8834
8835
# File 'lib/models/porcelain.rb', line 8833

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8835
8836
8837
# File 'lib/models/porcelain.rb', line 8835

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8837
8838
8839
# File 'lib/models/porcelain.rb', line 8837

def tags
  @tags
end

#urlObject

The base address of your website without the path.



8839
8840
8841
# File 'lib/models/porcelain.rb', line 8839

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8877
8878
8879
8880
8881
8882
8883
# File 'lib/models/porcelain.rb', line 8877

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end