Class: SDM::HTTPNoAuth
- Inherits:
-
Object
- Object
- SDM::HTTPNoAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#custom_headers ⇒ Object
Additional HTTP headers to include in requests.
-
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
-
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
constructor
A new instance of HTTPNoAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
Returns a new instance of HTTPNoAuth.
8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 8568 8569 8570 8571 8572 8573 8574 8575 8576 8577 8578 8579 8580 8581 8582 8583 8584 8585 8586 8587 8588 8589 |
# File 'lib/models/porcelain.rb', line 8555 def initialize( bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @custom_headers = custom_headers == nil ? nil : custom_headers @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
8523 8524 8525 |
# File 'lib/models/porcelain.rb', line 8523 def bind_interface @bind_interface end |
#custom_headers ⇒ Object
Additional HTTP headers to include in requests.
8525 8526 8527 |
# File 'lib/models/porcelain.rb', line 8525 def custom_headers @custom_headers end |
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
8527 8528 8529 |
# File 'lib/models/porcelain.rb', line 8527 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8529 8530 8531 |
# File 'lib/models/porcelain.rb', line 8529 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
8531 8532 8533 |
# File 'lib/models/porcelain.rb', line 8531 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
8533 8534 8535 |
# File 'lib/models/porcelain.rb', line 8533 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8535 8536 8537 |
# File 'lib/models/porcelain.rb', line 8535 def healthy @healthy end |
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
8537 8538 8539 |
# File 'lib/models/porcelain.rb', line 8537 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
8539 8540 8541 |
# File 'lib/models/porcelain.rb', line 8539 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8541 8542 8543 |
# File 'lib/models/porcelain.rb', line 8541 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
8543 8544 8545 |
# File 'lib/models/porcelain.rb', line 8543 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8545 8546 8547 |
# File 'lib/models/porcelain.rb', line 8545 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8547 8548 8549 |
# File 'lib/models/porcelain.rb', line 8547 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8549 8550 8551 |
# File 'lib/models/porcelain.rb', line 8549 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8551 8552 8553 |
# File 'lib/models/porcelain.rb', line 8551 def @tags end |
#url ⇒ Object
The base address of your website without the path.
8553 8554 8555 |
# File 'lib/models/porcelain.rb', line 8553 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8591 8592 8593 8594 8595 8596 8597 |
# File 'lib/models/porcelain.rb', line 8591 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |