Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
7965
7966
7967
7968
7969
# File 'lib/models/porcelain.rb', line 7937

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



7907
7908
7909
# File 'lib/models/porcelain.rb', line 7907

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



7909
7910
7911
# File 'lib/models/porcelain.rb', line 7909

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7911
7912
7913
# File 'lib/models/porcelain.rb', line 7911

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



7913
7914
7915
# File 'lib/models/porcelain.rb', line 7913

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



7915
7916
7917
# File 'lib/models/porcelain.rb', line 7915

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7917
7918
7919
# File 'lib/models/porcelain.rb', line 7917

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



7919
7920
7921
# File 'lib/models/porcelain.rb', line 7919

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



7921
7922
7923
# File 'lib/models/porcelain.rb', line 7921

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7923
7924
7925
# File 'lib/models/porcelain.rb', line 7923

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



7925
7926
7927
# File 'lib/models/porcelain.rb', line 7925

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7927
7928
7929
# File 'lib/models/porcelain.rb', line 7927

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7929
7930
7931
# File 'lib/models/porcelain.rb', line 7929

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7931
7932
7933
# File 'lib/models/porcelain.rb', line 7931

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7933
7934
7935
# File 'lib/models/porcelain.rb', line 7933

def tags
  @tags
end

#urlObject

The base address of your website without the path.



7935
7936
7937
# File 'lib/models/porcelain.rb', line 7935

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7971
7972
7973
7974
7975
7976
7977
# File 'lib/models/porcelain.rb', line 7971

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end