Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



6882
6883
6884
6885
6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
# File 'lib/models/porcelain.rb', line 6882

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6854
6855
6856
# File 'lib/models/porcelain.rb', line 6854

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6856
6857
6858
# File 'lib/models/porcelain.rb', line 6856

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6858
6859
6860
# File 'lib/models/porcelain.rb', line 6858

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6860
6861
6862
# File 'lib/models/porcelain.rb', line 6860

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6862
6863
6864
# File 'lib/models/porcelain.rb', line 6862

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6864
6865
6866
# File 'lib/models/porcelain.rb', line 6864

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6866
6867
6868
# File 'lib/models/porcelain.rb', line 6866

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6868
6869
6870
# File 'lib/models/porcelain.rb', line 6868

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6870
6871
6872
# File 'lib/models/porcelain.rb', line 6870

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6872
6873
6874
# File 'lib/models/porcelain.rb', line 6872

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6874
6875
6876
# File 'lib/models/porcelain.rb', line 6874

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6876
6877
6878
# File 'lib/models/porcelain.rb', line 6876

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6878
6879
6880
# File 'lib/models/porcelain.rb', line 6878

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6880
6881
6882
# File 'lib/models/porcelain.rb', line 6880

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6914
6915
6916
6917
6918
6919
6920
# File 'lib/models/porcelain.rb', line 6914

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end