Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



6587
6588
6589
6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
6600
6601
6602
6603
6604
6605
6606
6607
6608
6609
6610
6611
6612
6613
6614
6615
6616
6617
# File 'lib/models/porcelain.rb', line 6587

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6559
6560
6561
# File 'lib/models/porcelain.rb', line 6559

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6561
6562
6563
# File 'lib/models/porcelain.rb', line 6561

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6563
6564
6565
# File 'lib/models/porcelain.rb', line 6563

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6565
6566
6567
# File 'lib/models/porcelain.rb', line 6565

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6567
6568
6569
# File 'lib/models/porcelain.rb', line 6567

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6569
6570
6571
# File 'lib/models/porcelain.rb', line 6569

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6571
6572
6573
# File 'lib/models/porcelain.rb', line 6571

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6573
6574
6575
# File 'lib/models/porcelain.rb', line 6573

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6575
6576
6577
# File 'lib/models/porcelain.rb', line 6575

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6577
6578
6579
# File 'lib/models/porcelain.rb', line 6577

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6579
6580
6581
# File 'lib/models/porcelain.rb', line 6579

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6581
6582
6583
# File 'lib/models/porcelain.rb', line 6581

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6583
6584
6585
# File 'lib/models/porcelain.rb', line 6583

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6585
6586
6587
# File 'lib/models/porcelain.rb', line 6585

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6619
6620
6621
6622
6623
6624
6625
# File 'lib/models/porcelain.rb', line 6619

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end