Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
6468
6469
6470
6471
6472
6473
6474
# File 'lib/models/porcelain.rb', line 6444

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6416
6417
6418
# File 'lib/models/porcelain.rb', line 6416

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



6418
6419
6420
# File 'lib/models/porcelain.rb', line 6418

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6420
6421
6422
# File 'lib/models/porcelain.rb', line 6420

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



6422
6423
6424
# File 'lib/models/porcelain.rb', line 6422

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



6424
6425
6426
# File 'lib/models/porcelain.rb', line 6424

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6426
6427
6428
# File 'lib/models/porcelain.rb', line 6426

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



6428
6429
6430
# File 'lib/models/porcelain.rb', line 6428

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



6430
6431
6432
# File 'lib/models/porcelain.rb', line 6430

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6432
6433
6434
# File 'lib/models/porcelain.rb', line 6432

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6434
6435
6436
# File 'lib/models/porcelain.rb', line 6434

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6436
6437
6438
# File 'lib/models/porcelain.rb', line 6436

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6438
6439
6440
# File 'lib/models/porcelain.rb', line 6438

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6440
6441
6442
# File 'lib/models/porcelain.rb', line 6440

def tags
  @tags
end

#urlObject

The base address of your website without the path.



6442
6443
6444
# File 'lib/models/porcelain.rb', line 6442

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6476
6477
6478
6479
6480
6481
6482
# File 'lib/models/porcelain.rb', line 6476

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end