Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
5949
5950
5951
5952
5953
5954
5955
5956
5957
5958
5959
5960
5961
5962
# File 'lib/models/porcelain.rb', line 5932

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5904
5905
5906
# File 'lib/models/porcelain.rb', line 5904

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



5906
5907
5908
# File 'lib/models/porcelain.rb', line 5906

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5908
5909
5910
# File 'lib/models/porcelain.rb', line 5908

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



5910
5911
5912
# File 'lib/models/porcelain.rb', line 5910

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



5912
5913
5914
# File 'lib/models/porcelain.rb', line 5912

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5914
5915
5916
# File 'lib/models/porcelain.rb', line 5914

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



5916
5917
5918
# File 'lib/models/porcelain.rb', line 5916

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



5918
5919
5920
# File 'lib/models/porcelain.rb', line 5918

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5920
5921
5922
# File 'lib/models/porcelain.rb', line 5920

def name
  @name
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



5922
5923
5924
# File 'lib/models/porcelain.rb', line 5922

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5924
5925
5926
# File 'lib/models/porcelain.rb', line 5924

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5926
5927
5928
# File 'lib/models/porcelain.rb', line 5926

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5928
5929
5930
# File 'lib/models/porcelain.rb', line 5928

def tags
  @tags
end

#urlObject

The base address of your website without the path.



5930
5931
5932
# File 'lib/models/porcelain.rb', line 5930

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5964
5965
5966
5967
5968
5969
5970
# File 'lib/models/porcelain.rb', line 5964

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end