Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



5436
5437
5438
5439
5440
5441
5442
5443
5444
5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
# File 'lib/models/porcelain.rb', line 5436

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5410
5411
5412
# File 'lib/models/porcelain.rb', line 5410

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



5412
5413
5414
# File 'lib/models/porcelain.rb', line 5412

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5414
5415
5416
# File 'lib/models/porcelain.rb', line 5414

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



5416
5417
5418
# File 'lib/models/porcelain.rb', line 5416

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



5418
5419
5420
# File 'lib/models/porcelain.rb', line 5418

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5420
5421
5422
# File 'lib/models/porcelain.rb', line 5420

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



5422
5423
5424
# File 'lib/models/porcelain.rb', line 5422

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



5424
5425
5426
# File 'lib/models/porcelain.rb', line 5424

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5426
5427
5428
# File 'lib/models/porcelain.rb', line 5426

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5428
5429
5430
# File 'lib/models/porcelain.rb', line 5428

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5430
5431
5432
# File 'lib/models/porcelain.rb', line 5430

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5432
5433
5434
# File 'lib/models/porcelain.rb', line 5432

def tags
  @tags
end

#urlObject

The base address of your website without the path.



5434
5435
5436
# File 'lib/models/porcelain.rb', line 5434

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5466
5467
5468
5469
5470
5471
5472
# File 'lib/models/porcelain.rb', line 5466

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end