Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
4560
4561
4562
4563
4564
4565
4566
4567
4568
# File 'lib/models/porcelain.rb', line 4540

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4514
4515
4516
# File 'lib/models/porcelain.rb', line 4514

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



4516
4517
4518
# File 'lib/models/porcelain.rb', line 4516

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4518
4519
4520
# File 'lib/models/porcelain.rb', line 4518

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



4520
4521
4522
# File 'lib/models/porcelain.rb', line 4520

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



4522
4523
4524
# File 'lib/models/porcelain.rb', line 4522

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4524
4525
4526
# File 'lib/models/porcelain.rb', line 4524

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



4526
4527
4528
# File 'lib/models/porcelain.rb', line 4526

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



4528
4529
4530
# File 'lib/models/porcelain.rb', line 4528

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4530
4531
4532
# File 'lib/models/porcelain.rb', line 4530

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4532
4533
4534
# File 'lib/models/porcelain.rb', line 4532

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4534
4535
4536
# File 'lib/models/porcelain.rb', line 4534

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4536
4537
4538
# File 'lib/models/porcelain.rb', line 4536

def tags
  @tags
end

#urlObject

The base address of your website without the path.



4538
4539
4540
# File 'lib/models/porcelain.rb', line 4538

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4570
4571
4572
4573
4574
4575
4576
# File 'lib/models/porcelain.rb', line 4570

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end