Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
# File 'lib/models/porcelain.rb', line 4225

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4199
4200
4201
# File 'lib/models/porcelain.rb', line 4199

def bind_interface
  @bind_interface
end

#default_pathObject

Automatically redirect to this path upon connecting.



4201
4202
4203
# File 'lib/models/porcelain.rb', line 4201

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4203
4204
4205
# File 'lib/models/porcelain.rb', line 4203

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Header names (e.g. Authorization), to omit from logs.



4205
4206
4207
# File 'lib/models/porcelain.rb', line 4205

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

This path will be used to check the health of your site.



4207
4208
4209
# File 'lib/models/porcelain.rb', line 4207

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4209
4210
4211
# File 'lib/models/porcelain.rb', line 4209

def healthy
  @healthy
end

#host_overrideObject

The host header will be overwritten with this field if provided.



4211
4212
4213
# File 'lib/models/porcelain.rb', line 4211

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



4213
4214
4215
# File 'lib/models/porcelain.rb', line 4213

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4215
4216
4217
# File 'lib/models/porcelain.rb', line 4215

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4217
4218
4219
# File 'lib/models/porcelain.rb', line 4217

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4219
4220
4221
# File 'lib/models/porcelain.rb', line 4219

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4221
4222
4223
# File 'lib/models/porcelain.rb', line 4221

def tags
  @tags
end

#urlObject

The base address of your website without the path.



4223
4224
4225
# File 'lib/models/porcelain.rb', line 4223

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4255
4256
4257
4258
4259
4260
4261
# File 'lib/models/porcelain.rb', line 4255

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end