Class: SDM::HTTPNoAuth
- Inherits:
-
Object
- Object
- SDM::HTTPNoAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
constructor
A new instance of HTTPNoAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
Returns a new instance of HTTPNoAuth.
4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 |
# File 'lib/models/porcelain.rb', line 4102 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4076 4077 4078 |
# File 'lib/models/porcelain.rb', line 4076 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
4078 4079 4080 |
# File 'lib/models/porcelain.rb', line 4078 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4080 4081 4082 |
# File 'lib/models/porcelain.rb', line 4080 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
4082 4083 4084 |
# File 'lib/models/porcelain.rb', line 4082 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
4084 4085 4086 |
# File 'lib/models/porcelain.rb', line 4084 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4086 4087 4088 |
# File 'lib/models/porcelain.rb', line 4086 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
4088 4089 4090 |
# File 'lib/models/porcelain.rb', line 4088 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
4090 4091 4092 |
# File 'lib/models/porcelain.rb', line 4090 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4092 4093 4094 |
# File 'lib/models/porcelain.rb', line 4092 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4094 4095 4096 |
# File 'lib/models/porcelain.rb', line 4094 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
4096 4097 4098 |
# File 'lib/models/porcelain.rb', line 4096 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4098 4099 4100 |
# File 'lib/models/porcelain.rb', line 4098 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
4100 4101 4102 |
# File 'lib/models/porcelain.rb', line 4100 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4132 4133 4134 4135 4136 4137 4138 |
# File 'lib/models/porcelain.rb', line 4132 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |