Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



4078
4079
4080
4081
4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
# File 'lib/models/porcelain.rb', line 4078

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4052
4053
4054
# File 'lib/models/porcelain.rb', line 4052

def bind_interface
  @bind_interface
end

#default_pathObject

Returns the value of attribute default_path.



4054
4055
4056
# File 'lib/models/porcelain.rb', line 4054

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4056
4057
4058
# File 'lib/models/porcelain.rb', line 4056

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Returns the value of attribute headers_blacklist.



4058
4059
4060
# File 'lib/models/porcelain.rb', line 4058

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

Returns the value of attribute healthcheck_path.



4060
4061
4062
# File 'lib/models/porcelain.rb', line 4060

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4062
4063
4064
# File 'lib/models/porcelain.rb', line 4062

def healthy
  @healthy
end

#host_overrideObject

Returns the value of attribute host_override.



4064
4065
4066
# File 'lib/models/porcelain.rb', line 4064

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



4066
4067
4068
# File 'lib/models/porcelain.rb', line 4066

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4068
4069
4070
# File 'lib/models/porcelain.rb', line 4068

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4070
4071
4072
# File 'lib/models/porcelain.rb', line 4070

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



4072
4073
4074
# File 'lib/models/porcelain.rb', line 4072

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4074
4075
4076
# File 'lib/models/porcelain.rb', line 4074

def tags
  @tags
end

#urlObject

Returns the value of attribute url.



4076
4077
4078
# File 'lib/models/porcelain.rb', line 4076

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4108
4109
4110
4111
4112
4113
4114
# File 'lib/models/porcelain.rb', line 4108

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end