Class: SDM::HTTPNoAuth
- Inherits:
-
Object
- Object
- SDM::HTTPNoAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
constructor
A new instance of HTTPNoAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
Returns a new instance of HTTPNoAuth.
3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 |
# File 'lib/models/porcelain.rb', line 3784 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3758 3759 3760 |
# File 'lib/models/porcelain.rb', line 3758 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3760 3761 3762 |
# File 'lib/models/porcelain.rb', line 3760 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3762 3763 3764 |
# File 'lib/models/porcelain.rb', line 3762 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3764 3765 3766 |
# File 'lib/models/porcelain.rb', line 3764 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3766 3767 3768 |
# File 'lib/models/porcelain.rb', line 3766 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3768 3769 3770 |
# File 'lib/models/porcelain.rb', line 3768 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3770 3771 3772 |
# File 'lib/models/porcelain.rb', line 3770 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3772 3773 3774 |
# File 'lib/models/porcelain.rb', line 3772 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3774 3775 3776 |
# File 'lib/models/porcelain.rb', line 3774 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3776 3777 3778 |
# File 'lib/models/porcelain.rb', line 3776 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3778 3779 3780 |
# File 'lib/models/porcelain.rb', line 3778 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3780 3781 3782 |
# File 'lib/models/porcelain.rb', line 3780 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3782 3783 3784 |
# File 'lib/models/porcelain.rb', line 3782 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3814 3815 3816 3817 3818 3819 3820 |
# File 'lib/models/porcelain.rb', line 3814 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |