Class: SDM::HTTPNoAuth
- Inherits:
-
Object
- Object
- SDM::HTTPNoAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
constructor
A new instance of HTTPNoAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
Returns a new instance of HTTPNoAuth.
3446 3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 |
# File 'lib/models/porcelain.rb', line 3446 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3420 3421 3422 |
# File 'lib/models/porcelain.rb', line 3420 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3422 3423 3424 |
# File 'lib/models/porcelain.rb', line 3422 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3424 3425 3426 |
# File 'lib/models/porcelain.rb', line 3424 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3426 3427 3428 |
# File 'lib/models/porcelain.rb', line 3426 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3428 3429 3430 |
# File 'lib/models/porcelain.rb', line 3428 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3430 3431 3432 |
# File 'lib/models/porcelain.rb', line 3430 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3432 3433 3434 |
# File 'lib/models/porcelain.rb', line 3432 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3434 3435 3436 |
# File 'lib/models/porcelain.rb', line 3434 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3436 3437 3438 |
# File 'lib/models/porcelain.rb', line 3436 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3438 3439 3440 |
# File 'lib/models/porcelain.rb', line 3438 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3440 3441 3442 |
# File 'lib/models/porcelain.rb', line 3440 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3442 3443 3444 |
# File 'lib/models/porcelain.rb', line 3442 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3444 3445 3446 |
# File 'lib/models/porcelain.rb', line 3444 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3476 3477 3478 3479 3480 3481 3482 |
# File 'lib/models/porcelain.rb', line 3476 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |