Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
3471
3472
3473
3474
3475
# File 'lib/models/porcelain.rb', line 3447

def initialize(
  bind_interface: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3421
3422
3423
# File 'lib/models/porcelain.rb', line 3421

def bind_interface
  @bind_interface
end

#default_pathObject

Returns the value of attribute default_path.



3423
3424
3425
# File 'lib/models/porcelain.rb', line 3423

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3425
3426
3427
# File 'lib/models/porcelain.rb', line 3425

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Returns the value of attribute headers_blacklist.



3427
3428
3429
# File 'lib/models/porcelain.rb', line 3427

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

Returns the value of attribute healthcheck_path.



3429
3430
3431
# File 'lib/models/porcelain.rb', line 3429

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3431
3432
3433
# File 'lib/models/porcelain.rb', line 3431

def healthy
  @healthy
end

#host_overrideObject

Returns the value of attribute host_override.



3433
3434
3435
# File 'lib/models/porcelain.rb', line 3433

def host_override
  @host_override
end

#idObject

Unique identifier of the Resource.



3435
3436
3437
# File 'lib/models/porcelain.rb', line 3435

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3437
3438
3439
# File 'lib/models/porcelain.rb', line 3437

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3439
3440
3441
# File 'lib/models/porcelain.rb', line 3439

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



3441
3442
3443
# File 'lib/models/porcelain.rb', line 3441

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3443
3444
3445
# File 'lib/models/porcelain.rb', line 3443

def tags
  @tags
end

#urlObject

Returns the value of attribute url.



3445
3446
3447
# File 'lib/models/porcelain.rb', line 3445

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3477
3478
3479
3480
3481
3482
3483
# File 'lib/models/porcelain.rb', line 3477

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end