Class: SDM::HTTPNoAuth
- Inherits:
-
Object
- Object
- SDM::HTTPNoAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#default_path ⇒ Object
Returns the value of attribute default_path.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
-
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
Returns the value of attribute host_override.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Returns the value of attribute subdomain.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
Returns the value of attribute url.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
constructor
A new instance of HTTPNoAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
Returns a new instance of HTTPNoAuth.
3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 3349 3350 3351 3352 3353 3354 3355 3356 3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 |
# File 'lib/models/porcelain.rb', line 3339 def initialize( bind_interface: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3313 3314 3315 |
# File 'lib/models/porcelain.rb', line 3313 def bind_interface @bind_interface end |
#default_path ⇒ Object
Returns the value of attribute default_path.
3315 3316 3317 |
# File 'lib/models/porcelain.rb', line 3315 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3317 3318 3319 |
# File 'lib/models/porcelain.rb', line 3317 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Returns the value of attribute headers_blacklist.
3319 3320 3321 |
# File 'lib/models/porcelain.rb', line 3319 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
Returns the value of attribute healthcheck_path.
3321 3322 3323 |
# File 'lib/models/porcelain.rb', line 3321 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3323 3324 3325 |
# File 'lib/models/porcelain.rb', line 3323 def healthy @healthy end |
#host_override ⇒ Object
Returns the value of attribute host_override.
3325 3326 3327 |
# File 'lib/models/porcelain.rb', line 3325 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
3327 3328 3329 |
# File 'lib/models/porcelain.rb', line 3327 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3329 3330 3331 |
# File 'lib/models/porcelain.rb', line 3329 def name @name end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3331 3332 3333 |
# File 'lib/models/porcelain.rb', line 3331 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Returns the value of attribute subdomain.
3333 3334 3335 |
# File 'lib/models/porcelain.rb', line 3333 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3335 3336 3337 |
# File 'lib/models/porcelain.rb', line 3335 def @tags end |
#url ⇒ Object
Returns the value of attribute url.
3337 3338 3339 |
# File 'lib/models/porcelain.rb', line 3337 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3369 3370 3371 3372 3373 3374 3375 |
# File 'lib/models/porcelain.rb', line 3369 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |