Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, id: nil, name: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



3684
3685
3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
# File 'lib/models/porcelain.rb', line 3684

def initialize(
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  id: nil,
  name: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  if default_path != nil
    @default_path = default_path
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if headers_blacklist != nil
    @headers_blacklist = headers_blacklist
  end
  if healthcheck_path != nil
    @healthcheck_path = healthcheck_path
  end
  if healthy != nil
    @healthy = healthy
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if subdomain != nil
    @subdomain = subdomain
  end
  if tags != nil
    @tags = tags
  end
  if url != nil
    @url = url
  end
end

Instance Attribute Details

#default_pathObject

Returns the value of attribute default_path.



3662
3663
3664
# File 'lib/models/porcelain.rb', line 3662

def default_path
  @default_path
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3664
3665
3666
# File 'lib/models/porcelain.rb', line 3664

def egress_filter
  @egress_filter
end

#headers_blacklistObject

Returns the value of attribute headers_blacklist.



3666
3667
3668
# File 'lib/models/porcelain.rb', line 3666

def headers_blacklist
  @headers_blacklist
end

#healthcheck_pathObject

Returns the value of attribute healthcheck_path.



3668
3669
3670
# File 'lib/models/porcelain.rb', line 3668

def healthcheck_path
  @healthcheck_path
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3670
3671
3672
# File 'lib/models/porcelain.rb', line 3670

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



3672
3673
3674
# File 'lib/models/porcelain.rb', line 3672

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3674
3675
3676
# File 'lib/models/porcelain.rb', line 3674

def name
  @name
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3676
3677
3678
# File 'lib/models/porcelain.rb', line 3676

def secret_store_id
  @secret_store_id
end

#subdomainObject

Returns the value of attribute subdomain.



3678
3679
3680
# File 'lib/models/porcelain.rb', line 3678

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



3680
3681
3682
# File 'lib/models/porcelain.rb', line 3680

def tags
  @tags
end

#urlObject

Returns the value of attribute url.



3682
3683
3684
# File 'lib/models/porcelain.rb', line 3682

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3732
3733
3734
3735
3736
3737
3738
# File 'lib/models/porcelain.rb', line 3732

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end