Class: SDM::HTTPNoAuth
- Inherits:
-
Object
- Object
- SDM::HTTPNoAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#custom_headers ⇒ Object
Additional HTTP headers to include in requests.
-
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
-
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The base address of your website without the path.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
constructor
A new instance of HTTPNoAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ HTTPNoAuth
Returns a new instance of HTTPNoAuth.
9043 9044 9045 9046 9047 9048 9049 9050 9051 9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 9062 9063 9064 9065 9066 9067 9068 9069 9070 9071 9072 9073 9074 9075 9076 9077 |
# File 'lib/models/porcelain.rb', line 9043 def initialize( bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @custom_headers = custom_headers == nil ? nil : custom_headers @default_path = default_path == nil ? "" : default_path @egress_filter = egress_filter == nil ? "" : egress_filter @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path @healthy = healthy == nil ? false : healthy @host_override = host_override == nil ? "" : host_override @id = id == nil ? "" : id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
9011 9012 9013 |
# File 'lib/models/porcelain.rb', line 9011 def bind_interface @bind_interface end |
#custom_headers ⇒ Object
Additional HTTP headers to include in requests.
9013 9014 9015 |
# File 'lib/models/porcelain.rb', line 9013 def custom_headers @custom_headers end |
#default_path ⇒ Object
Automatically redirect to this path upon connecting.
9015 9016 9017 |
# File 'lib/models/porcelain.rb', line 9015 def default_path @default_path end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9017 9018 9019 |
# File 'lib/models/porcelain.rb', line 9017 def egress_filter @egress_filter end |
#headers_blacklist ⇒ Object
Header names (e.g. Authorization), to omit from logs.
9019 9020 9021 |
# File 'lib/models/porcelain.rb', line 9019 def headers_blacklist @headers_blacklist end |
#healthcheck_path ⇒ Object
This path will be used to check the health of your site.
9021 9022 9023 |
# File 'lib/models/porcelain.rb', line 9021 def healthcheck_path @healthcheck_path end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9023 9024 9025 |
# File 'lib/models/porcelain.rb', line 9023 def healthy @healthy end |
#host_override ⇒ Object
The host header will be overwritten with this field if provided.
9025 9026 9027 |
# File 'lib/models/porcelain.rb', line 9025 def host_override @host_override end |
#id ⇒ Object
Unique identifier of the Resource.
9027 9028 9029 |
# File 'lib/models/porcelain.rb', line 9027 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9029 9030 9031 |
# File 'lib/models/porcelain.rb', line 9029 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
9031 9032 9033 |
# File 'lib/models/porcelain.rb', line 9031 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9033 9034 9035 |
# File 'lib/models/porcelain.rb', line 9033 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9035 9036 9037 |
# File 'lib/models/porcelain.rb', line 9035 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9037 9038 9039 |
# File 'lib/models/porcelain.rb', line 9037 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9039 9040 9041 |
# File 'lib/models/porcelain.rb', line 9039 def end |
#url ⇒ Object
The base address of your website without the path.
9041 9042 9043 |
# File 'lib/models/porcelain.rb', line 9041 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9079 9080 9081 9082 9083 9084 9085 |
# File 'lib/models/porcelain.rb', line 9079 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |