Class: SDM::HTTPNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, custom_headers: nil, default_path: nil, egress_filter: nil, headers_blacklist: nil, healthcheck_path: nil, healthy: nil, host_override: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, tls_required: nil, url: nil) ⇒ HTTPNoAuth

Returns a new instance of HTTPNoAuth.



9226
9227
9228
9229
9230
9231
9232
9233
9234
9235
9236
9237
9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
9266
# File 'lib/models/porcelain.rb', line 9226

def initialize(
  bind_interface: nil,
  custom_headers: nil,
  default_path: nil,
  egress_filter: nil,
  headers_blacklist: nil,
  healthcheck_path: nil,
  healthy: nil,
  host_override: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  tls_required: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @custom_headers = custom_headers == nil ? nil : custom_headers
  @default_path = default_path == nil ? "" : default_path
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @headers_blacklist = headers_blacklist == nil ? "" : headers_blacklist
  @healthcheck_path = healthcheck_path == nil ? "" : healthcheck_path
  @healthy = healthy == nil ? false : healthy
  @host_override = host_override == nil ? "" : host_override
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @tls_required = tls_required == nil ? false : tls_required
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9188
9189
9190
# File 'lib/models/porcelain.rb', line 9188

def bind_interface
  @bind_interface
end

#custom_headers ⇒ Object

Additional HTTP headers to include in requests.



9190
9191
9192
# File 'lib/models/porcelain.rb', line 9190

def custom_headers
  @custom_headers
end

#default_path ⇒ Object

Automatically redirect to this path upon connecting.



9192
9193
9194
# File 'lib/models/porcelain.rb', line 9192

def default_path
  @default_path
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



9194
9195
9196
# File 'lib/models/porcelain.rb', line 9194

def egress_filter
  @egress_filter
end

#headers_blacklist ⇒ Object

Header names (e.g. Authorization), to omit from logs.



9196
9197
9198
# File 'lib/models/porcelain.rb', line 9196

def headers_blacklist
  @headers_blacklist
end

#healthcheck_path ⇒ Object

This path will be used to check the health of your site.



9198
9199
9200
# File 'lib/models/porcelain.rb', line 9198

def healthcheck_path
  @healthcheck_path
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



9200
9201
9202
# File 'lib/models/porcelain.rb', line 9200

def healthy
  @healthy
end

#host_override ⇒ Object

The host header will be overwritten with this field if provided.



9202
9203
9204
# File 'lib/models/porcelain.rb', line 9202

def host_override
  @host_override
end

#id ⇒ Object

Unique identifier of the Resource.



9204
9205
9206
# File 'lib/models/porcelain.rb', line 9204

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



9206
9207
9208
# File 'lib/models/porcelain.rb', line 9206

def name
  @name
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9208
9209
9210
# File 'lib/models/porcelain.rb', line 9208

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



9210
9211
9212
# File 'lib/models/porcelain.rb', line 9210

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



9212
9213
9214
# File 'lib/models/porcelain.rb', line 9212

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9214
9215
9216
# File 'lib/models/porcelain.rb', line 9214

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



9216
9217
9218
# File 'lib/models/porcelain.rb', line 9216

def tags
  @tags
end

#tls_cert ⇒ Object

Custom TLS certificate for upstream connection.



9218
9219
9220
# File 'lib/models/porcelain.rb', line 9218

def tls_cert
  @tls_cert
end

#tls_insecure ⇒ Object

Skip TLS certificate verification for the upstream connection.



9220
9221
9222
# File 'lib/models/porcelain.rb', line 9220

def tls_insecure
  @tls_insecure
end

#tls_required ⇒ Object

This option enforces HTTPS on the client, not resource connection.



9222
9223
9224
# File 'lib/models/porcelain.rb', line 9222

def tls_required
  @tls_required
end

#url ⇒ Object

The base address of your website without the path.



9224
9225
9226
# File 'lib/models/porcelain.rb', line 9224

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9268
9269
9270
9271
9272
9273
9274
# File 'lib/models/porcelain.rb', line 9268

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end