Class: SDM::HealthChecks
- Inherits:
-
Object
- Object
- SDM::HealthChecks
- Extended by:
- Gem::Deprecate
- Defined in:
- lib/svc.rb
Overview
HealthChecks lists the last healthcheck between each node and resource. Note the unconventional capitalization here is to prevent having a collision with GRPC
See Healthcheck.
Instance Method Summary collapse
-
#initialize(channel, parent) ⇒ HealthChecks
constructor
A new instance of HealthChecks.
-
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of Healthchecks matching a given set of criteria.
Constructor Details
#initialize(channel, parent) ⇒ HealthChecks
Returns a new instance of HealthChecks.
3815 3816 3817 3818 3819 3820 3821 3822 |
# File 'lib/svc.rb', line 3815 def initialize(channel, parent) begin @stub = V1::HealthChecks::Stub.new(nil, nil, channel_override: channel) rescue => exception raise Plumbing::convert_error_to_porcelain(exception) end @parent = parent end |
Instance Method Details
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of Healthchecks matching a given set of criteria.
3825 3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/svc.rb', line 3825 def list( filter, *args, deadline: nil ) req = V1::HealthcheckListRequest.new() req. = V1::ListRequestMetadata.new() if not @parent.page_limit.nil? req..limit = @parent.page_limit end if not @parent.snapshot_time.nil? req..snapshot_at = @parent.snapshot_time end req.filter = Plumbing::quote_filter_args(filter, *args) resp = Enumerator::Generator.new { |g| tries = 0 loop do begin plumbing_response = @stub.list(req, metadata: @parent.("HealthChecks.List", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end tries = 0 plumbing_response.healthchecks.each do |plumbing_item| g.yield Plumbing::convert_healthcheck_to_porcelain(plumbing_item) end break if plumbing_response..next_cursor == "" req..cursor = plumbing_response..next_cursor end } resp end |