Class: SDM::Healthcheck
- Inherits:
-
Object
- Object
- SDM::Healthcheck
- Defined in:
- lib/models/porcelain.rb
Overview
Healthcheck defines the status of the link between a node and a resource
Instance Attribute Summary collapse
-
#error_msg ⇒ Object
The error if unhealthy.
-
#healthy ⇒ Object
Whether the healthcheck succeeded.
-
#id ⇒ Object
Unique identifier of the healthcheck.
-
#node_id ⇒ Object
Unique identifier of the healthcheck node.
-
#node_name ⇒ Object
The name of the node.
-
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
-
#resource_name ⇒ Object
The name of the resource.
-
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
Instance Method Summary collapse
-
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
constructor
A new instance of Healthcheck.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
Returns a new instance of Healthcheck.
9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 9234 9235 9236 9237 9238 |
# File 'lib/models/porcelain.rb', line 9220 def initialize( error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil ) @error_msg = error_msg == nil ? "" : error_msg @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id @node_name = node_name == nil ? "" : node_name @resource_id = resource_id == nil ? "" : resource_id @resource_name = resource_name == nil ? "" : resource_name @timestamp = == nil ? nil : end |
Instance Attribute Details
#error_msg ⇒ Object
The error if unhealthy
9204 9205 9206 |
# File 'lib/models/porcelain.rb', line 9204 def error_msg @error_msg end |
#healthy ⇒ Object
Whether the healthcheck succeeded.
9206 9207 9208 |
# File 'lib/models/porcelain.rb', line 9206 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the healthcheck.
9208 9209 9210 |
# File 'lib/models/porcelain.rb', line 9208 def id @id end |
#node_id ⇒ Object
Unique identifier of the healthcheck node.
9210 9211 9212 |
# File 'lib/models/porcelain.rb', line 9210 def node_id @node_id end |
#node_name ⇒ Object
The name of the node.
9212 9213 9214 |
# File 'lib/models/porcelain.rb', line 9212 def node_name @node_name end |
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
9214 9215 9216 |
# File 'lib/models/porcelain.rb', line 9214 def resource_id @resource_id end |
#resource_name ⇒ Object
The name of the resource.
9216 9217 9218 |
# File 'lib/models/porcelain.rb', line 9216 def resource_name @resource_name end |
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
9218 9219 9220 |
# File 'lib/models/porcelain.rb', line 9218 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/models/porcelain.rb', line 9240 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |