Class: SDM::Healthcheck

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Healthcheck defines the status of the link between a node and a resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck

Returns a new instance of Healthcheck.



6942
6943
6944
6945
6946
6947
6948
6949
6950
6951
6952
6953
6954
6955
6956
6957
6958
6959
6960
# File 'lib/models/porcelain.rb', line 6942

def initialize(
  error_msg: nil,
  healthy: nil,
  id: nil,
  node_id: nil,
  node_name: nil,
  resource_id: nil,
  resource_name: nil,
  timestamp: nil
)
  @error_msg = error_msg == nil ? "" : error_msg
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @node_id = node_id == nil ? "" : node_id
  @node_name = node_name == nil ? "" : node_name
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#error_msgObject

The error if unhealthy



6926
6927
6928
# File 'lib/models/porcelain.rb', line 6926

def error_msg
  @error_msg
end

#healthyObject

Whether the healthcheck succeeded.



6928
6929
6930
# File 'lib/models/porcelain.rb', line 6928

def healthy
  @healthy
end

#idObject

Unique identifier of the healthcheck.



6930
6931
6932
# File 'lib/models/porcelain.rb', line 6930

def id
  @id
end

#node_idObject

Unique identifier of the healthcheck node.



6932
6933
6934
# File 'lib/models/porcelain.rb', line 6932

def node_id
  @node_id
end

#node_nameObject

The name of the node.



6934
6935
6936
# File 'lib/models/porcelain.rb', line 6934

def node_name
  @node_name
end

#resource_idObject

Unique identifier of the healthcheck resource.



6936
6937
6938
# File 'lib/models/porcelain.rb', line 6936

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource.



6938
6939
6940
# File 'lib/models/porcelain.rb', line 6938

def resource_name
  @resource_name
end

#timestampObject

The time at which the healthcheck state was recorded.



6940
6941
6942
# File 'lib/models/porcelain.rb', line 6940

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6962
6963
6964
6965
6966
6967
6968
# File 'lib/models/porcelain.rb', line 6962

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end