Class: SDM::Healthcheck
- Inherits:
-
Object
- Object
- SDM::Healthcheck
- Defined in:
- lib/models/porcelain.rb
Overview
Healthcheck defines the status of the link between a node and a resource
Instance Attribute Summary collapse
-
#error_msg ⇒ Object
The error if unhealthy.
-
#healthy ⇒ Object
Whether the healthcheck succeeded.
-
#id ⇒ Object
Unique identifier of the healthcheck.
-
#node_id ⇒ Object
Unique identifier of the healthcheck node.
-
#node_name ⇒ Object
The name of the node.
-
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
-
#resource_name ⇒ Object
The name of the resource.
-
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
Instance Method Summary collapse
-
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
constructor
A new instance of Healthcheck.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
Returns a new instance of Healthcheck.
6783 6784 6785 6786 6787 6788 6789 6790 6791 6792 6793 6794 6795 6796 6797 6798 6799 6800 6801 |
# File 'lib/models/porcelain.rb', line 6783 def initialize( error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil ) @error_msg = error_msg == nil ? "" : error_msg @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id @node_name = node_name == nil ? "" : node_name @resource_id = resource_id == nil ? "" : resource_id @resource_name = resource_name == nil ? "" : resource_name @timestamp = == nil ? nil : end |
Instance Attribute Details
#error_msg ⇒ Object
The error if unhealthy
6767 6768 6769 |
# File 'lib/models/porcelain.rb', line 6767 def error_msg @error_msg end |
#healthy ⇒ Object
Whether the healthcheck succeeded.
6769 6770 6771 |
# File 'lib/models/porcelain.rb', line 6769 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the healthcheck.
6771 6772 6773 |
# File 'lib/models/porcelain.rb', line 6771 def id @id end |
#node_id ⇒ Object
Unique identifier of the healthcheck node.
6773 6774 6775 |
# File 'lib/models/porcelain.rb', line 6773 def node_id @node_id end |
#node_name ⇒ Object
The name of the node.
6775 6776 6777 |
# File 'lib/models/porcelain.rb', line 6775 def node_name @node_name end |
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
6777 6778 6779 |
# File 'lib/models/porcelain.rb', line 6777 def resource_id @resource_id end |
#resource_name ⇒ Object
The name of the resource.
6779 6780 6781 |
# File 'lib/models/porcelain.rb', line 6779 def resource_name @resource_name end |
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
6781 6782 6783 |
# File 'lib/models/porcelain.rb', line 6781 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6803 6804 6805 6806 6807 6808 6809 |
# File 'lib/models/porcelain.rb', line 6803 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |