Class: SDM::Healthcheck
- Inherits:
-
Object
- Object
- SDM::Healthcheck
- Defined in:
- lib/models/porcelain.rb
Overview
Healthcheck defines the status of the link between a node and a resource
Instance Attribute Summary collapse
-
#error_msg ⇒ Object
The error if unhealthy.
-
#healthy ⇒ Object
Whether the healthcheck succeeded.
-
#id ⇒ Object
Unique identifier of the healthcheck.
-
#node_id ⇒ Object
Unique identifier of the healthcheck node.
-
#node_name ⇒ Object
The name of the node.
-
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
-
#resource_name ⇒ Object
The name of the resource.
-
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
Instance Method Summary collapse
-
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
constructor
A new instance of Healthcheck.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
Returns a new instance of Healthcheck.
6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 |
# File 'lib/models/porcelain.rb', line 6506 def initialize( error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil ) @error_msg = error_msg == nil ? "" : error_msg @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id @node_name = node_name == nil ? "" : node_name @resource_id = resource_id == nil ? "" : resource_id @resource_name = resource_name == nil ? "" : resource_name @timestamp = == nil ? nil : end |
Instance Attribute Details
#error_msg ⇒ Object
The error if unhealthy
6490 6491 6492 |
# File 'lib/models/porcelain.rb', line 6490 def error_msg @error_msg end |
#healthy ⇒ Object
Whether the healthcheck succeeded.
6492 6493 6494 |
# File 'lib/models/porcelain.rb', line 6492 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the healthcheck.
6494 6495 6496 |
# File 'lib/models/porcelain.rb', line 6494 def id @id end |
#node_id ⇒ Object
Unique identifier of the healthcheck node.
6496 6497 6498 |
# File 'lib/models/porcelain.rb', line 6496 def node_id @node_id end |
#node_name ⇒ Object
The name of the node.
6498 6499 6500 |
# File 'lib/models/porcelain.rb', line 6498 def node_name @node_name end |
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
6500 6501 6502 |
# File 'lib/models/porcelain.rb', line 6500 def resource_id @resource_id end |
#resource_name ⇒ Object
The name of the resource.
6502 6503 6504 |
# File 'lib/models/porcelain.rb', line 6502 def resource_name @resource_name end |
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
6504 6505 6506 |
# File 'lib/models/porcelain.rb', line 6504 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6526 6527 6528 6529 6530 6531 6532 |
# File 'lib/models/porcelain.rb', line 6526 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |