Class: SDM::Healthcheck

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Healthcheck defines the status of the link between a node and a resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck

Returns a new instance of Healthcheck.



6355
6356
6357
6358
6359
6360
6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
# File 'lib/models/porcelain.rb', line 6355

def initialize(
  error_msg: nil,
  healthy: nil,
  id: nil,
  node_id: nil,
  node_name: nil,
  resource_id: nil,
  resource_name: nil,
  timestamp: nil
)
  @error_msg = error_msg == nil ? "" : error_msg
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @node_id = node_id == nil ? "" : node_id
  @node_name = node_name == nil ? "" : node_name
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#error_msgObject

The error if unhealthy



6339
6340
6341
# File 'lib/models/porcelain.rb', line 6339

def error_msg
  @error_msg
end

#healthyObject

Whether the healthcheck succeeded.



6341
6342
6343
# File 'lib/models/porcelain.rb', line 6341

def healthy
  @healthy
end

#idObject

Unique identifier of the healthcheck.



6343
6344
6345
# File 'lib/models/porcelain.rb', line 6343

def id
  @id
end

#node_idObject

Unique identifier of the healthcheck node.



6345
6346
6347
# File 'lib/models/porcelain.rb', line 6345

def node_id
  @node_id
end

#node_nameObject

The name of the node.



6347
6348
6349
# File 'lib/models/porcelain.rb', line 6347

def node_name
  @node_name
end

#resource_idObject

Unique identifier of the healthcheck resource.



6349
6350
6351
# File 'lib/models/porcelain.rb', line 6349

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource.



6351
6352
6353
# File 'lib/models/porcelain.rb', line 6351

def resource_name
  @resource_name
end

#timestampObject

The time at which the healthcheck state was recorded.



6353
6354
6355
# File 'lib/models/porcelain.rb', line 6353

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6375
6376
6377
6378
6379
6380
6381
# File 'lib/models/porcelain.rb', line 6375

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end