Class: SDM::Healthcheck
- Inherits:
-
Object
- Object
- SDM::Healthcheck
- Defined in:
- lib/models/porcelain.rb
Overview
Healthcheck defines the status of the link between a node and a resource
Instance Attribute Summary collapse
-
#error_msg ⇒ Object
The error if unhealthy.
-
#healthy ⇒ Object
Whether the healthcheck succeeded.
-
#id ⇒ Object
Unique identifier of the healthcheck.
-
#node_id ⇒ Object
Unique identifier of the healthcheck node.
-
#node_name ⇒ Object
The name of the node.
-
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
-
#resource_name ⇒ Object
The name of the resource.
-
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
Instance Method Summary collapse
-
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
constructor
A new instance of Healthcheck.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
Returns a new instance of Healthcheck.
6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 6373 6374 |
# File 'lib/models/porcelain.rb', line 6356 def initialize( error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil ) @error_msg = error_msg == nil ? "" : error_msg @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id @node_name = node_name == nil ? "" : node_name @resource_id = resource_id == nil ? "" : resource_id @resource_name = resource_name == nil ? "" : resource_name @timestamp = == nil ? nil : end |
Instance Attribute Details
#error_msg ⇒ Object
The error if unhealthy
6340 6341 6342 |
# File 'lib/models/porcelain.rb', line 6340 def error_msg @error_msg end |
#healthy ⇒ Object
Whether the healthcheck succeeded.
6342 6343 6344 |
# File 'lib/models/porcelain.rb', line 6342 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the healthcheck.
6344 6345 6346 |
# File 'lib/models/porcelain.rb', line 6344 def id @id end |
#node_id ⇒ Object
Unique identifier of the healthcheck node.
6346 6347 6348 |
# File 'lib/models/porcelain.rb', line 6346 def node_id @node_id end |
#node_name ⇒ Object
The name of the node.
6348 6349 6350 |
# File 'lib/models/porcelain.rb', line 6348 def node_name @node_name end |
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
6350 6351 6352 |
# File 'lib/models/porcelain.rb', line 6350 def resource_id @resource_id end |
#resource_name ⇒ Object
The name of the resource.
6352 6353 6354 |
# File 'lib/models/porcelain.rb', line 6352 def resource_name @resource_name end |
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
6354 6355 6356 |
# File 'lib/models/porcelain.rb', line 6354 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/models/porcelain.rb', line 6376 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |