Class: SDM::Healthcheck
- Inherits:
-
Object
- Object
- SDM::Healthcheck
- Defined in:
- lib/models/porcelain.rb
Overview
Healthcheck defines the status of the link between a node and a resource
Instance Attribute Summary collapse
-
#error_msg ⇒ Object
The error if unhealthy.
-
#healthy ⇒ Object
Whether the healthcheck succeeded.
-
#id ⇒ Object
Unique identifier of the healthcheck.
-
#node_id ⇒ Object
Unique identifier of the healthcheck node.
-
#node_name ⇒ Object
The name of the node.
-
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
-
#resource_name ⇒ Object
The name of the resource.
-
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
Instance Method Summary collapse
-
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
constructor
A new instance of Healthcheck.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil) ⇒ Healthcheck
Returns a new instance of Healthcheck.
5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/models/porcelain.rb', line 5674 def initialize( error_msg: nil, healthy: nil, id: nil, node_id: nil, node_name: nil, resource_id: nil, resource_name: nil, timestamp: nil ) @error_msg = error_msg == nil ? "" : error_msg @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id @node_name = node_name == nil ? "" : node_name @resource_id = resource_id == nil ? "" : resource_id @resource_name = resource_name == nil ? "" : resource_name @timestamp = == nil ? nil : end |
Instance Attribute Details
#error_msg ⇒ Object
The error if unhealthy
5658 5659 5660 |
# File 'lib/models/porcelain.rb', line 5658 def error_msg @error_msg end |
#healthy ⇒ Object
Whether the healthcheck succeeded.
5660 5661 5662 |
# File 'lib/models/porcelain.rb', line 5660 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the healthcheck.
5662 5663 5664 |
# File 'lib/models/porcelain.rb', line 5662 def id @id end |
#node_id ⇒ Object
Unique identifier of the healthcheck node.
5664 5665 5666 |
# File 'lib/models/porcelain.rb', line 5664 def node_id @node_id end |
#node_name ⇒ Object
The name of the node.
5666 5667 5668 |
# File 'lib/models/porcelain.rb', line 5666 def node_name @node_name end |
#resource_id ⇒ Object
Unique identifier of the healthcheck resource.
5668 5669 5670 |
# File 'lib/models/porcelain.rb', line 5668 def resource_id @resource_id end |
#resource_name ⇒ Object
The name of the resource.
5670 5671 5672 |
# File 'lib/models/porcelain.rb', line 5670 def resource_name @resource_name end |
#timestamp ⇒ Object
The time at which the healthcheck state was recorded.
5672 5673 5674 |
# File 'lib/models/porcelain.rb', line 5672 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5694 5695 5696 5697 5698 5699 5700 |
# File 'lib/models/porcelain.rb', line 5694 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |