Class: SDM::HealthcheckResponse
- Inherits:
-
Object
- Object
- SDM::HealthcheckResponse
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#rate_limit ⇒ Object
Rate limit information.
-
#status ⇒ Object
Array of statuses of all nodes serving a secret engine.
Instance Method Summary collapse
-
#initialize(rate_limit: nil, status: nil) ⇒ HealthcheckResponse
constructor
A new instance of HealthcheckResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(rate_limit: nil, status: nil) ⇒ HealthcheckResponse
Returns a new instance of HealthcheckResponse.
6722 6723 6724 6725 6726 6727 6728 |
# File 'lib/models/porcelain.rb', line 6722 def initialize( rate_limit: nil, status: nil ) @rate_limit = rate_limit == nil ? nil : rate_limit @status = status == nil ? [] : status end |
Instance Attribute Details
#rate_limit ⇒ Object
Rate limit information.
6718 6719 6720 |
# File 'lib/models/porcelain.rb', line 6718 def rate_limit @rate_limit end |
#status ⇒ Object
Array of statuses of all nodes serving a secret engine
6720 6721 6722 |
# File 'lib/models/porcelain.rb', line 6720 def status @status end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6730 6731 6732 6733 6734 6735 6736 |
# File 'lib/models/porcelain.rb', line 6730 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |