Class: SDM::IdentityAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias

Returns a new instance of IdentityAlias.



9348
9349
9350
9351
9352
9353
9354
9355
9356
9357
9358
# File 'lib/models/porcelain.rb', line 9348

def initialize(
  account_id: nil,
  id: nil,
  identity_set_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this identity alias.



9340
9341
9342
# File 'lib/models/porcelain.rb', line 9340

def 
  @account_id
end

#idObject

Unique identifier of the IdentityAlias.



9342
9343
9344
# File 'lib/models/porcelain.rb', line 9342

def id
  @id
end

#identity_set_idObject

The identity set.



9344
9345
9346
# File 'lib/models/porcelain.rb', line 9344

def identity_set_id
  @identity_set_id
end

#usernameObject

The username to be used as the identity alias for this account.



9346
9347
9348
# File 'lib/models/porcelain.rb', line 9346

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9360
9361
9362
9363
9364
9365
9366
# File 'lib/models/porcelain.rb', line 9360

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end