Class: SDM::IdentityAlias
- Inherits:
-
Object
- Object
- SDM::IdentityAlias
- Defined in:
- lib/models/porcelain.rb
Overview
IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this identity alias.
-
#id ⇒ Object
Unique identifier of the IdentityAlias.
-
#identity_set_id ⇒ Object
The identity set.
-
#username ⇒ Object
The username to be used as the identity alias for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
constructor
A new instance of IdentityAlias.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
Returns a new instance of IdentityAlias.
9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/models/porcelain.rb', line 9312 def initialize( account_id: nil, id: nil, identity_set_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @identity_set_id = identity_set_id == nil ? "" : identity_set_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this identity alias.
9304 9305 9306 |
# File 'lib/models/porcelain.rb', line 9304 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the IdentityAlias.
9306 9307 9308 |
# File 'lib/models/porcelain.rb', line 9306 def id @id end |
#identity_set_id ⇒ Object
The identity set.
9308 9309 9310 |
# File 'lib/models/porcelain.rb', line 9308 def identity_set_id @identity_set_id end |
#username ⇒ Object
The username to be used as the identity alias for this account.
9310 9311 9312 |
# File 'lib/models/porcelain.rb', line 9310 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9324 9325 9326 9327 9328 9329 9330 |
# File 'lib/models/porcelain.rb', line 9324 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |