Class: SDM::IdentityAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias

Returns a new instance of IdentityAlias.



9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
# File 'lib/models/porcelain.rb', line 9037

def initialize(
  account_id: nil,
  id: nil,
  identity_set_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this identity alias.



9029
9030
9031
# File 'lib/models/porcelain.rb', line 9029

def 
  @account_id
end

#idObject

Unique identifier of the IdentityAlias.



9031
9032
9033
# File 'lib/models/porcelain.rb', line 9031

def id
  @id
end

#identity_set_idObject

The identity set.



9033
9034
9035
# File 'lib/models/porcelain.rb', line 9033

def identity_set_id
  @identity_set_id
end

#usernameObject

The username to be used as the identity alias for this account.



9035
9036
9037
# File 'lib/models/porcelain.rb', line 9035

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9049
9050
9051
9052
9053
9054
9055
# File 'lib/models/porcelain.rb', line 9049

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end