Class: SDM::IdentityAlias
- Inherits:
-
Object
- Object
- SDM::IdentityAlias
- Defined in:
- lib/models/porcelain.rb
Overview
IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this identity alias.
-
#id ⇒ Object
Unique identifier of the IdentityAlias.
-
#identity_set_id ⇒ Object
The identity set.
-
#username ⇒ Object
The username to be used as the identity alias for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
constructor
A new instance of IdentityAlias.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
Returns a new instance of IdentityAlias.
8127 8128 8129 8130 8131 8132 8133 8134 8135 8136 8137 |
# File 'lib/models/porcelain.rb', line 8127 def initialize( account_id: nil, id: nil, identity_set_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @identity_set_id = identity_set_id == nil ? "" : identity_set_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this identity alias.
8119 8120 8121 |
# File 'lib/models/porcelain.rb', line 8119 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the IdentityAlias.
8121 8122 8123 |
# File 'lib/models/porcelain.rb', line 8121 def id @id end |
#identity_set_id ⇒ Object
The identity set.
8123 8124 8125 |
# File 'lib/models/porcelain.rb', line 8123 def identity_set_id @identity_set_id end |
#username ⇒ Object
The username to be used as the identity alias for this account.
8125 8126 8127 |
# File 'lib/models/porcelain.rb', line 8125 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8139 8140 8141 8142 8143 8144 8145 |
# File 'lib/models/porcelain.rb', line 8139 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |