Class: SDM::IdentityAlias
- Inherits:
-
Object
- Object
- SDM::IdentityAlias
- Defined in:
- lib/models/porcelain.rb
Overview
IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this identity alias.
-
#id ⇒ Object
Unique identifier of the IdentityAlias.
-
#identity_set_id ⇒ Object
The identity set.
-
#username ⇒ Object
The username to be used as the identity alias for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
constructor
A new instance of IdentityAlias.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
Returns a new instance of IdentityAlias.
6775 6776 6777 6778 6779 6780 6781 6782 6783 6784 6785 |
# File 'lib/models/porcelain.rb', line 6775 def initialize( account_id: nil, id: nil, identity_set_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @identity_set_id = identity_set_id == nil ? "" : identity_set_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this identity alias.
6767 6768 6769 |
# File 'lib/models/porcelain.rb', line 6767 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the IdentityAlias.
6769 6770 6771 |
# File 'lib/models/porcelain.rb', line 6769 def id @id end |
#identity_set_id ⇒ Object
The identity set.
6771 6772 6773 |
# File 'lib/models/porcelain.rb', line 6771 def identity_set_id @identity_set_id end |
#username ⇒ Object
The username to be used as the identity alias for this account.
6773 6774 6775 |
# File 'lib/models/porcelain.rb', line 6773 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6787 6788 6789 6790 6791 6792 6793 |
# File 'lib/models/porcelain.rb', line 6787 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |