Class: SDM::IdentityAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias

Returns a new instance of IdentityAlias.



6488
6489
6490
6491
6492
6493
6494
6495
6496
6497
6498
# File 'lib/models/porcelain.rb', line 6488

def initialize(
  account_id: nil,
  id: nil,
  identity_set_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this identity alias.



6480
6481
6482
# File 'lib/models/porcelain.rb', line 6480

def 
  @account_id
end

#idObject

Unique identifier of the IdentityAlias.



6482
6483
6484
# File 'lib/models/porcelain.rb', line 6482

def id
  @id
end

#identity_set_idObject

The identity set.



6484
6485
6486
# File 'lib/models/porcelain.rb', line 6484

def identity_set_id
  @identity_set_id
end

#usernameObject

The username to be used as the identity alias for this account.



6486
6487
6488
# File 'lib/models/porcelain.rb', line 6486

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6500
6501
6502
6503
6504
6505
6506
# File 'lib/models/porcelain.rb', line 6500

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end