Class: SDM::IdentityAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias

Returns a new instance of IdentityAlias.



6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
# File 'lib/models/porcelain.rb', line 6056

def initialize(
  account_id: nil,
  id: nil,
  identity_set_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this identity alias.



6048
6049
6050
# File 'lib/models/porcelain.rb', line 6048

def 
  @account_id
end

#idObject

Unique identifier of the IdentityAlias.



6050
6051
6052
# File 'lib/models/porcelain.rb', line 6050

def id
  @id
end

#identity_set_idObject

The identity set.



6052
6053
6054
# File 'lib/models/porcelain.rb', line 6052

def identity_set_id
  @identity_set_id
end

#usernameObject

The username to be used as the identity alias for this account.



6054
6055
6056
# File 'lib/models/porcelain.rb', line 6054

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6068
6069
6070
6071
6072
6073
6074
# File 'lib/models/porcelain.rb', line 6068

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end