Class: SDM::IdentityAlias
- Inherits:
-
Object
- Object
- SDM::IdentityAlias
- Defined in:
- lib/models/porcelain.rb
Overview
IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this identity alias.
-
#id ⇒ Object
Unique identifier of the IdentityAlias.
-
#identity_set_id ⇒ Object
The identity set.
-
#username ⇒ Object
The username to be used as the identity alias for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
constructor
A new instance of IdentityAlias.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
Returns a new instance of IdentityAlias.
5807 5808 5809 5810 5811 5812 5813 5814 5815 5816 5817 |
# File 'lib/models/porcelain.rb', line 5807 def initialize( account_id: nil, id: nil, identity_set_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @identity_set_id = identity_set_id == nil ? "" : identity_set_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this identity alias.
5799 5800 5801 |
# File 'lib/models/porcelain.rb', line 5799 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the IdentityAlias.
5801 5802 5803 |
# File 'lib/models/porcelain.rb', line 5801 def id @id end |
#identity_set_id ⇒ Object
The identity set.
5803 5804 5805 |
# File 'lib/models/porcelain.rb', line 5803 def identity_set_id @identity_set_id end |
#username ⇒ Object
The username to be used as the identity alias for this account.
5805 5806 5807 |
# File 'lib/models/porcelain.rb', line 5805 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5819 5820 5821 5822 5823 5824 5825 |
# File 'lib/models/porcelain.rb', line 5819 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |