Class: SDM::IdentityAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias

Returns a new instance of IdentityAlias.



5487
5488
5489
5490
5491
5492
5493
5494
5495
5496
5497
# File 'lib/models/porcelain.rb', line 5487

def initialize(
  account_id: nil,
  id: nil,
  identity_set_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this identity alias.



5479
5480
5481
# File 'lib/models/porcelain.rb', line 5479

def 
  @account_id
end

#idObject

Unique identifier of the IdentityAlias.



5481
5482
5483
# File 'lib/models/porcelain.rb', line 5481

def id
  @id
end

#identity_set_idObject

The identity set.



5483
5484
5485
# File 'lib/models/porcelain.rb', line 5483

def identity_set_id
  @identity_set_id
end

#usernameObject

The username to be used as the identity alias for this account.



5485
5486
5487
# File 'lib/models/porcelain.rb', line 5485

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5499
5500
5501
5502
5503
5504
5505
# File 'lib/models/porcelain.rb', line 5499

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end