Class: SDM::IdentityAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias

Returns a new instance of IdentityAlias.



5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
# File 'lib/models/porcelain.rb', line 5329

def initialize(
  account_id: nil,
  id: nil,
  identity_set_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this identity alias.



5321
5322
5323
# File 'lib/models/porcelain.rb', line 5321

def 
  @account_id
end

#idObject

Unique identifier of the IdentityAlias.



5323
5324
5325
# File 'lib/models/porcelain.rb', line 5323

def id
  @id
end

#identity_set_idObject

The identity set.



5325
5326
5327
# File 'lib/models/porcelain.rb', line 5325

def identity_set_id
  @identity_set_id
end

#usernameObject

The username to be used as the identity alias for this account.



5327
5328
5329
# File 'lib/models/porcelain.rb', line 5327

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5341
5342
5343
5344
5345
5346
5347
# File 'lib/models/porcelain.rb', line 5341

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end