Class: SDM::IdentityAlias
- Inherits:
-
Object
- Object
- SDM::IdentityAlias
- Defined in:
- lib/models/porcelain.rb
Overview
IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this identity alias.
-
#id ⇒ Object
Unique identifier of the IdentityAlias.
-
#identity_set_id ⇒ Object
The identity set.
-
#username ⇒ Object
The username to be used as the identity alias for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
constructor
A new instance of IdentityAlias.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias
Returns a new instance of IdentityAlias.
9262 9263 9264 9265 9266 9267 9268 9269 9270 9271 9272 |
# File 'lib/models/porcelain.rb', line 9262 def initialize( account_id: nil, id: nil, identity_set_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @identity_set_id = identity_set_id == nil ? "" : identity_set_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this identity alias.
9254 9255 9256 |
# File 'lib/models/porcelain.rb', line 9254 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the IdentityAlias.
9256 9257 9258 |
# File 'lib/models/porcelain.rb', line 9256 def id @id end |
#identity_set_id ⇒ Object
The identity set.
9258 9259 9260 |
# File 'lib/models/porcelain.rb', line 9258 def identity_set_id @identity_set_id end |
#username ⇒ Object
The username to be used as the identity alias for this account.
9260 9261 9262 |
# File 'lib/models/porcelain.rb', line 9260 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9274 9275 9276 9277 9278 9279 9280 |
# File 'lib/models/porcelain.rb', line 9274 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |