Class: SDM::IdentityAlias

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliases define the username to be used for a specific account when connecting to a remote resource using that identity set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, identity_set_id: nil, username: nil) ⇒ IdentityAlias

Returns a new instance of IdentityAlias.



9110
9111
9112
9113
9114
9115
9116
9117
9118
9119
9120
# File 'lib/models/porcelain.rb', line 9110

def initialize(
  account_id: nil,
  id: nil,
  identity_set_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this identity alias.



9102
9103
9104
# File 'lib/models/porcelain.rb', line 9102

def 
  @account_id
end

#idObject

Unique identifier of the IdentityAlias.



9104
9105
9106
# File 'lib/models/porcelain.rb', line 9104

def id
  @id
end

#identity_set_idObject

The identity set.



9106
9107
9108
# File 'lib/models/porcelain.rb', line 9106

def identity_set_id
  @identity_set_id
end

#usernameObject

The username to be used as the identity alias for this account.



9108
9109
9110
# File 'lib/models/porcelain.rb', line 9108

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9122
9123
9124
9125
9126
9127
9128
# File 'lib/models/porcelain.rb', line 9122

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end