Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



9148
9149
9150
9151
9152
9153
9154
9155
9156
9157
9158
# File 'lib/models/porcelain.rb', line 9148

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



9140
9141
9142
# File 'lib/models/porcelain.rb', line 9140

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



9142
9143
9144
# File 'lib/models/porcelain.rb', line 9142

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



9144
9145
9146
# File 'lib/models/porcelain.rb', line 9144

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



9146
9147
9148
# File 'lib/models/porcelain.rb', line 9146

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9160
9161
9162
9163
9164
9165
9166
# File 'lib/models/porcelain.rb', line 9160

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end