Class: SDM::IdentityAliasHistory
- Inherits:
-
Object
- Object
- SDM::IdentityAliasHistory
- Defined in:
- lib/models/porcelain.rb
Overview
IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentityAlias.
-
#deleted_at ⇒ Object
If this IdentityAlias was deleted, the time it was deleted.
-
#identity_alias ⇒ Object
The complete IdentityAlias state at this time.
-
#timestamp ⇒ Object
The time at which the IdentityAlias state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory
constructor
A new instance of IdentityAliasHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory
Returns a new instance of IdentityAliasHistory.
9148 9149 9150 9151 9152 9153 9154 9155 9156 9157 9158 |
# File 'lib/models/porcelain.rb', line 9148 def initialize( activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @identity_alias = identity_alias == nil ? nil : identity_alias @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.
9140 9141 9142 |
# File 'lib/models/porcelain.rb', line 9140 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this IdentityAlias was deleted, the time it was deleted.
9142 9143 9144 |
# File 'lib/models/porcelain.rb', line 9142 def deleted_at @deleted_at end |
#identity_alias ⇒ Object
The complete IdentityAlias state at this time.
9144 9145 9146 |
# File 'lib/models/porcelain.rb', line 9144 def identity_alias @identity_alias end |
#timestamp ⇒ Object
The time at which the IdentityAlias state was recorded.
9146 9147 9148 |
# File 'lib/models/porcelain.rb', line 9146 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9160 9161 9162 9163 9164 9165 9166 |
# File 'lib/models/porcelain.rb', line 9160 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |