Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



7185
7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
# File 'lib/models/porcelain.rb', line 7185

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



7177
7178
7179
# File 'lib/models/porcelain.rb', line 7177

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



7179
7180
7181
# File 'lib/models/porcelain.rb', line 7179

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



7181
7182
7183
# File 'lib/models/porcelain.rb', line 7181

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



7183
7184
7185
# File 'lib/models/porcelain.rb', line 7183

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7197
7198
7199
7200
7201
7202
7203
# File 'lib/models/porcelain.rb', line 7197

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end