Class: SDM::IdentityAliasHistory
- Inherits:
-
Object
- Object
- SDM::IdentityAliasHistory
- Defined in:
- lib/models/porcelain.rb
Overview
IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentityAlias.
-
#deleted_at ⇒ Object
If this IdentityAlias was deleted, the time it was deleted.
-
#identity_alias ⇒ Object
The complete IdentityAlias state at this time.
-
#timestamp ⇒ Object
The time at which the IdentityAlias state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory
constructor
A new instance of IdentityAliasHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory
Returns a new instance of IdentityAliasHistory.
7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 |
# File 'lib/models/porcelain.rb', line 7026 def initialize( activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @identity_alias = identity_alias == nil ? nil : identity_alias @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.
7018 7019 7020 |
# File 'lib/models/porcelain.rb', line 7018 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this IdentityAlias was deleted, the time it was deleted.
7020 7021 7022 |
# File 'lib/models/porcelain.rb', line 7020 def deleted_at @deleted_at end |
#identity_alias ⇒ Object
The complete IdentityAlias state at this time.
7022 7023 7024 |
# File 'lib/models/porcelain.rb', line 7022 def identity_alias @identity_alias end |
#timestamp ⇒ Object
The time at which the IdentityAlias state was recorded.
7024 7025 7026 |
# File 'lib/models/porcelain.rb', line 7024 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7038 7039 7040 7041 7042 7043 7044 |
# File 'lib/models/porcelain.rb', line 7038 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |