Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
# File 'lib/models/porcelain.rb', line 6890

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



6882
6883
6884
# File 'lib/models/porcelain.rb', line 6882

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



6884
6885
6886
# File 'lib/models/porcelain.rb', line 6884

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



6886
6887
6888
# File 'lib/models/porcelain.rb', line 6886

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



6888
6889
6890
# File 'lib/models/porcelain.rb', line 6888

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6902
6903
6904
6905
6906
6907
6908
# File 'lib/models/porcelain.rb', line 6902

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end