Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



6603
6604
6605
6606
6607
6608
6609
6610
6611
6612
6613
# File 'lib/models/porcelain.rb', line 6603

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



6595
6596
6597
# File 'lib/models/porcelain.rb', line 6595

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



6597
6598
6599
# File 'lib/models/porcelain.rb', line 6597

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



6599
6600
6601
# File 'lib/models/porcelain.rb', line 6599

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



6601
6602
6603
# File 'lib/models/porcelain.rb', line 6601

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6615
6616
6617
6618
6619
6620
6621
# File 'lib/models/porcelain.rb', line 6615

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end