Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



6532
6533
6534
6535
6536
6537
6538
6539
6540
6541
6542
# File 'lib/models/porcelain.rb', line 6532

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



6524
6525
6526
# File 'lib/models/porcelain.rb', line 6524

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



6526
6527
6528
# File 'lib/models/porcelain.rb', line 6526

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



6528
6529
6530
# File 'lib/models/porcelain.rb', line 6528

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



6530
6531
6532
# File 'lib/models/porcelain.rb', line 6530

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6544
6545
6546
6547
6548
6549
6550
# File 'lib/models/porcelain.rb', line 6544

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end