Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
# File 'lib/models/porcelain.rb', line 6169

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



6161
6162
6163
# File 'lib/models/porcelain.rb', line 6161

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



6163
6164
6165
# File 'lib/models/porcelain.rb', line 6163

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



6165
6166
6167
# File 'lib/models/porcelain.rb', line 6165

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



6167
6168
6169
# File 'lib/models/porcelain.rb', line 6167

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6181
6182
6183
6184
6185
6186
6187
# File 'lib/models/porcelain.rb', line 6181

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end