Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
# File 'lib/models/porcelain.rb', line 5922

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



5914
5915
5916
# File 'lib/models/porcelain.rb', line 5914

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



5916
5917
5918
# File 'lib/models/porcelain.rb', line 5916

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



5918
5919
5920
# File 'lib/models/porcelain.rb', line 5918

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



5920
5921
5922
# File 'lib/models/porcelain.rb', line 5920

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5934
5935
5936
5937
5938
5939
5940
# File 'lib/models/porcelain.rb', line 5934

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end