Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



5851
5852
5853
5854
5855
5856
5857
5858
5859
5860
5861
# File 'lib/models/porcelain.rb', line 5851

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



5843
5844
5845
# File 'lib/models/porcelain.rb', line 5843

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



5845
5846
5847
# File 'lib/models/porcelain.rb', line 5845

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



5847
5848
5849
# File 'lib/models/porcelain.rb', line 5847

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



5849
5850
5851
# File 'lib/models/porcelain.rb', line 5849

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5863
5864
5865
5866
5867
5868
5869
# File 'lib/models/porcelain.rb', line 5863

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end