Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



9377
9378
9379
9380
9381
9382
9383
9384
9385
9386
9387
# File 'lib/models/porcelain.rb', line 9377

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



9369
9370
9371
# File 'lib/models/porcelain.rb', line 9369

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



9371
9372
9373
# File 'lib/models/porcelain.rb', line 9371

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



9373
9374
9375
# File 'lib/models/porcelain.rb', line 9373

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



9375
9376
9377
# File 'lib/models/porcelain.rb', line 9375

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9389
9390
9391
9392
9393
9394
9395
# File 'lib/models/porcelain.rb', line 9389

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end