Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



9225
9226
9227
9228
9229
9230
9231
9232
9233
9234
9235
# File 'lib/models/porcelain.rb', line 9225

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



9217
9218
9219
# File 'lib/models/porcelain.rb', line 9217

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentityAlias was deleted, the time it was deleted.



9219
9220
9221
# File 'lib/models/porcelain.rb', line 9219

def deleted_at
  @deleted_at
end

#identity_aliasObject

The complete IdentityAlias state at this time.



9221
9222
9223
# File 'lib/models/porcelain.rb', line 9221

def identity_alias
  @identity_alias
end

#timestampObject

The time at which the IdentityAlias state was recorded.



9223
9224
9225
# File 'lib/models/porcelain.rb', line 9223

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9237
9238
9239
9240
9241
9242
9243
# File 'lib/models/porcelain.rb', line 9237

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end