Class: SDM::IdentityAliasHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentityAliasHistory records the state of a IdentityAlias at a given point in time, where every change (create, update and delete) to a IdentityAlias produces an IdentityAliasHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_alias: nil, timestamp: nil) ⇒ IdentityAliasHistory

Returns a new instance of IdentityAliasHistory.



9539
9540
9541
9542
9543
9544
9545
9546
9547
9548
9549
# File 'lib/models/porcelain.rb', line 9539

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_alias: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_alias = identity_alias == nil ? nil : identity_alias
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the IdentityAlias. May be empty for some system-initiated updates.



9531
9532
9533
# File 'lib/models/porcelain.rb', line 9531

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this IdentityAlias was deleted, the time it was deleted.



9533
9534
9535
# File 'lib/models/porcelain.rb', line 9533

def deleted_at
  @deleted_at
end

#identity_alias ⇒ Object

The complete IdentityAlias state at this time.



9535
9536
9537
# File 'lib/models/porcelain.rb', line 9535

def identity_alias
  @identity_alias
end

#timestamp ⇒ Object

The time at which the IdentityAlias state was recorded.



9537
9538
9539
# File 'lib/models/porcelain.rb', line 9537

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9551
9552
9553
9554
9555
9556
9557
# File 'lib/models/porcelain.rb', line 9551

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end