Class: SDM::IdentitySetHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory

Returns a new instance of IdentitySetHistory.



9632
9633
9634
9635
9636
9637
9638
9639
9640
9641
9642
# File 'lib/models/porcelain.rb', line 9632

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_set: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_set = identity_set == nil ? nil : identity_set
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.



9624
9625
9626
# File 'lib/models/porcelain.rb', line 9624

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentitySet was deleted, the time it was deleted.



9626
9627
9628
# File 'lib/models/porcelain.rb', line 9626

def deleted_at
  @deleted_at
end

#identity_setObject

The complete IdentitySet state at this time.



9628
9629
9630
# File 'lib/models/porcelain.rb', line 9628

def identity_set
  @identity_set
end

#timestampObject

The time at which the IdentitySet state was recorded.



9630
9631
9632
# File 'lib/models/porcelain.rb', line 9630

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9644
9645
9646
9647
9648
9649
9650
# File 'lib/models/porcelain.rb', line 9644

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end