Class: SDM::IdentitySetHistory
- Inherits:
-
Object
- Object
- SDM::IdentitySetHistory
- Defined in:
- lib/models/porcelain.rb
Overview
IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentitySet.
-
#deleted_at ⇒ Object
If this IdentitySet was deleted, the time it was deleted.
-
#identity_set ⇒ Object
The complete IdentitySet state at this time.
-
#timestamp ⇒ Object
The time at which the IdentitySet state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory
constructor
A new instance of IdentitySetHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory
Returns a new instance of IdentitySetHistory.
9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 |
# File 'lib/models/porcelain.rb', line 9596 def initialize( activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @identity_set = identity_set == nil ? nil : identity_set @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.
9588 9589 9590 |
# File 'lib/models/porcelain.rb', line 9588 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this IdentitySet was deleted, the time it was deleted.
9590 9591 9592 |
# File 'lib/models/porcelain.rb', line 9590 def deleted_at @deleted_at end |
#identity_set ⇒ Object
The complete IdentitySet state at this time.
9592 9593 9594 |
# File 'lib/models/porcelain.rb', line 9592 def identity_set @identity_set end |
#timestamp ⇒ Object
The time at which the IdentitySet state was recorded.
9594 9595 9596 |
# File 'lib/models/porcelain.rb', line 9594 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9608 9609 9610 9611 9612 9613 9614 |
# File 'lib/models/porcelain.rb', line 9608 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |