Class: SDM::IdentitySetHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory

Returns a new instance of IdentitySetHistory.



6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
# File 'lib/models/porcelain.rb', line 6701

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_set: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_set = identity_set == nil ? nil : identity_set
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.



6693
6694
6695
# File 'lib/models/porcelain.rb', line 6693

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentitySet was deleted, the time it was deleted.



6695
6696
6697
# File 'lib/models/porcelain.rb', line 6695

def deleted_at
  @deleted_at
end

#identity_setObject

The complete IdentitySet state at this time.



6697
6698
6699
# File 'lib/models/porcelain.rb', line 6697

def identity_set
  @identity_set
end

#timestampObject

The time at which the IdentitySet state was recorded.



6699
6700
6701
# File 'lib/models/porcelain.rb', line 6699

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6713
6714
6715
6716
6717
6718
6719
# File 'lib/models/porcelain.rb', line 6713

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end