Class: SDM::IdentitySetHistory
- Inherits:
-
Object
- Object
- SDM::IdentitySetHistory
- Defined in:
- lib/models/porcelain.rb
Overview
IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentitySet.
-
#deleted_at ⇒ Object
If this IdentitySet was deleted, the time it was deleted.
-
#identity_set ⇒ Object
The complete IdentitySet state at this time.
-
#timestamp ⇒ Object
The time at which the IdentitySet state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory
constructor
A new instance of IdentitySetHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory
Returns a new instance of IdentitySetHistory.
6702 6703 6704 6705 6706 6707 6708 6709 6710 6711 6712 |
# File 'lib/models/porcelain.rb', line 6702 def initialize( activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @identity_set = identity_set == nil ? nil : identity_set @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.
6694 6695 6696 |
# File 'lib/models/porcelain.rb', line 6694 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this IdentitySet was deleted, the time it was deleted.
6696 6697 6698 |
# File 'lib/models/porcelain.rb', line 6696 def deleted_at @deleted_at end |
#identity_set ⇒ Object
The complete IdentitySet state at this time.
6698 6699 6700 |
# File 'lib/models/porcelain.rb', line 6698 def identity_set @identity_set end |
#timestamp ⇒ Object
The time at which the IdentitySet state was recorded.
6700 6701 6702 |
# File 'lib/models/porcelain.rb', line 6700 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6714 6715 6716 6717 6718 6719 6720 |
# File 'lib/models/porcelain.rb', line 6714 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |