Class: SDM::IdentitySetHistory
- Inherits:
-
Object
- Object
- SDM::IdentitySetHistory
- Defined in:
- lib/models/porcelain.rb
Overview
IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentitySet.
-
#deleted_at ⇒ Object
If this IdentitySet was deleted, the time it was deleted.
-
#identity_set ⇒ Object
The complete IdentitySet state at this time.
-
#timestamp ⇒ Object
The time at which the IdentitySet state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory
constructor
A new instance of IdentitySetHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory
Returns a new instance of IdentitySetHistory.
6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 |
# File 'lib/models/porcelain.rb', line 6338 def initialize( activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @identity_set = identity_set == nil ? nil : identity_set @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.
6330 6331 6332 |
# File 'lib/models/porcelain.rb', line 6330 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this IdentitySet was deleted, the time it was deleted.
6332 6333 6334 |
# File 'lib/models/porcelain.rb', line 6332 def deleted_at @deleted_at end |
#identity_set ⇒ Object
The complete IdentitySet state at this time.
6334 6335 6336 |
# File 'lib/models/porcelain.rb', line 6334 def identity_set @identity_set end |
#timestamp ⇒ Object
The time at which the IdentitySet state was recorded.
6336 6337 6338 |
# File 'lib/models/porcelain.rb', line 6336 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6350 6351 6352 6353 6354 6355 6356 |
# File 'lib/models/porcelain.rb', line 6350 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |