Class: SDM::IdentitySetHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory

Returns a new instance of IdentitySetHistory.



6020
6021
6022
6023
6024
6025
6026
6027
6028
6029
6030
# File 'lib/models/porcelain.rb', line 6020

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_set: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_set = identity_set == nil ? nil : identity_set
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.



6012
6013
6014
# File 'lib/models/porcelain.rb', line 6012

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentitySet was deleted, the time it was deleted.



6014
6015
6016
# File 'lib/models/porcelain.rb', line 6014

def deleted_at
  @deleted_at
end

#identity_setObject

The complete IdentitySet state at this time.



6016
6017
6018
# File 'lib/models/porcelain.rb', line 6016

def identity_set
  @identity_set
end

#timestampObject

The time at which the IdentitySet state was recorded.



6018
6019
6020
# File 'lib/models/porcelain.rb', line 6018

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6032
6033
6034
6035
6036
6037
6038
# File 'lib/models/porcelain.rb', line 6032

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end