Class: SDM::IdentitySetHistory
- Inherits:
-
Object
- Object
- SDM::IdentitySetHistory
- Defined in:
- lib/models/porcelain.rb
Overview
IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentitySet.
-
#deleted_at ⇒ Object
If this IdentitySet was deleted, the time it was deleted.
-
#identity_set ⇒ Object
The complete IdentitySet state at this time.
-
#timestamp ⇒ Object
The time at which the IdentitySet state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory
constructor
A new instance of IdentitySetHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory
Returns a new instance of IdentitySetHistory.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 |
# File 'lib/models/porcelain.rb', line 9394 def initialize( activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @identity_set = identity_set == nil ? nil : identity_set @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.
9386 9387 9388 |
# File 'lib/models/porcelain.rb', line 9386 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this IdentitySet was deleted, the time it was deleted.
9388 9389 9390 |
# File 'lib/models/porcelain.rb', line 9388 def deleted_at @deleted_at end |
#identity_set ⇒ Object
The complete IdentitySet state at this time.
9390 9391 9392 |
# File 'lib/models/porcelain.rb', line 9390 def identity_set @identity_set end |
#timestamp ⇒ Object
The time at which the IdentitySet state was recorded.
9392 9393 9394 |
# File 'lib/models/porcelain.rb', line 9392 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9406 9407 9408 9409 9410 9411 9412 |
# File 'lib/models/porcelain.rb', line 9406 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |