Class: SDM::IdentitySetHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory

Returns a new instance of IdentitySetHistory.



7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
# File 'lib/models/porcelain.rb', line 7195

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_set: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_set = identity_set == nil ? nil : identity_set
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.



7187
7188
7189
# File 'lib/models/porcelain.rb', line 7187

def activity_id
  @activity_id
end

#deleted_atObject

If this IdentitySet was deleted, the time it was deleted.



7189
7190
7191
# File 'lib/models/porcelain.rb', line 7189

def deleted_at
  @deleted_at
end

#identity_setObject

The complete IdentitySet state at this time.



7191
7192
7193
# File 'lib/models/porcelain.rb', line 7191

def identity_set
  @identity_set
end

#timestampObject

The time at which the IdentitySet state was recorded.



7193
7194
7195
# File 'lib/models/porcelain.rb', line 7193

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7207
7208
7209
7210
7211
7212
7213
# File 'lib/models/porcelain.rb', line 7207

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end