Class: SDM::IdentitySetHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

IdentitySetHistory records the state of a IdentitySet at a given point in time, where every change (create, update and delete) to a IdentitySet produces an IdentitySetHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, identity_set: nil, timestamp: nil) ⇒ IdentitySetHistory

Returns a new instance of IdentitySetHistory.



9708
9709
9710
9711
9712
9713
9714
9715
9716
9717
9718
# File 'lib/models/porcelain.rb', line 9708

def initialize(
  activity_id: nil,
  deleted_at: nil,
  identity_set: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @identity_set = identity_set == nil ? nil : identity_set
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the IdentitySet. May be empty for some system-initiated updates.



9700
9701
9702
# File 'lib/models/porcelain.rb', line 9700

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this IdentitySet was deleted, the time it was deleted.



9702
9703
9704
# File 'lib/models/porcelain.rb', line 9702

def deleted_at
  @deleted_at
end

#identity_set ⇒ Object

The complete IdentitySet state at this time.



9704
9705
9706
# File 'lib/models/porcelain.rb', line 9704

def identity_set
  @identity_set
end

#timestamp ⇒ Object

The time at which the IdentitySet state was recorded.



9706
9707
9708
# File 'lib/models/porcelain.rb', line 9706

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9720
9721
9722
9723
9724
9725
9726
# File 'lib/models/porcelain.rb', line 9720

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end