Class: SDM::KeyValueEngine
- Inherits:
-
Object
- Object
- SDM::KeyValueEngine
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Secret Engine.
-
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days.
-
#name ⇒ Object
Unique human-readable name of the Secret Engine.
-
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine.
-
#public_key ⇒ Object
Public key linked with a secret engine.
-
#secret_store_id ⇒ Object
Backing secret store identifier.
-
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine
constructor
A new instance of KeyValueEngine.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine
Returns a new instance of KeyValueEngine.
9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 |
# File 'lib/models/porcelain.rb', line 9664 def initialize( id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil ) @id = id == nil ? "" : id @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days @name = name == nil ? "" : name @node_selector = node_selector == nil ? "" : node_selector @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Secret Engine.
9648 9649 9650 |
# File 'lib/models/porcelain.rb', line 9648 def id @id end |
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days
9650 9651 9652 |
# File 'lib/models/porcelain.rb', line 9650 def key_rotation_interval_days @key_rotation_interval_days end |
#name ⇒ Object
Unique human-readable name of the Secret Engine.
9652 9653 9654 |
# File 'lib/models/porcelain.rb', line 9652 def name @name end |
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine
9654 9655 9656 |
# File 'lib/models/porcelain.rb', line 9654 def node_selector @node_selector end |
#public_key ⇒ Object
Public key linked with a secret engine
9656 9657 9658 |
# File 'lib/models/porcelain.rb', line 9656 def public_key @public_key end |
#secret_store_id ⇒ Object
Backing secret store identifier
9658 9659 9660 |
# File 'lib/models/porcelain.rb', line 9658 def secret_store_id @secret_store_id end |
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored
9660 9661 9662 |
# File 'lib/models/porcelain.rb', line 9660 def secret_store_root_path @secret_store_root_path end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9662 9663 9664 |
# File 'lib/models/porcelain.rb', line 9662 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9684 9685 9686 9687 9688 9689 9690 |
# File 'lib/models/porcelain.rb', line 9684 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |