Class: SDM::KeyValueEngine
- Inherits:
-
Object
- Object
- SDM::KeyValueEngine
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Secret Engine.
-
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days.
-
#name ⇒ Object
Unique human-readable name of the Secret Engine.
-
#public_key ⇒ Object
Public key linked with a secret engine.
-
#secret_store_id ⇒ Object
Backing secret store identifier.
-
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, key_rotation_interval_days: nil, name: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine
constructor
A new instance of KeyValueEngine.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, key_rotation_interval_days: nil, name: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine
Returns a new instance of KeyValueEngine.
8477 8478 8479 8480 8481 8482 8483 8484 8485 8486 8487 8488 8489 8490 8491 8492 8493 |
# File 'lib/models/porcelain.rb', line 8477 def initialize( id: nil, key_rotation_interval_days: nil, name: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil ) @id = id == nil ? "" : id @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days @name = name == nil ? "" : name @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Secret Engine.
8463 8464 8465 |
# File 'lib/models/porcelain.rb', line 8463 def id @id end |
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days
8465 8466 8467 |
# File 'lib/models/porcelain.rb', line 8465 def key_rotation_interval_days @key_rotation_interval_days end |
#name ⇒ Object
Unique human-readable name of the Secret Engine.
8467 8468 8469 |
# File 'lib/models/porcelain.rb', line 8467 def name @name end |
#public_key ⇒ Object
Public key linked with a secret engine
8469 8470 8471 |
# File 'lib/models/porcelain.rb', line 8469 def public_key @public_key end |
#secret_store_id ⇒ Object
Backing secret store identifier
8471 8472 8473 |
# File 'lib/models/porcelain.rb', line 8471 def secret_store_id @secret_store_id end |
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored
8473 8474 8475 |
# File 'lib/models/porcelain.rb', line 8473 def secret_store_root_path @secret_store_root_path end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8475 8476 8477 |
# File 'lib/models/porcelain.rb', line 8475 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8495 8496 8497 8498 8499 8500 8501 |
# File 'lib/models/porcelain.rb', line 8495 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |