Class: SDM::KeyValueEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KeyValueEngine is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, key_rotation_interval_days: nil, name: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine

Returns a new instance of KeyValueEngine.



7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
# File 'lib/models/porcelain.rb', line 7126

def initialize(
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Secret Engine.



7112
7113
7114
# File 'lib/models/porcelain.rb', line 7112

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



7114
7115
7116
# File 'lib/models/porcelain.rb', line 7114

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



7116
7117
7118
# File 'lib/models/porcelain.rb', line 7116

def name
  @name
end

#public_keyObject

Public key linked with a secret engine



7118
7119
7120
# File 'lib/models/porcelain.rb', line 7118

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



7120
7121
7122
# File 'lib/models/porcelain.rb', line 7120

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



7122
7123
7124
# File 'lib/models/porcelain.rb', line 7122

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



7124
7125
7126
# File 'lib/models/porcelain.rb', line 7124

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7144
7145
7146
7147
7148
7149
7150
# File 'lib/models/porcelain.rb', line 7144

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end