Class: SDM::KeyValueEngine
- Inherits:
-
Object
- Object
- SDM::KeyValueEngine
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Secret Engine.
-
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days.
-
#name ⇒ Object
Unique human-readable name of the Secret Engine.
-
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine.
-
#public_key ⇒ Object
Public key linked with a secret engine.
-
#secret_store_id ⇒ Object
Backing secret store identifier.
-
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine
constructor
A new instance of KeyValueEngine.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine
Returns a new instance of KeyValueEngine.
9614 9615 9616 9617 9618 9619 9620 9621 9622 9623 9624 9625 9626 9627 9628 9629 9630 9631 9632 |
# File 'lib/models/porcelain.rb', line 9614 def initialize( id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil ) @id = id == nil ? "" : id @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days @name = name == nil ? "" : name @node_selector = node_selector == nil ? "" : node_selector @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Secret Engine.
9598 9599 9600 |
# File 'lib/models/porcelain.rb', line 9598 def id @id end |
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days
9600 9601 9602 |
# File 'lib/models/porcelain.rb', line 9600 def key_rotation_interval_days @key_rotation_interval_days end |
#name ⇒ Object
Unique human-readable name of the Secret Engine.
9602 9603 9604 |
# File 'lib/models/porcelain.rb', line 9602 def name @name end |
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine
9604 9605 9606 |
# File 'lib/models/porcelain.rb', line 9604 def node_selector @node_selector end |
#public_key ⇒ Object
Public key linked with a secret engine
9606 9607 9608 |
# File 'lib/models/porcelain.rb', line 9606 def public_key @public_key end |
#secret_store_id ⇒ Object
Backing secret store identifier
9608 9609 9610 |
# File 'lib/models/porcelain.rb', line 9608 def secret_store_id @secret_store_id end |
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored
9610 9611 9612 |
# File 'lib/models/porcelain.rb', line 9610 def secret_store_root_path @secret_store_root_path end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9612 9613 9614 |
# File 'lib/models/porcelain.rb', line 9612 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9634 9635 9636 9637 9638 9639 9640 |
# File 'lib/models/porcelain.rb', line 9634 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |