Class: SDM::KeyValueEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KeyValueEngine is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, key_rotation_interval_days: nil, name: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine

Returns a new instance of KeyValueEngine.



7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
# File 'lib/models/porcelain.rb', line 7262

def initialize(
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Secret Engine.



7248
7249
7250
# File 'lib/models/porcelain.rb', line 7248

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



7250
7251
7252
# File 'lib/models/porcelain.rb', line 7250

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



7252
7253
7254
# File 'lib/models/porcelain.rb', line 7252

def name
  @name
end

#public_keyObject

Public key linked with a secret engine



7254
7255
7256
# File 'lib/models/porcelain.rb', line 7254

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



7256
7257
7258
# File 'lib/models/porcelain.rb', line 7256

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



7258
7259
7260
# File 'lib/models/porcelain.rb', line 7258

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



7260
7261
7262
# File 'lib/models/porcelain.rb', line 7260

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7280
7281
7282
7283
7284
7285
7286
# File 'lib/models/porcelain.rb', line 7280

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end