Class: SDM::KeyValueEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine

Returns a new instance of KeyValueEngine.



9587
9588
9589
9590
9591
9592
9593
9594
9595
9596
9597
9598
9599
9600
9601
9602
9603
9604
9605
# File 'lib/models/porcelain.rb', line 9587

def initialize(
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  node_selector: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil
)
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @node_selector = node_selector == nil ? "" : node_selector
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#idObject

Unique identifier of the Secret Engine.



9571
9572
9573
# File 'lib/models/porcelain.rb', line 9571

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



9573
9574
9575
# File 'lib/models/porcelain.rb', line 9573

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



9575
9576
9577
# File 'lib/models/porcelain.rb', line 9575

def name
  @name
end

#node_selectorObject

node selector is used to narrow down the nodes used to communicate with with secret engine



9577
9578
9579
# File 'lib/models/porcelain.rb', line 9577

def node_selector
  @node_selector
end

#public_keyObject

Public key linked with a secret engine



9579
9580
9581
# File 'lib/models/porcelain.rb', line 9579

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



9581
9582
9583
# File 'lib/models/porcelain.rb', line 9581

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



9583
9584
9585
# File 'lib/models/porcelain.rb', line 9583

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



9585
9586
9587
# File 'lib/models/porcelain.rb', line 9585

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9607
9608
9609
9610
9611
9612
9613
# File 'lib/models/porcelain.rb', line 9607

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end