Class: SDM::KeyValueEngine
- Inherits:
-
Object
- Object
- SDM::KeyValueEngine
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Unique identifier of the Secret Engine.
-
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days.
-
#name ⇒ Object
Unique human-readable name of the Secret Engine.
-
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine.
-
#public_key ⇒ Object
Public key linked with a secret engine.
-
#secret_store_id ⇒ Object
Backing secret store identifier.
-
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine
constructor
A new instance of KeyValueEngine.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil) ⇒ KeyValueEngine
Returns a new instance of KeyValueEngine.
9776 9777 9778 9779 9780 9781 9782 9783 9784 9785 9786 9787 9788 9789 9790 9791 9792 9793 9794 |
# File 'lib/models/porcelain.rb', line 9776 def initialize( id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil ) @id = id == nil ? "" : id @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days @name = name == nil ? "" : name @node_selector = node_selector == nil ? "" : node_selector @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path @tags = == nil ? SDM::() : end |
Instance Attribute Details
#id ⇒ Object
Unique identifier of the Secret Engine.
9760 9761 9762 |
# File 'lib/models/porcelain.rb', line 9760 def id @id end |
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days
9762 9763 9764 |
# File 'lib/models/porcelain.rb', line 9762 def key_rotation_interval_days @key_rotation_interval_days end |
#name ⇒ Object
Unique human-readable name of the Secret Engine.
9764 9765 9766 |
# File 'lib/models/porcelain.rb', line 9764 def name @name end |
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine
9766 9767 9768 |
# File 'lib/models/porcelain.rb', line 9766 def node_selector @node_selector end |
#public_key ⇒ Object
Public key linked with a secret engine
9768 9769 9770 |
# File 'lib/models/porcelain.rb', line 9768 def public_key @public_key end |
#secret_store_id ⇒ Object
Backing secret store identifier
9770 9771 9772 |
# File 'lib/models/porcelain.rb', line 9770 def secret_store_id @secret_store_id end |
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored
9772 9773 9774 |
# File 'lib/models/porcelain.rb', line 9772 def secret_store_root_path @secret_store_root_path end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9774 9775 9776 |
# File 'lib/models/porcelain.rb', line 9774 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9796 9797 9798 9799 9800 9801 9802 |
# File 'lib/models/porcelain.rb', line 9796 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |