Class: SDM::KeyfactorSSHStore
- Inherits:
-
Object
- Object
- SDM::KeyfactorSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection.
-
#certificate_file_path ⇒ Object
Path to client certificate in PEM format.
-
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
-
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
-
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
-
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment.
-
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#key_file_path ⇒ Object
Path to private key in PEM format.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#server_address ⇒ Object
the host of the Key Factor CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorSSHStore
constructor
A new instance of KeyfactorSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorSSHStore
Returns a new instance of KeyfactorSSHStore.
9761 9762 9763 9764 9765 9766 9767 9768 9769 9770 9771 9772 9773 9774 9775 9776 9777 9778 9779 9780 9781 9782 9783 9784 9785 9786 9787 |
# File 'lib/models/porcelain.rb', line 9761 def initialize( ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil ) @ca_file_path = ca_file_path == nil ? "" : ca_file_path @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path @default_certificate_authority_name = == nil ? "" : @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var @id = id == nil ? "" : id @key_file_path = key_file_path == nil ? "" : key_file_path @name = name == nil ? "" : name @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.
9733 9734 9735 |
# File 'lib/models/porcelain.rb', line 9733 def ca_file_path @ca_file_path end |
#certificate_file_path ⇒ Object
Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.
9737 9738 9739 |
# File 'lib/models/porcelain.rb', line 9737 def certificate_file_path @certificate_file_path end |
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
9739 9740 9741 |
# File 'lib/models/porcelain.rb', line 9739 def @default_certificate_authority_name end |
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
9741 9742 9743 |
# File 'lib/models/porcelain.rb', line 9741 def default_certificate_profile_name @default_certificate_profile_name end |
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
9743 9744 9745 |
# File 'lib/models/porcelain.rb', line 9743 def default_end_entity_profile_name @default_end_entity_profile_name end |
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment. May be left blank if no code is required.
9745 9746 9747 |
# File 'lib/models/porcelain.rb', line 9745 def enrollment_code_env_var @enrollment_code_env_var end |
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.
9748 9749 9750 |
# File 'lib/models/porcelain.rb', line 9748 def enrollment_username_env_var @enrollment_username_env_var end |
#id ⇒ Object
Unique identifier of the SecretStore.
9750 9751 9752 |
# File 'lib/models/porcelain.rb', line 9750 def id @id end |
#key_file_path ⇒ Object
Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.
9753 9754 9755 |
# File 'lib/models/porcelain.rb', line 9753 def key_file_path @key_file_path end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
9755 9756 9757 |
# File 'lib/models/porcelain.rb', line 9755 def name @name end |
#server_address ⇒ Object
the host of the Key Factor CA
9757 9758 9759 |
# File 'lib/models/porcelain.rb', line 9757 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9759 9760 9761 |
# File 'lib/models/porcelain.rb', line 9759 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9789 9790 9791 9792 9793 9794 9795 |
# File 'lib/models/porcelain.rb', line 9789 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |