Class: SDM::KeyfactorSSHStore
- Inherits:
-
Object
- Object
- SDM::KeyfactorSSHStore
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection.
-
#certificate_file_path ⇒ Object
Path to client certificate in PEM format.
-
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
-
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
-
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
-
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment.
-
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#key_file_path ⇒ Object
Path to private key in PEM format.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#server_address ⇒ Object
the host of the Key Factor CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorSSHStore
constructor
A new instance of KeyfactorSSHStore.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorSSHStore
Returns a new instance of KeyfactorSSHStore.
8536 8537 8538 8539 8540 8541 8542 8543 8544 8545 8546 8547 8548 8549 8550 8551 8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 |
# File 'lib/models/porcelain.rb', line 8536 def initialize( ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil ) @ca_file_path = ca_file_path == nil ? "" : ca_file_path @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path @default_certificate_authority_name = == nil ? "" : @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var @id = id == nil ? "" : id @key_file_path = key_file_path == nil ? "" : key_file_path @name = name == nil ? "" : name @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.
8508 8509 8510 |
# File 'lib/models/porcelain.rb', line 8508 def ca_file_path @ca_file_path end |
#certificate_file_path ⇒ Object
Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.
8512 8513 8514 |
# File 'lib/models/porcelain.rb', line 8512 def certificate_file_path @certificate_file_path end |
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
8514 8515 8516 |
# File 'lib/models/porcelain.rb', line 8514 def @default_certificate_authority_name end |
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
8516 8517 8518 |
# File 'lib/models/porcelain.rb', line 8516 def default_certificate_profile_name @default_certificate_profile_name end |
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
8518 8519 8520 |
# File 'lib/models/porcelain.rb', line 8518 def default_end_entity_profile_name @default_end_entity_profile_name end |
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment. May be left blank if no code is required.
8520 8521 8522 |
# File 'lib/models/porcelain.rb', line 8520 def enrollment_code_env_var @enrollment_code_env_var end |
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.
8523 8524 8525 |
# File 'lib/models/porcelain.rb', line 8523 def enrollment_username_env_var @enrollment_username_env_var end |
#id ⇒ Object
Unique identifier of the SecretStore.
8525 8526 8527 |
# File 'lib/models/porcelain.rb', line 8525 def id @id end |
#key_file_path ⇒ Object
Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.
8528 8529 8530 |
# File 'lib/models/porcelain.rb', line 8528 def key_file_path @key_file_path end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
8530 8531 8532 |
# File 'lib/models/porcelain.rb', line 8530 def name @name end |
#server_address ⇒ Object
the host of the Key Factor CA
8532 8533 8534 |
# File 'lib/models/porcelain.rb', line 8532 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8534 8535 8536 |
# File 'lib/models/porcelain.rb', line 8534 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8564 8565 8566 8567 8568 8569 8570 |
# File 'lib/models/porcelain.rb', line 8564 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |