Class: SDM::KeyfactorSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorSSHStore

Returns a new instance of KeyfactorSSHStore.



6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
6878
6879
6880
# File 'lib/models/porcelain.rb', line 6854

def initialize(
  ca_file_path: nil,
  certificate_file_path: nil,
  default_certificate_authority_name: nil,
  default_certificate_profile_name: nil,
  default_end_entity_profile_name: nil,
  enrollment_code_env_var: nil,
  enrollment_username_env_var: nil,
  id: nil,
  key_file_path: nil,
  name: nil,
  server_address: nil,
  tags: nil
)
  @ca_file_path = ca_file_path == nil ? "" : ca_file_path
  @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path
  @default_certificate_authority_name = default_certificate_authority_name == nil ? "" : default_certificate_authority_name
  @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name
  @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name
  @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var
  @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var
  @id = id == nil ? "" : id
  @key_file_path = key_file_path == nil ? "" : key_file_path
  @name = name == nil ? "" : name
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_file_pathObject

Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.



6826
6827
6828
# File 'lib/models/porcelain.rb', line 6826

def ca_file_path
  @ca_file_path
end

#certificate_file_pathObject

Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.



6830
6831
6832
# File 'lib/models/porcelain.rb', line 6830

def certificate_file_path
  @certificate_file_path
end

#default_certificate_authority_nameObject

Name of EJBCA certificate authority that will enroll CSR.



6832
6833
6834
# File 'lib/models/porcelain.rb', line 6832

def default_certificate_authority_name
  @default_certificate_authority_name
end

#default_certificate_profile_nameObject

Certificate profile name that EJBCA will enroll the CSR with.



6834
6835
6836
# File 'lib/models/porcelain.rb', line 6834

def default_certificate_profile_name
  @default_certificate_profile_name
end

#default_end_entity_profile_nameObject

End entity profile that EJBCA will enroll the CSR with.



6836
6837
6838
# File 'lib/models/porcelain.rb', line 6836

def default_end_entity_profile_name
  @default_end_entity_profile_name
end

#enrollment_code_env_varObject

code used by EJBCA during enrollment. May be left blank if no code is required.



6838
6839
6840
# File 'lib/models/porcelain.rb', line 6838

def enrollment_code_env_var
  @enrollment_code_env_var
end

#enrollment_username_env_varObject

username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.



6841
6842
6843
# File 'lib/models/porcelain.rb', line 6841

def enrollment_username_env_var
  @enrollment_username_env_var
end

#idObject

Unique identifier of the SecretStore.



6843
6844
6845
# File 'lib/models/porcelain.rb', line 6843

def id
  @id
end

#key_file_pathObject

Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.



6846
6847
6848
# File 'lib/models/porcelain.rb', line 6846

def key_file_path
  @key_file_path
end

#nameObject

Unique human-readable name of the SecretStore.



6848
6849
6850
# File 'lib/models/porcelain.rb', line 6848

def name
  @name
end

#server_addressObject

the host of the Key Factor CA



6850
6851
6852
# File 'lib/models/porcelain.rb', line 6850

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



6852
6853
6854
# File 'lib/models/porcelain.rb', line 6852

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6882
6883
6884
6885
6886
6887
6888
# File 'lib/models/porcelain.rb', line 6882

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end