Class: SDM::KeyfactorSSHStore

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorSSHStore

Returns a new instance of KeyfactorSSHStore.



9837
9838
9839
9840
9841
9842
9843
9844
9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
# File 'lib/models/porcelain.rb', line 9837

def initialize(
  ca_file_path: nil,
  certificate_file_path: nil,
  default_certificate_authority_name: nil,
  default_certificate_profile_name: nil,
  default_end_entity_profile_name: nil,
  enrollment_code_env_var: nil,
  enrollment_username_env_var: nil,
  id: nil,
  key_file_path: nil,
  name: nil,
  server_address: nil,
  tags: nil
)
  @ca_file_path = ca_file_path == nil ? "" : ca_file_path
  @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path
  @default_certificate_authority_name = default_certificate_authority_name == nil ? "" : default_certificate_authority_name
  @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name
  @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name
  @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var
  @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var
  @id = id == nil ? "" : id
  @key_file_path = key_file_path == nil ? "" : key_file_path
  @name = name == nil ? "" : name
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_file_path ⇒ Object

Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.



9809
9810
9811
# File 'lib/models/porcelain.rb', line 9809

def ca_file_path
  @ca_file_path
end

#certificate_file_path ⇒ Object

Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.



9813
9814
9815
# File 'lib/models/porcelain.rb', line 9813

def certificate_file_path
  @certificate_file_path
end

#default_certificate_authority_name ⇒ Object

Name of EJBCA certificate authority that will enroll CSR.



9815
9816
9817
# File 'lib/models/porcelain.rb', line 9815

def default_certificate_authority_name
  @default_certificate_authority_name
end

#default_certificate_profile_name ⇒ Object

Certificate profile name that EJBCA will enroll the CSR with.



9817
9818
9819
# File 'lib/models/porcelain.rb', line 9817

def default_certificate_profile_name
  @default_certificate_profile_name
end

#default_end_entity_profile_name ⇒ Object

End entity profile that EJBCA will enroll the CSR with.



9819
9820
9821
# File 'lib/models/porcelain.rb', line 9819

def default_end_entity_profile_name
  @default_end_entity_profile_name
end

#enrollment_code_env_var ⇒ Object

code used by EJBCA during enrollment. May be left blank if no code is required.



9821
9822
9823
# File 'lib/models/porcelain.rb', line 9821

def enrollment_code_env_var
  @enrollment_code_env_var
end

#enrollment_username_env_var ⇒ Object

username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.



9824
9825
9826
# File 'lib/models/porcelain.rb', line 9824

def enrollment_username_env_var
  @enrollment_username_env_var
end

#id ⇒ Object

Unique identifier of the SecretStore.



9826
9827
9828
# File 'lib/models/porcelain.rb', line 9826

def id
  @id
end

#key_file_path ⇒ Object

Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.



9829
9830
9831
# File 'lib/models/porcelain.rb', line 9829

def key_file_path
  @key_file_path
end

#name ⇒ Object

Unique human-readable name of the SecretStore.



9831
9832
9833
# File 'lib/models/porcelain.rb', line 9831

def name
  @name
end

#server_address ⇒ Object

the host of the Key Factor CA



9833
9834
9835
# File 'lib/models/porcelain.rb', line 9833

def server_address
  @server_address
end

#tags ⇒ Object

Tags is a map of key, value pairs.



9835
9836
9837
# File 'lib/models/porcelain.rb', line 9835

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9865
9866
9867
9868
9869
9870
9871
# File 'lib/models/porcelain.rb', line 9865

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end