Class: SDM::KeyfactorX509Store
- Inherits:
-
Object
- Object
- SDM::KeyfactorX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection.
-
#certificate_file_path ⇒ Object
Path to client certificate in PEM format.
-
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
-
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
-
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
-
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment.
-
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#key_file_path ⇒ Object
Path to private key in PEM format.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#server_address ⇒ Object
the host of the Key Factor CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorX509Store
constructor
A new instance of KeyfactorX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorX509Store
Returns a new instance of KeyfactorX509Store.
9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 9610 9611 9612 9613 9614 9615 9616 9617 9618 9619 |
# File 'lib/models/porcelain.rb', line 9593 def initialize( ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil ) @ca_file_path = ca_file_path == nil ? "" : ca_file_path @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path @default_certificate_authority_name = == nil ? "" : @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var @id = id == nil ? "" : id @key_file_path = key_file_path == nil ? "" : key_file_path @name = name == nil ? "" : name @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.
9565 9566 9567 |
# File 'lib/models/porcelain.rb', line 9565 def ca_file_path @ca_file_path end |
#certificate_file_path ⇒ Object
Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.
9569 9570 9571 |
# File 'lib/models/porcelain.rb', line 9569 def certificate_file_path @certificate_file_path end |
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
9571 9572 9573 |
# File 'lib/models/porcelain.rb', line 9571 def @default_certificate_authority_name end |
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
9573 9574 9575 |
# File 'lib/models/porcelain.rb', line 9573 def default_certificate_profile_name @default_certificate_profile_name end |
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
9575 9576 9577 |
# File 'lib/models/porcelain.rb', line 9575 def default_end_entity_profile_name @default_end_entity_profile_name end |
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment. May be left blank if no code is required.
9577 9578 9579 |
# File 'lib/models/porcelain.rb', line 9577 def enrollment_code_env_var @enrollment_code_env_var end |
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.
9580 9581 9582 |
# File 'lib/models/porcelain.rb', line 9580 def enrollment_username_env_var @enrollment_username_env_var end |
#id ⇒ Object
Unique identifier of the SecretStore.
9582 9583 9584 |
# File 'lib/models/porcelain.rb', line 9582 def id @id end |
#key_file_path ⇒ Object
Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.
9585 9586 9587 |
# File 'lib/models/porcelain.rb', line 9585 def key_file_path @key_file_path end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
9587 9588 9589 |
# File 'lib/models/porcelain.rb', line 9587 def name @name end |
#server_address ⇒ Object
the host of the Key Factor CA
9589 9590 9591 |
# File 'lib/models/porcelain.rb', line 9589 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9591 9592 9593 |
# File 'lib/models/porcelain.rb', line 9591 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9621 9622 9623 9624 9625 9626 9627 |
# File 'lib/models/porcelain.rb', line 9621 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |