Class: SDM::KeyfactorX509Store
- Inherits:
-
Object
- Object
- SDM::KeyfactorX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection.
-
#certificate_file_path ⇒ Object
Path to client certificate in PEM format.
-
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
-
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
-
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
-
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment.
-
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#key_file_path ⇒ Object
Path to private key in PEM format.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#server_address ⇒ Object
the host of the Key Factor CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorX509Store
constructor
A new instance of KeyfactorX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorX509Store
Returns a new instance of KeyfactorX509Store.
7003 7004 7005 7006 7007 7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 7027 7028 7029 |
# File 'lib/models/porcelain.rb', line 7003 def initialize( ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil ) @ca_file_path = ca_file_path == nil ? "" : ca_file_path @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path @default_certificate_authority_name = == nil ? "" : @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var @id = id == nil ? "" : id @key_file_path = key_file_path == nil ? "" : key_file_path @name = name == nil ? "" : name @server_address = server_address == nil ? "" : server_address @tags = == nil ? SDM::() : end |
Instance Attribute Details
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.
6975 6976 6977 |
# File 'lib/models/porcelain.rb', line 6975 def ca_file_path @ca_file_path end |
#certificate_file_path ⇒ Object
Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.
6979 6980 6981 |
# File 'lib/models/porcelain.rb', line 6979 def certificate_file_path @certificate_file_path end |
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
6981 6982 6983 |
# File 'lib/models/porcelain.rb', line 6981 def @default_certificate_authority_name end |
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
6983 6984 6985 |
# File 'lib/models/porcelain.rb', line 6983 def default_certificate_profile_name @default_certificate_profile_name end |
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
6985 6986 6987 |
# File 'lib/models/porcelain.rb', line 6985 def default_end_entity_profile_name @default_end_entity_profile_name end |
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment. May be left blank if no code is required.
6987 6988 6989 |
# File 'lib/models/porcelain.rb', line 6987 def enrollment_code_env_var @enrollment_code_env_var end |
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.
6990 6991 6992 |
# File 'lib/models/porcelain.rb', line 6990 def enrollment_username_env_var @enrollment_username_env_var end |
#id ⇒ Object
Unique identifier of the SecretStore.
6992 6993 6994 |
# File 'lib/models/porcelain.rb', line 6992 def id @id end |
#key_file_path ⇒ Object
Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.
6995 6996 6997 |
# File 'lib/models/porcelain.rb', line 6995 def key_file_path @key_file_path end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
6997 6998 6999 |
# File 'lib/models/porcelain.rb', line 6997 def name @name end |
#server_address ⇒ Object
the host of the Key Factor CA
6999 7000 7001 |
# File 'lib/models/porcelain.rb', line 6999 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7001 7002 7003 |
# File 'lib/models/porcelain.rb', line 7001 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7031 7032 7033 7034 7035 7036 7037 |
# File 'lib/models/porcelain.rb', line 7031 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |