Class: SDM::KeyfactorX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorX509Store

Returns a new instance of KeyfactorX509Store.



6489
6490
6491
6492
6493
6494
6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
6505
6506
6507
6508
6509
6510
6511
6512
6513
6514
6515
# File 'lib/models/porcelain.rb', line 6489

def initialize(
  ca_file_path: nil,
  certificate_file_path: nil,
  default_certificate_authority_name: nil,
  default_certificate_profile_name: nil,
  default_end_entity_profile_name: nil,
  enrollment_code_env_var: nil,
  enrollment_username_env_var: nil,
  id: nil,
  key_file_path: nil,
  name: nil,
  server_address: nil,
  tags: nil
)
  @ca_file_path = ca_file_path == nil ? "" : ca_file_path
  @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path
  @default_certificate_authority_name = default_certificate_authority_name == nil ? "" : default_certificate_authority_name
  @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name
  @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name
  @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var
  @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var
  @id = id == nil ? "" : id
  @key_file_path = key_file_path == nil ? "" : key_file_path
  @name = name == nil ? "" : name
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_file_pathObject

Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.



6461
6462
6463
# File 'lib/models/porcelain.rb', line 6461

def ca_file_path
  @ca_file_path
end

#certificate_file_pathObject

Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.



6465
6466
6467
# File 'lib/models/porcelain.rb', line 6465

def certificate_file_path
  @certificate_file_path
end

#default_certificate_authority_nameObject

Name of EJBCA certificate authority that will enroll CSR.



6467
6468
6469
# File 'lib/models/porcelain.rb', line 6467

def default_certificate_authority_name
  @default_certificate_authority_name
end

#default_certificate_profile_nameObject

Certificate profile name that EJBCA will enroll the CSR with.



6469
6470
6471
# File 'lib/models/porcelain.rb', line 6469

def default_certificate_profile_name
  @default_certificate_profile_name
end

#default_end_entity_profile_nameObject

End entity profile that EJBCA will enroll the CSR with.



6471
6472
6473
# File 'lib/models/porcelain.rb', line 6471

def default_end_entity_profile_name
  @default_end_entity_profile_name
end

#enrollment_code_env_varObject

code used by EJBCA during enrollment. May be left blank if no code is required.



6473
6474
6475
# File 'lib/models/porcelain.rb', line 6473

def enrollment_code_env_var
  @enrollment_code_env_var
end

#enrollment_username_env_varObject

username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.



6476
6477
6478
# File 'lib/models/porcelain.rb', line 6476

def enrollment_username_env_var
  @enrollment_username_env_var
end

#idObject

Unique identifier of the SecretStore.



6478
6479
6480
# File 'lib/models/porcelain.rb', line 6478

def id
  @id
end

#key_file_pathObject

Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.



6481
6482
6483
# File 'lib/models/porcelain.rb', line 6481

def key_file_path
  @key_file_path
end

#nameObject

Unique human-readable name of the SecretStore.



6483
6484
6485
# File 'lib/models/porcelain.rb', line 6483

def name
  @name
end

#server_addressObject

the host of the Key Factor CA



6485
6486
6487
# File 'lib/models/porcelain.rb', line 6485

def server_address
  @server_address
end

#tagsObject

Tags is a map of key, value pairs.



6487
6488
6489
# File 'lib/models/porcelain.rb', line 6487

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6517
6518
6519
6520
6521
6522
6523
# File 'lib/models/porcelain.rb', line 6517

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end