Class: SDM::KeyfactorX509Store
- Inherits:
-
Object
- Object
- SDM::KeyfactorX509Store
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection.
-
#certificate_file_path ⇒ Object
Path to client certificate in PEM format.
-
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
-
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
-
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
-
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment.
-
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment.
-
#id ⇒ Object
Unique identifier of the SecretStore.
-
#key_file_path ⇒ Object
Path to private key in PEM format.
-
#name ⇒ Object
Unique human-readable name of the SecretStore.
-
#server_address ⇒ Object
the host of the Key Factor CA.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorX509Store
constructor
A new instance of KeyfactorX509Store.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorX509Store
7390 7391 7392 7393 7394 7395 7396 7397 7398 7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 |
# File 'lib/models/porcelain.rb', line 7390 def initialize( ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil ) @ca_file_path = ca_file_path == nil ? "" : ca_file_path @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path = == nil ? "" : @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var @id = id == nil ? "" : id @key_file_path = key_file_path == nil ? "" : key_file_path @name = name == nil ? "" : name @server_address = server_address == nil ? "" : server_address = == nil ? SDM::() : end |
Instance Attribute Details
#ca_file_path ⇒ Object
Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.
7362 7363 7364 |
# File 'lib/models/porcelain.rb', line 7362 def ca_file_path @ca_file_path end |
#certificate_file_path ⇒ Object
Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.
7366 7367 7368 |
# File 'lib/models/porcelain.rb', line 7366 def certificate_file_path @certificate_file_path end |
#default_certificate_authority_name ⇒ Object
Name of EJBCA certificate authority that will enroll CSR.
7368 7369 7370 |
# File 'lib/models/porcelain.rb', line 7368 def end |
#default_certificate_profile_name ⇒ Object
Certificate profile name that EJBCA will enroll the CSR with.
7370 7371 7372 |
# File 'lib/models/porcelain.rb', line 7370 def default_certificate_profile_name @default_certificate_profile_name end |
#default_end_entity_profile_name ⇒ Object
End entity profile that EJBCA will enroll the CSR with.
7372 7373 7374 |
# File 'lib/models/porcelain.rb', line 7372 def default_end_entity_profile_name @default_end_entity_profile_name end |
#enrollment_code_env_var ⇒ Object
code used by EJBCA during enrollment. May be left blank if no code is required.
7374 7375 7376 |
# File 'lib/models/porcelain.rb', line 7374 def enrollment_code_env_var @enrollment_code_env_var end |
#enrollment_username_env_var ⇒ Object
username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.
7377 7378 7379 |
# File 'lib/models/porcelain.rb', line 7377 def enrollment_username_env_var @enrollment_username_env_var end |
#id ⇒ Object
Unique identifier of the SecretStore.
7379 7380 7381 |
# File 'lib/models/porcelain.rb', line 7379 def id @id end |
#key_file_path ⇒ Object
Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.
7382 7383 7384 |
# File 'lib/models/porcelain.rb', line 7382 def key_file_path @key_file_path end |
#name ⇒ Object
Unique human-readable name of the SecretStore.
7384 7385 7386 |
# File 'lib/models/porcelain.rb', line 7384 def name @name end |
#server_address ⇒ Object
the host of the Key Factor CA
7386 7387 7388 |
# File 'lib/models/porcelain.rb', line 7386 def server_address @server_address end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7388 7389 7390 |
# File 'lib/models/porcelain.rb', line 7388 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7418 7419 7420 7421 7422 7423 7424 |
# File 'lib/models/porcelain.rb', line 7418 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |