Class: SDM::KeyfactorX509Store

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ca_file_path: nil, certificate_file_path: nil, default_certificate_authority_name: nil, default_certificate_profile_name: nil, default_end_entity_profile_name: nil, enrollment_code_env_var: nil, enrollment_username_env_var: nil, id: nil, key_file_path: nil, name: nil, server_address: nil, tags: nil) ⇒ KeyfactorX509Store

Returns a new instance of KeyfactorX509Store.



9906
9907
9908
9909
9910
9911
9912
9913
9914
9915
9916
9917
9918
9919
9920
9921
9922
9923
9924
9925
9926
9927
9928
9929
9930
9931
9932
# File 'lib/models/porcelain.rb', line 9906

def initialize(
  ca_file_path: nil,
  certificate_file_path: nil,
  default_certificate_authority_name: nil,
  default_certificate_profile_name: nil,
  default_end_entity_profile_name: nil,
  enrollment_code_env_var: nil,
  enrollment_username_env_var: nil,
  id: nil,
  key_file_path: nil,
  name: nil,
  server_address: nil,
  tags: nil
)
  @ca_file_path = ca_file_path == nil ? "" : ca_file_path
  @certificate_file_path = certificate_file_path == nil ? "" : certificate_file_path
  @default_certificate_authority_name = default_certificate_authority_name == nil ? "" : default_certificate_authority_name
  @default_certificate_profile_name = default_certificate_profile_name == nil ? "" : default_certificate_profile_name
  @default_end_entity_profile_name = default_end_entity_profile_name == nil ? "" : default_end_entity_profile_name
  @enrollment_code_env_var = enrollment_code_env_var == nil ? "" : enrollment_code_env_var
  @enrollment_username_env_var = enrollment_username_env_var == nil ? "" : enrollment_username_env_var
  @id = id == nil ? "" : id
  @key_file_path = key_file_path == nil ? "" : key_file_path
  @name = name == nil ? "" : name
  @server_address = server_address == nil ? "" : server_address
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#ca_file_path ⇒ Object

Path to the root CA that signed the certificate passed to the client for HTTPS connection. This is not required if the CA is trusted by the host operating system. This should be a PEM formatted certificate, and doesn't necessarily have to be the CA that signed CertificateFile.



9878
9879
9880
# File 'lib/models/porcelain.rb', line 9878

def ca_file_path
  @ca_file_path
end

#certificate_file_path ⇒ Object

Path to client certificate in PEM format. This certificate must contain a client certificate that is recognized by the EJBCA instance represented by Hostname. This PEM file may also contain the private key associated with the certificate, but KeyFile can also be set to configure the private key.



9882
9883
9884
# File 'lib/models/porcelain.rb', line 9882

def certificate_file_path
  @certificate_file_path
end

#default_certificate_authority_name ⇒ Object

Name of EJBCA certificate authority that will enroll CSR.



9884
9885
9886
# File 'lib/models/porcelain.rb', line 9884

def default_certificate_authority_name
  @default_certificate_authority_name
end

#default_certificate_profile_name ⇒ Object

Certificate profile name that EJBCA will enroll the CSR with.



9886
9887
9888
# File 'lib/models/porcelain.rb', line 9886

def default_certificate_profile_name
  @default_certificate_profile_name
end

#default_end_entity_profile_name ⇒ Object

End entity profile that EJBCA will enroll the CSR with.



9888
9889
9890
# File 'lib/models/porcelain.rb', line 9888

def default_end_entity_profile_name
  @default_end_entity_profile_name
end

#enrollment_code_env_var ⇒ Object

code used by EJBCA during enrollment. May be left blank if no code is required.



9890
9891
9892
# File 'lib/models/porcelain.rb', line 9890

def enrollment_code_env_var
  @enrollment_code_env_var
end

#enrollment_username_env_var ⇒ Object

username that used by the EJBCA during enrollment. This can be left out. If so, the username must be auto-generated on the Keyfactor side.



9893
9894
9895
# File 'lib/models/porcelain.rb', line 9893

def enrollment_username_env_var
  @enrollment_username_env_var
end

#id ⇒ Object

Unique identifier of the SecretStore.



9895
9896
9897
# File 'lib/models/porcelain.rb', line 9895

def id
  @id
end

#key_file_path ⇒ Object

Path to private key in PEM format. This file should contain the private key associated with the client certificate configured in CertificateFile.



9898
9899
9900
# File 'lib/models/porcelain.rb', line 9898

def key_file_path
  @key_file_path
end

#name ⇒ Object

Unique human-readable name of the SecretStore.



9900
9901
9902
# File 'lib/models/porcelain.rb', line 9900

def name
  @name
end

#server_address ⇒ Object

the host of the Key Factor CA



9902
9903
9904
# File 'lib/models/porcelain.rb', line 9902

def server_address
  @server_address
end

#tags ⇒ Object

Tags is a map of key, value pairs.



9904
9905
9906
# File 'lib/models/porcelain.rb', line 9904

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9934
9935
9936
9937
9938
9939
9940
# File 'lib/models/porcelain.rb', line 9934

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end