Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
9613
9614
9615
9616
9617
9618
9619
9620
9621
9622
9623
9624
9625
9626
9627
9628
9629
9630
9631
9632
9633
9634
9635
9636
9637
9638
9639
9640
9641
9642
9643
9644
9645
9646
# File 'lib/models/porcelain.rb', line 9602

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



9559
9560
9561
# File 'lib/models/porcelain.rb', line 9559

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9561
9562
9563
# File 'lib/models/porcelain.rb', line 9561

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



9563
9564
9565
# File 'lib/models/porcelain.rb', line 9563

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



9565
9566
9567
# File 'lib/models/porcelain.rb', line 9565

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



9567
9568
9569
# File 'lib/models/porcelain.rb', line 9567

def client_key
  @client_key
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



9569
9570
9571
# File 'lib/models/porcelain.rb', line 9569

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



9572
9573
9574
# File 'lib/models/porcelain.rb', line 9572

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9574
9575
9576
# File 'lib/models/porcelain.rb', line 9574

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



9576
9577
9578
# File 'lib/models/porcelain.rb', line 9576

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9578
9579
9580
# File 'lib/models/porcelain.rb', line 9578

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9580
9581
9582
# File 'lib/models/porcelain.rb', line 9580

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9582
9583
9584
# File 'lib/models/porcelain.rb', line 9582

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



9584
9585
9586
# File 'lib/models/porcelain.rb', line 9584

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



9586
9587
9588
# File 'lib/models/porcelain.rb', line 9586

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



9588
9589
9590
# File 'lib/models/porcelain.rb', line 9588

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9590
9591
9592
# File 'lib/models/porcelain.rb', line 9590

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9592
9593
9594
# File 'lib/models/porcelain.rb', line 9592

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9594
9595
9596
# File 'lib/models/porcelain.rb', line 9594

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9596
9597
9598
# File 'lib/models/porcelain.rb', line 9596

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



9598
9599
9600
# File 'lib/models/porcelain.rb', line 9598

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9600
9601
9602
# File 'lib/models/porcelain.rb', line 9600

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9648
9649
9650
9651
9652
9653
9654
# File 'lib/models/porcelain.rb', line 9648

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end