Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
# File 'lib/models/porcelain.rb', line 7006

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



6963
6964
6965
# File 'lib/models/porcelain.rb', line 6963

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6965
6966
6967
# File 'lib/models/porcelain.rb', line 6965

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6967
6968
6969
# File 'lib/models/porcelain.rb', line 6967

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6969
6970
6971
# File 'lib/models/porcelain.rb', line 6969

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6971
6972
6973
# File 'lib/models/porcelain.rb', line 6971

def client_key
  @client_key
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



6973
6974
6975
# File 'lib/models/porcelain.rb', line 6973

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



6976
6977
6978
# File 'lib/models/porcelain.rb', line 6976

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6978
6979
6980
# File 'lib/models/porcelain.rb', line 6978

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6980
6981
6982
# File 'lib/models/porcelain.rb', line 6980

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6982
6983
6984
# File 'lib/models/porcelain.rb', line 6982

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6984
6985
6986
# File 'lib/models/porcelain.rb', line 6984

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6986
6987
6988
# File 'lib/models/porcelain.rb', line 6986

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



6988
6989
6990
# File 'lib/models/porcelain.rb', line 6988

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



6990
6991
6992
# File 'lib/models/porcelain.rb', line 6990

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



6992
6993
6994
# File 'lib/models/porcelain.rb', line 6992

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6994
6995
6996
# File 'lib/models/porcelain.rb', line 6994

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6996
6997
6998
# File 'lib/models/porcelain.rb', line 6996

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6998
6999
7000
# File 'lib/models/porcelain.rb', line 6998

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7000
7001
7002
# File 'lib/models/porcelain.rb', line 7000

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7002
7003
7004
# File 'lib/models/porcelain.rb', line 7002

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7004
7005
7006
# File 'lib/models/porcelain.rb', line 7004

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7052
7053
7054
7055
7056
7057
7058
# File 'lib/models/porcelain.rb', line 7052

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end