Class: SDM::Kubernetes
- Inherits:
-
Object
- Object
- SDM::Kubernetes
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
-
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes
constructor
A new instance of Kubernetes.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes
Returns a new instance of Kubernetes.
6936 6937 6938 6939 6940 6941 6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 |
# File 'lib/models/porcelain.rb', line 6936 def initialize( allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled @discovery_username = discovery_username == nil ? "" : discovery_username @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
6893 6894 6895 |
# File 'lib/models/porcelain.rb', line 6893 def allow_resource_role_bypass @allow_resource_role_bypass end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6895 6896 6897 |
# File 'lib/models/porcelain.rb', line 6895 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
6897 6898 6899 |
# File 'lib/models/porcelain.rb', line 6897 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
6899 6900 6901 |
# File 'lib/models/porcelain.rb', line 6899 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
6901 6902 6903 |
# File 'lib/models/porcelain.rb', line 6901 def client_key @client_key end |
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
6903 6904 6905 |
# File 'lib/models/porcelain.rb', line 6903 def discovery_enabled @discovery_enabled end |
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
6906 6907 6908 |
# File 'lib/models/porcelain.rb', line 6906 def discovery_username @discovery_username end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6908 6909 6910 |
# File 'lib/models/porcelain.rb', line 6908 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
6910 6911 6912 |
# File 'lib/models/porcelain.rb', line 6910 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6912 6913 6914 |
# File 'lib/models/porcelain.rb', line 6912 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6914 6915 6916 |
# File 'lib/models/porcelain.rb', line 6914 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6916 6917 6918 |
# File 'lib/models/porcelain.rb', line 6916 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
6918 6919 6920 |
# File 'lib/models/porcelain.rb', line 6918 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
6920 6921 6922 |
# File 'lib/models/porcelain.rb', line 6920 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6922 6923 6924 |
# File 'lib/models/porcelain.rb', line 6922 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6924 6925 6926 |
# File 'lib/models/porcelain.rb', line 6924 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6926 6927 6928 |
# File 'lib/models/porcelain.rb', line 6926 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
6928 6929 6930 |
# File 'lib/models/porcelain.rb', line 6928 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6930 6931 6932 |
# File 'lib/models/porcelain.rb', line 6930 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6932 6933 6934 |
# File 'lib/models/porcelain.rb', line 6932 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6934 6935 6936 |
# File 'lib/models/porcelain.rb', line 6934 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6982 6983 6984 6985 6986 6987 6988 |
# File 'lib/models/porcelain.rb', line 6982 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |