Class: SDM::Kubernetes
- Inherits:
-
Object
- Object
- SDM::Kubernetes
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
-
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes
constructor
A new instance of Kubernetes.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes
Returns a new instance of Kubernetes.
6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/models/porcelain.rb', line 6325 def initialize( allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled @discovery_username = discovery_username == nil ? "" : discovery_username @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
6282 6283 6284 |
# File 'lib/models/porcelain.rb', line 6282 def allow_resource_role_bypass @allow_resource_role_bypass end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6284 6285 6286 |
# File 'lib/models/porcelain.rb', line 6284 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
6286 6287 6288 |
# File 'lib/models/porcelain.rb', line 6286 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
6288 6289 6290 |
# File 'lib/models/porcelain.rb', line 6288 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
6290 6291 6292 |
# File 'lib/models/porcelain.rb', line 6290 def client_key @client_key end |
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
6292 6293 6294 |
# File 'lib/models/porcelain.rb', line 6292 def discovery_enabled @discovery_enabled end |
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
6295 6296 6297 |
# File 'lib/models/porcelain.rb', line 6295 def discovery_username @discovery_username end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6297 6298 6299 |
# File 'lib/models/porcelain.rb', line 6297 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
6299 6300 6301 |
# File 'lib/models/porcelain.rb', line 6299 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6301 6302 6303 |
# File 'lib/models/porcelain.rb', line 6301 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6303 6304 6305 |
# File 'lib/models/porcelain.rb', line 6303 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6305 6306 6307 |
# File 'lib/models/porcelain.rb', line 6305 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
6307 6308 6309 |
# File 'lib/models/porcelain.rb', line 6307 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
6309 6310 6311 |
# File 'lib/models/porcelain.rb', line 6309 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6311 6312 6313 |
# File 'lib/models/porcelain.rb', line 6311 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6313 6314 6315 |
# File 'lib/models/porcelain.rb', line 6313 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6315 6316 6317 |
# File 'lib/models/porcelain.rb', line 6315 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
6317 6318 6319 |
# File 'lib/models/porcelain.rb', line 6317 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6319 6320 6321 |
# File 'lib/models/porcelain.rb', line 6319 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6321 6322 6323 |
# File 'lib/models/porcelain.rb', line 6321 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6323 6324 6325 |
# File 'lib/models/porcelain.rb', line 6323 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6371 6372 6373 6374 6375 6376 6377 |
# File 'lib/models/porcelain.rb', line 6371 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |