Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
# File 'lib/models/porcelain.rb', line 6254

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



6211
6212
6213
# File 'lib/models/porcelain.rb', line 6211

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6213
6214
6215
# File 'lib/models/porcelain.rb', line 6213

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6215
6216
6217
# File 'lib/models/porcelain.rb', line 6215

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6217
6218
6219
# File 'lib/models/porcelain.rb', line 6217

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6219
6220
6221
# File 'lib/models/porcelain.rb', line 6219

def client_key
  @client_key
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



6221
6222
6223
# File 'lib/models/porcelain.rb', line 6221

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



6224
6225
6226
# File 'lib/models/porcelain.rb', line 6224

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6226
6227
6228
# File 'lib/models/porcelain.rb', line 6226

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6228
6229
6230
# File 'lib/models/porcelain.rb', line 6228

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6230
6231
6232
# File 'lib/models/porcelain.rb', line 6230

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6232
6233
6234
# File 'lib/models/porcelain.rb', line 6232

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6234
6235
6236
# File 'lib/models/porcelain.rb', line 6234

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



6236
6237
6238
# File 'lib/models/porcelain.rb', line 6236

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



6238
6239
6240
# File 'lib/models/porcelain.rb', line 6238

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



6240
6241
6242
# File 'lib/models/porcelain.rb', line 6240

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6242
6243
6244
# File 'lib/models/porcelain.rb', line 6242

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6244
6245
6246
# File 'lib/models/porcelain.rb', line 6244

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6246
6247
6248
# File 'lib/models/porcelain.rb', line 6246

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6248
6249
6250
# File 'lib/models/porcelain.rb', line 6248

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6250
6251
6252
# File 'lib/models/porcelain.rb', line 6250

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6252
6253
6254
# File 'lib/models/porcelain.rb', line 6252

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6300
6301
6302
6303
6304
6305
6306
# File 'lib/models/porcelain.rb', line 6300

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end