Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
6027
6028
6029
6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
6043
6044
6045
# File 'lib/models/porcelain.rb', line 6003

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



5962
5963
5964
# File 'lib/models/porcelain.rb', line 5962

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5964
5965
5966
# File 'lib/models/porcelain.rb', line 5964

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5966
5967
5968
# File 'lib/models/porcelain.rb', line 5966

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



5968
5969
5970
# File 'lib/models/porcelain.rb', line 5968

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



5970
5971
5972
# File 'lib/models/porcelain.rb', line 5970

def client_key
  @client_key
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



5972
5973
5974
# File 'lib/models/porcelain.rb', line 5972

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



5975
5976
5977
# File 'lib/models/porcelain.rb', line 5975

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5977
5978
5979
# File 'lib/models/porcelain.rb', line 5977

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5979
5980
5981
# File 'lib/models/porcelain.rb', line 5979

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5981
5982
5983
# File 'lib/models/porcelain.rb', line 5981

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5983
5984
5985
# File 'lib/models/porcelain.rb', line 5983

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5985
5986
5987
# File 'lib/models/porcelain.rb', line 5985

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5987
5988
5989
# File 'lib/models/porcelain.rb', line 5987

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5989
5990
5991
# File 'lib/models/porcelain.rb', line 5989

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5991
5992
5993
# File 'lib/models/porcelain.rb', line 5991

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5993
5994
5995
# File 'lib/models/porcelain.rb', line 5993

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5995
5996
5997
# File 'lib/models/porcelain.rb', line 5995

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5997
5998
5999
# File 'lib/models/porcelain.rb', line 5997

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5999
6000
6001
# File 'lib/models/porcelain.rb', line 5999

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6001
6002
6003
# File 'lib/models/porcelain.rb', line 6001

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6047
6048
6049
6050
6051
6052
6053
# File 'lib/models/porcelain.rb', line 6047

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end