Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
5856
5857
5858
5859
5860
5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
# File 'lib/models/porcelain.rb', line 5845

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



5804
5805
5806
# File 'lib/models/porcelain.rb', line 5804

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5806
5807
5808
# File 'lib/models/porcelain.rb', line 5806

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5808
5809
5810
# File 'lib/models/porcelain.rb', line 5808

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



5810
5811
5812
# File 'lib/models/porcelain.rb', line 5810

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



5812
5813
5814
# File 'lib/models/porcelain.rb', line 5812

def client_key
  @client_key
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



5814
5815
5816
# File 'lib/models/porcelain.rb', line 5814

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



5817
5818
5819
# File 'lib/models/porcelain.rb', line 5817

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5819
5820
5821
# File 'lib/models/porcelain.rb', line 5819

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5821
5822
5823
# File 'lib/models/porcelain.rb', line 5821

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5823
5824
5825
# File 'lib/models/porcelain.rb', line 5823

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5825
5826
5827
# File 'lib/models/porcelain.rb', line 5825

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5827
5828
5829
# File 'lib/models/porcelain.rb', line 5827

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5829
5830
5831
# File 'lib/models/porcelain.rb', line 5829

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5831
5832
5833
# File 'lib/models/porcelain.rb', line 5831

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5833
5834
5835
# File 'lib/models/porcelain.rb', line 5833

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5835
5836
5837
# File 'lib/models/porcelain.rb', line 5835

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5837
5838
5839
# File 'lib/models/porcelain.rb', line 5837

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5839
5840
5841
# File 'lib/models/porcelain.rb', line 5839

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5841
5842
5843
# File 'lib/models/porcelain.rb', line 5841

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5843
5844
5845
# File 'lib/models/porcelain.rb', line 5843

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5889
5890
5891
5892
5893
5894
5895
# File 'lib/models/porcelain.rb', line 5889

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end