Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



5686
5687
5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
5719
5720
5721
5722
# File 'lib/models/porcelain.rb', line 5686

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5652
5653
5654
# File 'lib/models/porcelain.rb', line 5652

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



5654
5655
5656
# File 'lib/models/porcelain.rb', line 5654

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



5656
5657
5658
# File 'lib/models/porcelain.rb', line 5656

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



5658
5659
5660
# File 'lib/models/porcelain.rb', line 5658

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5660
5661
5662
# File 'lib/models/porcelain.rb', line 5660

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



5662
5663
5664
# File 'lib/models/porcelain.rb', line 5662

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5664
5665
5666
# File 'lib/models/porcelain.rb', line 5664

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5666
5667
5668
# File 'lib/models/porcelain.rb', line 5666

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5668
5669
5670
# File 'lib/models/porcelain.rb', line 5668

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



5670
5671
5672
# File 'lib/models/porcelain.rb', line 5670

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



5672
5673
5674
# File 'lib/models/porcelain.rb', line 5672

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



5674
5675
5676
# File 'lib/models/porcelain.rb', line 5674

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5676
5677
5678
# File 'lib/models/porcelain.rb', line 5676

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5678
5679
5680
# File 'lib/models/porcelain.rb', line 5678

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5680
5681
5682
# File 'lib/models/porcelain.rb', line 5680

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5682
5683
5684
# File 'lib/models/porcelain.rb', line 5682

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5684
5685
5686
# File 'lib/models/porcelain.rb', line 5684

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5724
5725
5726
5727
5728
5729
5730
# File 'lib/models/porcelain.rb', line 5724

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end