Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



4464
4465
4466
4467
4468
4469
4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
4481
4482
4483
4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
4497
4498
4499
4500
# File 'lib/models/porcelain.rb', line 4464

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4430
4431
4432
# File 'lib/models/porcelain.rb', line 4430

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4432
4433
4434
# File 'lib/models/porcelain.rb', line 4432

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4434
4435
4436
# File 'lib/models/porcelain.rb', line 4434

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4436
4437
4438
# File 'lib/models/porcelain.rb', line 4436

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4438
4439
4440
# File 'lib/models/porcelain.rb', line 4438

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4440
4441
4442
# File 'lib/models/porcelain.rb', line 4440

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4442
4443
4444
# File 'lib/models/porcelain.rb', line 4442

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4444
4445
4446
# File 'lib/models/porcelain.rb', line 4444

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4446
4447
4448
# File 'lib/models/porcelain.rb', line 4446

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4448
4449
4450
# File 'lib/models/porcelain.rb', line 4448

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4450
4451
4452
# File 'lib/models/porcelain.rb', line 4450

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4452
4453
4454
# File 'lib/models/porcelain.rb', line 4452

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



4454
4455
4456
# File 'lib/models/porcelain.rb', line 4454

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



4456
4457
4458
# File 'lib/models/porcelain.rb', line 4456

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4458
4459
4460
# File 'lib/models/porcelain.rb', line 4458

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4460
4461
4462
# File 'lib/models/porcelain.rb', line 4460

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4462
4463
4464
# File 'lib/models/porcelain.rb', line 4462

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4502
4503
4504
4505
4506
4507
4508
# File 'lib/models/porcelain.rb', line 4502

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end