Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



4292
4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
4317
4318
4319
4320
4321
4322
4323
4324
4325
4326
4327
4328
# File 'lib/models/porcelain.rb', line 4292

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4258
4259
4260
# File 'lib/models/porcelain.rb', line 4258

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4260
4261
4262
# File 'lib/models/porcelain.rb', line 4260

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4262
4263
4264
# File 'lib/models/porcelain.rb', line 4262

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4264
4265
4266
# File 'lib/models/porcelain.rb', line 4264

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4266
4267
4268
# File 'lib/models/porcelain.rb', line 4266

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4268
4269
4270
# File 'lib/models/porcelain.rb', line 4268

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4270
4271
4272
# File 'lib/models/porcelain.rb', line 4270

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4272
4273
4274
# File 'lib/models/porcelain.rb', line 4272

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4274
4275
4276
# File 'lib/models/porcelain.rb', line 4274

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4276
4277
4278
# File 'lib/models/porcelain.rb', line 4276

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4278
4279
4280
# File 'lib/models/porcelain.rb', line 4278

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4280
4281
4282
# File 'lib/models/porcelain.rb', line 4280

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



4282
4283
4284
# File 'lib/models/porcelain.rb', line 4282

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



4284
4285
4286
# File 'lib/models/porcelain.rb', line 4284

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4286
4287
4288
# File 'lib/models/porcelain.rb', line 4286

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4288
4289
4290
# File 'lib/models/porcelain.rb', line 4288

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4290
4291
4292
# File 'lib/models/porcelain.rb', line 4290

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4330
4331
4332
4333
4334
4335
4336
# File 'lib/models/porcelain.rb', line 4330

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end