Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
4197
4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
# File 'lib/models/porcelain.rb', line 4177

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4143
4144
4145
# File 'lib/models/porcelain.rb', line 4143

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



4145
4146
4147
# File 'lib/models/porcelain.rb', line 4145

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



4147
4148
4149
# File 'lib/models/porcelain.rb', line 4147

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



4149
4150
4151
# File 'lib/models/porcelain.rb', line 4149

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4151
4152
4153
# File 'lib/models/porcelain.rb', line 4151

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4153
4154
4155
# File 'lib/models/porcelain.rb', line 4153

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4155
4156
4157
# File 'lib/models/porcelain.rb', line 4155

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4157
4158
4159
# File 'lib/models/porcelain.rb', line 4157

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4159
4160
4161
# File 'lib/models/porcelain.rb', line 4159

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4161
4162
4163
# File 'lib/models/porcelain.rb', line 4161

def name
  @name
end

#portObject

Returns the value of attribute port.



4163
4164
4165
# File 'lib/models/porcelain.rb', line 4163

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4165
4166
4167
# File 'lib/models/porcelain.rb', line 4165

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



4167
4168
4169
# File 'lib/models/porcelain.rb', line 4167

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



4169
4170
4171
# File 'lib/models/porcelain.rb', line 4169

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4171
4172
4173
# File 'lib/models/porcelain.rb', line 4171

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4173
4174
4175
# File 'lib/models/porcelain.rb', line 4173

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4175
4176
4177
# File 'lib/models/porcelain.rb', line 4175

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4215
4216
4217
4218
4219
4220
4221
# File 'lib/models/porcelain.rb', line 4215

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end