Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
3888
3889
3890
3891
# File 'lib/models/porcelain.rb', line 3857

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3825
3826
3827
# File 'lib/models/porcelain.rb', line 3825

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3827
3828
3829
# File 'lib/models/porcelain.rb', line 3827

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3829
3830
3831
# File 'lib/models/porcelain.rb', line 3829

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3831
3832
3833
# File 'lib/models/porcelain.rb', line 3831

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3833
3834
3835
# File 'lib/models/porcelain.rb', line 3833

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3835
3836
3837
# File 'lib/models/porcelain.rb', line 3835

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3837
3838
3839
# File 'lib/models/porcelain.rb', line 3837

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3839
3840
3841
# File 'lib/models/porcelain.rb', line 3839

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3841
3842
3843
# File 'lib/models/porcelain.rb', line 3841

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3843
3844
3845
# File 'lib/models/porcelain.rb', line 3843

def name
  @name
end

#portObject

Returns the value of attribute port.



3845
3846
3847
# File 'lib/models/porcelain.rb', line 3845

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3847
3848
3849
# File 'lib/models/porcelain.rb', line 3847

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3849
3850
3851
# File 'lib/models/porcelain.rb', line 3849

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3851
3852
3853
# File 'lib/models/porcelain.rb', line 3851

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3853
3854
3855
# File 'lib/models/porcelain.rb', line 3853

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3855
3856
3857
# File 'lib/models/porcelain.rb', line 3855

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3893
3894
3895
3896
3897
3898
3899
# File 'lib/models/porcelain.rb', line 3893

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end