Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
# File 'lib/models/porcelain.rb', line 3519

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3487
3488
3489
# File 'lib/models/porcelain.rb', line 3487

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3489
3490
3491
# File 'lib/models/porcelain.rb', line 3489

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3491
3492
3493
# File 'lib/models/porcelain.rb', line 3491

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3493
3494
3495
# File 'lib/models/porcelain.rb', line 3493

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3495
3496
3497
# File 'lib/models/porcelain.rb', line 3495

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3497
3498
3499
# File 'lib/models/porcelain.rb', line 3497

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3499
3500
3501
# File 'lib/models/porcelain.rb', line 3499

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3501
3502
3503
# File 'lib/models/porcelain.rb', line 3501

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3503
3504
3505
# File 'lib/models/porcelain.rb', line 3503

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3505
3506
3507
# File 'lib/models/porcelain.rb', line 3505

def name
  @name
end

#portObject

Returns the value of attribute port.



3507
3508
3509
# File 'lib/models/porcelain.rb', line 3507

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3509
3510
3511
# File 'lib/models/porcelain.rb', line 3509

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3511
3512
3513
# File 'lib/models/porcelain.rb', line 3511

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3513
3514
3515
# File 'lib/models/porcelain.rb', line 3513

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3515
3516
3517
# File 'lib/models/porcelain.rb', line 3515

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3517
3518
3519
# File 'lib/models/porcelain.rb', line 3517

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3555
3556
3557
3558
3559
3560
3561
# File 'lib/models/porcelain.rb', line 3555

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end