Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
3412
3413
3414
3415
3416
3417
3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
# File 'lib/models/porcelain.rb', line 3393

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3361
3362
3363
# File 'lib/models/porcelain.rb', line 3361

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3363
3364
3365
# File 'lib/models/porcelain.rb', line 3363

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3365
3366
3367
# File 'lib/models/porcelain.rb', line 3365

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3367
3368
3369
# File 'lib/models/porcelain.rb', line 3367

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3369
3370
3371
# File 'lib/models/porcelain.rb', line 3369

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3371
3372
3373
# File 'lib/models/porcelain.rb', line 3371

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3373
3374
3375
# File 'lib/models/porcelain.rb', line 3373

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3375
3376
3377
# File 'lib/models/porcelain.rb', line 3375

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3377
3378
3379
# File 'lib/models/porcelain.rb', line 3377

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3379
3380
3381
# File 'lib/models/porcelain.rb', line 3379

def name
  @name
end

#portObject

Returns the value of attribute port.



3381
3382
3383
# File 'lib/models/porcelain.rb', line 3381

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3383
3384
3385
# File 'lib/models/porcelain.rb', line 3383

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3385
3386
3387
# File 'lib/models/porcelain.rb', line 3385

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3387
3388
3389
# File 'lib/models/porcelain.rb', line 3387

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3389
3390
3391
# File 'lib/models/porcelain.rb', line 3389

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3391
3392
3393
# File 'lib/models/porcelain.rb', line 3391

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3429
3430
3431
3432
3433
3434
3435
# File 'lib/models/porcelain.rb', line 3429

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end