Class: SDM::Kubernetes
- Inherits:
-
Object
- Object
- SDM::Kubernetes
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil) ⇒ Kubernetes
constructor
A new instance of Kubernetes.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil) ⇒ Kubernetes
Returns a new instance of Kubernetes.
3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 |
# File 'lib/models/porcelain.rb', line 3766 def initialize( certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil ) if != nil @certificate_authority = end if client_certificate != nil @client_certificate = client_certificate end if client_key != nil @client_key = client_key end if egress_filter != nil @egress_filter = egress_filter end if healthcheck_namespace != nil @healthcheck_namespace = healthcheck_namespace end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if port != nil @port = port end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end end |
Instance Attribute Details
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3742 3743 3744 |
# File 'lib/models/porcelain.rb', line 3742 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
3744 3745 3746 |
# File 'lib/models/porcelain.rb', line 3744 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
3746 3747 3748 |
# File 'lib/models/porcelain.rb', line 3746 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3748 3749 3750 |
# File 'lib/models/porcelain.rb', line 3748 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to `default`.
3750 3751 3752 |
# File 'lib/models/porcelain.rb', line 3750 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3752 3753 3754 |
# File 'lib/models/porcelain.rb', line 3752 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3754 3755 3756 |
# File 'lib/models/porcelain.rb', line 3754 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3756 3757 3758 |
# File 'lib/models/porcelain.rb', line 3756 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3758 3759 3760 |
# File 'lib/models/porcelain.rb', line 3758 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
3760 3761 3762 |
# File 'lib/models/porcelain.rb', line 3760 def port @port end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3762 3763 3764 |
# File 'lib/models/porcelain.rb', line 3762 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3764 3765 3766 |
# File 'lib/models/porcelain.rb', line 3764 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3818 3819 3820 3821 3822 3823 3824 |
# File 'lib/models/porcelain.rb', line 3818 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |