Class: SDM::Kubernetes

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Kubernetes

Returns a new instance of Kubernetes.



9989
9990
9991
9992
9993
9994
9995
9996
9997
9998
9999
10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
10027
10028
10029
10030
10031
10032
10033
# File 'lib/models/porcelain.rb', line 9989

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypass ⇒ Object

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



9946
9947
9948
# File 'lib/models/porcelain.rb', line 9946

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9948
9949
9950
# File 'lib/models/porcelain.rb', line 9948

def bind_interface
  @bind_interface
end

#certificate_authority ⇒ Object

The CA to authenticate TLS connections with.



9950
9951
9952
# File 'lib/models/porcelain.rb', line 9950

def certificate_authority
  @certificate_authority
end

#client_certificate ⇒ Object

The certificate to authenticate TLS connections with.



9952
9953
9954
# File 'lib/models/porcelain.rb', line 9952

def client_certificate
  @client_certificate
end

#client_key ⇒ Object

The key to authenticate TLS connections with.



9954
9955
9956
# File 'lib/models/porcelain.rb', line 9954

def client_key
  @client_key
end

#discovery_enabled ⇒ Object

If true, configures discovery of a cluster to be run from a node.



9956
9957
9958
# File 'lib/models/porcelain.rb', line 9956

def discovery_enabled
  @discovery_enabled
end

#discovery_username ⇒ Object

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



9959
9960
9961
# File 'lib/models/porcelain.rb', line 9959

def discovery_username
  @discovery_username
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



9961
9962
9963
# File 'lib/models/porcelain.rb', line 9961

def egress_filter
  @egress_filter
end

#healthcheck_namespace ⇒ Object

The path used to check the health of your connection. Defaults to default.



9963
9964
9965
# File 'lib/models/porcelain.rb', line 9963

def healthcheck_namespace
  @healthcheck_namespace
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



9965
9966
9967
# File 'lib/models/porcelain.rb', line 9965

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



9967
9968
9969
# File 'lib/models/porcelain.rb', line 9967

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



9969
9970
9971
# File 'lib/models/porcelain.rb', line 9969

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



9971
9972
9973
# File 'lib/models/porcelain.rb', line 9971

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



9973
9974
9975
# File 'lib/models/porcelain.rb', line 9973

def identity_set_id
  @identity_set_id
end

#name ⇒ Object

Unique human-readable name of the Resource.



9975
9976
9977
# File 'lib/models/porcelain.rb', line 9975

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



9977
9978
9979
# File 'lib/models/porcelain.rb', line 9977

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9979
9980
9981
# File 'lib/models/porcelain.rb', line 9979

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



9981
9982
9983
# File 'lib/models/porcelain.rb', line 9981

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



9983
9984
9985
# File 'lib/models/porcelain.rb', line 9983

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



9985
9986
9987
# File 'lib/models/porcelain.rb', line 9985

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



9987
9988
9989
# File 'lib/models/porcelain.rb', line 9987

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10035
10036
10037
10038
10039
10040
10041
# File 'lib/models/porcelain.rb', line 10035

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end