Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
9981
9982
9983
9984
9985
9986
9987
9988
9989
9990
9991
9992
9993
9994
9995
9996
9997
# File 'lib/models/porcelain.rb', line 9965

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9935
9936
9937
# File 'lib/models/porcelain.rb', line 9935

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9937
9938
9939
# File 'lib/models/porcelain.rb', line 9937

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



9939
9940
9941
# File 'lib/models/porcelain.rb', line 9939

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9941
9942
9943
# File 'lib/models/porcelain.rb', line 9941

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9943
9944
9945
# File 'lib/models/porcelain.rb', line 9943

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9945
9946
9947
# File 'lib/models/porcelain.rb', line 9945

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9947
9948
9949
# File 'lib/models/porcelain.rb', line 9947

def name
  @name
end

#passwordObject

The password to authenticate with.



9949
9950
9951
# File 'lib/models/porcelain.rb', line 9949

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9951
9952
9953
# File 'lib/models/porcelain.rb', line 9951

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9953
9954
9955
# File 'lib/models/porcelain.rb', line 9953

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9955
9956
9957
# File 'lib/models/porcelain.rb', line 9955

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9957
9958
9959
# File 'lib/models/porcelain.rb', line 9957

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



9959
9960
9961
# File 'lib/models/porcelain.rb', line 9959

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9961
9962
9963
# File 'lib/models/porcelain.rb', line 9961

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9963
9964
9965
# File 'lib/models/porcelain.rb', line 9963

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9999
10000
10001
10002
10003
10004
10005
# File 'lib/models/porcelain.rb', line 9999

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end