Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
# File 'lib/models/porcelain.rb', line 9764

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9734
9735
9736
# File 'lib/models/porcelain.rb', line 9734

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9736
9737
9738
# File 'lib/models/porcelain.rb', line 9736

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



9738
9739
9740
# File 'lib/models/porcelain.rb', line 9738

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9740
9741
9742
# File 'lib/models/porcelain.rb', line 9740

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9742
9743
9744
# File 'lib/models/porcelain.rb', line 9742

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9744
9745
9746
# File 'lib/models/porcelain.rb', line 9744

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9746
9747
9748
# File 'lib/models/porcelain.rb', line 9746

def name
  @name
end

#passwordObject

The password to authenticate with.



9748
9749
9750
# File 'lib/models/porcelain.rb', line 9748

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9750
9751
9752
# File 'lib/models/porcelain.rb', line 9750

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9752
9753
9754
# File 'lib/models/porcelain.rb', line 9752

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9754
9755
9756
# File 'lib/models/porcelain.rb', line 9754

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9756
9757
9758
# File 'lib/models/porcelain.rb', line 9756

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



9758
9759
9760
# File 'lib/models/porcelain.rb', line 9758

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9760
9761
9762
# File 'lib/models/porcelain.rb', line 9760

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9762
9763
9764
# File 'lib/models/porcelain.rb', line 9762

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9798
9799
9800
9801
9802
9803
9804
# File 'lib/models/porcelain.rb', line 9798

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end