Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



9690
9691
9692
9693
9694
9695
9696
9697
9698
9699
9700
9701
9702
9703
9704
9705
9706
9707
9708
9709
9710
9711
9712
9713
9714
9715
9716
9717
9718
9719
9720
9721
9722
# File 'lib/models/porcelain.rb', line 9690

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9660
9661
9662
# File 'lib/models/porcelain.rb', line 9660

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9662
9663
9664
# File 'lib/models/porcelain.rb', line 9662

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



9664
9665
9666
# File 'lib/models/porcelain.rb', line 9664

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9666
9667
9668
# File 'lib/models/porcelain.rb', line 9666

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9668
9669
9670
# File 'lib/models/porcelain.rb', line 9668

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9670
9671
9672
# File 'lib/models/porcelain.rb', line 9670

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9672
9673
9674
# File 'lib/models/porcelain.rb', line 9672

def name
  @name
end

#passwordObject

The password to authenticate with.



9674
9675
9676
# File 'lib/models/porcelain.rb', line 9674

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9676
9677
9678
# File 'lib/models/porcelain.rb', line 9676

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9678
9679
9680
# File 'lib/models/porcelain.rb', line 9678

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9680
9681
9682
# File 'lib/models/porcelain.rb', line 9680

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9682
9683
9684
# File 'lib/models/porcelain.rb', line 9682

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



9684
9685
9686
# File 'lib/models/porcelain.rb', line 9684

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9686
9687
9688
# File 'lib/models/porcelain.rb', line 9686

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9688
9689
9690
# File 'lib/models/porcelain.rb', line 9688

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9724
9725
9726
9727
9728
9729
9730
# File 'lib/models/porcelain.rb', line 9724

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end