Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
# File 'lib/models/porcelain.rb', line 7094

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7064
7065
7066
# File 'lib/models/porcelain.rb', line 7064

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7066
7067
7068
# File 'lib/models/porcelain.rb', line 7066

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7068
7069
7070
# File 'lib/models/porcelain.rb', line 7068

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7070
7071
7072
# File 'lib/models/porcelain.rb', line 7070

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7072
7073
7074
# File 'lib/models/porcelain.rb', line 7072

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7074
7075
7076
# File 'lib/models/porcelain.rb', line 7074

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7076
7077
7078
# File 'lib/models/porcelain.rb', line 7076

def name
  @name
end

#passwordObject

The password to authenticate with.



7078
7079
7080
# File 'lib/models/porcelain.rb', line 7078

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7080
7081
7082
# File 'lib/models/porcelain.rb', line 7080

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7082
7083
7084
# File 'lib/models/porcelain.rb', line 7082

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7084
7085
7086
# File 'lib/models/porcelain.rb', line 7084

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7086
7087
7088
# File 'lib/models/porcelain.rb', line 7086

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7088
7089
7090
# File 'lib/models/porcelain.rb', line 7088

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7090
7091
7092
# File 'lib/models/porcelain.rb', line 7090

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7092
7093
7094
# File 'lib/models/porcelain.rb', line 7092

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7128
7129
7130
7131
7132
7133
7134
# File 'lib/models/porcelain.rb', line 7128

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end