Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
# File 'lib/models/porcelain.rb', line 7024

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6994
6995
6996
# File 'lib/models/porcelain.rb', line 6994

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6996
6997
6998
# File 'lib/models/porcelain.rb', line 6996

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6998
6999
7000
# File 'lib/models/porcelain.rb', line 6998

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7000
7001
7002
# File 'lib/models/porcelain.rb', line 7000

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7002
7003
7004
# File 'lib/models/porcelain.rb', line 7002

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7004
7005
7006
# File 'lib/models/porcelain.rb', line 7004

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7006
7007
7008
# File 'lib/models/porcelain.rb', line 7006

def name
  @name
end

#passwordObject

The password to authenticate with.



7008
7009
7010
# File 'lib/models/porcelain.rb', line 7008

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7010
7011
7012
# File 'lib/models/porcelain.rb', line 7010

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7012
7013
7014
# File 'lib/models/porcelain.rb', line 7012

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7014
7015
7016
# File 'lib/models/porcelain.rb', line 7014

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7016
7017
7018
# File 'lib/models/porcelain.rb', line 7016

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7018
7019
7020
# File 'lib/models/porcelain.rb', line 7018

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7020
7021
7022
# File 'lib/models/porcelain.rb', line 7020

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7022
7023
7024
# File 'lib/models/porcelain.rb', line 7022

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7058
7059
7060
7061
7062
7063
7064
# File 'lib/models/porcelain.rb', line 7058

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end