Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



6413
6414
6415
6416
6417
6418
6419
6420
6421
6422
6423
6424
6425
6426
6427
6428
6429
6430
6431
6432
6433
6434
6435
6436
6437
6438
6439
6440
6441
6442
6443
6444
6445
# File 'lib/models/porcelain.rb', line 6413

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6383
6384
6385
# File 'lib/models/porcelain.rb', line 6383

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6385
6386
6387
# File 'lib/models/porcelain.rb', line 6385

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6387
6388
6389
# File 'lib/models/porcelain.rb', line 6387

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6389
6390
6391
# File 'lib/models/porcelain.rb', line 6389

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6391
6392
6393
# File 'lib/models/porcelain.rb', line 6391

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6393
6394
6395
# File 'lib/models/porcelain.rb', line 6393

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6395
6396
6397
# File 'lib/models/porcelain.rb', line 6395

def name
  @name
end

#passwordObject

The password to authenticate with.



6397
6398
6399
# File 'lib/models/porcelain.rb', line 6397

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6399
6400
6401
# File 'lib/models/porcelain.rb', line 6399

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6401
6402
6403
# File 'lib/models/porcelain.rb', line 6401

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6403
6404
6405
# File 'lib/models/porcelain.rb', line 6403

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6405
6406
6407
# File 'lib/models/porcelain.rb', line 6405

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6407
6408
6409
# File 'lib/models/porcelain.rb', line 6407

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6409
6410
6411
# File 'lib/models/porcelain.rb', line 6409

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6411
6412
6413
# File 'lib/models/porcelain.rb', line 6411

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6447
6448
6449
6450
6451
6452
6453
# File 'lib/models/porcelain.rb', line 6447

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end