Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
# File 'lib/models/porcelain.rb', line 6342

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6312
6313
6314
# File 'lib/models/porcelain.rb', line 6312

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6314
6315
6316
# File 'lib/models/porcelain.rb', line 6314

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6316
6317
6318
# File 'lib/models/porcelain.rb', line 6316

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6318
6319
6320
# File 'lib/models/porcelain.rb', line 6318

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6320
6321
6322
# File 'lib/models/porcelain.rb', line 6320

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6322
6323
6324
# File 'lib/models/porcelain.rb', line 6322

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6324
6325
6326
# File 'lib/models/porcelain.rb', line 6324

def name
  @name
end

#passwordObject

The password to authenticate with.



6326
6327
6328
# File 'lib/models/porcelain.rb', line 6326

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6328
6329
6330
# File 'lib/models/porcelain.rb', line 6328

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6330
6331
6332
# File 'lib/models/porcelain.rb', line 6330

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6332
6333
6334
# File 'lib/models/porcelain.rb', line 6332

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6334
6335
6336
# File 'lib/models/porcelain.rb', line 6334

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6336
6337
6338
# File 'lib/models/porcelain.rb', line 6336

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6338
6339
6340
# File 'lib/models/porcelain.rb', line 6338

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6340
6341
6342
# File 'lib/models/porcelain.rb', line 6340

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6376
6377
6378
6379
6380
6381
6382
# File 'lib/models/porcelain.rb', line 6376

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end