Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



6087
6088
6089
6090
6091
6092
6093
6094
6095
6096
6097
6098
6099
6100
6101
6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
6112
6113
6114
6115
6116
6117
# File 'lib/models/porcelain.rb', line 6087

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6059
6060
6061
# File 'lib/models/porcelain.rb', line 6059

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6061
6062
6063
# File 'lib/models/porcelain.rb', line 6061

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6063
6064
6065
# File 'lib/models/porcelain.rb', line 6063

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6065
6066
6067
# File 'lib/models/porcelain.rb', line 6065

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6067
6068
6069
# File 'lib/models/porcelain.rb', line 6067

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6069
6070
6071
# File 'lib/models/porcelain.rb', line 6069

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6071
6072
6073
# File 'lib/models/porcelain.rb', line 6071

def name
  @name
end

#passwordObject

The password to authenticate with.



6073
6074
6075
# File 'lib/models/porcelain.rb', line 6073

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6075
6076
6077
# File 'lib/models/porcelain.rb', line 6075

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6077
6078
6079
# File 'lib/models/porcelain.rb', line 6077

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6079
6080
6081
# File 'lib/models/porcelain.rb', line 6079

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6081
6082
6083
# File 'lib/models/porcelain.rb', line 6081

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6083
6084
6085
# File 'lib/models/porcelain.rb', line 6083

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6085
6086
6087
# File 'lib/models/porcelain.rb', line 6085

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6119
6120
6121
6122
6123
6124
6125
# File 'lib/models/porcelain.rb', line 6119

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end