Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
# File 'lib/models/porcelain.rb', line 4374

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4346
4347
4348
# File 'lib/models/porcelain.rb', line 4346

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4348
4349
4350
# File 'lib/models/porcelain.rb', line 4348

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4350
4351
4352
# File 'lib/models/porcelain.rb', line 4350

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4352
4353
4354
# File 'lib/models/porcelain.rb', line 4352

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4354
4355
4356
# File 'lib/models/porcelain.rb', line 4354

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4356
4357
4358
# File 'lib/models/porcelain.rb', line 4356

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4358
4359
4360
# File 'lib/models/porcelain.rb', line 4358

def name
  @name
end

#passwordObject

The password to authenticate with.



4360
4361
4362
# File 'lib/models/porcelain.rb', line 4360

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4362
4363
4364
# File 'lib/models/porcelain.rb', line 4362

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4364
4365
4366
# File 'lib/models/porcelain.rb', line 4364

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4366
4367
4368
# File 'lib/models/porcelain.rb', line 4366

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4368
4369
4370
# File 'lib/models/porcelain.rb', line 4368

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4370
4371
4372
# File 'lib/models/porcelain.rb', line 4370

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4372
4373
4374
# File 'lib/models/porcelain.rb', line 4372

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4406
4407
4408
4409
4410
4411
4412
# File 'lib/models/porcelain.rb', line 4406

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end