Class: SDM::KubernetesBasicAuth
- Inherits:
-
Object
- Object
- SDM::KubernetesBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth
constructor
A new instance of KubernetesBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth
Returns a new instance of KubernetesBasicAuth.
4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 |
# File 'lib/models/porcelain.rb', line 4254 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4226 4227 4228 |
# File 'lib/models/porcelain.rb', line 4226 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4228 4229 4230 |
# File 'lib/models/porcelain.rb', line 4228 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
4230 4231 4232 |
# File 'lib/models/porcelain.rb', line 4230 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4232 4233 4234 |
# File 'lib/models/porcelain.rb', line 4232 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4234 4235 4236 |
# File 'lib/models/porcelain.rb', line 4234 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4236 4237 4238 |
# File 'lib/models/porcelain.rb', line 4236 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4238 4239 4240 |
# File 'lib/models/porcelain.rb', line 4238 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4240 4241 4242 |
# File 'lib/models/porcelain.rb', line 4240 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4242 4243 4244 |
# File 'lib/models/porcelain.rb', line 4242 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4244 4245 4246 |
# File 'lib/models/porcelain.rb', line 4244 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4246 4247 4248 |
# File 'lib/models/porcelain.rb', line 4246 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4248 4249 4250 |
# File 'lib/models/porcelain.rb', line 4248 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4250 4251 4252 |
# File 'lib/models/porcelain.rb', line 4250 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4252 4253 4254 |
# File 'lib/models/porcelain.rb', line 4252 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4286 4287 4288 4289 4290 4291 4292 |
# File 'lib/models/porcelain.rb', line 4286 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |