Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
3957
3958
# File 'lib/models/porcelain.rb', line 3930

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3904
3905
3906
# File 'lib/models/porcelain.rb', line 3904

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3906
3907
3908
# File 'lib/models/porcelain.rb', line 3906

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3908
3909
3910
# File 'lib/models/porcelain.rb', line 3908

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3910
3911
3912
# File 'lib/models/porcelain.rb', line 3910

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3912
3913
3914
# File 'lib/models/porcelain.rb', line 3912

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3914
3915
3916
# File 'lib/models/porcelain.rb', line 3914

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3916
3917
3918
# File 'lib/models/porcelain.rb', line 3916

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3918
3919
3920
# File 'lib/models/porcelain.rb', line 3918

def password
  @password
end

#portObject

Returns the value of attribute port.



3920
3921
3922
# File 'lib/models/porcelain.rb', line 3920

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3922
3923
3924
# File 'lib/models/porcelain.rb', line 3922

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3924
3925
3926
# File 'lib/models/porcelain.rb', line 3924

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3926
3927
3928
# File 'lib/models/porcelain.rb', line 3926

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3928
3929
3930
# File 'lib/models/porcelain.rb', line 3928

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3960
3961
3962
3963
3964
3965
3966
# File 'lib/models/porcelain.rb', line 3960

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end