Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



3592
3593
3594
3595
3596
3597
3598
3599
3600
3601
3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
# File 'lib/models/porcelain.rb', line 3592

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3566
3567
3568
# File 'lib/models/porcelain.rb', line 3566

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3568
3569
3570
# File 'lib/models/porcelain.rb', line 3568

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3570
3571
3572
# File 'lib/models/porcelain.rb', line 3570

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3572
3573
3574
# File 'lib/models/porcelain.rb', line 3572

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3574
3575
3576
# File 'lib/models/porcelain.rb', line 3574

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3576
3577
3578
# File 'lib/models/porcelain.rb', line 3576

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3578
3579
3580
# File 'lib/models/porcelain.rb', line 3578

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3580
3581
3582
# File 'lib/models/porcelain.rb', line 3580

def password
  @password
end

#portObject

Returns the value of attribute port.



3582
3583
3584
# File 'lib/models/porcelain.rb', line 3582

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3584
3585
3586
# File 'lib/models/porcelain.rb', line 3584

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3586
3587
3588
# File 'lib/models/porcelain.rb', line 3586

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3588
3589
3590
# File 'lib/models/porcelain.rb', line 3588

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3590
3591
3592
# File 'lib/models/porcelain.rb', line 3590

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3622
3623
3624
3625
3626
3627
3628
# File 'lib/models/porcelain.rb', line 3622

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end