Class: SDM::KubernetesBasicAuth
- Inherits:
-
Object
- Object
- SDM::KubernetesBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth
constructor
A new instance of KubernetesBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth
Returns a new instance of KubernetesBasicAuth.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 |
# File 'lib/models/porcelain.rb', line 3593 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3567 3568 3569 |
# File 'lib/models/porcelain.rb', line 3567 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3569 3570 3571 |
# File 'lib/models/porcelain.rb', line 3569 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3571 3572 3573 |
# File 'lib/models/porcelain.rb', line 3571 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3573 3574 3575 |
# File 'lib/models/porcelain.rb', line 3573 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3575 3576 3577 |
# File 'lib/models/porcelain.rb', line 3575 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3577 3578 3579 |
# File 'lib/models/porcelain.rb', line 3577 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3579 3580 3581 |
# File 'lib/models/porcelain.rb', line 3579 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3581 3582 3583 |
# File 'lib/models/porcelain.rb', line 3581 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3583 3584 3585 |
# File 'lib/models/porcelain.rb', line 3583 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3585 3586 3587 |
# File 'lib/models/porcelain.rb', line 3585 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3587 3588 3589 |
# File 'lib/models/porcelain.rb', line 3587 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3589 3590 3591 |
# File 'lib/models/porcelain.rb', line 3589 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3591 3592 3593 |
# File 'lib/models/porcelain.rb', line 3591 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3623 3624 3625 3626 3627 3628 3629 |
# File 'lib/models/porcelain.rb', line 3623 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |