Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



3466
3467
3468
3469
3470
3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
3482
3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
# File 'lib/models/porcelain.rb', line 3466

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3440
3441
3442
# File 'lib/models/porcelain.rb', line 3440

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3442
3443
3444
# File 'lib/models/porcelain.rb', line 3442

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3444
3445
3446
# File 'lib/models/porcelain.rb', line 3444

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3446
3447
3448
# File 'lib/models/porcelain.rb', line 3446

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3448
3449
3450
# File 'lib/models/porcelain.rb', line 3448

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3450
3451
3452
# File 'lib/models/porcelain.rb', line 3450

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3452
3453
3454
# File 'lib/models/porcelain.rb', line 3452

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3454
3455
3456
# File 'lib/models/porcelain.rb', line 3454

def password
  @password
end

#portObject

Returns the value of attribute port.



3456
3457
3458
# File 'lib/models/porcelain.rb', line 3456

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3458
3459
3460
# File 'lib/models/porcelain.rb', line 3458

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3460
3461
3462
# File 'lib/models/porcelain.rb', line 3460

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3462
3463
3464
# File 'lib/models/porcelain.rb', line 3462

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3464
3465
3466
# File 'lib/models/porcelain.rb', line 3464

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3496
3497
3498
3499
3500
3501
3502
# File 'lib/models/porcelain.rb', line 3496

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end