Class: SDM::KubernetesBasicAuth
- Inherits:
-
Object
- Object
- SDM::KubernetesBasicAuth
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth
constructor
A new instance of KubernetesBasicAuth.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth
Returns a new instance of KubernetesBasicAuth.
3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 |
# File 'lib/models/porcelain.rb', line 3851 def initialize( egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, secret_store_id: nil, tags: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthcheck_namespace != nil @healthcheck_namespace = healthcheck_namespace end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3829 3830 3831 |
# File 'lib/models/porcelain.rb', line 3829 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to `default`.
3831 3832 3833 |
# File 'lib/models/porcelain.rb', line 3831 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3833 3834 3835 |
# File 'lib/models/porcelain.rb', line 3833 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3835 3836 3837 |
# File 'lib/models/porcelain.rb', line 3835 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3837 3838 3839 |
# File 'lib/models/porcelain.rb', line 3837 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3839 3840 3841 |
# File 'lib/models/porcelain.rb', line 3839 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3841 3842 3843 |
# File 'lib/models/porcelain.rb', line 3841 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3843 3844 3845 |
# File 'lib/models/porcelain.rb', line 3843 def port @port end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3845 3846 3847 |
# File 'lib/models/porcelain.rb', line 3845 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3847 3848 3849 |
# File 'lib/models/porcelain.rb', line 3847 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3849 3850 3851 |
# File 'lib/models/porcelain.rb', line 3849 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3899 3900 3901 3902 3903 3904 3905 |
# File 'lib/models/porcelain.rb', line 3899 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |