Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
# File 'lib/models/porcelain.rb', line 7561

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7531
7532
7533
# File 'lib/models/porcelain.rb', line 7531

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7533
7534
7535
# File 'lib/models/porcelain.rb', line 7533

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7535
7536
7537
# File 'lib/models/porcelain.rb', line 7535

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7537
7538
7539
# File 'lib/models/porcelain.rb', line 7537

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7539
7540
7541
# File 'lib/models/porcelain.rb', line 7539

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7541
7542
7543
# File 'lib/models/porcelain.rb', line 7541

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7543
7544
7545
# File 'lib/models/porcelain.rb', line 7543

def name
  @name
end

#passwordObject

The password to authenticate with.



7545
7546
7547
# File 'lib/models/porcelain.rb', line 7545

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7547
7548
7549
# File 'lib/models/porcelain.rb', line 7547

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7549
7550
7551
# File 'lib/models/porcelain.rb', line 7549

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7551
7552
7553
# File 'lib/models/porcelain.rb', line 7551

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7553
7554
7555
# File 'lib/models/porcelain.rb', line 7553

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7555
7556
7557
# File 'lib/models/porcelain.rb', line 7555

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7557
7558
7559
# File 'lib/models/porcelain.rb', line 7557

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7559
7560
7561
# File 'lib/models/porcelain.rb', line 7559

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7595
7596
7597
7598
7599
7600
7601
# File 'lib/models/porcelain.rb', line 7595

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end