Class: SDM::KubernetesBasicAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesBasicAuth is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ KubernetesBasicAuth

Returns a new instance of KubernetesBasicAuth.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
10090
10091
10092
10093
10094
10095
10096
10097
10098
10099
10100
10101
10102
10103
10104
10105
10106
10107
10108
10109
# File 'lib/models/porcelain.rb', line 10077

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10047
10048
10049
# File 'lib/models/porcelain.rb', line 10047

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



10049
10050
10051
# File 'lib/models/porcelain.rb', line 10049

def egress_filter
  @egress_filter
end

#healthcheck_namespace ⇒ Object

The path used to check the health of your connection. Defaults to default.



10051
10052
10053
# File 'lib/models/porcelain.rb', line 10051

def healthcheck_namespace
  @healthcheck_namespace
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



10053
10054
10055
# File 'lib/models/porcelain.rb', line 10053

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



10055
10056
10057
# File 'lib/models/porcelain.rb', line 10055

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



10057
10058
10059
# File 'lib/models/porcelain.rb', line 10057

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



10059
10060
10061
# File 'lib/models/porcelain.rb', line 10059

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



10061
10062
10063
# File 'lib/models/porcelain.rb', line 10061

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



10063
10064
10065
# File 'lib/models/porcelain.rb', line 10063

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10065
10066
10067
# File 'lib/models/porcelain.rb', line 10065

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



10067
10068
10069
# File 'lib/models/porcelain.rb', line 10067

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



10069
10070
10071
# File 'lib/models/porcelain.rb', line 10069

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10071
10072
10073
# File 'lib/models/porcelain.rb', line 10071

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



10073
10074
10075
# File 'lib/models/porcelain.rb', line 10073

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



10075
10076
10077
# File 'lib/models/porcelain.rb', line 10075

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10111
10112
10113
10114
10115
10116
10117
# File 'lib/models/porcelain.rb', line 10111

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end