Class: SDM::KubernetesPodIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesPodIdentity

Returns a new instance of KubernetesPodIdentity.



7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
7259
7260
7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
# File 'lib/models/porcelain.rb', line 7248

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  certificate_authority: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



7218
7219
7220
# File 'lib/models/porcelain.rb', line 7218

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7220
7221
7222
# File 'lib/models/porcelain.rb', line 7220

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7222
7223
7224
# File 'lib/models/porcelain.rb', line 7222

def certificate_authority
  @certificate_authority
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7224
7225
7226
# File 'lib/models/porcelain.rb', line 7224

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7226
7227
7228
# File 'lib/models/porcelain.rb', line 7226

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7228
7229
7230
# File 'lib/models/porcelain.rb', line 7228

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7230
7231
7232
# File 'lib/models/porcelain.rb', line 7230

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



7232
7233
7234
# File 'lib/models/porcelain.rb', line 7232

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



7234
7235
7236
# File 'lib/models/porcelain.rb', line 7234

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



7236
7237
7238
# File 'lib/models/porcelain.rb', line 7236

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource.



7238
7239
7240
# File 'lib/models/porcelain.rb', line 7238

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7240
7241
7242
# File 'lib/models/porcelain.rb', line 7240

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7242
7243
7244
# File 'lib/models/porcelain.rb', line 7242

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7244
7245
7246
# File 'lib/models/porcelain.rb', line 7244

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7246
7247
7248
# File 'lib/models/porcelain.rb', line 7246

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7282
7283
7284
7285
7286
7287
7288
# File 'lib/models/porcelain.rb', line 7282

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end