Class: SDM::KubernetesPodIdentity
- Inherits:
-
Object
- Object
- SDM::KubernetesPodIdentity
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
-
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesPodIdentity
constructor
A new instance of KubernetesPodIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesPodIdentity
Returns a new instance of KubernetesPodIdentity.
10158 10159 10160 10161 10162 10163 10164 10165 10166 10167 10168 10169 10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 |
# File 'lib/models/porcelain.rb', line 10158 def initialize( allow_resource_role_bypass: nil, bind_interface: nil, certificate_authority: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled @discovery_username = discovery_username == nil ? "" : discovery_username @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
10123 10124 10125 |
# File 'lib/models/porcelain.rb', line 10123 def allow_resource_role_bypass @allow_resource_role_bypass end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
10125 10126 10127 |
# File 'lib/models/porcelain.rb', line 10125 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
10127 10128 10129 |
# File 'lib/models/porcelain.rb', line 10127 def @certificate_authority end |
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
10129 10130 10131 |
# File 'lib/models/porcelain.rb', line 10129 def discovery_enabled @discovery_enabled end |
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
10132 10133 10134 |
# File 'lib/models/porcelain.rb', line 10132 def discovery_username @discovery_username end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10134 10135 10136 |
# File 'lib/models/porcelain.rb', line 10134 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
10136 10137 10138 |
# File 'lib/models/porcelain.rb', line 10136 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10138 10139 10140 |
# File 'lib/models/porcelain.rb', line 10138 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
10140 10141 10142 |
# File 'lib/models/porcelain.rb', line 10140 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
10142 10143 10144 |
# File 'lib/models/porcelain.rb', line 10142 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
10144 10145 10146 |
# File 'lib/models/porcelain.rb', line 10144 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10146 10147 10148 |
# File 'lib/models/porcelain.rb', line 10146 def name @name end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
10148 10149 10150 |
# File 'lib/models/porcelain.rb', line 10148 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10150 10151 10152 |
# File 'lib/models/porcelain.rb', line 10150 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10152 10153 10154 |
# File 'lib/models/porcelain.rb', line 10152 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
10154 10155 10156 |
# File 'lib/models/porcelain.rb', line 10154 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10156 10157 10158 |
# File 'lib/models/porcelain.rb', line 10156 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10196 10197 10198 10199 10200 10201 10202 |
# File 'lib/models/porcelain.rb', line 10196 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |