Class: SDM::KubernetesServiceAccount
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccount
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
-
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
The API token to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount
constructor
A new instance of KubernetesServiceAccount.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount
Returns a new instance of KubernetesServiceAccount.
7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 |
# File 'lib/models/porcelain.rb', line 7905 def initialize( allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil ) @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass @bind_interface = bind_interface == nil ? "" : bind_interface @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled @discovery_username = discovery_username == nil ? "" : discovery_username @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
7866 7867 7868 |
# File 'lib/models/porcelain.rb', line 7866 def allow_resource_role_bypass @allow_resource_role_bypass end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7868 7869 7870 |
# File 'lib/models/porcelain.rb', line 7868 def bind_interface @bind_interface end |
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
7870 7871 7872 |
# File 'lib/models/porcelain.rb', line 7870 def discovery_enabled @discovery_enabled end |
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
7873 7874 7875 |
# File 'lib/models/porcelain.rb', line 7873 def discovery_username @discovery_username end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7875 7876 7877 |
# File 'lib/models/porcelain.rb', line 7875 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
7877 7878 7879 |
# File 'lib/models/porcelain.rb', line 7877 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7879 7880 7881 |
# File 'lib/models/porcelain.rb', line 7879 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7881 7882 7883 |
# File 'lib/models/porcelain.rb', line 7881 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7883 7884 7885 |
# File 'lib/models/porcelain.rb', line 7883 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
7885 7886 7887 |
# File 'lib/models/porcelain.rb', line 7885 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
7887 7888 7889 |
# File 'lib/models/porcelain.rb', line 7887 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7889 7890 7891 |
# File 'lib/models/porcelain.rb', line 7889 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7891 7892 7893 |
# File 'lib/models/porcelain.rb', line 7891 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7893 7894 7895 |
# File 'lib/models/porcelain.rb', line 7893 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7895 7896 7897 |
# File 'lib/models/porcelain.rb', line 7895 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7897 7898 7899 |
# File 'lib/models/porcelain.rb', line 7897 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7899 7900 7901 |
# File 'lib/models/porcelain.rb', line 7899 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7901 7902 7903 |
# File 'lib/models/porcelain.rb', line 7901 def @tags end |
#token ⇒ Object
The API token to authenticate with.
7903 7904 7905 |
# File 'lib/models/porcelain.rb', line 7903 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7947 7948 7949 7950 7951 7952 7953 |
# File 'lib/models/porcelain.rb', line 7947 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |