Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
7939
7940
7941
7942
# File 'lib/models/porcelain.rb', line 7902

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



7863
7864
7865
# File 'lib/models/porcelain.rb', line 7863

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7865
7866
7867
# File 'lib/models/porcelain.rb', line 7865

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



7867
7868
7869
# File 'lib/models/porcelain.rb', line 7867

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



7870
7871
7872
# File 'lib/models/porcelain.rb', line 7870

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7872
7873
7874
# File 'lib/models/porcelain.rb', line 7872

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7874
7875
7876
# File 'lib/models/porcelain.rb', line 7874

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7876
7877
7878
# File 'lib/models/porcelain.rb', line 7876

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7878
7879
7880
# File 'lib/models/porcelain.rb', line 7878

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7880
7881
7882
# File 'lib/models/porcelain.rb', line 7880

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



7882
7883
7884
# File 'lib/models/porcelain.rb', line 7882

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



7884
7885
7886
# File 'lib/models/porcelain.rb', line 7884

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



7886
7887
7888
# File 'lib/models/porcelain.rb', line 7886

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7888
7889
7890
# File 'lib/models/porcelain.rb', line 7888

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7890
7891
7892
# File 'lib/models/porcelain.rb', line 7890

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7892
7893
7894
# File 'lib/models/porcelain.rb', line 7892

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7894
7895
7896
# File 'lib/models/porcelain.rb', line 7894

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7896
7897
7898
# File 'lib/models/porcelain.rb', line 7896

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7898
7899
7900
# File 'lib/models/porcelain.rb', line 7898

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



7900
7901
7902
# File 'lib/models/porcelain.rb', line 7900

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7944
7945
7946
7947
7948
7949
7950
# File 'lib/models/porcelain.rb', line 7944

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end