Class: SDM::KubernetesServiceAccount
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccount
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
-
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
The API token to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount
constructor
A new instance of KubernetesServiceAccount.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount
Returns a new instance of KubernetesServiceAccount.
7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 7622 7623 7624 7625 7626 |
# File 'lib/models/porcelain.rb', line 7586 def initialize( allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil ) @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass @bind_interface = bind_interface == nil ? "" : bind_interface @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled @discovery_username = discovery_username == nil ? "" : discovery_username @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#allow_resource_role_bypass ⇒ Object
If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.
7547 7548 7549 |
# File 'lib/models/porcelain.rb', line 7547 def allow_resource_role_bypass @allow_resource_role_bypass end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7549 7550 7551 |
# File 'lib/models/porcelain.rb', line 7549 def bind_interface @bind_interface end |
#discovery_enabled ⇒ Object
If true, configures discovery of a cluster to be run from a node.
7551 7552 7553 |
# File 'lib/models/porcelain.rb', line 7551 def discovery_enabled @discovery_enabled end |
#discovery_username ⇒ Object
If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.
7554 7555 7556 |
# File 'lib/models/porcelain.rb', line 7554 def discovery_username @discovery_username end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7556 7557 7558 |
# File 'lib/models/porcelain.rb', line 7556 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
7558 7559 7560 |
# File 'lib/models/porcelain.rb', line 7558 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7560 7561 7562 |
# File 'lib/models/porcelain.rb', line 7560 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7562 7563 7564 |
# File 'lib/models/porcelain.rb', line 7562 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7564 7565 7566 |
# File 'lib/models/porcelain.rb', line 7564 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
7566 7567 7568 |
# File 'lib/models/porcelain.rb', line 7566 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
7568 7569 7570 |
# File 'lib/models/porcelain.rb', line 7568 def identity_set_id @identity_set_id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7570 7571 7572 |
# File 'lib/models/porcelain.rb', line 7570 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7572 7573 7574 |
# File 'lib/models/porcelain.rb', line 7572 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7574 7575 7576 |
# File 'lib/models/porcelain.rb', line 7574 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7576 7577 7578 |
# File 'lib/models/porcelain.rb', line 7576 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7578 7579 7580 |
# File 'lib/models/porcelain.rb', line 7578 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7580 7581 7582 |
# File 'lib/models/porcelain.rb', line 7580 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7582 7583 7584 |
# File 'lib/models/porcelain.rb', line 7582 def @tags end |
#token ⇒ Object
The API token to authenticate with.
7584 7585 7586 |
# File 'lib/models/porcelain.rb', line 7584 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7628 7629 7630 7631 7632 7633 7634 |
# File 'lib/models/porcelain.rb', line 7628 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |