Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
# File 'lib/models/porcelain.rb', line 7333

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



7294
7295
7296
# File 'lib/models/porcelain.rb', line 7294

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7296
7297
7298
# File 'lib/models/porcelain.rb', line 7296

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



7298
7299
7300
# File 'lib/models/porcelain.rb', line 7298

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



7301
7302
7303
# File 'lib/models/porcelain.rb', line 7301

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7303
7304
7305
# File 'lib/models/porcelain.rb', line 7303

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7305
7306
7307
# File 'lib/models/porcelain.rb', line 7305

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7307
7308
7309
# File 'lib/models/porcelain.rb', line 7307

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7309
7310
7311
# File 'lib/models/porcelain.rb', line 7309

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7311
7312
7313
# File 'lib/models/porcelain.rb', line 7311

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



7313
7314
7315
# File 'lib/models/porcelain.rb', line 7313

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



7315
7316
7317
# File 'lib/models/porcelain.rb', line 7315

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



7317
7318
7319
# File 'lib/models/porcelain.rb', line 7317

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7319
7320
7321
# File 'lib/models/porcelain.rb', line 7319

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7321
7322
7323
# File 'lib/models/porcelain.rb', line 7321

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7323
7324
7325
# File 'lib/models/porcelain.rb', line 7323

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7325
7326
7327
# File 'lib/models/porcelain.rb', line 7325

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7327
7328
7329
# File 'lib/models/porcelain.rb', line 7327

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7329
7330
7331
# File 'lib/models/porcelain.rb', line 7329

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



7331
7332
7333
# File 'lib/models/porcelain.rb', line 7331

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7375
7376
7377
7378
7379
7380
7381
# File 'lib/models/porcelain.rb', line 7375

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end