Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



7255
7256
7257
7258
7259
7260
7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
# File 'lib/models/porcelain.rb', line 7255

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



7216
7217
7218
# File 'lib/models/porcelain.rb', line 7216

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7218
7219
7220
# File 'lib/models/porcelain.rb', line 7218

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



7220
7221
7222
# File 'lib/models/porcelain.rb', line 7220

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



7223
7224
7225
# File 'lib/models/porcelain.rb', line 7223

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7225
7226
7227
# File 'lib/models/porcelain.rb', line 7225

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7227
7228
7229
# File 'lib/models/porcelain.rb', line 7227

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7229
7230
7231
# File 'lib/models/porcelain.rb', line 7229

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7231
7232
7233
# File 'lib/models/porcelain.rb', line 7231

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7233
7234
7235
# File 'lib/models/porcelain.rb', line 7233

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



7235
7236
7237
# File 'lib/models/porcelain.rb', line 7235

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



7237
7238
7239
# File 'lib/models/porcelain.rb', line 7237

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



7239
7240
7241
# File 'lib/models/porcelain.rb', line 7239

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7241
7242
7243
# File 'lib/models/porcelain.rb', line 7241

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7243
7244
7245
# File 'lib/models/porcelain.rb', line 7243

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7245
7246
7247
# File 'lib/models/porcelain.rb', line 7245

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7247
7248
7249
# File 'lib/models/porcelain.rb', line 7247

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7249
7250
7251
# File 'lib/models/porcelain.rb', line 7249

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7251
7252
7253
# File 'lib/models/porcelain.rb', line 7251

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



7253
7254
7255
# File 'lib/models/porcelain.rb', line 7253

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7297
7298
7299
7300
7301
7302
7303
# File 'lib/models/porcelain.rb', line 7297

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end