Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
7218
7219
# File 'lib/models/porcelain.rb', line 7179

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



7140
7141
7142
# File 'lib/models/porcelain.rb', line 7140

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7142
7143
7144
# File 'lib/models/porcelain.rb', line 7142

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



7144
7145
7146
# File 'lib/models/porcelain.rb', line 7144

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



7147
7148
7149
# File 'lib/models/porcelain.rb', line 7147

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7149
7150
7151
# File 'lib/models/porcelain.rb', line 7149

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7151
7152
7153
# File 'lib/models/porcelain.rb', line 7151

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7153
7154
7155
# File 'lib/models/porcelain.rb', line 7153

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7155
7156
7157
# File 'lib/models/porcelain.rb', line 7155

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7157
7158
7159
# File 'lib/models/porcelain.rb', line 7157

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



7159
7160
7161
# File 'lib/models/porcelain.rb', line 7159

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



7161
7162
7163
# File 'lib/models/porcelain.rb', line 7161

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



7163
7164
7165
# File 'lib/models/porcelain.rb', line 7163

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7165
7166
7167
# File 'lib/models/porcelain.rb', line 7165

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7167
7168
7169
# File 'lib/models/porcelain.rb', line 7167

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7169
7170
7171
# File 'lib/models/porcelain.rb', line 7169

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7171
7172
7173
# File 'lib/models/porcelain.rb', line 7171

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7173
7174
7175
# File 'lib/models/porcelain.rb', line 7173

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7175
7176
7177
# File 'lib/models/porcelain.rb', line 7175

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



7177
7178
7179
# File 'lib/models/porcelain.rb', line 7177

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7221
7222
7223
7224
7225
7226
7227
# File 'lib/models/porcelain.rb', line 7221

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end