Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
# File 'lib/models/porcelain.rb', line 6168

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



6131
6132
6133
# File 'lib/models/porcelain.rb', line 6131

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6133
6134
6135
# File 'lib/models/porcelain.rb', line 6133

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



6135
6136
6137
# File 'lib/models/porcelain.rb', line 6135

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



6138
6139
6140
# File 'lib/models/porcelain.rb', line 6138

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6140
6141
6142
# File 'lib/models/porcelain.rb', line 6140

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6142
6143
6144
# File 'lib/models/porcelain.rb', line 6142

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6144
6145
6146
# File 'lib/models/porcelain.rb', line 6144

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6146
6147
6148
# File 'lib/models/porcelain.rb', line 6146

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6148
6149
6150
# File 'lib/models/porcelain.rb', line 6148

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



6150
6151
6152
# File 'lib/models/porcelain.rb', line 6150

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



6152
6153
6154
# File 'lib/models/porcelain.rb', line 6152

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



6154
6155
6156
# File 'lib/models/porcelain.rb', line 6154

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6156
6157
6158
# File 'lib/models/porcelain.rb', line 6156

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6158
6159
6160
# File 'lib/models/porcelain.rb', line 6158

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6160
6161
6162
# File 'lib/models/porcelain.rb', line 6160

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6162
6163
6164
# File 'lib/models/porcelain.rb', line 6162

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6164
6165
6166
# File 'lib/models/porcelain.rb', line 6164

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



6166
6167
6168
# File 'lib/models/porcelain.rb', line 6166

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6208
6209
6210
6211
6212
6213
6214
# File 'lib/models/porcelain.rb', line 6208

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end