Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
# File 'lib/models/porcelain.rb', line 4765

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4735
4736
4737
# File 'lib/models/porcelain.rb', line 4735

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4737
4738
4739
# File 'lib/models/porcelain.rb', line 4737

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4739
4740
4741
# File 'lib/models/porcelain.rb', line 4739

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4741
4742
4743
# File 'lib/models/porcelain.rb', line 4741

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4743
4744
4745
# File 'lib/models/porcelain.rb', line 4743

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4745
4746
4747
# File 'lib/models/porcelain.rb', line 4745

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4747
4748
4749
# File 'lib/models/porcelain.rb', line 4747

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4749
4750
4751
# File 'lib/models/porcelain.rb', line 4749

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4751
4752
4753
# File 'lib/models/porcelain.rb', line 4751

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



4753
4754
4755
# File 'lib/models/porcelain.rb', line 4753

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



4755
4756
4757
# File 'lib/models/porcelain.rb', line 4755

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4757
4758
4759
# File 'lib/models/porcelain.rb', line 4757

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4759
4760
4761
# File 'lib/models/porcelain.rb', line 4759

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4761
4762
4763
# File 'lib/models/porcelain.rb', line 4761

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



4763
4764
4765
# File 'lib/models/porcelain.rb', line 4763

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4799
4800
4801
4802
4803
4804
4805
# File 'lib/models/porcelain.rb', line 4799

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end