Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



4614
4615
4616
4617
4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
4637
4638
4639
4640
4641
4642
4643
4644
4645
4646
# File 'lib/models/porcelain.rb', line 4614

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4584
4585
4586
# File 'lib/models/porcelain.rb', line 4584

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4586
4587
4588
# File 'lib/models/porcelain.rb', line 4586

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4588
4589
4590
# File 'lib/models/porcelain.rb', line 4588

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4590
4591
4592
# File 'lib/models/porcelain.rb', line 4590

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4592
4593
4594
# File 'lib/models/porcelain.rb', line 4592

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4594
4595
4596
# File 'lib/models/porcelain.rb', line 4594

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4596
4597
4598
# File 'lib/models/porcelain.rb', line 4596

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4598
4599
4600
# File 'lib/models/porcelain.rb', line 4598

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4600
4601
4602
# File 'lib/models/porcelain.rb', line 4600

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



4602
4603
4604
# File 'lib/models/porcelain.rb', line 4602

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



4604
4605
4606
# File 'lib/models/porcelain.rb', line 4604

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4606
4607
4608
# File 'lib/models/porcelain.rb', line 4606

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4608
4609
4610
# File 'lib/models/porcelain.rb', line 4608

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4610
4611
4612
# File 'lib/models/porcelain.rb', line 4610

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



4612
4613
4614
# File 'lib/models/porcelain.rb', line 4612

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4648
4649
4650
4651
4652
4653
4654
# File 'lib/models/porcelain.rb', line 4648

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end