Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
4466
4467
4468
4469
4470
4471
4472
4473
4474
# File 'lib/models/porcelain.rb', line 4442

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4412
4413
4414
# File 'lib/models/porcelain.rb', line 4412

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4414
4415
4416
# File 'lib/models/porcelain.rb', line 4414

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4416
4417
4418
# File 'lib/models/porcelain.rb', line 4416

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4418
4419
4420
# File 'lib/models/porcelain.rb', line 4418

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4420
4421
4422
# File 'lib/models/porcelain.rb', line 4420

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4422
4423
4424
# File 'lib/models/porcelain.rb', line 4422

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4424
4425
4426
# File 'lib/models/porcelain.rb', line 4424

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4426
4427
4428
# File 'lib/models/porcelain.rb', line 4426

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4428
4429
4430
# File 'lib/models/porcelain.rb', line 4428

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



4430
4431
4432
# File 'lib/models/porcelain.rb', line 4430

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



4432
4433
4434
# File 'lib/models/porcelain.rb', line 4432

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4434
4435
4436
# File 'lib/models/porcelain.rb', line 4434

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4436
4437
4438
# File 'lib/models/porcelain.rb', line 4436

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4438
4439
4440
# File 'lib/models/porcelain.rb', line 4438

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



4440
4441
4442
# File 'lib/models/porcelain.rb', line 4440

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4476
4477
4478
4479
4480
4481
4482
# File 'lib/models/porcelain.rb', line 4476

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end