Class: SDM::KubernetesServiceAccount
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccount
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
-
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
Returns the value of attribute token.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount
constructor
A new instance of KubernetesServiceAccount.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount
Returns a new instance of KubernetesServiceAccount.
4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 |
# File 'lib/models/porcelain.rb', line 4327 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4297 4298 4299 |
# File 'lib/models/porcelain.rb', line 4297 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4299 4300 4301 |
# File 'lib/models/porcelain.rb', line 4299 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
4301 4302 4303 |
# File 'lib/models/porcelain.rb', line 4301 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4303 4304 4305 |
# File 'lib/models/porcelain.rb', line 4303 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4305 4306 4307 |
# File 'lib/models/porcelain.rb', line 4305 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4307 4308 4309 |
# File 'lib/models/porcelain.rb', line 4307 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4309 4310 4311 |
# File 'lib/models/porcelain.rb', line 4309 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4311 4312 4313 |
# File 'lib/models/porcelain.rb', line 4311 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4313 4314 4315 |
# File 'lib/models/porcelain.rb', line 4313 def port_override @port_override end |
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
4315 4316 4317 |
# File 'lib/models/porcelain.rb', line 4315 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
4317 4318 4319 |
# File 'lib/models/porcelain.rb', line 4317 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4319 4320 4321 |
# File 'lib/models/porcelain.rb', line 4319 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4321 4322 4323 |
# File 'lib/models/porcelain.rb', line 4321 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4323 4324 4325 |
# File 'lib/models/porcelain.rb', line 4323 def @tags end |
#token ⇒ Object
Returns the value of attribute token.
4325 4326 4327 |
# File 'lib/models/porcelain.rb', line 4325 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4361 4362 4363 4364 4365 4366 4367 |
# File 'lib/models/porcelain.rb', line 4361 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |