Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
4317
4318
4319
4320
4321
4322
4323
4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
4335
# File 'lib/models/porcelain.rb', line 4303

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4273
4274
4275
# File 'lib/models/porcelain.rb', line 4273

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4275
4276
4277
# File 'lib/models/porcelain.rb', line 4275

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4277
4278
4279
# File 'lib/models/porcelain.rb', line 4277

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4279
4280
4281
# File 'lib/models/porcelain.rb', line 4279

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4281
4282
4283
# File 'lib/models/porcelain.rb', line 4281

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4283
4284
4285
# File 'lib/models/porcelain.rb', line 4283

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4285
4286
4287
# File 'lib/models/porcelain.rb', line 4285

def name
  @name
end

#portObject

Returns the value of attribute port.



4287
4288
4289
# File 'lib/models/porcelain.rb', line 4287

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4289
4290
4291
# File 'lib/models/porcelain.rb', line 4289

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



4291
4292
4293
# File 'lib/models/porcelain.rb', line 4291

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



4293
4294
4295
# File 'lib/models/porcelain.rb', line 4293

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4295
4296
4297
# File 'lib/models/porcelain.rb', line 4295

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4297
4298
4299
# File 'lib/models/porcelain.rb', line 4297

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4299
4300
4301
# File 'lib/models/porcelain.rb', line 4299

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



4301
4302
4303
# File 'lib/models/porcelain.rb', line 4301

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4337
4338
4339
4340
4341
4342
4343
# File 'lib/models/porcelain.rb', line 4337

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end