Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
# File 'lib/models/porcelain.rb', line 3999

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3971
3972
3973
# File 'lib/models/porcelain.rb', line 3971

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3973
3974
3975
# File 'lib/models/porcelain.rb', line 3973

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3975
3976
3977
# File 'lib/models/porcelain.rb', line 3975

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3977
3978
3979
# File 'lib/models/porcelain.rb', line 3977

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3979
3980
3981
# File 'lib/models/porcelain.rb', line 3979

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3981
3982
3983
# File 'lib/models/porcelain.rb', line 3981

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3983
3984
3985
# File 'lib/models/porcelain.rb', line 3983

def name
  @name
end

#portObject

Returns the value of attribute port.



3985
3986
3987
# File 'lib/models/porcelain.rb', line 3985

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3987
3988
3989
# File 'lib/models/porcelain.rb', line 3987

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3989
3990
3991
# File 'lib/models/porcelain.rb', line 3989

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3991
3992
3993
# File 'lib/models/porcelain.rb', line 3991

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3993
3994
3995
# File 'lib/models/porcelain.rb', line 3993

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3995
3996
3997
# File 'lib/models/porcelain.rb', line 3995

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



3997
3998
3999
# File 'lib/models/porcelain.rb', line 3997

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4031
4032
4033
4034
4035
4036
4037
# File 'lib/models/porcelain.rb', line 4031

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end