Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



3661
3662
3663
3664
3665
3666
3667
3668
3669
3670
3671
3672
3673
3674
3675
3676
3677
3678
3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
# File 'lib/models/porcelain.rb', line 3661

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3633
3634
3635
# File 'lib/models/porcelain.rb', line 3633

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3635
3636
3637
# File 'lib/models/porcelain.rb', line 3635

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3637
3638
3639
# File 'lib/models/porcelain.rb', line 3637

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3639
3640
3641
# File 'lib/models/porcelain.rb', line 3639

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3641
3642
3643
# File 'lib/models/porcelain.rb', line 3641

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3643
3644
3645
# File 'lib/models/porcelain.rb', line 3643

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3645
3646
3647
# File 'lib/models/porcelain.rb', line 3645

def name
  @name
end

#portObject

Returns the value of attribute port.



3647
3648
3649
# File 'lib/models/porcelain.rb', line 3647

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3649
3650
3651
# File 'lib/models/porcelain.rb', line 3649

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3651
3652
3653
# File 'lib/models/porcelain.rb', line 3651

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3653
3654
3655
# File 'lib/models/porcelain.rb', line 3653

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3655
3656
3657
# File 'lib/models/porcelain.rb', line 3655

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3657
3658
3659
# File 'lib/models/porcelain.rb', line 3657

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



3659
3660
3661
# File 'lib/models/porcelain.rb', line 3659

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3693
3694
3695
3696
3697
3698
3699
# File 'lib/models/porcelain.rb', line 3693

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end