Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



3662
3663
3664
3665
3666
3667
3668
3669
3670
3671
3672
3673
3674
3675
3676
3677
3678
3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
# File 'lib/models/porcelain.rb', line 3662

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3634
3635
3636
# File 'lib/models/porcelain.rb', line 3634

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3636
3637
3638
# File 'lib/models/porcelain.rb', line 3636

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3638
3639
3640
# File 'lib/models/porcelain.rb', line 3638

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3640
3641
3642
# File 'lib/models/porcelain.rb', line 3640

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3642
3643
3644
# File 'lib/models/porcelain.rb', line 3642

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3644
3645
3646
# File 'lib/models/porcelain.rb', line 3644

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3646
3647
3648
# File 'lib/models/porcelain.rb', line 3646

def name
  @name
end

#portObject

Returns the value of attribute port.



3648
3649
3650
# File 'lib/models/porcelain.rb', line 3648

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3650
3651
3652
# File 'lib/models/porcelain.rb', line 3650

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3652
3653
3654
# File 'lib/models/porcelain.rb', line 3652

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3654
3655
3656
# File 'lib/models/porcelain.rb', line 3654

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3656
3657
3658
# File 'lib/models/porcelain.rb', line 3656

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3658
3659
3660
# File 'lib/models/porcelain.rb', line 3658

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



3660
3661
3662
# File 'lib/models/porcelain.rb', line 3660

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3694
3695
3696
3697
3698
3699
3700
# File 'lib/models/porcelain.rb', line 3694

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end