Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
# File 'lib/models/porcelain.rb', line 3554

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3526
3527
3528
# File 'lib/models/porcelain.rb', line 3526

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3528
3529
3530
# File 'lib/models/porcelain.rb', line 3528

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3530
3531
3532
# File 'lib/models/porcelain.rb', line 3530

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3532
3533
3534
# File 'lib/models/porcelain.rb', line 3532

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3534
3535
3536
# File 'lib/models/porcelain.rb', line 3534

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3536
3537
3538
# File 'lib/models/porcelain.rb', line 3536

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3538
3539
3540
# File 'lib/models/porcelain.rb', line 3538

def name
  @name
end

#portObject

Returns the value of attribute port.



3540
3541
3542
# File 'lib/models/porcelain.rb', line 3540

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3542
3543
3544
# File 'lib/models/porcelain.rb', line 3542

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



3544
3545
3546
# File 'lib/models/porcelain.rb', line 3544

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



3546
3547
3548
# File 'lib/models/porcelain.rb', line 3546

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3548
3549
3550
# File 'lib/models/porcelain.rb', line 3548

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3550
3551
3552
# File 'lib/models/porcelain.rb', line 3550

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



3552
3553
3554
# File 'lib/models/porcelain.rb', line 3552

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3586
3587
3588
3589
3590
3591
3592
# File 'lib/models/porcelain.rb', line 3586

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end