Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
# File 'lib/models/porcelain.rb', line 3930

def initialize(
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthcheck_namespace != nil
    @healthcheck_namespace = healthcheck_namespace
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if port != nil
    @port = port
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
  if token != nil
    @token = token
  end
end

Instance Attribute Details

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3910
3911
3912
# File 'lib/models/porcelain.rb', line 3910

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to `default`.



3912
3913
3914
# File 'lib/models/porcelain.rb', line 3912

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3914
3915
3916
# File 'lib/models/porcelain.rb', line 3914

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3916
3917
3918
# File 'lib/models/porcelain.rb', line 3916

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3918
3919
3920
# File 'lib/models/porcelain.rb', line 3918

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3920
3921
3922
# File 'lib/models/porcelain.rb', line 3920

def name
  @name
end

#portObject

Returns the value of attribute port.



3922
3923
3924
# File 'lib/models/porcelain.rb', line 3922

def port
  @port
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3924
3925
3926
# File 'lib/models/porcelain.rb', line 3924

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3926
3927
3928
# File 'lib/models/porcelain.rb', line 3926

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



3928
3929
3930
# File 'lib/models/porcelain.rb', line 3928

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3974
3975
3976
3977
3978
3979
3980
# File 'lib/models/porcelain.rb', line 3974

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end