Class: SDM::KubernetesServiceAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_resource_role_bypass: nil, bind_interface: nil, discovery_enabled: nil, discovery_username: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccount

Returns a new instance of KubernetesServiceAccount.



10085
10086
10087
10088
10089
10090
10091
10092
10093
10094
10095
10096
10097
10098
10099
10100
10101
10102
10103
10104
10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
# File 'lib/models/porcelain.rb', line 10085

def initialize(
  allow_resource_role_bypass: nil,
  bind_interface: nil,
  discovery_enabled: nil,
  discovery_username: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @allow_resource_role_bypass = allow_resource_role_bypass == nil ? false : allow_resource_role_bypass
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @discovery_username = discovery_username == nil ? "" : discovery_username
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#allow_resource_role_bypassObject

If true, allows users to fallback to the existing authentication mode (Leased Credential or Identity Set) when a resource role is not provided.



10046
10047
10048
# File 'lib/models/porcelain.rb', line 10046

def allow_resource_role_bypass
  @allow_resource_role_bypass
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10048
10049
10050
# File 'lib/models/porcelain.rb', line 10048

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of a cluster to be run from a node.



10050
10051
10052
# File 'lib/models/porcelain.rb', line 10050

def discovery_enabled
  @discovery_enabled
end

#discovery_usernameObject

If a cluster is configured for user impersonation, this is the user to impersonate when running discovery.



10053
10054
10055
# File 'lib/models/porcelain.rb', line 10053

def discovery_username
  @discovery_username
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10055
10056
10057
# File 'lib/models/porcelain.rb', line 10055

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



10057
10058
10059
# File 'lib/models/porcelain.rb', line 10057

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10059
10060
10061
# File 'lib/models/porcelain.rb', line 10059

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10061
10062
10063
# File 'lib/models/porcelain.rb', line 10061

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10063
10064
10065
# File 'lib/models/porcelain.rb', line 10063

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



10065
10066
10067
# File 'lib/models/porcelain.rb', line 10065

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



10067
10068
10069
# File 'lib/models/porcelain.rb', line 10067

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



10069
10070
10071
# File 'lib/models/porcelain.rb', line 10069

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10071
10072
10073
# File 'lib/models/porcelain.rb', line 10071

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10073
10074
10075
# File 'lib/models/porcelain.rb', line 10073

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10075
10076
10077
# File 'lib/models/porcelain.rb', line 10075

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10077
10078
10079
# File 'lib/models/porcelain.rb', line 10077

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10079
10080
10081
# File 'lib/models/porcelain.rb', line 10079

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10081
10082
10083
# File 'lib/models/porcelain.rb', line 10081

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



10083
10084
10085
# File 'lib/models/porcelain.rb', line 10083

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10127
10128
10129
10130
10131
10132
10133
# File 'lib/models/porcelain.rb', line 10127

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end