Class: SDM::KubernetesServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Overview
KubernetesServiceAccountUserImpersonation is deprecated, see docs for more info.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
The API token to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
constructor
A new instance of KubernetesServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
Returns a new instance of KubernetesServiceAccountUserImpersonation.
10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 10269 10270 10271 10272 10273 10274 10275 10276 10277 10278 10279 10280 10281 10282 10283 |
# File 'lib/models/porcelain.rb', line 10253 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
10225 10226 10227 |
# File 'lib/models/porcelain.rb', line 10225 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10227 10228 10229 |
# File 'lib/models/porcelain.rb', line 10227 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
10229 10230 10231 |
# File 'lib/models/porcelain.rb', line 10229 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10231 10232 10233 |
# File 'lib/models/porcelain.rb', line 10231 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10233 10234 10235 |
# File 'lib/models/porcelain.rb', line 10233 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10235 10236 10237 |
# File 'lib/models/porcelain.rb', line 10235 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10237 10238 10239 |
# File 'lib/models/porcelain.rb', line 10237 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10239 10240 10241 |
# File 'lib/models/porcelain.rb', line 10239 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
10241 10242 10243 |
# File 'lib/models/porcelain.rb', line 10241 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10243 10244 10245 |
# File 'lib/models/porcelain.rb', line 10243 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10245 10246 10247 |
# File 'lib/models/porcelain.rb', line 10245 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
10247 10248 10249 |
# File 'lib/models/porcelain.rb', line 10247 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10249 10250 10251 |
# File 'lib/models/porcelain.rb', line 10249 def @tags end |
#token ⇒ Object
The API token to authenticate with.
10251 10252 10253 |
# File 'lib/models/porcelain.rb', line 10251 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10285 10286 10287 10288 10289 10290 10291 |
# File 'lib/models/porcelain.rb', line 10285 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |