Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesServiceAccountUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
# File 'lib/models/porcelain.rb', line 10015

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9987
9988
9989
# File 'lib/models/porcelain.rb', line 9987

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9989
9990
9991
# File 'lib/models/porcelain.rb', line 9989

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



9991
9992
9993
# File 'lib/models/porcelain.rb', line 9991

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9993
9994
9995
# File 'lib/models/porcelain.rb', line 9993

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9995
9996
9997
# File 'lib/models/porcelain.rb', line 9995

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9997
9998
9999
# File 'lib/models/porcelain.rb', line 9997

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9999
10000
10001
# File 'lib/models/porcelain.rb', line 9999

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10001
10002
10003
# File 'lib/models/porcelain.rb', line 10001

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10003
10004
10005
# File 'lib/models/porcelain.rb', line 10003

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10005
10006
10007
# File 'lib/models/porcelain.rb', line 10005

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10007
10008
10009
# File 'lib/models/porcelain.rb', line 10007

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10009
10010
10011
# File 'lib/models/porcelain.rb', line 10009

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10011
10012
10013
# File 'lib/models/porcelain.rb', line 10011

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



10013
10014
10015
# File 'lib/models/porcelain.rb', line 10013

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10047
10048
10049
10050
10051
10052
10053
# File 'lib/models/porcelain.rb', line 10047

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end