Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesServiceAccountUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



9028
9029
9030
9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
# File 'lib/models/porcelain.rb', line 9028

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



9000
9001
9002
# File 'lib/models/porcelain.rb', line 9000

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9002
9003
9004
# File 'lib/models/porcelain.rb', line 9002

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



9004
9005
9006
# File 'lib/models/porcelain.rb', line 9004

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9006
9007
9008
# File 'lib/models/porcelain.rb', line 9006

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9008
9009
9010
# File 'lib/models/porcelain.rb', line 9008

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9010
9011
9012
# File 'lib/models/porcelain.rb', line 9010

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9012
9013
9014
# File 'lib/models/porcelain.rb', line 9012

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9014
9015
9016
# File 'lib/models/porcelain.rb', line 9014

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



9016
9017
9018
# File 'lib/models/porcelain.rb', line 9016

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9018
9019
9020
# File 'lib/models/porcelain.rb', line 9018

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9020
9021
9022
# File 'lib/models/porcelain.rb', line 9020

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



9022
9023
9024
# File 'lib/models/porcelain.rb', line 9022

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9024
9025
9026
# File 'lib/models/porcelain.rb', line 9024

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



9026
9027
9028
# File 'lib/models/porcelain.rb', line 9026

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9060
9061
9062
9063
9064
9065
9066
# File 'lib/models/porcelain.rb', line 9060

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end