Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesServiceAccountUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



8162
8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
8187
8188
8189
8190
8191
8192
# File 'lib/models/porcelain.rb', line 8162

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8134
8135
8136
# File 'lib/models/porcelain.rb', line 8134

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8136
8137
8138
# File 'lib/models/porcelain.rb', line 8136

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



8138
8139
8140
# File 'lib/models/porcelain.rb', line 8138

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8140
8141
8142
# File 'lib/models/porcelain.rb', line 8140

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8142
8143
8144
# File 'lib/models/porcelain.rb', line 8142

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8144
8145
8146
# File 'lib/models/porcelain.rb', line 8144

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8146
8147
8148
# File 'lib/models/porcelain.rb', line 8146

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8148
8149
8150
# File 'lib/models/porcelain.rb', line 8148

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8150
8151
8152
# File 'lib/models/porcelain.rb', line 8150

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8152
8153
8154
# File 'lib/models/porcelain.rb', line 8152

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8154
8155
8156
# File 'lib/models/porcelain.rb', line 8154

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8156
8157
8158
# File 'lib/models/porcelain.rb', line 8156

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8158
8159
8160
# File 'lib/models/porcelain.rb', line 8158

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



8160
8161
8162
# File 'lib/models/porcelain.rb', line 8160

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8194
8195
8196
8197
8198
8199
8200
# File 'lib/models/porcelain.rb', line 8194

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end