Class: SDM::KubernetesServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
The API token to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
constructor
A new instance of KubernetesServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
Returns a new instance of KubernetesServiceAccountUserImpersonation.
7986 7987 7988 7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 |
# File 'lib/models/porcelain.rb', line 7986 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7958 7959 7960 |
# File 'lib/models/porcelain.rb', line 7958 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7960 7961 7962 |
# File 'lib/models/porcelain.rb', line 7960 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
7962 7963 7964 |
# File 'lib/models/porcelain.rb', line 7962 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7964 7965 7966 |
# File 'lib/models/porcelain.rb', line 7964 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7966 7967 7968 |
# File 'lib/models/porcelain.rb', line 7966 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7968 7969 7970 |
# File 'lib/models/porcelain.rb', line 7968 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7970 7971 7972 |
# File 'lib/models/porcelain.rb', line 7970 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7972 7973 7974 |
# File 'lib/models/porcelain.rb', line 7972 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7974 7975 7976 |
# File 'lib/models/porcelain.rb', line 7974 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7976 7977 7978 |
# File 'lib/models/porcelain.rb', line 7976 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7978 7979 7980 |
# File 'lib/models/porcelain.rb', line 7978 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7980 7981 7982 |
# File 'lib/models/porcelain.rb', line 7980 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7982 7983 7984 |
# File 'lib/models/porcelain.rb', line 7982 def @tags end |
#token ⇒ Object
The API token to authenticate with.
7984 7985 7986 |
# File 'lib/models/porcelain.rb', line 7984 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8018 8019 8020 8021 8022 8023 8024 |
# File 'lib/models/porcelain.rb', line 8018 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |