Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



7814
7815
7816
7817
7818
7819
7820
7821
7822
7823
7824
7825
7826
7827
7828
7829
7830
7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
7843
7844
# File 'lib/models/porcelain.rb', line 7814

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7786
7787
7788
# File 'lib/models/porcelain.rb', line 7786

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7788
7789
7790
# File 'lib/models/porcelain.rb', line 7788

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7790
7791
7792
# File 'lib/models/porcelain.rb', line 7790

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7792
7793
7794
# File 'lib/models/porcelain.rb', line 7792

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7794
7795
7796
# File 'lib/models/porcelain.rb', line 7794

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7796
7797
7798
# File 'lib/models/porcelain.rb', line 7796

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7798
7799
7800
# File 'lib/models/porcelain.rb', line 7798

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7800
7801
7802
# File 'lib/models/porcelain.rb', line 7800

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7802
7803
7804
# File 'lib/models/porcelain.rb', line 7802

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7804
7805
7806
# File 'lib/models/porcelain.rb', line 7804

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7806
7807
7808
# File 'lib/models/porcelain.rb', line 7806

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7808
7809
7810
# File 'lib/models/porcelain.rb', line 7808

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7810
7811
7812
# File 'lib/models/porcelain.rb', line 7810

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



7812
7813
7814
# File 'lib/models/porcelain.rb', line 7812

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7846
7847
7848
7849
7850
7851
7852
# File 'lib/models/porcelain.rb', line 7846

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end