Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
7695
7696
7697
# File 'lib/models/porcelain.rb', line 7667

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7639
7640
7641
# File 'lib/models/porcelain.rb', line 7639

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7641
7642
7643
# File 'lib/models/porcelain.rb', line 7641

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7643
7644
7645
# File 'lib/models/porcelain.rb', line 7643

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7645
7646
7647
# File 'lib/models/porcelain.rb', line 7645

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7647
7648
7649
# File 'lib/models/porcelain.rb', line 7647

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7649
7650
7651
# File 'lib/models/porcelain.rb', line 7649

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7651
7652
7653
# File 'lib/models/porcelain.rb', line 7651

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7653
7654
7655
# File 'lib/models/porcelain.rb', line 7653

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7655
7656
7657
# File 'lib/models/porcelain.rb', line 7655

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7657
7658
7659
# File 'lib/models/porcelain.rb', line 7657

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7659
7660
7661
# File 'lib/models/porcelain.rb', line 7659

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7661
7662
7663
# File 'lib/models/porcelain.rb', line 7661

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7663
7664
7665
# File 'lib/models/porcelain.rb', line 7663

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



7665
7666
7667
# File 'lib/models/porcelain.rb', line 7665

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7699
7700
7701
7702
7703
7704
7705
# File 'lib/models/porcelain.rb', line 7699

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end