Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



7414
7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
# File 'lib/models/porcelain.rb', line 7414

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7386
7387
7388
# File 'lib/models/porcelain.rb', line 7386

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7388
7389
7390
# File 'lib/models/porcelain.rb', line 7388

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7390
7391
7392
# File 'lib/models/porcelain.rb', line 7390

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7392
7393
7394
# File 'lib/models/porcelain.rb', line 7392

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7394
7395
7396
# File 'lib/models/porcelain.rb', line 7394

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7396
7397
7398
# File 'lib/models/porcelain.rb', line 7396

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7398
7399
7400
# File 'lib/models/porcelain.rb', line 7398

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7400
7401
7402
# File 'lib/models/porcelain.rb', line 7400

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7402
7403
7404
# File 'lib/models/porcelain.rb', line 7402

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7404
7405
7406
# File 'lib/models/porcelain.rb', line 7404

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7406
7407
7408
# File 'lib/models/porcelain.rb', line 7406

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7408
7409
7410
# File 'lib/models/porcelain.rb', line 7408

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7410
7411
7412
# File 'lib/models/porcelain.rb', line 7410

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



7412
7413
7414
# File 'lib/models/porcelain.rb', line 7412

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7446
7447
7448
7449
7450
7451
7452
# File 'lib/models/porcelain.rb', line 7446

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end