Class: SDM::KubernetesServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
The API token to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
constructor
A new instance of KubernetesServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
Returns a new instance of KubernetesServiceAccountUserImpersonation.
7190 7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 |
# File 'lib/models/porcelain.rb', line 7190 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7162 7163 7164 |
# File 'lib/models/porcelain.rb', line 7162 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7164 7165 7166 |
# File 'lib/models/porcelain.rb', line 7164 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
7166 7167 7168 |
# File 'lib/models/porcelain.rb', line 7166 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7168 7169 7170 |
# File 'lib/models/porcelain.rb', line 7168 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7170 7171 7172 |
# File 'lib/models/porcelain.rb', line 7170 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7172 7173 7174 |
# File 'lib/models/porcelain.rb', line 7172 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7174 7175 7176 |
# File 'lib/models/porcelain.rb', line 7174 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7176 7177 7178 |
# File 'lib/models/porcelain.rb', line 7176 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7178 7179 7180 |
# File 'lib/models/porcelain.rb', line 7178 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7180 7181 7182 |
# File 'lib/models/porcelain.rb', line 7180 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7182 7183 7184 |
# File 'lib/models/porcelain.rb', line 7182 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7184 7185 7186 |
# File 'lib/models/porcelain.rb', line 7184 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7186 7187 7188 |
# File 'lib/models/porcelain.rb', line 7186 def @tags end |
#token ⇒ Object
The API token to authenticate with.
7188 7189 7190 |
# File 'lib/models/porcelain.rb', line 7188 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7222 7223 7224 7225 7226 7227 7228 |
# File 'lib/models/porcelain.rb', line 7222 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |