Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



7123
7124
7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
# File 'lib/models/porcelain.rb', line 7123

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7095
7096
7097
# File 'lib/models/porcelain.rb', line 7095

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7097
7098
7099
# File 'lib/models/porcelain.rb', line 7097

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7099
7100
7101
# File 'lib/models/porcelain.rb', line 7099

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7101
7102
7103
# File 'lib/models/porcelain.rb', line 7101

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7103
7104
7105
# File 'lib/models/porcelain.rb', line 7103

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7105
7106
7107
# File 'lib/models/porcelain.rb', line 7105

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7107
7108
7109
# File 'lib/models/porcelain.rb', line 7107

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7109
7110
7111
# File 'lib/models/porcelain.rb', line 7109

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7111
7112
7113
# File 'lib/models/porcelain.rb', line 7111

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7113
7114
7115
# File 'lib/models/porcelain.rb', line 7113

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7115
7116
7117
# File 'lib/models/porcelain.rb', line 7115

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7117
7118
7119
# File 'lib/models/porcelain.rb', line 7117

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7119
7120
7121
# File 'lib/models/porcelain.rb', line 7119

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



7121
7122
7123
# File 'lib/models/porcelain.rb', line 7121

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7155
7156
7157
7158
7159
7160
7161
# File 'lib/models/porcelain.rb', line 7155

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end