Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
6273
# File 'lib/models/porcelain.rb', line 6245

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6219
6220
6221
# File 'lib/models/porcelain.rb', line 6219

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6221
6222
6223
# File 'lib/models/porcelain.rb', line 6221

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6223
6224
6225
# File 'lib/models/porcelain.rb', line 6223

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6225
6226
6227
# File 'lib/models/porcelain.rb', line 6225

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6227
6228
6229
# File 'lib/models/porcelain.rb', line 6227

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6229
6230
6231
# File 'lib/models/porcelain.rb', line 6229

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6231
6232
6233
# File 'lib/models/porcelain.rb', line 6231

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6233
6234
6235
# File 'lib/models/porcelain.rb', line 6233

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6235
6236
6237
# File 'lib/models/porcelain.rb', line 6235

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6237
6238
6239
# File 'lib/models/porcelain.rb', line 6237

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6239
6240
6241
# File 'lib/models/porcelain.rb', line 6239

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6241
6242
6243
# File 'lib/models/porcelain.rb', line 6241

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



6243
6244
6245
# File 'lib/models/porcelain.rb', line 6243

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6275
6276
6277
6278
6279
6280
6281
# File 'lib/models/porcelain.rb', line 6275

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end