Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
4708
4709
4710
4711
4712
4713
# File 'lib/models/porcelain.rb', line 4685

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4659
4660
4661
# File 'lib/models/porcelain.rb', line 4659

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4661
4662
4663
# File 'lib/models/porcelain.rb', line 4661

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4663
4664
4665
# File 'lib/models/porcelain.rb', line 4663

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4665
4666
4667
# File 'lib/models/porcelain.rb', line 4665

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4667
4668
4669
# File 'lib/models/porcelain.rb', line 4667

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4669
4670
4671
# File 'lib/models/porcelain.rb', line 4669

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4671
4672
4673
# File 'lib/models/porcelain.rb', line 4671

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4673
4674
4675
# File 'lib/models/porcelain.rb', line 4673

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4675
4676
4677
# File 'lib/models/porcelain.rb', line 4675

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4677
4678
4679
# File 'lib/models/porcelain.rb', line 4677

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4679
4680
4681
# File 'lib/models/porcelain.rb', line 4679

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4681
4682
4683
# File 'lib/models/porcelain.rb', line 4681

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



4683
4684
4685
# File 'lib/models/porcelain.rb', line 4683

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4715
4716
4717
4718
4719
4720
4721
# File 'lib/models/porcelain.rb', line 4715

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end