Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
# File 'lib/models/porcelain.rb', line 4513

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4487
4488
4489
# File 'lib/models/porcelain.rb', line 4487

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4489
4490
4491
# File 'lib/models/porcelain.rb', line 4489

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4491
4492
4493
# File 'lib/models/porcelain.rb', line 4491

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4493
4494
4495
# File 'lib/models/porcelain.rb', line 4493

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4495
4496
4497
# File 'lib/models/porcelain.rb', line 4495

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4497
4498
4499
# File 'lib/models/porcelain.rb', line 4497

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4499
4500
4501
# File 'lib/models/porcelain.rb', line 4499

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4501
4502
4503
# File 'lib/models/porcelain.rb', line 4501

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4503
4504
4505
# File 'lib/models/porcelain.rb', line 4503

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4505
4506
4507
# File 'lib/models/porcelain.rb', line 4505

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4507
4508
4509
# File 'lib/models/porcelain.rb', line 4507

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4509
4510
4511
# File 'lib/models/porcelain.rb', line 4509

def tags
  @tags
end

#tokenObject

The API token to authenticate with.



4511
4512
4513
# File 'lib/models/porcelain.rb', line 4511

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4543
4544
4545
4546
4547
4548
4549
# File 'lib/models/porcelain.rb', line 4543

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end