Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



4358
4359
4360
4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
# File 'lib/models/porcelain.rb', line 4358

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4332
4333
4334
# File 'lib/models/porcelain.rb', line 4332

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4334
4335
4336
# File 'lib/models/porcelain.rb', line 4334

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4336
4337
4338
# File 'lib/models/porcelain.rb', line 4336

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4338
4339
4340
# File 'lib/models/porcelain.rb', line 4338

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4340
4341
4342
# File 'lib/models/porcelain.rb', line 4340

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4342
4343
4344
# File 'lib/models/porcelain.rb', line 4342

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4344
4345
4346
# File 'lib/models/porcelain.rb', line 4344

def name
  @name
end

#portObject

Returns the value of attribute port.



4346
4347
4348
# File 'lib/models/porcelain.rb', line 4346

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4348
4349
4350
# File 'lib/models/porcelain.rb', line 4348

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4350
4351
4352
# File 'lib/models/porcelain.rb', line 4350

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4352
4353
4354
# File 'lib/models/porcelain.rb', line 4352

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4354
4355
4356
# File 'lib/models/porcelain.rb', line 4354

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



4356
4357
4358
# File 'lib/models/porcelain.rb', line 4356

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4388
4389
4390
4391
4392
4393
4394
# File 'lib/models/porcelain.rb', line 4388

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end