Class: SDM::KubernetesServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
Returns the value of attribute token.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
constructor
A new instance of KubernetesServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
Returns a new instance of KubernetesServiceAccountUserImpersonation.
4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 |
# File 'lib/models/porcelain.rb', line 4204 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4178 4179 4180 |
# File 'lib/models/porcelain.rb', line 4178 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4180 4181 4182 |
# File 'lib/models/porcelain.rb', line 4180 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
4182 4183 4184 |
# File 'lib/models/porcelain.rb', line 4182 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4184 4185 4186 |
# File 'lib/models/porcelain.rb', line 4184 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4186 4187 4188 |
# File 'lib/models/porcelain.rb', line 4186 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4188 4189 4190 |
# File 'lib/models/porcelain.rb', line 4188 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4190 4191 4192 |
# File 'lib/models/porcelain.rb', line 4190 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4192 4193 4194 |
# File 'lib/models/porcelain.rb', line 4192 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4194 4195 4196 |
# File 'lib/models/porcelain.rb', line 4194 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4196 4197 4198 |
# File 'lib/models/porcelain.rb', line 4196 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4198 4199 4200 |
# File 'lib/models/porcelain.rb', line 4198 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4200 4201 4202 |
# File 'lib/models/porcelain.rb', line 4200 def @tags end |
#token ⇒ Object
Returns the value of attribute token.
4202 4203 4204 |
# File 'lib/models/porcelain.rb', line 4202 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4234 4235 4236 4237 4238 4239 4240 |
# File 'lib/models/porcelain.rb', line 4234 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |