Class: SDM::KubernetesServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
Returns the value of attribute token.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
constructor
A new instance of KubernetesServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
Returns a new instance of KubernetesServiceAccountUserImpersonation.
4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 |
# File 'lib/models/porcelain.rb', line 4066 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4042 4043 4044 |
# File 'lib/models/porcelain.rb', line 4042 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4044 4045 4046 |
# File 'lib/models/porcelain.rb', line 4044 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
4046 4047 4048 |
# File 'lib/models/porcelain.rb', line 4046 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4048 4049 4050 |
# File 'lib/models/porcelain.rb', line 4048 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4050 4051 4052 |
# File 'lib/models/porcelain.rb', line 4050 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4052 4053 4054 |
# File 'lib/models/porcelain.rb', line 4052 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4054 4055 4056 |
# File 'lib/models/porcelain.rb', line 4054 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4056 4057 4058 |
# File 'lib/models/porcelain.rb', line 4056 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4058 4059 4060 |
# File 'lib/models/porcelain.rb', line 4058 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4060 4061 4062 |
# File 'lib/models/porcelain.rb', line 4060 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4062 4063 4064 |
# File 'lib/models/porcelain.rb', line 4062 def @tags end |
#token ⇒ Object
Returns the value of attribute token.
4064 4065 4066 |
# File 'lib/models/porcelain.rb', line 4064 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4094 4095 4096 4097 4098 4099 4100 |
# File 'lib/models/porcelain.rb', line 4094 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |