Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
# File 'lib/models/porcelain.rb', line 3728

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3704
3705
3706
# File 'lib/models/porcelain.rb', line 3704

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3706
3707
3708
# File 'lib/models/porcelain.rb', line 3706

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3708
3709
3710
# File 'lib/models/porcelain.rb', line 3708

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3710
3711
3712
# File 'lib/models/porcelain.rb', line 3710

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3712
3713
3714
# File 'lib/models/porcelain.rb', line 3712

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3714
3715
3716
# File 'lib/models/porcelain.rb', line 3714

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3716
3717
3718
# File 'lib/models/porcelain.rb', line 3716

def name
  @name
end

#portObject

Returns the value of attribute port.



3718
3719
3720
# File 'lib/models/porcelain.rb', line 3718

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3720
3721
3722
# File 'lib/models/porcelain.rb', line 3720

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3722
3723
3724
# File 'lib/models/porcelain.rb', line 3722

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3724
3725
3726
# File 'lib/models/porcelain.rb', line 3724

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



3726
3727
3728
# File 'lib/models/porcelain.rb', line 3726

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3756
3757
3758
3759
3760
3761
3762
# File 'lib/models/porcelain.rb', line 3756

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end