Class: SDM::KubernetesServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
Returns the value of attribute token.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
constructor
A new instance of KubernetesServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
Returns a new instance of KubernetesServiceAccountUserImpersonation.
3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 |
# File 'lib/models/porcelain.rb', line 3729 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3705 3706 3707 |
# File 'lib/models/porcelain.rb', line 3705 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3707 3708 3709 |
# File 'lib/models/porcelain.rb', line 3707 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3709 3710 3711 |
# File 'lib/models/porcelain.rb', line 3709 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3711 3712 3713 |
# File 'lib/models/porcelain.rb', line 3711 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3713 3714 3715 |
# File 'lib/models/porcelain.rb', line 3713 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3715 3716 3717 |
# File 'lib/models/porcelain.rb', line 3715 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3717 3718 3719 |
# File 'lib/models/porcelain.rb', line 3717 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
3719 3720 3721 |
# File 'lib/models/porcelain.rb', line 3719 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3721 3722 3723 |
# File 'lib/models/porcelain.rb', line 3721 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3723 3724 3725 |
# File 'lib/models/porcelain.rb', line 3723 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3725 3726 3727 |
# File 'lib/models/porcelain.rb', line 3725 def @tags end |
#token ⇒ Object
Returns the value of attribute token.
3727 3728 3729 |
# File 'lib/models/porcelain.rb', line 3727 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3757 3758 3759 3760 3761 3762 3763 |
# File 'lib/models/porcelain.rb', line 3757 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |