Class: SDM::KubernetesServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
Returns the value of attribute token.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
constructor
A new instance of KubernetesServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
Returns a new instance of KubernetesServiceAccountUserImpersonation.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 |
# File 'lib/models/porcelain.rb', line 3621 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3597 3598 3599 |
# File 'lib/models/porcelain.rb', line 3597 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3599 3600 3601 |
# File 'lib/models/porcelain.rb', line 3599 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3601 3602 3603 |
# File 'lib/models/porcelain.rb', line 3601 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3603 3604 3605 |
# File 'lib/models/porcelain.rb', line 3603 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3605 3606 3607 |
# File 'lib/models/porcelain.rb', line 3605 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3607 3608 3609 |
# File 'lib/models/porcelain.rb', line 3607 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3609 3610 3611 |
# File 'lib/models/porcelain.rb', line 3609 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
3611 3612 3613 |
# File 'lib/models/porcelain.rb', line 3611 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3613 3614 3615 |
# File 'lib/models/porcelain.rb', line 3613 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3615 3616 3617 |
# File 'lib/models/porcelain.rb', line 3615 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3617 3618 3619 |
# File 'lib/models/porcelain.rb', line 3617 def @tags end |
#token ⇒ Object
Returns the value of attribute token.
3619 3620 3621 |
# File 'lib/models/porcelain.rb', line 3619 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3649 3650 3651 3652 3653 3654 3655 |
# File 'lib/models/porcelain.rb', line 3649 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |