Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
3643
# File 'lib/models/porcelain.rb', line 3617

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3593
3594
3595
# File 'lib/models/porcelain.rb', line 3593

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3595
3596
3597
# File 'lib/models/porcelain.rb', line 3595

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3597
3598
3599
# File 'lib/models/porcelain.rb', line 3597

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3599
3600
3601
# File 'lib/models/porcelain.rb', line 3599

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3601
3602
3603
# File 'lib/models/porcelain.rb', line 3601

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3603
3604
3605
# File 'lib/models/porcelain.rb', line 3603

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3605
3606
3607
# File 'lib/models/porcelain.rb', line 3605

def name
  @name
end

#portObject

Returns the value of attribute port.



3607
3608
3609
# File 'lib/models/porcelain.rb', line 3607

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3609
3610
3611
# File 'lib/models/porcelain.rb', line 3609

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3611
3612
3613
# File 'lib/models/porcelain.rb', line 3611

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3613
3614
3615
# File 'lib/models/porcelain.rb', line 3613

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



3615
3616
3617
# File 'lib/models/porcelain.rb', line 3615

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3645
3646
3647
3648
3649
3650
3651
# File 'lib/models/porcelain.rb', line 3645

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end