Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
# File 'lib/models/porcelain.rb', line 3261

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3237
3238
3239
# File 'lib/models/porcelain.rb', line 3237

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3239
3240
3241
# File 'lib/models/porcelain.rb', line 3239

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3241
3242
3243
# File 'lib/models/porcelain.rb', line 3241

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3243
3244
3245
# File 'lib/models/porcelain.rb', line 3243

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3245
3246
3247
# File 'lib/models/porcelain.rb', line 3245

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3247
3248
3249
# File 'lib/models/porcelain.rb', line 3247

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3249
3250
3251
# File 'lib/models/porcelain.rb', line 3249

def name
  @name
end

#portObject

Returns the value of attribute port.



3251
3252
3253
# File 'lib/models/porcelain.rb', line 3251

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3253
3254
3255
# File 'lib/models/porcelain.rb', line 3253

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3255
3256
3257
# File 'lib/models/porcelain.rb', line 3255

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3257
3258
3259
# File 'lib/models/porcelain.rb', line 3257

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



3259
3260
3261
# File 'lib/models/porcelain.rb', line 3259

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3289
3290
3291
3292
3293
3294
3295
# File 'lib/models/porcelain.rb', line 3289

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end