Class: SDM::KubernetesServiceAccountUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesServiceAccountUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#token ⇒ Object
Returns the value of attribute token.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
constructor
A new instance of KubernetesServiceAccountUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation
Returns a new instance of KubernetesServiceAccountUserImpersonation.
3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 |
# File 'lib/models/porcelain.rb', line 3263 def initialize( bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, token: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @token = token == nil ? "" : token end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3239 3240 3241 |
# File 'lib/models/porcelain.rb', line 3239 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3241 3242 3243 |
# File 'lib/models/porcelain.rb', line 3241 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3243 3244 3245 |
# File 'lib/models/porcelain.rb', line 3243 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3245 3246 3247 |
# File 'lib/models/porcelain.rb', line 3245 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3247 3248 3249 |
# File 'lib/models/porcelain.rb', line 3247 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3249 3250 3251 |
# File 'lib/models/porcelain.rb', line 3249 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3251 3252 3253 |
# File 'lib/models/porcelain.rb', line 3251 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
3253 3254 3255 |
# File 'lib/models/porcelain.rb', line 3253 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3255 3256 3257 |
# File 'lib/models/porcelain.rb', line 3255 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3257 3258 3259 |
# File 'lib/models/porcelain.rb', line 3257 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3259 3260 3261 |
# File 'lib/models/porcelain.rb', line 3259 def @tags end |
#token ⇒ Object
Returns the value of attribute token.
3261 3262 3263 |
# File 'lib/models/porcelain.rb', line 3261 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3291 3292 3293 3294 3295 3296 3297 |
# File 'lib/models/porcelain.rb', line 3291 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |