Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
4044
4045
4046
4047
# File 'lib/models/porcelain.rb', line 4005

def initialize(
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  secret_store_id: nil,
  tags: nil,
  token: nil
)
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthcheck_namespace != nil
    @healthcheck_namespace = healthcheck_namespace
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if port != nil
    @port = port
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
  if token != nil
    @token = token
  end
end

Instance Attribute Details

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3985
3986
3987
# File 'lib/models/porcelain.rb', line 3985

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to `default`.



3987
3988
3989
# File 'lib/models/porcelain.rb', line 3987

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3989
3990
3991
# File 'lib/models/porcelain.rb', line 3989

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3991
3992
3993
# File 'lib/models/porcelain.rb', line 3991

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3993
3994
3995
# File 'lib/models/porcelain.rb', line 3993

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3995
3996
3997
# File 'lib/models/porcelain.rb', line 3995

def name
  @name
end

#portObject

Returns the value of attribute port.



3997
3998
3999
# File 'lib/models/porcelain.rb', line 3997

def port
  @port
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3999
4000
4001
# File 'lib/models/porcelain.rb', line 3999

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4001
4002
4003
# File 'lib/models/porcelain.rb', line 4001

def tags
  @tags
end

#tokenObject

Returns the value of attribute token.



4003
4004
4005
# File 'lib/models/porcelain.rb', line 4003

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4049
4050
4051
4052
4053
4054
4055
# File 'lib/models/porcelain.rb', line 4049

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end