Class: SDM::KubernetesServiceAccountUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

KubernetesServiceAccountUserImpersonation is deprecated, see docs for more info.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, token: nil) ⇒ KubernetesServiceAccountUserImpersonation

Returns a new instance of KubernetesServiceAccountUserImpersonation.



10329
10330
10331
10332
10333
10334
10335
10336
10337
10338
10339
10340
10341
10342
10343
10344
10345
10346
10347
10348
10349
10350
10351
10352
10353
10354
10355
10356
10357
10358
10359
# File 'lib/models/porcelain.rb', line 10329

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  token: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @token = token == nil ? "" : token
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10301
10302
10303
# File 'lib/models/porcelain.rb', line 10301

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



10303
10304
10305
# File 'lib/models/porcelain.rb', line 10303

def egress_filter
  @egress_filter
end

#healthcheck_namespace ⇒ Object

The path used to check the health of your connection. Defaults to default.



10305
10306
10307
# File 'lib/models/porcelain.rb', line 10305

def healthcheck_namespace
  @healthcheck_namespace
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



10307
10308
10309
# File 'lib/models/porcelain.rb', line 10307

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



10309
10310
10311
# File 'lib/models/porcelain.rb', line 10309

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



10311
10312
10313
# File 'lib/models/porcelain.rb', line 10311

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



10313
10314
10315
# File 'lib/models/porcelain.rb', line 10313

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



10315
10316
10317
# File 'lib/models/porcelain.rb', line 10315

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10317
10318
10319
# File 'lib/models/porcelain.rb', line 10317

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



10319
10320
10321
# File 'lib/models/porcelain.rb', line 10319

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



10321
10322
10323
# File 'lib/models/porcelain.rb', line 10321

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10323
10324
10325
# File 'lib/models/porcelain.rb', line 10323

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



10325
10326
10327
# File 'lib/models/porcelain.rb', line 10325

def tags
  @tags
end

#token ⇒ Object

The API token to authenticate with.



10327
10328
10329
# File 'lib/models/porcelain.rb', line 10327

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10361
10362
10363
10364
10365
10366
10367
# File 'lib/models/porcelain.rb', line 10361

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end