Class: SDM::KubernetesUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Overview
KubernetesUserImpersonation is deprecated, see docs for more info.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
constructor
A new instance of KubernetesUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
Returns a new instance of KubernetesUserImpersonation.
10018 10019 10020 10021 10022 10023 10024 10025 10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 10040 10041 10042 10043 10044 10045 10046 10047 10048 10049 10050 10051 10052 |
# File 'lib/models/porcelain.rb', line 10018 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
9986 9987 9988 |
# File 'lib/models/porcelain.rb', line 9986 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
9988 9989 9990 |
# File 'lib/models/porcelain.rb', line 9988 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
9990 9991 9992 |
# File 'lib/models/porcelain.rb', line 9990 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
9992 9993 9994 |
# File 'lib/models/porcelain.rb', line 9992 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9994 9995 9996 |
# File 'lib/models/porcelain.rb', line 9994 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
9996 9997 9998 |
# File 'lib/models/porcelain.rb', line 9996 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9998 9999 10000 |
# File 'lib/models/porcelain.rb', line 9998 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10000 10001 10002 |
# File 'lib/models/porcelain.rb', line 10000 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10002 10003 10004 |
# File 'lib/models/porcelain.rb', line 10002 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10004 10005 10006 |
# File 'lib/models/porcelain.rb', line 10004 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10006 10007 10008 |
# File 'lib/models/porcelain.rb', line 10006 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
10008 10009 10010 |
# File 'lib/models/porcelain.rb', line 10008 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10010 10011 10012 |
# File 'lib/models/porcelain.rb', line 10010 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10012 10013 10014 |
# File 'lib/models/porcelain.rb', line 10012 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
10014 10015 10016 |
# File 'lib/models/porcelain.rb', line 10014 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10016 10017 10018 |
# File 'lib/models/porcelain.rb', line 10016 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10054 10055 10056 10057 10058 10059 10060 |
# File 'lib/models/porcelain.rb', line 10054 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |