Class: SDM::KubernetesUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
constructor
A new instance of KubernetesUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
Returns a new instance of KubernetesUserImpersonation.
8046 8047 8048 8049 8050 8051 8052 8053 8054 8055 8056 8057 8058 8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 |
# File 'lib/models/porcelain.rb', line 8046 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8014 8015 8016 |
# File 'lib/models/porcelain.rb', line 8014 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
8016 8017 8018 |
# File 'lib/models/porcelain.rb', line 8016 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
8018 8019 8020 |
# File 'lib/models/porcelain.rb', line 8018 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
8020 8021 8022 |
# File 'lib/models/porcelain.rb', line 8020 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8022 8023 8024 |
# File 'lib/models/porcelain.rb', line 8022 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
8024 8025 8026 |
# File 'lib/models/porcelain.rb', line 8024 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8026 8027 8028 |
# File 'lib/models/porcelain.rb', line 8026 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8028 8029 8030 |
# File 'lib/models/porcelain.rb', line 8028 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8030 8031 8032 |
# File 'lib/models/porcelain.rb', line 8030 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8032 8033 8034 |
# File 'lib/models/porcelain.rb', line 8032 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8034 8035 8036 |
# File 'lib/models/porcelain.rb', line 8034 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8036 8037 8038 |
# File 'lib/models/porcelain.rb', line 8036 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8038 8039 8040 |
# File 'lib/models/porcelain.rb', line 8038 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8040 8041 8042 |
# File 'lib/models/porcelain.rb', line 8040 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8042 8043 8044 |
# File 'lib/models/porcelain.rb', line 8042 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8044 8045 8046 |
# File 'lib/models/porcelain.rb', line 8044 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8082 8083 8084 8085 8086 8087 8088 |
# File 'lib/models/porcelain.rb', line 8082 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |