Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
7888
7889
7890
7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
# File 'lib/models/porcelain.rb', line 7878

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7846
7847
7848
# File 'lib/models/porcelain.rb', line 7846

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7848
7849
7850
# File 'lib/models/porcelain.rb', line 7848

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7850
7851
7852
# File 'lib/models/porcelain.rb', line 7850

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7852
7853
7854
# File 'lib/models/porcelain.rb', line 7852

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7854
7855
7856
# File 'lib/models/porcelain.rb', line 7854

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7856
7857
7858
# File 'lib/models/porcelain.rb', line 7856

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7858
7859
7860
# File 'lib/models/porcelain.rb', line 7858

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7860
7861
7862
# File 'lib/models/porcelain.rb', line 7860

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7862
7863
7864
# File 'lib/models/porcelain.rb', line 7862

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7864
7865
7866
# File 'lib/models/porcelain.rb', line 7864

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7866
7867
7868
# File 'lib/models/porcelain.rb', line 7866

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7868
7869
7870
# File 'lib/models/porcelain.rb', line 7868

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7870
7871
7872
# File 'lib/models/porcelain.rb', line 7870

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7872
7873
7874
# File 'lib/models/porcelain.rb', line 7872

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7874
7875
7876
# File 'lib/models/porcelain.rb', line 7874

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7876
7877
7878
# File 'lib/models/porcelain.rb', line 7876

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7914
7915
7916
7917
7918
7919
7920
# File 'lib/models/porcelain.rb', line 7914

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end