Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



7490
7491
7492
7493
7494
7495
7496
7497
7498
7499
7500
7501
7502
7503
7504
7505
7506
7507
7508
7509
7510
7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
# File 'lib/models/porcelain.rb', line 7490

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7458
7459
7460
# File 'lib/models/porcelain.rb', line 7458

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7460
7461
7462
# File 'lib/models/porcelain.rb', line 7460

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7462
7463
7464
# File 'lib/models/porcelain.rb', line 7462

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7464
7465
7466
# File 'lib/models/porcelain.rb', line 7464

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7466
7467
7468
# File 'lib/models/porcelain.rb', line 7466

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7468
7469
7470
# File 'lib/models/porcelain.rb', line 7468

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7470
7471
7472
# File 'lib/models/porcelain.rb', line 7470

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7472
7473
7474
# File 'lib/models/porcelain.rb', line 7472

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7474
7475
7476
# File 'lib/models/porcelain.rb', line 7474

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7476
7477
7478
# File 'lib/models/porcelain.rb', line 7476

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7478
7479
7480
# File 'lib/models/porcelain.rb', line 7478

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7480
7481
7482
# File 'lib/models/porcelain.rb', line 7480

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7482
7483
7484
# File 'lib/models/porcelain.rb', line 7482

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7484
7485
7486
# File 'lib/models/porcelain.rb', line 7484

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7486
7487
7488
# File 'lib/models/porcelain.rb', line 7486

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7488
7489
7490
# File 'lib/models/porcelain.rb', line 7488

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7526
7527
7528
7529
7530
7531
7532
# File 'lib/models/porcelain.rb', line 7526

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end