Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
# File 'lib/models/porcelain.rb', line 7415

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7383
7384
7385
# File 'lib/models/porcelain.rb', line 7383

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7385
7386
7387
# File 'lib/models/porcelain.rb', line 7385

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7387
7388
7389
# File 'lib/models/porcelain.rb', line 7387

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7389
7390
7391
# File 'lib/models/porcelain.rb', line 7389

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7391
7392
7393
# File 'lib/models/porcelain.rb', line 7391

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7393
7394
7395
# File 'lib/models/porcelain.rb', line 7393

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7395
7396
7397
# File 'lib/models/porcelain.rb', line 7395

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7397
7398
7399
# File 'lib/models/porcelain.rb', line 7397

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7399
7400
7401
# File 'lib/models/porcelain.rb', line 7399

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7401
7402
7403
# File 'lib/models/porcelain.rb', line 7401

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7403
7404
7405
# File 'lib/models/porcelain.rb', line 7403

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7405
7406
7407
# File 'lib/models/porcelain.rb', line 7405

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7407
7408
7409
# File 'lib/models/porcelain.rb', line 7407

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7409
7410
7411
# File 'lib/models/porcelain.rb', line 7409

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7411
7412
7413
# File 'lib/models/porcelain.rb', line 7411

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7413
7414
7415
# File 'lib/models/porcelain.rb', line 7413

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7451
7452
7453
7454
7455
7456
7457
# File 'lib/models/porcelain.rb', line 7451

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end