Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
# File 'lib/models/porcelain.rb', line 7335

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7303
7304
7305
# File 'lib/models/porcelain.rb', line 7303

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7305
7306
7307
# File 'lib/models/porcelain.rb', line 7305

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7307
7308
7309
# File 'lib/models/porcelain.rb', line 7307

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7309
7310
7311
# File 'lib/models/porcelain.rb', line 7309

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7311
7312
7313
# File 'lib/models/porcelain.rb', line 7311

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7313
7314
7315
# File 'lib/models/porcelain.rb', line 7313

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7315
7316
7317
# File 'lib/models/porcelain.rb', line 7315

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7317
7318
7319
# File 'lib/models/porcelain.rb', line 7317

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7319
7320
7321
# File 'lib/models/porcelain.rb', line 7319

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7321
7322
7323
# File 'lib/models/porcelain.rb', line 7321

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7323
7324
7325
# File 'lib/models/porcelain.rb', line 7323

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7325
7326
7327
# File 'lib/models/porcelain.rb', line 7325

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7327
7328
7329
# File 'lib/models/porcelain.rb', line 7327

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7329
7330
7331
# File 'lib/models/porcelain.rb', line 7329

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7331
7332
7333
# File 'lib/models/porcelain.rb', line 7331

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7333
7334
7335
# File 'lib/models/porcelain.rb', line 7333

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7371
7372
7373
7374
7375
7376
7377
# File 'lib/models/porcelain.rb', line 7371

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end