Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
7218
7219
7220
7221
7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
# File 'lib/models/porcelain.rb', line 7198

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7166
7167
7168
# File 'lib/models/porcelain.rb', line 7166

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7168
7169
7170
# File 'lib/models/porcelain.rb', line 7168

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7170
7171
7172
# File 'lib/models/porcelain.rb', line 7170

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7172
7173
7174
# File 'lib/models/porcelain.rb', line 7172

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7174
7175
7176
# File 'lib/models/porcelain.rb', line 7174

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



7176
7177
7178
# File 'lib/models/porcelain.rb', line 7176

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7178
7179
7180
# File 'lib/models/porcelain.rb', line 7178

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7180
7181
7182
# File 'lib/models/porcelain.rb', line 7180

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7182
7183
7184
# File 'lib/models/porcelain.rb', line 7182

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7184
7185
7186
# File 'lib/models/porcelain.rb', line 7184

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7186
7187
7188
# File 'lib/models/porcelain.rb', line 7186

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7188
7189
7190
# File 'lib/models/porcelain.rb', line 7188

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7190
7191
7192
# File 'lib/models/porcelain.rb', line 7190

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7192
7193
7194
# File 'lib/models/porcelain.rb', line 7192

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7194
7195
7196
# File 'lib/models/porcelain.rb', line 7194

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7196
7197
7198
# File 'lib/models/porcelain.rb', line 7196

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7234
7235
7236
7237
7238
7239
7240
# File 'lib/models/porcelain.rb', line 7234

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end