Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
6932
6933
6934
6935
6936
6937
# File 'lib/models/porcelain.rb', line 6903

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6871
6872
6873
# File 'lib/models/porcelain.rb', line 6871

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6873
6874
6875
# File 'lib/models/porcelain.rb', line 6873

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6875
6876
6877
# File 'lib/models/porcelain.rb', line 6875

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6877
6878
6879
# File 'lib/models/porcelain.rb', line 6877

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6879
6880
6881
# File 'lib/models/porcelain.rb', line 6879

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6881
6882
6883
# File 'lib/models/porcelain.rb', line 6881

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6883
6884
6885
# File 'lib/models/porcelain.rb', line 6883

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6885
6886
6887
# File 'lib/models/porcelain.rb', line 6885

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6887
6888
6889
# File 'lib/models/porcelain.rb', line 6887

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6889
6890
6891
# File 'lib/models/porcelain.rb', line 6889

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6891
6892
6893
# File 'lib/models/porcelain.rb', line 6891

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6893
6894
6895
# File 'lib/models/porcelain.rb', line 6893

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6895
6896
6897
# File 'lib/models/porcelain.rb', line 6895

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6897
6898
6899
# File 'lib/models/porcelain.rb', line 6897

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6899
6900
6901
# File 'lib/models/porcelain.rb', line 6899

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6901
6902
6903
# File 'lib/models/porcelain.rb', line 6901

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6939
6940
6941
6942
6943
6944
6945
# File 'lib/models/porcelain.rb', line 6939

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end