Class: SDM::KubernetesUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
constructor
A new instance of KubernetesUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
Returns a new instance of KubernetesUserImpersonation.
6583 6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 6599 6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 6610 6611 6612 6613 6614 6615 6616 6617 |
# File 'lib/models/porcelain.rb', line 6583 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6551 6552 6553 |
# File 'lib/models/porcelain.rb', line 6551 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
6553 6554 6555 |
# File 'lib/models/porcelain.rb', line 6553 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
6555 6556 6557 |
# File 'lib/models/porcelain.rb', line 6555 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
6557 6558 6559 |
# File 'lib/models/porcelain.rb', line 6557 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6559 6560 6561 |
# File 'lib/models/porcelain.rb', line 6559 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
6561 6562 6563 |
# File 'lib/models/porcelain.rb', line 6561 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6563 6564 6565 |
# File 'lib/models/porcelain.rb', line 6563 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6565 6566 6567 |
# File 'lib/models/porcelain.rb', line 6565 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6567 6568 6569 |
# File 'lib/models/porcelain.rb', line 6567 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6569 6570 6571 |
# File 'lib/models/porcelain.rb', line 6569 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6571 6572 6573 |
# File 'lib/models/porcelain.rb', line 6571 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6573 6574 6575 |
# File 'lib/models/porcelain.rb', line 6573 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
6575 6576 6577 |
# File 'lib/models/porcelain.rb', line 6575 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6577 6578 6579 |
# File 'lib/models/porcelain.rb', line 6577 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6579 6580 6581 |
# File 'lib/models/porcelain.rb', line 6579 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6581 6582 6583 |
# File 'lib/models/porcelain.rb', line 6581 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6619 6620 6621 6622 6623 6624 6625 |
# File 'lib/models/porcelain.rb', line 6619 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |