Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
# File 'lib/models/porcelain.rb', line 6316

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6286
6287
6288
# File 'lib/models/porcelain.rb', line 6286

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6288
6289
6290
# File 'lib/models/porcelain.rb', line 6288

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6290
6291
6292
# File 'lib/models/porcelain.rb', line 6290

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6292
6293
6294
# File 'lib/models/porcelain.rb', line 6292

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6294
6295
6296
# File 'lib/models/porcelain.rb', line 6294

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



6296
6297
6298
# File 'lib/models/porcelain.rb', line 6296

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6298
6299
6300
# File 'lib/models/porcelain.rb', line 6298

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6300
6301
6302
# File 'lib/models/porcelain.rb', line 6300

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6302
6303
6304
# File 'lib/models/porcelain.rb', line 6302

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6304
6305
6306
# File 'lib/models/porcelain.rb', line 6304

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6306
6307
6308
# File 'lib/models/porcelain.rb', line 6306

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6308
6309
6310
# File 'lib/models/porcelain.rb', line 6308

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6310
6311
6312
# File 'lib/models/porcelain.rb', line 6310

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6312
6313
6314
# File 'lib/models/porcelain.rb', line 6312

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6314
6315
6316
# File 'lib/models/porcelain.rb', line 6314

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6350
6351
6352
6353
6354
6355
6356
# File 'lib/models/porcelain.rb', line 6350

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end