Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
4916
4917
4918
4919
4920
4921
4922
4923
4924
4925
4926
4927
4928
4929
4930
4931
4932
4933
4934
4935
# File 'lib/models/porcelain.rb', line 4903

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4873
4874
4875
# File 'lib/models/porcelain.rb', line 4873

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4875
4876
4877
# File 'lib/models/porcelain.rb', line 4875

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4877
4878
4879
# File 'lib/models/porcelain.rb', line 4877

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4879
4880
4881
# File 'lib/models/porcelain.rb', line 4879

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4881
4882
4883
# File 'lib/models/porcelain.rb', line 4881

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4883
4884
4885
# File 'lib/models/porcelain.rb', line 4883

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4885
4886
4887
# File 'lib/models/porcelain.rb', line 4885

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4887
4888
4889
# File 'lib/models/porcelain.rb', line 4887

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4889
4890
4891
# File 'lib/models/porcelain.rb', line 4889

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4891
4892
4893
# File 'lib/models/porcelain.rb', line 4891

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4893
4894
4895
# File 'lib/models/porcelain.rb', line 4893

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4895
4896
4897
# File 'lib/models/porcelain.rb', line 4895

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4897
4898
4899
# File 'lib/models/porcelain.rb', line 4897

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4899
4900
4901
# File 'lib/models/porcelain.rb', line 4899

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4901
4902
4903
# File 'lib/models/porcelain.rb', line 4901

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4937
4938
4939
4940
4941
4942
4943
# File 'lib/models/porcelain.rb', line 4937

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end