Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



4756
4757
4758
4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
# File 'lib/models/porcelain.rb', line 4756

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4726
4727
4728
# File 'lib/models/porcelain.rb', line 4726

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4728
4729
4730
# File 'lib/models/porcelain.rb', line 4728

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4730
4731
4732
# File 'lib/models/porcelain.rb', line 4730

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4732
4733
4734
# File 'lib/models/porcelain.rb', line 4732

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4734
4735
4736
# File 'lib/models/porcelain.rb', line 4734

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4736
4737
4738
# File 'lib/models/porcelain.rb', line 4736

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4738
4739
4740
# File 'lib/models/porcelain.rb', line 4738

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4740
4741
4742
# File 'lib/models/porcelain.rb', line 4740

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4742
4743
4744
# File 'lib/models/porcelain.rb', line 4742

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4744
4745
4746
# File 'lib/models/porcelain.rb', line 4744

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4746
4747
4748
# File 'lib/models/porcelain.rb', line 4746

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4748
4749
4750
# File 'lib/models/porcelain.rb', line 4748

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4750
4751
4752
# File 'lib/models/porcelain.rb', line 4750

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4752
4753
4754
# File 'lib/models/porcelain.rb', line 4752

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4754
4755
4756
# File 'lib/models/porcelain.rb', line 4754

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4790
4791
4792
4793
4794
4795
4796
# File 'lib/models/porcelain.rb', line 4790

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end