Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



4589
4590
4591
4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
4615
4616
4617
4618
4619
4620
4621
# File 'lib/models/porcelain.rb', line 4589

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4559
4560
4561
# File 'lib/models/porcelain.rb', line 4559

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4561
4562
4563
# File 'lib/models/porcelain.rb', line 4561

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4563
4564
4565
# File 'lib/models/porcelain.rb', line 4563

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4565
4566
4567
# File 'lib/models/porcelain.rb', line 4565

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4567
4568
4569
# File 'lib/models/porcelain.rb', line 4567

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4569
4570
4571
# File 'lib/models/porcelain.rb', line 4569

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4571
4572
4573
# File 'lib/models/porcelain.rb', line 4571

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4573
4574
4575
# File 'lib/models/porcelain.rb', line 4573

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4575
4576
4577
# File 'lib/models/porcelain.rb', line 4575

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4577
4578
4579
# File 'lib/models/porcelain.rb', line 4577

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4579
4580
4581
# File 'lib/models/porcelain.rb', line 4579

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4581
4582
4583
# File 'lib/models/porcelain.rb', line 4581

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4583
4584
4585
# File 'lib/models/porcelain.rb', line 4583

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4585
4586
4587
# File 'lib/models/porcelain.rb', line 4585

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4587
4588
4589
# File 'lib/models/porcelain.rb', line 4587

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4623
4624
4625
4626
4627
4628
4629
# File 'lib/models/porcelain.rb', line 4623

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end