Class: SDM::KubernetesUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
constructor
A new instance of KubernetesUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
Returns a new instance of KubernetesUserImpersonation.
4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 |
# File 'lib/models/porcelain.rb', line 4469 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4439 4440 4441 |
# File 'lib/models/porcelain.rb', line 4439 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
4441 4442 4443 |
# File 'lib/models/porcelain.rb', line 4441 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
4443 4444 4445 |
# File 'lib/models/porcelain.rb', line 4443 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
4445 4446 4447 |
# File 'lib/models/porcelain.rb', line 4445 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4447 4448 4449 |
# File 'lib/models/porcelain.rb', line 4447 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
4449 4450 4451 |
# File 'lib/models/porcelain.rb', line 4449 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4451 4452 4453 |
# File 'lib/models/porcelain.rb', line 4451 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4453 4454 4455 |
# File 'lib/models/porcelain.rb', line 4453 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4455 4456 4457 |
# File 'lib/models/porcelain.rb', line 4455 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4457 4458 4459 |
# File 'lib/models/porcelain.rb', line 4457 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4459 4460 4461 |
# File 'lib/models/porcelain.rb', line 4459 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4461 4462 4463 |
# File 'lib/models/porcelain.rb', line 4461 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4463 4464 4465 |
# File 'lib/models/porcelain.rb', line 4463 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4465 4466 4467 |
# File 'lib/models/porcelain.rb', line 4465 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4467 4468 4469 |
# File 'lib/models/porcelain.rb', line 4467 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4503 4504 4505 4506 4507 4508 4509 |
# File 'lib/models/porcelain.rb', line 4503 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |