Class: SDM::KubernetesUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
constructor
A new instance of KubernetesUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
Returns a new instance of KubernetesUserImpersonation.
4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/models/porcelain.rb', line 4424 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4394 4395 4396 |
# File 'lib/models/porcelain.rb', line 4394 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
4396 4397 4398 |
# File 'lib/models/porcelain.rb', line 4396 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
4398 4399 4400 |
# File 'lib/models/porcelain.rb', line 4398 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
4400 4401 4402 |
# File 'lib/models/porcelain.rb', line 4400 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4402 4403 4404 |
# File 'lib/models/porcelain.rb', line 4402 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
4404 4405 4406 |
# File 'lib/models/porcelain.rb', line 4404 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4406 4407 4408 |
# File 'lib/models/porcelain.rb', line 4406 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4408 4409 4410 |
# File 'lib/models/porcelain.rb', line 4408 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4410 4411 4412 |
# File 'lib/models/porcelain.rb', line 4410 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4412 4413 4414 |
# File 'lib/models/porcelain.rb', line 4412 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4414 4415 4416 |
# File 'lib/models/porcelain.rb', line 4414 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4416 4417 4418 |
# File 'lib/models/porcelain.rb', line 4416 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4418 4419 4420 |
# File 'lib/models/porcelain.rb', line 4418 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4420 4421 4422 |
# File 'lib/models/porcelain.rb', line 4420 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4422 4423 4424 |
# File 'lib/models/porcelain.rb', line 4422 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4458 4459 4460 4461 4462 4463 4464 |
# File 'lib/models/porcelain.rb', line 4458 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |