Class: SDM::KubernetesUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
constructor
A new instance of KubernetesUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ KubernetesUserImpersonation
Returns a new instance of KubernetesUserImpersonation.
4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 |
# File 'lib/models/porcelain.rb', line 4275 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4245 4246 4247 |
# File 'lib/models/porcelain.rb', line 4245 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
4247 4248 4249 |
# File 'lib/models/porcelain.rb', line 4247 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
4249 4250 4251 |
# File 'lib/models/porcelain.rb', line 4249 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
4251 4252 4253 |
# File 'lib/models/porcelain.rb', line 4251 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4253 4254 4255 |
# File 'lib/models/porcelain.rb', line 4253 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
4255 4256 4257 |
# File 'lib/models/porcelain.rb', line 4255 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4257 4258 4259 |
# File 'lib/models/porcelain.rb', line 4257 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4259 4260 4261 |
# File 'lib/models/porcelain.rb', line 4259 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4261 4262 4263 |
# File 'lib/models/porcelain.rb', line 4261 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4263 4264 4265 |
# File 'lib/models/porcelain.rb', line 4263 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4265 4266 4267 |
# File 'lib/models/porcelain.rb', line 4265 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4267 4268 4269 |
# File 'lib/models/porcelain.rb', line 4267 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4269 4270 4271 |
# File 'lib/models/porcelain.rb', line 4269 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4271 4272 4273 |
# File 'lib/models/porcelain.rb', line 4271 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4273 4274 4275 |
# File 'lib/models/porcelain.rb', line 4273 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4309 4310 4311 4312 4313 4314 4315 |
# File 'lib/models/porcelain.rb', line 4309 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |