Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



4133
4134
4135
4136
4137
4138
4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
# File 'lib/models/porcelain.rb', line 4133

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4105
4106
4107
# File 'lib/models/porcelain.rb', line 4105

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



4107
4108
4109
# File 'lib/models/porcelain.rb', line 4107

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



4109
4110
4111
# File 'lib/models/porcelain.rb', line 4109

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



4111
4112
4113
# File 'lib/models/porcelain.rb', line 4111

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4113
4114
4115
# File 'lib/models/porcelain.rb', line 4113

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



4115
4116
4117
# File 'lib/models/porcelain.rb', line 4115

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4117
4118
4119
# File 'lib/models/porcelain.rb', line 4117

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4119
4120
4121
# File 'lib/models/porcelain.rb', line 4119

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4121
4122
4123
# File 'lib/models/porcelain.rb', line 4121

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4123
4124
4125
# File 'lib/models/porcelain.rb', line 4123

def name
  @name
end

#portObject

Returns the value of attribute port.



4125
4126
4127
# File 'lib/models/porcelain.rb', line 4125

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4127
4128
4129
# File 'lib/models/porcelain.rb', line 4127

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4129
4130
4131
# File 'lib/models/porcelain.rb', line 4129

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4131
4132
4133
# File 'lib/models/porcelain.rb', line 4131

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4165
4166
4167
4168
4169
4170
4171
# File 'lib/models/porcelain.rb', line 4165

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end