Class: SDM::KubernetesUserImpersonation
- Inherits:
-
Object
- Object
- SDM::KubernetesUserImpersonation
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ KubernetesUserImpersonation
constructor
A new instance of KubernetesUserImpersonation.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ KubernetesUserImpersonation
Returns a new instance of KubernetesUserImpersonation.
3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 |
# File 'lib/models/porcelain.rb', line 3796 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @egress_filter = egress_filter == nil ? "" : egress_filter @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3768 3769 3770 |
# File 'lib/models/porcelain.rb', line 3768 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3770 3771 3772 |
# File 'lib/models/porcelain.rb', line 3770 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
3772 3773 3774 |
# File 'lib/models/porcelain.rb', line 3772 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
3774 3775 3776 |
# File 'lib/models/porcelain.rb', line 3774 def client_key @client_key end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3776 3777 3778 |
# File 'lib/models/porcelain.rb', line 3776 def egress_filter @egress_filter end |
#healthcheck_namespace ⇒ Object
The path used to check the health of your connection. Defaults to default.
3778 3779 3780 |
# File 'lib/models/porcelain.rb', line 3778 def healthcheck_namespace @healthcheck_namespace end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3780 3781 3782 |
# File 'lib/models/porcelain.rb', line 3780 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3782 3783 3784 |
# File 'lib/models/porcelain.rb', line 3782 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3784 3785 3786 |
# File 'lib/models/porcelain.rb', line 3784 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3786 3787 3788 |
# File 'lib/models/porcelain.rb', line 3786 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
3788 3789 3790 |
# File 'lib/models/porcelain.rb', line 3788 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3790 3791 3792 |
# File 'lib/models/porcelain.rb', line 3790 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3792 3793 3794 |
# File 'lib/models/porcelain.rb', line 3792 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3794 3795 3796 |
# File 'lib/models/porcelain.rb', line 3794 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3828 3829 3830 3831 3832 3833 3834 |
# File 'lib/models/porcelain.rb', line 3828 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |