Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
3747
3748
3749
# File 'lib/models/porcelain.rb', line 3719

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3691
3692
3693
# File 'lib/models/porcelain.rb', line 3691

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3693
3694
3695
# File 'lib/models/porcelain.rb', line 3693

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3695
3696
3697
# File 'lib/models/porcelain.rb', line 3695

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3697
3698
3699
# File 'lib/models/porcelain.rb', line 3697

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3699
3700
3701
# File 'lib/models/porcelain.rb', line 3699

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3701
3702
3703
# File 'lib/models/porcelain.rb', line 3701

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3703
3704
3705
# File 'lib/models/porcelain.rb', line 3703

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3705
3706
3707
# File 'lib/models/porcelain.rb', line 3705

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3707
3708
3709
# File 'lib/models/porcelain.rb', line 3707

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3709
3710
3711
# File 'lib/models/porcelain.rb', line 3709

def name
  @name
end

#portObject

Returns the value of attribute port.



3711
3712
3713
# File 'lib/models/porcelain.rb', line 3711

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3713
3714
3715
# File 'lib/models/porcelain.rb', line 3713

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3715
3716
3717
# File 'lib/models/porcelain.rb', line 3715

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3717
3718
3719
# File 'lib/models/porcelain.rb', line 3717

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3751
3752
3753
3754
3755
3756
3757
# File 'lib/models/porcelain.rb', line 3751

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end