Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



3684
3685
3686
3687
3688
3689
3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
# File 'lib/models/porcelain.rb', line 3684

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3656
3657
3658
# File 'lib/models/porcelain.rb', line 3656

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3658
3659
3660
# File 'lib/models/porcelain.rb', line 3658

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3660
3661
3662
# File 'lib/models/porcelain.rb', line 3660

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3662
3663
3664
# File 'lib/models/porcelain.rb', line 3662

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3664
3665
3666
# File 'lib/models/porcelain.rb', line 3664

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3666
3667
3668
# File 'lib/models/porcelain.rb', line 3666

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3668
3669
3670
# File 'lib/models/porcelain.rb', line 3668

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3670
3671
3672
# File 'lib/models/porcelain.rb', line 3670

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3672
3673
3674
# File 'lib/models/porcelain.rb', line 3672

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3674
3675
3676
# File 'lib/models/porcelain.rb', line 3674

def name
  @name
end

#portObject

Returns the value of attribute port.



3676
3677
3678
# File 'lib/models/porcelain.rb', line 3676

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3678
3679
3680
# File 'lib/models/porcelain.rb', line 3678

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3680
3681
3682
# File 'lib/models/porcelain.rb', line 3680

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3682
3683
3684
# File 'lib/models/porcelain.rb', line 3682

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3716
3717
3718
3719
3720
3721
3722
# File 'lib/models/porcelain.rb', line 3716

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end