Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



3589
3590
3591
3592
3593
3594
3595
3596
3597
3598
3599
3600
3601
3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
# File 'lib/models/porcelain.rb', line 3589

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3561
3562
3563
# File 'lib/models/porcelain.rb', line 3561

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3563
3564
3565
# File 'lib/models/porcelain.rb', line 3563

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3565
3566
3567
# File 'lib/models/porcelain.rb', line 3565

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3567
3568
3569
# File 'lib/models/porcelain.rb', line 3567

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3569
3570
3571
# File 'lib/models/porcelain.rb', line 3569

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3571
3572
3573
# File 'lib/models/porcelain.rb', line 3571

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3573
3574
3575
# File 'lib/models/porcelain.rb', line 3573

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3575
3576
3577
# File 'lib/models/porcelain.rb', line 3575

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3577
3578
3579
# File 'lib/models/porcelain.rb', line 3577

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3579
3580
3581
# File 'lib/models/porcelain.rb', line 3579

def name
  @name
end

#portObject

Returns the value of attribute port.



3581
3582
3583
# File 'lib/models/porcelain.rb', line 3581

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3583
3584
3585
# File 'lib/models/porcelain.rb', line 3583

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3585
3586
3587
# File 'lib/models/porcelain.rb', line 3585

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3587
3588
3589
# File 'lib/models/porcelain.rb', line 3587

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3621
3622
3623
3624
3625
3626
3627
# File 'lib/models/porcelain.rb', line 3621

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end