Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
# File 'lib/models/porcelain.rb', line 3330

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthcheck_namespace = healthcheck_namespace == nil ? "" : healthcheck_namespace
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3302
3303
3304
# File 'lib/models/porcelain.rb', line 3302

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3304
3305
3306
# File 'lib/models/porcelain.rb', line 3304

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3306
3307
3308
# File 'lib/models/porcelain.rb', line 3306

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3308
3309
3310
# File 'lib/models/porcelain.rb', line 3308

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3310
3311
3312
# File 'lib/models/porcelain.rb', line 3310

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to default.



3312
3313
3314
# File 'lib/models/porcelain.rb', line 3312

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3314
3315
3316
# File 'lib/models/porcelain.rb', line 3314

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3316
3317
3318
# File 'lib/models/porcelain.rb', line 3316

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3318
3319
3320
# File 'lib/models/porcelain.rb', line 3318

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3320
3321
3322
# File 'lib/models/porcelain.rb', line 3320

def name
  @name
end

#portObject

Returns the value of attribute port.



3322
3323
3324
# File 'lib/models/porcelain.rb', line 3322

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3324
3325
3326
# File 'lib/models/porcelain.rb', line 3324

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3326
3327
3328
# File 'lib/models/porcelain.rb', line 3326

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3328
3329
3330
# File 'lib/models/porcelain.rb', line 3328

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3362
3363
3364
3365
3366
3367
3368
# File 'lib/models/porcelain.rb', line 3362

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end