Class: SDM::KubernetesUserImpersonation

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(certificate_authority: nil, client_certificate: nil, client_key: nil, egress_filter: nil, healthcheck_namespace: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, secret_store_id: nil, tags: nil) ⇒ KubernetesUserImpersonation

Returns a new instance of KubernetesUserImpersonation.



4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
# File 'lib/models/porcelain.rb', line 4083

def initialize(
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  egress_filter: nil,
  healthcheck_namespace: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  secret_store_id: nil,
  tags: nil
)
  if certificate_authority != nil
    @certificate_authority = certificate_authority
  end
  if client_certificate != nil
    @client_certificate = client_certificate
  end
  if client_key != nil
    @client_key = client_key
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthcheck_namespace != nil
    @healthcheck_namespace = healthcheck_namespace
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if port != nil
    @port = port
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
end

Instance Attribute Details

#certificate_authorityObject

Returns the value of attribute certificate_authority.



4059
4060
4061
# File 'lib/models/porcelain.rb', line 4059

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



4061
4062
4063
# File 'lib/models/porcelain.rb', line 4061

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



4063
4064
4065
# File 'lib/models/porcelain.rb', line 4063

def client_key
  @client_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4065
4066
4067
# File 'lib/models/porcelain.rb', line 4065

def egress_filter
  @egress_filter
end

#healthcheck_namespaceObject

The path used to check the health of your connection. Defaults to `default`.



4067
4068
4069
# File 'lib/models/porcelain.rb', line 4067

def healthcheck_namespace
  @healthcheck_namespace
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4069
4070
4071
# File 'lib/models/porcelain.rb', line 4069

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4071
4072
4073
# File 'lib/models/porcelain.rb', line 4071

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4073
4074
4075
# File 'lib/models/porcelain.rb', line 4073

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4075
4076
4077
# File 'lib/models/porcelain.rb', line 4075

def name
  @name
end

#portObject

Returns the value of attribute port.



4077
4078
4079
# File 'lib/models/porcelain.rb', line 4077

def port
  @port
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4079
4080
4081
# File 'lib/models/porcelain.rb', line 4079

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4081
4082
4083
# File 'lib/models/porcelain.rb', line 4081

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4135
4136
4137
4138
4139
4140
4141
# File 'lib/models/porcelain.rb', line 4135

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end