Class: SDM::LLM
- Inherits:
-
Object
- Object
- SDM::LLM
- Defined in:
- lib/models/porcelain.rb
Overview
LLM is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#models ⇒ Object
Space-separated list of model names this resource accepts.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, models: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ LLM
constructor
A new instance of LLM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, models: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ LLM
Returns a new instance of LLM.
10367 10368 10369 10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 10390 10391 10392 10393 10394 10395 |
# File 'lib/models/porcelain.rb', line 10367 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, models: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @models = models == nil ? "" : models @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
10341 10342 10343 |
# File 'lib/models/porcelain.rb', line 10341 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10343 10344 10345 |
# File 'lib/models/porcelain.rb', line 10343 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10345 10346 10347 |
# File 'lib/models/porcelain.rb', line 10345 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
10347 10348 10349 |
# File 'lib/models/porcelain.rb', line 10347 def id @id end |
#models ⇒ Object
Space-separated list of model names this resource accepts. Requests for unlisted models are rejected. Leave empty to allow all models.
10349 10350 10351 |
# File 'lib/models/porcelain.rb', line 10349 def models @models end |
#name ⇒ Object
Unique human-readable name of the Resource.
10351 10352 10353 |
# File 'lib/models/porcelain.rb', line 10351 def name @name end |
#password ⇒ Object
The password to authenticate with.
10353 10354 10355 |
# File 'lib/models/porcelain.rb', line 10353 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
10355 10356 10357 |
# File 'lib/models/porcelain.rb', line 10355 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10357 10358 10359 |
# File 'lib/models/porcelain.rb', line 10357 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10359 10360 10361 |
# File 'lib/models/porcelain.rb', line 10359 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
10361 10362 10363 |
# File 'lib/models/porcelain.rb', line 10361 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10363 10364 10365 |
# File 'lib/models/porcelain.rb', line 10363 def @tags end |
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
10365 10366 10367 |
# File 'lib/models/porcelain.rb', line 10365 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10397 10398 10399 10400 10401 10402 10403 |
# File 'lib/models/porcelain.rb', line 10397 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |