Class: SDM::LLM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

LLM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, models: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ LLM

Returns a new instance of LLM.



10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
10331
10332
10333
10334
10335
10336
10337
10338
10339
10340
10341
10342
10343
10344
10345
10346
10347
# File 'lib/models/porcelain.rb', line 10319

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  id: nil,
  models: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @models = models == nil ? "" : models
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10293
10294
10295
# File 'lib/models/porcelain.rb', line 10293

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10295
10296
10297
# File 'lib/models/porcelain.rb', line 10295

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10297
10298
10299
# File 'lib/models/porcelain.rb', line 10297

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



10299
10300
10301
# File 'lib/models/porcelain.rb', line 10299

def id
  @id
end

#modelsObject

Space-separated list of model names this resource accepts. Requests for unlisted models are rejected. Leave empty to allow all models.



10301
10302
10303
# File 'lib/models/porcelain.rb', line 10301

def models
  @models
end

#nameObject

Unique human-readable name of the Resource.



10303
10304
10305
# File 'lib/models/porcelain.rb', line 10303

def name
  @name
end

#passwordObject

The password to authenticate with.



10305
10306
10307
# File 'lib/models/porcelain.rb', line 10305

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10307
10308
10309
# File 'lib/models/porcelain.rb', line 10307

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10309
10310
10311
# File 'lib/models/porcelain.rb', line 10309

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10311
10312
10313
# File 'lib/models/porcelain.rb', line 10311

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10313
10314
10315
# File 'lib/models/porcelain.rb', line 10313

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10315
10316
10317
# File 'lib/models/porcelain.rb', line 10315

def tags
  @tags
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10317
10318
10319
# File 'lib/models/porcelain.rb', line 10317

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10349
10350
10351
10352
10353
10354
10355
# File 'lib/models/porcelain.rb', line 10349

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end