Class: SDM::LogCategoryConfig
- Inherits:
-
Object
- Object
- SDM::LogCategoryConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#remote_discard_replays ⇒ Object
Indicates if the Organization should exclude replay data from remote logging for the log category.
-
#remote_encoder ⇒ Object
The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.
Instance Method Summary collapse
-
#initialize(remote_discard_replays: nil, remote_encoder: nil) ⇒ LogCategoryConfig
constructor
A new instance of LogCategoryConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(remote_discard_replays: nil, remote_encoder: nil) ⇒ LogCategoryConfig
Returns a new instance of LogCategoryConfig.
10364 10365 10366 10367 10368 10369 10370 |
# File 'lib/models/porcelain.rb', line 10364 def initialize( remote_discard_replays: nil, remote_encoder: nil ) @remote_discard_replays = remote_discard_replays == nil ? false : remote_discard_replays @remote_encoder = remote_encoder == nil ? "" : remote_encoder end |
Instance Attribute Details
#remote_discard_replays ⇒ Object
Indicates if the Organization should exclude replay data from remote logging for the log category.
10360 10361 10362 |
# File 'lib/models/porcelain.rb', line 10360 def remote_discard_replays @remote_discard_replays end |
#remote_encoder ⇒ Object
The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.
10362 10363 10364 |
# File 'lib/models/porcelain.rb', line 10362 def remote_encoder @remote_encoder end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10372 10373 10374 10375 10376 10377 10378 |
# File 'lib/models/porcelain.rb', line 10372 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |