Class: SDM::LogCategoryConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(remote_discard_replays: nil, remote_encoder: nil) ⇒ LogCategoryConfig

Returns a new instance of LogCategoryConfig.



10069
10070
10071
10072
10073
10074
10075
# File 'lib/models/porcelain.rb', line 10069

def initialize(
  remote_discard_replays: nil,
  remote_encoder: nil
)
  @remote_discard_replays = remote_discard_replays == nil ? false : remote_discard_replays
  @remote_encoder = remote_encoder == nil ? "" : remote_encoder
end

Instance Attribute Details

#remote_discard_replaysObject

Indicates if the Organization should exclude replay data from remote logging for the log category.



10065
10066
10067
# File 'lib/models/porcelain.rb', line 10065

def remote_discard_replays
  @remote_discard_replays
end

#remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.



10067
10068
10069
# File 'lib/models/porcelain.rb', line 10067

def remote_encoder
  @remote_encoder
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10077
10078
10079
10080
10081
10082
10083
# File 'lib/models/porcelain.rb', line 10077

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end