Class: SDM::LogCategoryConfig
- Inherits:
-
Object
- Object
- SDM::LogCategoryConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#remote_discard_replays ⇒ Object
Indicates if the Organization should exclude replay data from remote logging for the log category.
-
#remote_encoder ⇒ Object
The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.
Instance Method Summary collapse
-
#initialize(remote_discard_replays: nil, remote_encoder: nil) ⇒ LogCategoryConfig
constructor
A new instance of LogCategoryConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(remote_discard_replays: nil, remote_encoder: nil) ⇒ LogCategoryConfig
Returns a new instance of LogCategoryConfig.
9775 9776 9777 9778 9779 9780 9781 |
# File 'lib/models/porcelain.rb', line 9775 def initialize( remote_discard_replays: nil, remote_encoder: nil ) @remote_discard_replays = remote_discard_replays == nil ? false : remote_discard_replays @remote_encoder = remote_encoder == nil ? "" : remote_encoder end |
Instance Attribute Details
#remote_discard_replays ⇒ Object
Indicates if the Organization should exclude replay data from remote logging for the log category.
9771 9772 9773 |
# File 'lib/models/porcelain.rb', line 9771 def remote_discard_replays @remote_discard_replays end |
#remote_encoder ⇒ Object
The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.
9773 9774 9775 |
# File 'lib/models/porcelain.rb', line 9773 def remote_encoder @remote_encoder end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9783 9784 9785 9786 9787 9788 9789 |
# File 'lib/models/porcelain.rb', line 9783 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |