Class: SDM::LogCategoryConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(remote_discard_replays: nil, remote_encoder: nil) ⇒ LogCategoryConfig

Returns a new instance of LogCategoryConfig.



8112
8113
8114
8115
8116
8117
8118
# File 'lib/models/porcelain.rb', line 8112

def initialize(
  remote_discard_replays: nil,
  remote_encoder: nil
)
  @remote_discard_replays = remote_discard_replays == nil ? false : remote_discard_replays
  @remote_encoder = remote_encoder == nil ? "" : remote_encoder
end

Instance Attribute Details

#remote_discard_replaysObject

Indicates if the Organization should exclude replay data from remote logging for the log category.



8108
8109
8110
# File 'lib/models/porcelain.rb', line 8108

def remote_discard_replays
  @remote_discard_replays
end

#remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.



8110
8111
8112
# File 'lib/models/porcelain.rb', line 8110

def remote_encoder
  @remote_encoder
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8120
8121
8122
8123
8124
8125
8126
# File 'lib/models/porcelain.rb', line 8120

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end