Class: SDM::LogConfig
- Inherits:
-
Object
- Object
- SDM::LogConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#categories ⇒ Object
The Organization's log category configuration settings.
-
#local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
-
#local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
-
#local_socket_path ⇒ Object
The Organization's local log socket path.
-
#local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
-
#local_tcp_address ⇒ Object
The Organization's local log TCP address.
-
#public_key ⇒ Object
The Organization's public key in PEM format for encrypting logs.
Instance Method Summary collapse
-
#initialize(categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil) ⇒ LogConfig
constructor
A new instance of LogConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil) ⇒ LogConfig
Returns a new instance of LogConfig.
10445 10446 10447 10448 10449 10450 10451 10452 10453 10454 10455 10456 10457 10458 10459 10460 10461 |
# File 'lib/models/porcelain.rb', line 10445 def initialize( categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil ) @categories = categories == nil ? SDM::_porcelain_zero_value_log_category_config_map() : categories @local_encoder = local_encoder == nil ? "" : local_encoder @local_format = local_format == nil ? "" : local_format @local_socket_path = local_socket_path == nil ? "" : local_socket_path @local_storage = local_storage == nil ? "" : local_storage @local_tcp_address = local_tcp_address == nil ? "" : local_tcp_address @public_key = public_key == nil ? "" : public_key end |
Instance Attribute Details
#categories ⇒ Object
The Organization's log category configuration settings.
10431 10432 10433 |
# File 'lib/models/porcelain.rb', line 10431 def categories @categories end |
#local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
10433 10434 10435 |
# File 'lib/models/porcelain.rb', line 10433 def local_encoder @local_encoder end |
#local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
10435 10436 10437 |
# File 'lib/models/porcelain.rb', line 10435 def local_format @local_format end |
#local_socket_path ⇒ Object
The Organization's local log socket path.
10437 10438 10439 |
# File 'lib/models/porcelain.rb', line 10437 def local_socket_path @local_socket_path end |
#local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
10439 10440 10441 |
# File 'lib/models/porcelain.rb', line 10439 def local_storage @local_storage end |
#local_tcp_address ⇒ Object
The Organization's local log TCP address.
10441 10442 10443 |
# File 'lib/models/porcelain.rb', line 10441 def local_tcp_address @local_tcp_address end |
#public_key ⇒ Object
The Organization's public key in PEM format for encrypting logs.
10443 10444 10445 |
# File 'lib/models/porcelain.rb', line 10443 def public_key @public_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10463 10464 10465 10466 10467 10468 10469 |
# File 'lib/models/porcelain.rb', line 10463 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |