Class: SDM::LogConfig
- Inherits:
-
Object
- Object
- SDM::LogConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#categories ⇒ Object
The Organization's log category configuration settings.
-
#local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
-
#local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
-
#local_socket_path ⇒ Object
The Organization's local log socket path.
-
#local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
-
#local_tcp_address ⇒ Object
The Organization's local log TCP address.
-
#public_key ⇒ Object
The Organization's public key in PEM format for encrypting logs.
Instance Method Summary collapse
-
#initialize(categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil) ⇒ LogConfig
constructor
A new instance of LogConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil) ⇒ LogConfig
Returns a new instance of LogConfig.
10397 10398 10399 10400 10401 10402 10403 10404 10405 10406 10407 10408 10409 10410 10411 10412 10413 |
# File 'lib/models/porcelain.rb', line 10397 def initialize( categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil ) @categories = categories == nil ? SDM::_porcelain_zero_value_log_category_config_map() : categories @local_encoder = local_encoder == nil ? "" : local_encoder @local_format = local_format == nil ? "" : local_format @local_socket_path = local_socket_path == nil ? "" : local_socket_path @local_storage = local_storage == nil ? "" : local_storage @local_tcp_address = local_tcp_address == nil ? "" : local_tcp_address @public_key = public_key == nil ? "" : public_key end |
Instance Attribute Details
#categories ⇒ Object
The Organization's log category configuration settings.
10383 10384 10385 |
# File 'lib/models/porcelain.rb', line 10383 def categories @categories end |
#local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
10385 10386 10387 |
# File 'lib/models/porcelain.rb', line 10385 def local_encoder @local_encoder end |
#local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
10387 10388 10389 |
# File 'lib/models/porcelain.rb', line 10387 def local_format @local_format end |
#local_socket_path ⇒ Object
The Organization's local log socket path.
10389 10390 10391 |
# File 'lib/models/porcelain.rb', line 10389 def local_socket_path @local_socket_path end |
#local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
10391 10392 10393 |
# File 'lib/models/porcelain.rb', line 10391 def local_storage @local_storage end |
#local_tcp_address ⇒ Object
The Organization's local log TCP address.
10393 10394 10395 |
# File 'lib/models/porcelain.rb', line 10393 def local_tcp_address @local_tcp_address end |
#public_key ⇒ Object
The Organization's public key in PEM format for encrypting logs.
10395 10396 10397 |
# File 'lib/models/porcelain.rb', line 10395 def public_key @public_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10415 10416 10417 10418 10419 10420 10421 |
# File 'lib/models/porcelain.rb', line 10415 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |