Class: SDM::LogConfig
- Inherits:
-
Object
- Object
- SDM::LogConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#categories ⇒ Object
The Organization's log category configuration settings.
-
#local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
-
#local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
-
#local_socket_path ⇒ Object
The Organization's local log socket path.
-
#local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
-
#local_tcp_address ⇒ Object
The Organization's local log TCP address.
-
#public_key ⇒ Object
The Organization's public key in PEM format for encrypting logs.
Instance Method Summary collapse
-
#initialize(categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil) ⇒ LogConfig
constructor
A new instance of LogConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil) ⇒ LogConfig
Returns a new instance of LogConfig.
10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 |
# File 'lib/models/porcelain.rb', line 10175 def initialize( categories: nil, local_encoder: nil, local_format: nil, local_socket_path: nil, local_storage: nil, local_tcp_address: nil, public_key: nil ) @categories = categories == nil ? SDM::_porcelain_zero_value_log_category_config_map() : categories @local_encoder = local_encoder == nil ? "" : local_encoder @local_format = local_format == nil ? "" : local_format @local_socket_path = local_socket_path == nil ? "" : local_socket_path @local_storage = local_storage == nil ? "" : local_storage @local_tcp_address = local_tcp_address == nil ? "" : local_tcp_address @public_key = public_key == nil ? "" : public_key end |
Instance Attribute Details
#categories ⇒ Object
The Organization's log category configuration settings.
10161 10162 10163 |
# File 'lib/models/porcelain.rb', line 10161 def categories @categories end |
#local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
10163 10164 10165 |
# File 'lib/models/porcelain.rb', line 10163 def local_encoder @local_encoder end |
#local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
10165 10166 10167 |
# File 'lib/models/porcelain.rb', line 10165 def local_format @local_format end |
#local_socket_path ⇒ Object
The Organization's local log socket path.
10167 10168 10169 |
# File 'lib/models/porcelain.rb', line 10167 def local_socket_path @local_socket_path end |
#local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
10169 10170 10171 |
# File 'lib/models/porcelain.rb', line 10169 def local_storage @local_storage end |
#local_tcp_address ⇒ Object
The Organization's local log TCP address.
10171 10172 10173 |
# File 'lib/models/porcelain.rb', line 10171 def local_tcp_address @local_tcp_address end |
#public_key ⇒ Object
The Organization's public key in PEM format for encrypting logs.
10173 10174 10175 |
# File 'lib/models/porcelain.rb', line 10173 def public_key @public_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10193 10194 10195 10196 10197 10198 10199 |
# File 'lib/models/porcelain.rb', line 10193 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |