Class: SDM::MCP
- Inherits:
-
Object
- Object
- SDM::MCP
- Defined in:
- lib/models/porcelain.rb
Overview
MCP is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#oauth_auth_endpoint ⇒ Object
The OAuth 2.0 authorization endpoint URL.
-
#oauth_token_endpoint ⇒ Object
The OAuth 2.0 token endpoint URL.
-
#password ⇒ Object
OAuth App Client Secret.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
OAuth App Client ID.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_token_endpoint: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ MCP
constructor
A new instance of MCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_token_endpoint: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ MCP
Returns a new instance of MCP.
10236 10237 10238 10239 10240 10241 10242 10243 10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 |
# File 'lib/models/porcelain.rb', line 10236 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_token_endpoint: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
10206 10207 10208 |
# File 'lib/models/porcelain.rb', line 10206 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10208 10209 10210 |
# File 'lib/models/porcelain.rb', line 10208 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10210 10211 10212 |
# File 'lib/models/porcelain.rb', line 10210 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10212 10213 10214 |
# File 'lib/models/porcelain.rb', line 10212 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10214 10215 10216 |
# File 'lib/models/porcelain.rb', line 10214 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10216 10217 10218 |
# File 'lib/models/porcelain.rb', line 10216 def name @name end |
#oauth_auth_endpoint ⇒ Object
The OAuth 2.0 authorization endpoint URL.
10218 10219 10220 |
# File 'lib/models/porcelain.rb', line 10218 def oauth_auth_endpoint @oauth_auth_endpoint end |
#oauth_token_endpoint ⇒ Object
The OAuth 2.0 token endpoint URL.
10220 10221 10222 |
# File 'lib/models/porcelain.rb', line 10220 def oauth_token_endpoint @oauth_token_endpoint end |
#password ⇒ Object
OAuth App Client Secret
10222 10223 10224 |
# File 'lib/models/porcelain.rb', line 10222 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
10224 10225 10226 |
# File 'lib/models/porcelain.rb', line 10224 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10226 10227 10228 |
# File 'lib/models/porcelain.rb', line 10226 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10228 10229 10230 |
# File 'lib/models/porcelain.rb', line 10228 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
10230 10231 10232 |
# File 'lib/models/porcelain.rb', line 10230 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10232 10233 10234 |
# File 'lib/models/porcelain.rb', line 10232 def @tags end |
#username ⇒ Object
OAuth App Client ID
10234 10235 10236 |
# File 'lib/models/porcelain.rb', line 10234 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10270 10271 10272 10273 10274 10275 10276 |
# File 'lib/models/porcelain.rb', line 10270 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |