Class: SDM::MCP
- Inherits:
-
Object
- Object
- SDM::MCP
- Defined in:
- lib/models/porcelain.rb
Overview
MCP is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#oauth_auth_endpoint ⇒ Object
The OAuth 2.0 authorization endpoint URL.
-
#oauth_register_endpoint ⇒ Object
The OAuth 2.0 dynamic client registration endpoint URL.
-
#oauth_token_endpoint ⇒ Object
The OAuth 2.0 token endpoint URL.
-
#password ⇒ Object
OAuth App Client Secret.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
OAuth App Client ID.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_token_endpoint: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ MCP
constructor
A new instance of MCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_token_endpoint: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ MCP
Returns a new instance of MCP.
9872 9873 9874 9875 9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 9905 9906 9907 9908 |
# File 'lib/models/porcelain.rb', line 9872 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_token_endpoint: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint @oauth_register_endpoint = oauth_register_endpoint == nil ? "" : oauth_register_endpoint @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
9838 9839 9840 |
# File 'lib/models/porcelain.rb', line 9838 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9840 9841 9842 |
# File 'lib/models/porcelain.rb', line 9840 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9842 9843 9844 |
# File 'lib/models/porcelain.rb', line 9842 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9844 9845 9846 |
# File 'lib/models/porcelain.rb', line 9844 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9846 9847 9848 |
# File 'lib/models/porcelain.rb', line 9846 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9848 9849 9850 |
# File 'lib/models/porcelain.rb', line 9848 def name @name end |
#oauth_auth_endpoint ⇒ Object
The OAuth 2.0 authorization endpoint URL.
9850 9851 9852 |
# File 'lib/models/porcelain.rb', line 9850 def oauth_auth_endpoint @oauth_auth_endpoint end |
#oauth_register_endpoint ⇒ Object
The OAuth 2.0 dynamic client registration endpoint URL.
9852 9853 9854 |
# File 'lib/models/porcelain.rb', line 9852 def oauth_register_endpoint @oauth_register_endpoint end |
#oauth_token_endpoint ⇒ Object
The OAuth 2.0 token endpoint URL.
9854 9855 9856 |
# File 'lib/models/porcelain.rb', line 9854 def oauth_token_endpoint @oauth_token_endpoint end |
#password ⇒ Object
OAuth App Client Secret
9856 9857 9858 |
# File 'lib/models/porcelain.rb', line 9856 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9858 9859 9860 |
# File 'lib/models/porcelain.rb', line 9858 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
9860 9861 9862 |
# File 'lib/models/porcelain.rb', line 9860 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9862 9863 9864 |
# File 'lib/models/porcelain.rb', line 9862 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9864 9865 9866 |
# File 'lib/models/porcelain.rb', line 9864 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
9866 9867 9868 |
# File 'lib/models/porcelain.rb', line 9866 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9868 9869 9870 |
# File 'lib/models/porcelain.rb', line 9868 def @tags end |
#username ⇒ Object
OAuth App Client ID
9870 9871 9872 |
# File 'lib/models/porcelain.rb', line 9870 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9910 9911 9912 9913 9914 9915 9916 |
# File 'lib/models/porcelain.rb', line 9910 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |