Class: SDM::MCPDCR
- Inherits:
-
Object
- Object
- SDM::MCPDCR
- Defined in:
- lib/models/porcelain.rb
Overview
MCPDCR is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#oauth_auth_endpoint ⇒ Object
The OAuth 2.0 authorization endpoint URL.
-
#oauth_register_endpoint ⇒ Object
The OAuth 2.0 dynamic client registration endpoint URL.
-
#oauth_token_endpoint ⇒ Object
The OAuth 2.0 token endpoint URL.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ MCPDCR
constructor
A new instance of MCPDCR.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ MCPDCR
Returns a new instance of MCPDCR.
9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 |
# File 'lib/models/porcelain.rb', line 9942 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint @oauth_register_endpoint = oauth_register_endpoint == nil ? "" : oauth_register_endpoint @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
9914 9915 9916 |
# File 'lib/models/porcelain.rb', line 9914 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9916 9917 9918 |
# File 'lib/models/porcelain.rb', line 9916 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9918 9919 9920 |
# File 'lib/models/porcelain.rb', line 9918 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9920 9921 9922 |
# File 'lib/models/porcelain.rb', line 9920 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9922 9923 9924 |
# File 'lib/models/porcelain.rb', line 9922 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9924 9925 9926 |
# File 'lib/models/porcelain.rb', line 9924 def name @name end |
#oauth_auth_endpoint ⇒ Object
The OAuth 2.0 authorization endpoint URL.
9926 9927 9928 |
# File 'lib/models/porcelain.rb', line 9926 def oauth_auth_endpoint @oauth_auth_endpoint end |
#oauth_register_endpoint ⇒ Object
The OAuth 2.0 dynamic client registration endpoint URL.
9928 9929 9930 |
# File 'lib/models/porcelain.rb', line 9928 def oauth_register_endpoint @oauth_register_endpoint end |
#oauth_token_endpoint ⇒ Object
The OAuth 2.0 token endpoint URL.
9930 9931 9932 |
# File 'lib/models/porcelain.rb', line 9930 def oauth_token_endpoint @oauth_token_endpoint end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
9932 9933 9934 |
# File 'lib/models/porcelain.rb', line 9932 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9934 9935 9936 |
# File 'lib/models/porcelain.rb', line 9934 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9936 9937 9938 |
# File 'lib/models/porcelain.rb', line 9936 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
9938 9939 9940 |
# File 'lib/models/porcelain.rb', line 9938 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9940 9941 9942 |
# File 'lib/models/porcelain.rb', line 9940 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9974 9975 9976 9977 9978 9979 9980 |
# File 'lib/models/porcelain.rb', line 9974 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |