Class: SDM::MCPGatewayNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayNoAuth

Returns a new instance of MCPGatewayNoAuth.



10538
10539
10540
10541
10542
10543
10544
10545
10546
10547
10548
10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
# File 'lib/models/porcelain.rb', line 10538

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10510
10511
10512
# File 'lib/models/porcelain.rb', line 10510

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10512
10513
10514
# File 'lib/models/porcelain.rb', line 10512

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10514
10515
10516
# File 'lib/models/porcelain.rb', line 10514

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10516
10517
10518
# File 'lib/models/porcelain.rb', line 10516

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10518
10519
10520
# File 'lib/models/porcelain.rb', line 10518

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10520
10521
10522
# File 'lib/models/porcelain.rb', line 10520

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10522
10523
10524
# File 'lib/models/porcelain.rb', line 10522

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10524
10525
10526
# File 'lib/models/porcelain.rb', line 10524

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10526
10527
10528
# File 'lib/models/porcelain.rb', line 10526

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10528
10529
10530
# File 'lib/models/porcelain.rb', line 10528

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10530
10531
10532
# File 'lib/models/porcelain.rb', line 10530

def tags
  @tags
end

#tls_certObject

Custom TLS certificate for upstream connection.



10532
10533
10534
# File 'lib/models/porcelain.rb', line 10532

def tls_cert
  @tls_cert
end

#tls_insecureObject

Skip TLS certificate verification for the upstream connection.



10534
10535
10536
# File 'lib/models/porcelain.rb', line 10534

def tls_insecure
  @tls_insecure
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10536
10537
10538
# File 'lib/models/porcelain.rb', line 10536

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10570
10571
10572
10573
10574
10575
10576
# File 'lib/models/porcelain.rb', line 10570

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end