Class: SDM::MCPGatewayNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ MCPGatewayNoAuth

Returns a new instance of MCPGatewayNoAuth.



10450
10451
10452
10453
10454
10455
10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
# File 'lib/models/porcelain.rb', line 10450

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10426
10427
10428
# File 'lib/models/porcelain.rb', line 10426

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10428
10429
10430
# File 'lib/models/porcelain.rb', line 10428

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10430
10431
10432
# File 'lib/models/porcelain.rb', line 10430

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10432
10433
10434
# File 'lib/models/porcelain.rb', line 10432

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10434
10435
10436
# File 'lib/models/porcelain.rb', line 10434

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10436
10437
10438
# File 'lib/models/porcelain.rb', line 10436

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10438
10439
10440
# File 'lib/models/porcelain.rb', line 10438

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10440
10441
10442
# File 'lib/models/porcelain.rb', line 10440

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10442
10443
10444
# File 'lib/models/porcelain.rb', line 10442

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10444
10445
10446
# File 'lib/models/porcelain.rb', line 10444

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10446
10447
10448
# File 'lib/models/porcelain.rb', line 10446

def tags
  @tags
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10448
10449
10450
# File 'lib/models/porcelain.rb', line 10448

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10478
10479
10480
10481
10482
10483
10484
# File 'lib/models/porcelain.rb', line 10478

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end