Class: SDM::MCPGatewayNoAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ MCPGatewayNoAuth

Returns a new instance of MCPGatewayNoAuth.



10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
10399
10400
10401
10402
10403
10404
10405
10406
# File 'lib/models/porcelain.rb', line 10380

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10356
10357
10358
# File 'lib/models/porcelain.rb', line 10356

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10358
10359
10360
# File 'lib/models/porcelain.rb', line 10358

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10360
10361
10362
# File 'lib/models/porcelain.rb', line 10360

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10362
10363
10364
# File 'lib/models/porcelain.rb', line 10362

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10364
10365
10366
# File 'lib/models/porcelain.rb', line 10364

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10366
10367
10368
# File 'lib/models/porcelain.rb', line 10366

def name
  @name
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10368
10369
10370
# File 'lib/models/porcelain.rb', line 10368

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10370
10371
10372
# File 'lib/models/porcelain.rb', line 10370

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10372
10373
10374
# File 'lib/models/porcelain.rb', line 10372

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10374
10375
10376
# File 'lib/models/porcelain.rb', line 10374

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10376
10377
10378
# File 'lib/models/porcelain.rb', line 10376

def tags
  @tags
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10378
10379
10380
# File 'lib/models/porcelain.rb', line 10378

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10408
10409
10410
10411
10412
10413
10414
# File 'lib/models/porcelain.rb', line 10408

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end