Class: SDM::MCPGatewayOAuth

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_scopes: nil, oauth_token_endpoint: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil, username: nil) ⇒ MCPGatewayOAuth

Returns a new instance of MCPGatewayOAuth.



10453
10454
10455
10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/models/porcelain.rb', line 10453

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  oauth_auth_endpoint: nil,
  oauth_scopes: nil,
  oauth_token_endpoint: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint
  @oauth_scopes = oauth_scopes == nil ? "" : oauth_scopes
  @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10419
10420
10421
# File 'lib/models/porcelain.rb', line 10419

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10421
10422
10423
# File 'lib/models/porcelain.rb', line 10421

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10423
10424
10425
# File 'lib/models/porcelain.rb', line 10423

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10425
10426
10427
# File 'lib/models/porcelain.rb', line 10425

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10427
10428
10429
# File 'lib/models/porcelain.rb', line 10427

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10429
10430
10431
# File 'lib/models/porcelain.rb', line 10429

def name
  @name
end

#oauth_auth_endpointObject

The OAuth 2.0 authorization endpoint URL.



10431
10432
10433
# File 'lib/models/porcelain.rb', line 10431

def oauth_auth_endpoint
  @oauth_auth_endpoint
end

#oauth_scopesObject

Space-separated list of OAuth scopes to request.



10433
10434
10435
# File 'lib/models/porcelain.rb', line 10433

def oauth_scopes
  @oauth_scopes
end

#oauth_token_endpointObject

The OAuth 2.0 token endpoint URL.



10435
10436
10437
# File 'lib/models/porcelain.rb', line 10435

def oauth_token_endpoint
  @oauth_token_endpoint
end

#passwordObject

OAuth App Client Secret



10437
10438
10439
# File 'lib/models/porcelain.rb', line 10437

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10439
10440
10441
# File 'lib/models/porcelain.rb', line 10439

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10441
10442
10443
# File 'lib/models/porcelain.rb', line 10441

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10443
10444
10445
# File 'lib/models/porcelain.rb', line 10443

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10445
10446
10447
# File 'lib/models/porcelain.rb', line 10445

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10447
10448
10449
# File 'lib/models/porcelain.rb', line 10447

def tags
  @tags
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10449
10450
10451
# File 'lib/models/porcelain.rb', line 10449

def url
  @url
end

#usernameObject

OAuth App Client ID



10451
10452
10453
# File 'lib/models/porcelain.rb', line 10451

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10491
10492
10493
10494
10495
10496
10497
# File 'lib/models/porcelain.rb', line 10491

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end