Class: SDM::MCPGatewayOAuthDCR
- Inherits:
-
Object
- Object
- SDM::MCPGatewayOAuthDCR
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#oauth_auth_endpoint ⇒ Object
The OAuth 2.0 authorization endpoint URL.
-
#oauth_register_endpoint ⇒ Object
The OAuth 2.0 dynamic client registration endpoint URL.
-
#oauth_scopes ⇒ Object
Space-separated list of OAuth scopes to request.
-
#oauth_token_endpoint ⇒ Object
The OAuth 2.0 token endpoint URL.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_cert ⇒ Object
Custom TLS certificate for upstream connection.
-
#tls_insecure ⇒ Object
Skip TLS certificate verification for the upstream connection.
-
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_scopes: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayOAuthDCR
constructor
A new instance of MCPGatewayOAuthDCR.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_scopes: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayOAuthDCR
Returns a new instance of MCPGatewayOAuthDCR.
10708 10709 10710 10711 10712 10713 10714 10715 10716 10717 10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 10733 10734 10735 10736 10737 10738 10739 10740 10741 10742 10743 10744 10745 10746 |
# File 'lib/models/porcelain.rb', line 10708 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_scopes: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint @oauth_register_endpoint = oauth_register_endpoint == nil ? "" : oauth_register_endpoint @oauth_scopes = oauth_scopes == nil ? "" : oauth_scopes @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_cert = tls_cert == nil ? "" : tls_cert @tls_insecure = tls_insecure == nil ? false : tls_insecure @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
10672 10673 10674 |
# File 'lib/models/porcelain.rb', line 10672 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10674 10675 10676 |
# File 'lib/models/porcelain.rb', line 10674 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10676 10677 10678 |
# File 'lib/models/porcelain.rb', line 10676 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10678 10679 10680 |
# File 'lib/models/porcelain.rb', line 10678 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10680 10681 10682 |
# File 'lib/models/porcelain.rb', line 10680 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10682 10683 10684 |
# File 'lib/models/porcelain.rb', line 10682 def name @name end |
#oauth_auth_endpoint ⇒ Object
The OAuth 2.0 authorization endpoint URL.
10684 10685 10686 |
# File 'lib/models/porcelain.rb', line 10684 def oauth_auth_endpoint @oauth_auth_endpoint end |
#oauth_register_endpoint ⇒ Object
The OAuth 2.0 dynamic client registration endpoint URL.
10686 10687 10688 |
# File 'lib/models/porcelain.rb', line 10686 def oauth_register_endpoint @oauth_register_endpoint end |
#oauth_scopes ⇒ Object
Space-separated list of OAuth scopes to request.
10688 10689 10690 |
# File 'lib/models/porcelain.rb', line 10688 def oauth_scopes @oauth_scopes end |
#oauth_token_endpoint ⇒ Object
The OAuth 2.0 token endpoint URL.
10690 10691 10692 |
# File 'lib/models/porcelain.rb', line 10690 def oauth_token_endpoint @oauth_token_endpoint end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
10692 10693 10694 |
# File 'lib/models/porcelain.rb', line 10692 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10694 10695 10696 |
# File 'lib/models/porcelain.rb', line 10694 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10696 10697 10698 |
# File 'lib/models/porcelain.rb', line 10696 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
10698 10699 10700 |
# File 'lib/models/porcelain.rb', line 10698 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10700 10701 10702 |
# File 'lib/models/porcelain.rb', line 10700 def @tags end |
#tls_cert ⇒ Object
Custom TLS certificate for upstream connection.
10702 10703 10704 |
# File 'lib/models/porcelain.rb', line 10702 def tls_cert @tls_cert end |
#tls_insecure ⇒ Object
Skip TLS certificate verification for the upstream connection.
10704 10705 10706 |
# File 'lib/models/porcelain.rb', line 10704 def tls_insecure @tls_insecure end |
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
10706 10707 10708 |
# File 'lib/models/porcelain.rb', line 10706 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10748 10749 10750 10751 10752 10753 10754 |
# File 'lib/models/porcelain.rb', line 10748 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |