Class: SDM::MCPGatewayOAuthDCR

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_scopes: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayOAuthDCR

Returns a new instance of MCPGatewayOAuthDCR.



10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
10693
10694
10695
10696
10697
10698
10699
10700
10701
10702
10703
10704
10705
10706
10707
10708
10709
10710
# File 'lib/models/porcelain.rb', line 10672

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  oauth_auth_endpoint: nil,
  oauth_register_endpoint: nil,
  oauth_scopes: nil,
  oauth_token_endpoint: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint
  @oauth_register_endpoint = oauth_register_endpoint == nil ? "" : oauth_register_endpoint
  @oauth_scopes = oauth_scopes == nil ? "" : oauth_scopes
  @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10636
10637
10638
# File 'lib/models/porcelain.rb', line 10636

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10638
10639
10640
# File 'lib/models/porcelain.rb', line 10638

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10640
10641
10642
# File 'lib/models/porcelain.rb', line 10640

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10642
10643
10644
# File 'lib/models/porcelain.rb', line 10642

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10644
10645
10646
# File 'lib/models/porcelain.rb', line 10644

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10646
10647
10648
# File 'lib/models/porcelain.rb', line 10646

def name
  @name
end

#oauth_auth_endpointObject

The OAuth 2.0 authorization endpoint URL.



10648
10649
10650
# File 'lib/models/porcelain.rb', line 10648

def oauth_auth_endpoint
  @oauth_auth_endpoint
end

#oauth_register_endpointObject

The OAuth 2.0 dynamic client registration endpoint URL.



10650
10651
10652
# File 'lib/models/porcelain.rb', line 10650

def oauth_register_endpoint
  @oauth_register_endpoint
end

#oauth_scopesObject

Space-separated list of OAuth scopes to request.



10652
10653
10654
# File 'lib/models/porcelain.rb', line 10652

def oauth_scopes
  @oauth_scopes
end

#oauth_token_endpointObject

The OAuth 2.0 token endpoint URL.



10654
10655
10656
# File 'lib/models/porcelain.rb', line 10654

def oauth_token_endpoint
  @oauth_token_endpoint
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10656
10657
10658
# File 'lib/models/porcelain.rb', line 10656

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10658
10659
10660
# File 'lib/models/porcelain.rb', line 10658

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10660
10661
10662
# File 'lib/models/porcelain.rb', line 10660

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10662
10663
10664
# File 'lib/models/porcelain.rb', line 10662

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10664
10665
10666
# File 'lib/models/porcelain.rb', line 10664

def tags
  @tags
end

#tls_certObject

Custom TLS certificate for upstream connection.



10666
10667
10668
# File 'lib/models/porcelain.rb', line 10666

def tls_cert
  @tls_cert
end

#tls_insecureObject

Skip TLS certificate verification for the upstream connection.



10668
10669
10670
# File 'lib/models/porcelain.rb', line 10668

def tls_insecure
  @tls_insecure
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10670
10671
10672
# File 'lib/models/porcelain.rb', line 10670

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10712
10713
10714
10715
10716
10717
10718
# File 'lib/models/porcelain.rb', line 10712

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end