Class: SDM::MCPGatewayOAuthDCR

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, oauth_auth_endpoint: nil, oauth_register_endpoint: nil, oauth_scopes: nil, oauth_token_endpoint: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ MCPGatewayOAuthDCR

Returns a new instance of MCPGatewayOAuthDCR.



10604
10605
10606
10607
10608
10609
10610
10611
10612
10613
10614
10615
10616
10617
10618
10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
10629
10630
10631
10632
10633
10634
10635
10636
10637
10638
# File 'lib/models/porcelain.rb', line 10604

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  oauth_auth_endpoint: nil,
  oauth_register_endpoint: nil,
  oauth_scopes: nil,
  oauth_token_endpoint: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @oauth_auth_endpoint = oauth_auth_endpoint == nil ? "" : oauth_auth_endpoint
  @oauth_register_endpoint = oauth_register_endpoint == nil ? "" : oauth_register_endpoint
  @oauth_scopes = oauth_scopes == nil ? "" : oauth_scopes
  @oauth_token_endpoint = oauth_token_endpoint == nil ? "" : oauth_token_endpoint
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10572
10573
10574
# File 'lib/models/porcelain.rb', line 10572

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10574
10575
10576
# File 'lib/models/porcelain.rb', line 10574

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10576
10577
10578
# File 'lib/models/porcelain.rb', line 10576

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10578
10579
10580
# File 'lib/models/porcelain.rb', line 10578

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10580
10581
10582
# File 'lib/models/porcelain.rb', line 10580

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10582
10583
10584
# File 'lib/models/porcelain.rb', line 10582

def name
  @name
end

#oauth_auth_endpointObject

The OAuth 2.0 authorization endpoint URL.



10584
10585
10586
# File 'lib/models/porcelain.rb', line 10584

def oauth_auth_endpoint
  @oauth_auth_endpoint
end

#oauth_register_endpointObject

The OAuth 2.0 dynamic client registration endpoint URL.



10586
10587
10588
# File 'lib/models/porcelain.rb', line 10586

def oauth_register_endpoint
  @oauth_register_endpoint
end

#oauth_scopesObject

Space-separated list of OAuth scopes to request.



10588
10589
10590
# File 'lib/models/porcelain.rb', line 10588

def oauth_scopes
  @oauth_scopes
end

#oauth_token_endpointObject

The OAuth 2.0 token endpoint URL.



10590
10591
10592
# File 'lib/models/porcelain.rb', line 10590

def oauth_token_endpoint
  @oauth_token_endpoint
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10592
10593
10594
# File 'lib/models/porcelain.rb', line 10592

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10594
10595
10596
# File 'lib/models/porcelain.rb', line 10594

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10596
10597
10598
# File 'lib/models/porcelain.rb', line 10596

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10598
10599
10600
# File 'lib/models/porcelain.rb', line 10598

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10600
10601
10602
# File 'lib/models/porcelain.rb', line 10600

def tags
  @tags
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10602
10603
10604
# File 'lib/models/porcelain.rb', line 10602

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10640
10641
10642
10643
10644
10645
10646
# File 'lib/models/porcelain.rb', line 10640

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end