Class: SDM::MCPGatewayPAT

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayPAT

Returns a new instance of MCPGatewayPAT.



10789
10790
10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
10802
10803
10804
10805
10806
10807
10808
10809
10810
10811
10812
10813
10814
10815
10816
10817
10818
10819
10820
10821
# File 'lib/models/porcelain.rb', line 10789

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10759
10760
10761
# File 'lib/models/porcelain.rb', line 10759

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10761
10762
10763
# File 'lib/models/porcelain.rb', line 10761

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10763
10764
10765
# File 'lib/models/porcelain.rb', line 10763

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10765
10766
10767
# File 'lib/models/porcelain.rb', line 10765

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10767
10768
10769
# File 'lib/models/porcelain.rb', line 10767

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10769
10770
10771
# File 'lib/models/porcelain.rb', line 10769

def name
  @name
end

#passwordObject

The password to authenticate with.



10771
10772
10773
# File 'lib/models/porcelain.rb', line 10771

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10773
10774
10775
# File 'lib/models/porcelain.rb', line 10773

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10775
10776
10777
# File 'lib/models/porcelain.rb', line 10775

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10777
10778
10779
# File 'lib/models/porcelain.rb', line 10777

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10779
10780
10781
# File 'lib/models/porcelain.rb', line 10779

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10781
10782
10783
# File 'lib/models/porcelain.rb', line 10781

def tags
  @tags
end

#tls_certObject

Custom TLS certificate for upstream connection.



10783
10784
10785
# File 'lib/models/porcelain.rb', line 10783

def tls_cert
  @tls_cert
end

#tls_insecureObject

Skip TLS certificate verification for the upstream connection.



10785
10786
10787
# File 'lib/models/porcelain.rb', line 10785

def tls_insecure
  @tls_insecure
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10787
10788
10789
# File 'lib/models/porcelain.rb', line 10787

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10823
10824
10825
10826
10827
10828
10829
# File 'lib/models/porcelain.rb', line 10823

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end