Class: SDM::MCPGatewayPAT

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayPAT

Returns a new instance of MCPGatewayPAT.



10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
10780
10781
10782
10783
10784
10785
# File 'lib/models/porcelain.rb', line 10753

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_cert: nil,
  tls_insecure: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_cert = tls_cert == nil ? "" : tls_cert
  @tls_insecure = tls_insecure == nil ? false : tls_insecure
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10723
10724
10725
# File 'lib/models/porcelain.rb', line 10723

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10725
10726
10727
# File 'lib/models/porcelain.rb', line 10725

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10727
10728
10729
# File 'lib/models/porcelain.rb', line 10727

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10729
10730
10731
# File 'lib/models/porcelain.rb', line 10729

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10731
10732
10733
# File 'lib/models/porcelain.rb', line 10731

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10733
10734
10735
# File 'lib/models/porcelain.rb', line 10733

def name
  @name
end

#passwordObject

The password to authenticate with.



10735
10736
10737
# File 'lib/models/porcelain.rb', line 10735

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10737
10738
10739
# File 'lib/models/porcelain.rb', line 10737

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10739
10740
10741
# File 'lib/models/porcelain.rb', line 10739

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10741
10742
10743
# File 'lib/models/porcelain.rb', line 10741

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10743
10744
10745
# File 'lib/models/porcelain.rb', line 10743

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10745
10746
10747
# File 'lib/models/porcelain.rb', line 10745

def tags
  @tags
end

#tls_certObject

Custom TLS certificate for upstream connection.



10747
10748
10749
# File 'lib/models/porcelain.rb', line 10747

def tls_cert
  @tls_cert
end

#tls_insecureObject

Skip TLS certificate verification for the upstream connection.



10749
10750
10751
# File 'lib/models/porcelain.rb', line 10749

def tls_insecure
  @tls_insecure
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10751
10752
10753
# File 'lib/models/porcelain.rb', line 10751

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10787
10788
10789
10790
10791
10792
10793
# File 'lib/models/porcelain.rb', line 10787

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end