Class: SDM::MCPGatewayPAT

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ MCPGatewayPAT

Returns a new instance of MCPGatewayPAT.



10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
10693
10694
10695
10696
10697
10698
10699
10700
10701
10702
10703
10704
10705
# File 'lib/models/porcelain.rb', line 10677

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  url: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @url = url == nil ? "" : url
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10651
10652
10653
# File 'lib/models/porcelain.rb', line 10651

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10653
10654
10655
# File 'lib/models/porcelain.rb', line 10653

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10655
10656
10657
# File 'lib/models/porcelain.rb', line 10655

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10657
10658
10659
# File 'lib/models/porcelain.rb', line 10657

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10659
10660
10661
# File 'lib/models/porcelain.rb', line 10659

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10661
10662
10663
# File 'lib/models/porcelain.rb', line 10661

def name
  @name
end

#passwordObject

The password to authenticate with.



10663
10664
10665
# File 'lib/models/porcelain.rb', line 10663

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10665
10666
10667
# File 'lib/models/porcelain.rb', line 10665

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10667
10668
10669
# File 'lib/models/porcelain.rb', line 10667

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10669
10670
10671
# File 'lib/models/porcelain.rb', line 10669

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10671
10672
10673
# File 'lib/models/porcelain.rb', line 10671

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10673
10674
10675
# File 'lib/models/porcelain.rb', line 10673

def tags
  @tags
end

#urlObject

The URL to dial to initiate a connection from the egress node to this resource.



10675
10676
10677
# File 'lib/models/porcelain.rb', line 10675

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10707
10708
10709
10710
10711
10712
10713
# File 'lib/models/porcelain.rb', line 10707

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end