Class: SDM::MCPGatewayPAT
- Inherits:
-
Object
- Object
- SDM::MCPGatewayPAT
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ MCPGatewayPAT
constructor
A new instance of MCPGatewayPAT.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil) ⇒ MCPGatewayPAT
Returns a new instance of MCPGatewayPAT.
10677 10678 10679 10680 10681 10682 10683 10684 10685 10686 10687 10688 10689 10690 10691 10692 10693 10694 10695 10696 10697 10698 10699 10700 10701 10702 10703 10704 10705 |
# File 'lib/models/porcelain.rb', line 10677 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
10651 10652 10653 |
# File 'lib/models/porcelain.rb', line 10651 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10653 10654 10655 |
# File 'lib/models/porcelain.rb', line 10653 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10655 10656 10657 |
# File 'lib/models/porcelain.rb', line 10655 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10657 10658 10659 |
# File 'lib/models/porcelain.rb', line 10657 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10659 10660 10661 |
# File 'lib/models/porcelain.rb', line 10659 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10661 10662 10663 |
# File 'lib/models/porcelain.rb', line 10661 def name @name end |
#password ⇒ Object
The password to authenticate with.
10663 10664 10665 |
# File 'lib/models/porcelain.rb', line 10663 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
10665 10666 10667 |
# File 'lib/models/porcelain.rb', line 10665 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10667 10668 10669 |
# File 'lib/models/porcelain.rb', line 10667 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10669 10670 10671 |
# File 'lib/models/porcelain.rb', line 10669 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
10671 10672 10673 |
# File 'lib/models/porcelain.rb', line 10671 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10673 10674 10675 |
# File 'lib/models/porcelain.rb', line 10673 def @tags end |
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
10675 10676 10677 |
# File 'lib/models/porcelain.rb', line 10675 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10707 10708 10709 10710 10711 10712 10713 |
# File 'lib/models/porcelain.rb', line 10707 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |