Class: SDM::MCPGatewayPAT
- Inherits:
-
Object
- Object
- SDM::MCPGatewayPAT
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_cert ⇒ Object
Custom TLS certificate for upstream connection.
-
#tls_insecure ⇒ Object
Skip TLS certificate verification for the upstream connection.
-
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayPAT
constructor
A new instance of MCPGatewayPAT.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil) ⇒ MCPGatewayPAT
Returns a new instance of MCPGatewayPAT.
10851 10852 10853 10854 10855 10856 10857 10858 10859 10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 |
# File 'lib/models/porcelain.rb', line 10851 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_cert: nil, tls_insecure: nil, url: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_cert = tls_cert == nil ? "" : tls_cert @tls_insecure = tls_insecure == nil ? false : tls_insecure @url = url == nil ? "" : url end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
10823 10824 10825 |
# File 'lib/models/porcelain.rb', line 10823 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10825 10826 10827 |
# File 'lib/models/porcelain.rb', line 10825 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10827 10828 10829 |
# File 'lib/models/porcelain.rb', line 10827 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
10829 10830 10831 |
# File 'lib/models/porcelain.rb', line 10829 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10831 10832 10833 |
# File 'lib/models/porcelain.rb', line 10831 def name @name end |
#password ⇒ Object
The password to authenticate with.
10833 10834 10835 |
# File 'lib/models/porcelain.rb', line 10833 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
10835 10836 10837 |
# File 'lib/models/porcelain.rb', line 10835 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10837 10838 10839 |
# File 'lib/models/porcelain.rb', line 10837 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10839 10840 10841 |
# File 'lib/models/porcelain.rb', line 10839 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
10841 10842 10843 |
# File 'lib/models/porcelain.rb', line 10841 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10843 10844 10845 |
# File 'lib/models/porcelain.rb', line 10843 def @tags end |
#tls_cert ⇒ Object
Custom TLS certificate for upstream connection.
10845 10846 10847 |
# File 'lib/models/porcelain.rb', line 10845 def tls_cert @tls_cert end |
#tls_insecure ⇒ Object
Skip TLS certificate verification for the upstream connection.
10847 10848 10849 |
# File 'lib/models/porcelain.rb', line 10847 def tls_insecure @tls_insecure end |
#url ⇒ Object
The URL to dial to initiate a connection from the egress node to this resource.
10849 10850 10851 |
# File 'lib/models/porcelain.rb', line 10849 def url @url end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/models/porcelain.rb', line 10883 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |