Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



10903
10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
10920
10921
10922
10923
10924
10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
# File 'lib/models/porcelain.rb', line 10903

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10861
10862
10863
# File 'lib/models/porcelain.rb', line 10861

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10863
10864
10865
# File 'lib/models/porcelain.rb', line 10863

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10865
10866
10867
# File 'lib/models/porcelain.rb', line 10865

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10867
10868
10869
# File 'lib/models/porcelain.rb', line 10867

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10869
10870
10871
# File 'lib/models/porcelain.rb', line 10869

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10871
10872
10873
# File 'lib/models/porcelain.rb', line 10871

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10873
10874
10875
# File 'lib/models/porcelain.rb', line 10873

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10875
10876
10877
# File 'lib/models/porcelain.rb', line 10875

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10877
10878
10879
# File 'lib/models/porcelain.rb', line 10877

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10879
10880
10881
# File 'lib/models/porcelain.rb', line 10879

def name
  @name
end

#passwordObject

The password to authenticate with.



10881
10882
10883
# File 'lib/models/porcelain.rb', line 10881

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10883
10884
10885
# File 'lib/models/porcelain.rb', line 10883

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10885
10886
10887
# File 'lib/models/porcelain.rb', line 10885

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10887
10888
10889
# File 'lib/models/porcelain.rb', line 10887

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10889
10890
10891
# File 'lib/models/porcelain.rb', line 10889

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10891
10892
10893
# File 'lib/models/porcelain.rb', line 10891

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10893
10894
10895
# File 'lib/models/porcelain.rb', line 10893

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10895
10896
10897
# File 'lib/models/porcelain.rb', line 10895

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10897
10898
10899
# File 'lib/models/porcelain.rb', line 10897

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10899
10900
10901
# File 'lib/models/porcelain.rb', line 10899

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10901
10902
10903
# File 'lib/models/porcelain.rb', line 10901

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10949
10950
10951
10952
10953
10954
10955
# File 'lib/models/porcelain.rb', line 10949

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end