Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



10867
10868
10869
10870
10871
10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
10906
10907
10908
10909
10910
10911
# File 'lib/models/porcelain.rb', line 10867

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10825
10826
10827
# File 'lib/models/porcelain.rb', line 10825

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10827
10828
10829
# File 'lib/models/porcelain.rb', line 10827

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10829
10830
10831
# File 'lib/models/porcelain.rb', line 10829

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10831
10832
10833
# File 'lib/models/porcelain.rb', line 10831

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10833
10834
10835
# File 'lib/models/porcelain.rb', line 10833

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10835
10836
10837
# File 'lib/models/porcelain.rb', line 10835

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10837
10838
10839
# File 'lib/models/porcelain.rb', line 10837

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10839
10840
10841
# File 'lib/models/porcelain.rb', line 10839

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10841
10842
10843
# File 'lib/models/porcelain.rb', line 10841

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10843
10844
10845
# File 'lib/models/porcelain.rb', line 10843

def name
  @name
end

#passwordObject

The password to authenticate with.



10845
10846
10847
# File 'lib/models/porcelain.rb', line 10845

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10847
10848
10849
# File 'lib/models/porcelain.rb', line 10847

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10849
10850
10851
# File 'lib/models/porcelain.rb', line 10849

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10851
10852
10853
# File 'lib/models/porcelain.rb', line 10851

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10853
10854
10855
# File 'lib/models/porcelain.rb', line 10853

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10855
10856
10857
# File 'lib/models/porcelain.rb', line 10855

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10857
10858
10859
# File 'lib/models/porcelain.rb', line 10857

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10859
10860
10861
# File 'lib/models/porcelain.rb', line 10859

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10861
10862
10863
# File 'lib/models/porcelain.rb', line 10861

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10863
10864
10865
# File 'lib/models/porcelain.rb', line 10863

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10865
10866
10867
# File 'lib/models/porcelain.rb', line 10865

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10913
10914
10915
10916
10917
10918
10919
# File 'lib/models/porcelain.rb', line 10913

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end