Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



10691
10692
10693
10694
10695
10696
10697
10698
10699
10700
10701
10702
10703
10704
10705
10706
10707
10708
10709
10710
10711
10712
10713
10714
10715
10716
10717
10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
10733
10734
10735
# File 'lib/models/porcelain.rb', line 10691

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10649
10650
10651
# File 'lib/models/porcelain.rb', line 10649

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10651
10652
10653
# File 'lib/models/porcelain.rb', line 10651

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10653
10654
10655
# File 'lib/models/porcelain.rb', line 10653

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10655
10656
10657
# File 'lib/models/porcelain.rb', line 10655

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10657
10658
10659
# File 'lib/models/porcelain.rb', line 10657

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10659
10660
10661
# File 'lib/models/porcelain.rb', line 10659

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10661
10662
10663
# File 'lib/models/porcelain.rb', line 10661

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10663
10664
10665
# File 'lib/models/porcelain.rb', line 10663

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10665
10666
10667
# File 'lib/models/porcelain.rb', line 10665

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10667
10668
10669
# File 'lib/models/porcelain.rb', line 10667

def name
  @name
end

#passwordObject

The password to authenticate with.



10669
10670
10671
# File 'lib/models/porcelain.rb', line 10669

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10671
10672
10673
# File 'lib/models/porcelain.rb', line 10671

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10673
10674
10675
# File 'lib/models/porcelain.rb', line 10673

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10675
10676
10677
# File 'lib/models/porcelain.rb', line 10675

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10677
10678
10679
# File 'lib/models/porcelain.rb', line 10677

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10679
10680
10681
# File 'lib/models/porcelain.rb', line 10679

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10681
10682
10683
# File 'lib/models/porcelain.rb', line 10681

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10683
10684
10685
# File 'lib/models/porcelain.rb', line 10683

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10685
10686
10687
# File 'lib/models/porcelain.rb', line 10685

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10687
10688
10689
# File 'lib/models/porcelain.rb', line 10687

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10689
10690
10691
# File 'lib/models/porcelain.rb', line 10689

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10737
10738
10739
10740
10741
10742
10743
# File 'lib/models/porcelain.rb', line 10737

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end