Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



10395
10396
10397
10398
10399
10400
10401
10402
10403
10404
10405
10406
10407
10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
10426
10427
10428
10429
10430
10431
10432
10433
10434
10435
10436
10437
10438
10439
# File 'lib/models/porcelain.rb', line 10395

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10353
10354
10355
# File 'lib/models/porcelain.rb', line 10353

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10355
10356
10357
# File 'lib/models/porcelain.rb', line 10355

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10357
10358
10359
# File 'lib/models/porcelain.rb', line 10357

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10359
10360
10361
# File 'lib/models/porcelain.rb', line 10359

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10361
10362
10363
# File 'lib/models/porcelain.rb', line 10361

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10363
10364
10365
# File 'lib/models/porcelain.rb', line 10363

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10365
10366
10367
# File 'lib/models/porcelain.rb', line 10365

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10367
10368
10369
# File 'lib/models/porcelain.rb', line 10367

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10369
10370
10371
# File 'lib/models/porcelain.rb', line 10369

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10371
10372
10373
# File 'lib/models/porcelain.rb', line 10371

def name
  @name
end

#passwordObject

The password to authenticate with.



10373
10374
10375
# File 'lib/models/porcelain.rb', line 10373

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10375
10376
10377
# File 'lib/models/porcelain.rb', line 10375

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10377
10378
10379
# File 'lib/models/porcelain.rb', line 10377

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10379
10380
10381
# File 'lib/models/porcelain.rb', line 10379

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10381
10382
10383
# File 'lib/models/porcelain.rb', line 10381

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10383
10384
10385
# File 'lib/models/porcelain.rb', line 10383

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10385
10386
10387
# File 'lib/models/porcelain.rb', line 10385

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10387
10388
10389
# File 'lib/models/porcelain.rb', line 10387

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10389
10390
10391
# File 'lib/models/porcelain.rb', line 10389

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10391
10392
10393
# File 'lib/models/porcelain.rb', line 10391

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10393
10394
10395
# File 'lib/models/porcelain.rb', line 10393

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10441
10442
10443
10444
10445
10446
10447
# File 'lib/models/porcelain.rb', line 10441

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end