Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
10331
10332
10333
10334
10335
10336
10337
10338
10339
10340
10341
10342
10343
10344
10345
10346
10347
10348
10349
10350
10351
10352
10353
10354
10355
10356
10357
10358
10359
10360
10361
10362
10363
10364
10365
# File 'lib/models/porcelain.rb', line 10321

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10279
10280
10281
# File 'lib/models/porcelain.rb', line 10279

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10281
10282
10283
# File 'lib/models/porcelain.rb', line 10281

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10283
10284
10285
# File 'lib/models/porcelain.rb', line 10283

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10285
10286
10287
# File 'lib/models/porcelain.rb', line 10285

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10287
10288
10289
# File 'lib/models/porcelain.rb', line 10287

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10289
10290
10291
# File 'lib/models/porcelain.rb', line 10289

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10291
10292
10293
# File 'lib/models/porcelain.rb', line 10291

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10293
10294
10295
# File 'lib/models/porcelain.rb', line 10293

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10295
10296
10297
# File 'lib/models/porcelain.rb', line 10295

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10297
10298
10299
# File 'lib/models/porcelain.rb', line 10297

def name
  @name
end

#passwordObject

The password to authenticate with.



10299
10300
10301
# File 'lib/models/porcelain.rb', line 10299

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10301
10302
10303
# File 'lib/models/porcelain.rb', line 10301

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10303
10304
10305
# File 'lib/models/porcelain.rb', line 10303

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10305
10306
10307
# File 'lib/models/porcelain.rb', line 10305

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10307
10308
10309
# File 'lib/models/porcelain.rb', line 10307

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10309
10310
10311
# File 'lib/models/porcelain.rb', line 10309

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10311
10312
10313
# File 'lib/models/porcelain.rb', line 10311

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10313
10314
10315
# File 'lib/models/porcelain.rb', line 10313

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10315
10316
10317
# File 'lib/models/porcelain.rb', line 10315

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10317
10318
10319
# File 'lib/models/porcelain.rb', line 10317

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10319
10320
10321
# File 'lib/models/porcelain.rb', line 10319

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10367
10368
10369
10370
10371
10372
10373
# File 'lib/models/porcelain.rb', line 10367

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end