Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



8148
8149
8150
8151
8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
8162
8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
8187
8188
8189
8190
8191
8192
# File 'lib/models/porcelain.rb', line 8148

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8106
8107
8108
# File 'lib/models/porcelain.rb', line 8106

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



8108
8109
8110
# File 'lib/models/porcelain.rb', line 8108

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



8110
8111
8112
# File 'lib/models/porcelain.rb', line 8110

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



8112
8113
8114
# File 'lib/models/porcelain.rb', line 8112

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



8114
8115
8116
# File 'lib/models/porcelain.rb', line 8114

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8116
8117
8118
# File 'lib/models/porcelain.rb', line 8116

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8118
8119
8120
# File 'lib/models/porcelain.rb', line 8118

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8120
8121
8122
# File 'lib/models/porcelain.rb', line 8120

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8122
8123
8124
# File 'lib/models/porcelain.rb', line 8122

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8124
8125
8126
# File 'lib/models/porcelain.rb', line 8124

def name
  @name
end

#passwordObject

The password to authenticate with.



8126
8127
8128
# File 'lib/models/porcelain.rb', line 8126

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8128
8129
8130
# File 'lib/models/porcelain.rb', line 8128

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8130
8131
8132
# File 'lib/models/porcelain.rb', line 8130

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8132
8133
8134
# File 'lib/models/porcelain.rb', line 8132

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8134
8135
8136
# File 'lib/models/porcelain.rb', line 8134

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8136
8137
8138
# File 'lib/models/porcelain.rb', line 8136

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



8138
8139
8140
# File 'lib/models/porcelain.rb', line 8138

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8140
8141
8142
# File 'lib/models/porcelain.rb', line 8140

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8142
8143
8144
# File 'lib/models/porcelain.rb', line 8142

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8144
8145
8146
# File 'lib/models/porcelain.rb', line 8144

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8146
8147
8148
# File 'lib/models/porcelain.rb', line 8146

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8194
8195
8196
8197
8198
8199
8200
# File 'lib/models/porcelain.rb', line 8194

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end