Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



7968
7969
7970
7971
7972
7973
7974
7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
8010
8011
8012
# File 'lib/models/porcelain.rb', line 7968

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7926
7927
7928
# File 'lib/models/porcelain.rb', line 7926

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7928
7929
7930
# File 'lib/models/porcelain.rb', line 7928

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7930
7931
7932
# File 'lib/models/porcelain.rb', line 7930

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7932
7933
7934
# File 'lib/models/porcelain.rb', line 7932

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7934
7935
7936
# File 'lib/models/porcelain.rb', line 7934

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7936
7937
7938
# File 'lib/models/porcelain.rb', line 7936

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7938
7939
7940
# File 'lib/models/porcelain.rb', line 7938

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7940
7941
7942
# File 'lib/models/porcelain.rb', line 7940

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7942
7943
7944
# File 'lib/models/porcelain.rb', line 7942

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7944
7945
7946
# File 'lib/models/porcelain.rb', line 7944

def name
  @name
end

#passwordObject

The password to authenticate with.



7946
7947
7948
# File 'lib/models/porcelain.rb', line 7946

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7948
7949
7950
# File 'lib/models/porcelain.rb', line 7948

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7950
7951
7952
# File 'lib/models/porcelain.rb', line 7950

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7952
7953
7954
# File 'lib/models/porcelain.rb', line 7952

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7954
7955
7956
# File 'lib/models/porcelain.rb', line 7954

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7956
7957
7958
# File 'lib/models/porcelain.rb', line 7956

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



7958
7959
7960
# File 'lib/models/porcelain.rb', line 7958

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7960
7961
7962
# File 'lib/models/porcelain.rb', line 7960

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7962
7963
7964
# File 'lib/models/porcelain.rb', line 7962

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7964
7965
7966
# File 'lib/models/porcelain.rb', line 7964

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7966
7967
7968
# File 'lib/models/porcelain.rb', line 7966

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8014
8015
8016
8017
8018
8019
8020
# File 'lib/models/porcelain.rb', line 8014

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end