Class: SDM::MTLSMysql
- Inherits:
-
Object
- Object
- SDM::MTLSMysql
- Defined in:
- lib/models/porcelain.rb
Overview
MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Server name for TLS verification (unverified by StrongDM if empty).
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql
constructor
A new instance of MTLSMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql
Returns a new instance of MTLSMysql.
7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 7869 7870 7871 7872 7873 7874 7875 7876 |
# File 'lib/models/porcelain.rb', line 7832 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7790 7791 7792 |
# File 'lib/models/porcelain.rb', line 7790 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
7792 7793 7794 |
# File 'lib/models/porcelain.rb', line 7792 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
7794 7795 7796 |
# File 'lib/models/porcelain.rb', line 7794 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
7796 7797 7798 |
# File 'lib/models/porcelain.rb', line 7796 def client_key @client_key end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests.
7798 7799 7800 |
# File 'lib/models/porcelain.rb', line 7798 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7800 7801 7802 |
# File 'lib/models/porcelain.rb', line 7800 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7802 7803 7804 |
# File 'lib/models/porcelain.rb', line 7802 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7804 7805 7806 |
# File 'lib/models/porcelain.rb', line 7804 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7806 7807 7808 |
# File 'lib/models/porcelain.rb', line 7806 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7808 7809 7810 |
# File 'lib/models/porcelain.rb', line 7808 def name @name end |
#password ⇒ Object
The password to authenticate with.
7810 7811 7812 |
# File 'lib/models/porcelain.rb', line 7810 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7812 7813 7814 |
# File 'lib/models/porcelain.rb', line 7812 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7814 7815 7816 |
# File 'lib/models/porcelain.rb', line 7814 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7816 7817 7818 |
# File 'lib/models/porcelain.rb', line 7816 def proxy_cluster_id @proxy_cluster_id end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
7818 7819 7820 |
# File 'lib/models/porcelain.rb', line 7818 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7820 7821 7822 |
# File 'lib/models/porcelain.rb', line 7820 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Server name for TLS verification (unverified by StrongDM if empty)
7822 7823 7824 |
# File 'lib/models/porcelain.rb', line 7822 def server_name @server_name end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7824 7825 7826 |
# File 'lib/models/porcelain.rb', line 7824 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7826 7827 7828 |
# File 'lib/models/porcelain.rb', line 7826 def @tags end |
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address
7828 7829 7830 |
# File 'lib/models/porcelain.rb', line 7828 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
The username to authenticate with.
7830 7831 7832 |
# File 'lib/models/porcelain.rb', line 7830 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7878 7879 7880 7881 7882 7883 7884 |
# File 'lib/models/porcelain.rb', line 7878 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |