Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



7504
7505
7506
7507
7508
7509
7510
7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
# File 'lib/models/porcelain.rb', line 7504

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7462
7463
7464
# File 'lib/models/porcelain.rb', line 7462

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7464
7465
7466
# File 'lib/models/porcelain.rb', line 7464

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7466
7467
7468
# File 'lib/models/porcelain.rb', line 7466

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7468
7469
7470
# File 'lib/models/porcelain.rb', line 7468

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7470
7471
7472
# File 'lib/models/porcelain.rb', line 7470

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7472
7473
7474
# File 'lib/models/porcelain.rb', line 7472

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7474
7475
7476
# File 'lib/models/porcelain.rb', line 7474

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7476
7477
7478
# File 'lib/models/porcelain.rb', line 7476

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7478
7479
7480
# File 'lib/models/porcelain.rb', line 7478

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7480
7481
7482
# File 'lib/models/porcelain.rb', line 7480

def name
  @name
end

#passwordObject

The password to authenticate with.



7482
7483
7484
# File 'lib/models/porcelain.rb', line 7482

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7484
7485
7486
# File 'lib/models/porcelain.rb', line 7484

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7486
7487
7488
# File 'lib/models/porcelain.rb', line 7486

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7488
7489
7490
# File 'lib/models/porcelain.rb', line 7488

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7490
7491
7492
# File 'lib/models/porcelain.rb', line 7490

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7492
7493
7494
# File 'lib/models/porcelain.rb', line 7492

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



7494
7495
7496
# File 'lib/models/porcelain.rb', line 7494

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7496
7497
7498
# File 'lib/models/porcelain.rb', line 7496

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7498
7499
7500
# File 'lib/models/porcelain.rb', line 7498

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7500
7501
7502
# File 'lib/models/porcelain.rb', line 7500

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7502
7503
7504
# File 'lib/models/porcelain.rb', line 7502

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7550
7551
7552
7553
7554
7555
7556
# File 'lib/models/porcelain.rb', line 7550

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end