Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
7459
7460
7461
7462
7463
7464
7465
7466
7467
7468
7469
# File 'lib/models/porcelain.rb', line 7425

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7383
7384
7385
# File 'lib/models/porcelain.rb', line 7383

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7385
7386
7387
# File 'lib/models/porcelain.rb', line 7385

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7387
7388
7389
# File 'lib/models/porcelain.rb', line 7387

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7389
7390
7391
# File 'lib/models/porcelain.rb', line 7389

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7391
7392
7393
# File 'lib/models/porcelain.rb', line 7391

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7393
7394
7395
# File 'lib/models/porcelain.rb', line 7393

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7395
7396
7397
# File 'lib/models/porcelain.rb', line 7395

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7397
7398
7399
# File 'lib/models/porcelain.rb', line 7397

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7399
7400
7401
# File 'lib/models/porcelain.rb', line 7399

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7401
7402
7403
# File 'lib/models/porcelain.rb', line 7401

def name
  @name
end

#passwordObject

The password to authenticate with.



7403
7404
7405
# File 'lib/models/porcelain.rb', line 7403

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7405
7406
7407
# File 'lib/models/porcelain.rb', line 7405

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7407
7408
7409
# File 'lib/models/porcelain.rb', line 7407

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7409
7410
7411
# File 'lib/models/porcelain.rb', line 7409

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7411
7412
7413
# File 'lib/models/porcelain.rb', line 7411

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7413
7414
7415
# File 'lib/models/porcelain.rb', line 7413

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



7415
7416
7417
# File 'lib/models/porcelain.rb', line 7415

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7417
7418
7419
# File 'lib/models/porcelain.rb', line 7417

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7419
7420
7421
# File 'lib/models/porcelain.rb', line 7419

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7421
7422
7423
# File 'lib/models/porcelain.rb', line 7421

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7423
7424
7425
# File 'lib/models/porcelain.rb', line 7423

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7471
7472
7473
7474
7475
7476
7477
# File 'lib/models/porcelain.rb', line 7471

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end