Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
# File 'lib/models/porcelain.rb', line 7354

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7312
7313
7314
# File 'lib/models/porcelain.rb', line 7312

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7314
7315
7316
# File 'lib/models/porcelain.rb', line 7314

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7316
7317
7318
# File 'lib/models/porcelain.rb', line 7316

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7318
7319
7320
# File 'lib/models/porcelain.rb', line 7318

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7320
7321
7322
# File 'lib/models/porcelain.rb', line 7320

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7322
7323
7324
# File 'lib/models/porcelain.rb', line 7322

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7324
7325
7326
# File 'lib/models/porcelain.rb', line 7324

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7326
7327
7328
# File 'lib/models/porcelain.rb', line 7326

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7328
7329
7330
# File 'lib/models/porcelain.rb', line 7328

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7330
7331
7332
# File 'lib/models/porcelain.rb', line 7330

def name
  @name
end

#passwordObject

The password to authenticate with.



7332
7333
7334
# File 'lib/models/porcelain.rb', line 7332

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7334
7335
7336
# File 'lib/models/porcelain.rb', line 7334

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7336
7337
7338
# File 'lib/models/porcelain.rb', line 7336

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7338
7339
7340
# File 'lib/models/porcelain.rb', line 7338

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7340
7341
7342
# File 'lib/models/porcelain.rb', line 7340

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7342
7343
7344
# File 'lib/models/porcelain.rb', line 7342

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



7344
7345
7346
# File 'lib/models/porcelain.rb', line 7344

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7346
7347
7348
# File 'lib/models/porcelain.rb', line 7346

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7348
7349
7350
# File 'lib/models/porcelain.rb', line 7348

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7350
7351
7352
# File 'lib/models/porcelain.rb', line 7350

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7352
7353
7354
# File 'lib/models/porcelain.rb', line 7352

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7400
7401
7402
7403
7404
7405
7406
# File 'lib/models/porcelain.rb', line 7400

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end