Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



6991
6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
# File 'lib/models/porcelain.rb', line 6991

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6949
6950
6951
# File 'lib/models/porcelain.rb', line 6949

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6951
6952
6953
# File 'lib/models/porcelain.rb', line 6951

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6953
6954
6955
# File 'lib/models/porcelain.rb', line 6953

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6955
6956
6957
# File 'lib/models/porcelain.rb', line 6955

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



6957
6958
6959
# File 'lib/models/porcelain.rb', line 6957

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6959
6960
6961
# File 'lib/models/porcelain.rb', line 6959

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6961
6962
6963
# File 'lib/models/porcelain.rb', line 6961

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6963
6964
6965
# File 'lib/models/porcelain.rb', line 6963

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6965
6966
6967
# File 'lib/models/porcelain.rb', line 6965

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6967
6968
6969
# File 'lib/models/porcelain.rb', line 6967

def name
  @name
end

#passwordObject

The password to authenticate with.



6969
6970
6971
# File 'lib/models/porcelain.rb', line 6969

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6971
6972
6973
# File 'lib/models/porcelain.rb', line 6971

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6973
6974
6975
# File 'lib/models/porcelain.rb', line 6973

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6975
6976
6977
# File 'lib/models/porcelain.rb', line 6975

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



6977
6978
6979
# File 'lib/models/porcelain.rb', line 6977

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6979
6980
6981
# File 'lib/models/porcelain.rb', line 6979

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



6981
6982
6983
# File 'lib/models/porcelain.rb', line 6981

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6983
6984
6985
# File 'lib/models/porcelain.rb', line 6983

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6985
6986
6987
# File 'lib/models/porcelain.rb', line 6985

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



6987
6988
6989
# File 'lib/models/porcelain.rb', line 6987

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



6989
6990
6991
# File 'lib/models/porcelain.rb', line 6989

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7037
7038
7039
7040
7041
7042
7043
# File 'lib/models/porcelain.rb', line 7037

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end