Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
6783
6784
6785
6786
6787
6788
# File 'lib/models/porcelain.rb', line 6744

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6702
6703
6704
# File 'lib/models/porcelain.rb', line 6702

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6704
6705
6706
# File 'lib/models/porcelain.rb', line 6704

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6706
6707
6708
# File 'lib/models/porcelain.rb', line 6706

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6708
6709
6710
# File 'lib/models/porcelain.rb', line 6708

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



6710
6711
6712
# File 'lib/models/porcelain.rb', line 6710

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6712
6713
6714
# File 'lib/models/porcelain.rb', line 6712

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6714
6715
6716
# File 'lib/models/porcelain.rb', line 6714

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6716
6717
6718
# File 'lib/models/porcelain.rb', line 6716

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6718
6719
6720
# File 'lib/models/porcelain.rb', line 6718

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6720
6721
6722
# File 'lib/models/porcelain.rb', line 6720

def name
  @name
end

#passwordObject

The password to authenticate with.



6722
6723
6724
# File 'lib/models/porcelain.rb', line 6722

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6724
6725
6726
# File 'lib/models/porcelain.rb', line 6724

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6726
6727
6728
# File 'lib/models/porcelain.rb', line 6726

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6728
6729
6730
# File 'lib/models/porcelain.rb', line 6728

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



6730
6731
6732
# File 'lib/models/porcelain.rb', line 6730

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6732
6733
6734
# File 'lib/models/porcelain.rb', line 6732

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



6734
6735
6736
# File 'lib/models/porcelain.rb', line 6734

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6736
6737
6738
# File 'lib/models/porcelain.rb', line 6736

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6738
6739
6740
# File 'lib/models/porcelain.rb', line 6738

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



6740
6741
6742
# File 'lib/models/porcelain.rb', line 6740

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



6742
6743
6744
# File 'lib/models/porcelain.rb', line 6742

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6790
6791
6792
6793
6794
6795
6796
# File 'lib/models/porcelain.rb', line 6790

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end