Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



6673
6674
6675
6676
6677
6678
6679
6680
6681
6682
6683
6684
6685
6686
6687
6688
6689
6690
6691
6692
6693
6694
6695
6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
6712
6713
6714
6715
6716
6717
# File 'lib/models/porcelain.rb', line 6673

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6631
6632
6633
# File 'lib/models/porcelain.rb', line 6631

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6633
6634
6635
# File 'lib/models/porcelain.rb', line 6633

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6635
6636
6637
# File 'lib/models/porcelain.rb', line 6635

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6637
6638
6639
# File 'lib/models/porcelain.rb', line 6637

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



6639
6640
6641
# File 'lib/models/porcelain.rb', line 6639

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6641
6642
6643
# File 'lib/models/porcelain.rb', line 6641

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6643
6644
6645
# File 'lib/models/porcelain.rb', line 6643

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6645
6646
6647
# File 'lib/models/porcelain.rb', line 6645

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6647
6648
6649
# File 'lib/models/porcelain.rb', line 6647

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6649
6650
6651
# File 'lib/models/porcelain.rb', line 6649

def name
  @name
end

#passwordObject

The password to authenticate with.



6651
6652
6653
# File 'lib/models/porcelain.rb', line 6651

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6653
6654
6655
# File 'lib/models/porcelain.rb', line 6653

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6655
6656
6657
# File 'lib/models/porcelain.rb', line 6655

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6657
6658
6659
# File 'lib/models/porcelain.rb', line 6657

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



6659
6660
6661
# File 'lib/models/porcelain.rb', line 6659

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6661
6662
6663
# File 'lib/models/porcelain.rb', line 6661

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



6663
6664
6665
# File 'lib/models/porcelain.rb', line 6663

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6665
6666
6667
# File 'lib/models/porcelain.rb', line 6665

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6667
6668
6669
# File 'lib/models/porcelain.rb', line 6667

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



6669
6670
6671
# File 'lib/models/porcelain.rb', line 6669

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



6671
6672
6673
# File 'lib/models/porcelain.rb', line 6671

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6719
6720
6721
6722
6723
6724
6725
# File 'lib/models/porcelain.rb', line 6719

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end