Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
# File 'lib/models/porcelain.rb', line 6209

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6169
6170
6171
# File 'lib/models/porcelain.rb', line 6169

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6171
6172
6173
# File 'lib/models/porcelain.rb', line 6171

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6173
6174
6175
# File 'lib/models/porcelain.rb', line 6173

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6175
6176
6177
# File 'lib/models/porcelain.rb', line 6175

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



6177
6178
6179
# File 'lib/models/porcelain.rb', line 6177

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6179
6180
6181
# File 'lib/models/porcelain.rb', line 6179

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6181
6182
6183
# File 'lib/models/porcelain.rb', line 6181

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6183
6184
6185
# File 'lib/models/porcelain.rb', line 6183

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6185
6186
6187
# File 'lib/models/porcelain.rb', line 6185

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6187
6188
6189
# File 'lib/models/porcelain.rb', line 6187

def name
  @name
end

#passwordObject

The password to authenticate with.



6189
6190
6191
# File 'lib/models/porcelain.rb', line 6189

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6191
6192
6193
# File 'lib/models/porcelain.rb', line 6191

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6193
6194
6195
# File 'lib/models/porcelain.rb', line 6193

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



6195
6196
6197
# File 'lib/models/porcelain.rb', line 6195

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6197
6198
6199
# File 'lib/models/porcelain.rb', line 6197

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



6199
6200
6201
# File 'lib/models/porcelain.rb', line 6199

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6201
6202
6203
# File 'lib/models/porcelain.rb', line 6201

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6203
6204
6205
# File 'lib/models/porcelain.rb', line 6203

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



6205
6206
6207
# File 'lib/models/porcelain.rb', line 6205

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



6207
6208
6209
# File 'lib/models/porcelain.rb', line 6207

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6253
6254
6255
6256
6257
6258
6259
# File 'lib/models/porcelain.rb', line 6253

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end