Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
6093
6094
6095
6096
6097
6098
6099
6100
6101
6102
6103
6104
6105
6106
# File 'lib/models/porcelain.rb', line 6064

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6024
6025
6026
# File 'lib/models/porcelain.rb', line 6024

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6026
6027
6028
# File 'lib/models/porcelain.rb', line 6026

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6028
6029
6030
# File 'lib/models/porcelain.rb', line 6028

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6030
6031
6032
# File 'lib/models/porcelain.rb', line 6030

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



6032
6033
6034
# File 'lib/models/porcelain.rb', line 6032

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6034
6035
6036
# File 'lib/models/porcelain.rb', line 6034

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6036
6037
6038
# File 'lib/models/porcelain.rb', line 6036

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6038
6039
6040
# File 'lib/models/porcelain.rb', line 6038

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6040
6041
6042
# File 'lib/models/porcelain.rb', line 6040

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6042
6043
6044
# File 'lib/models/porcelain.rb', line 6042

def name
  @name
end

#passwordObject

The password to authenticate with.



6044
6045
6046
# File 'lib/models/porcelain.rb', line 6044

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6046
6047
6048
# File 'lib/models/porcelain.rb', line 6046

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6048
6049
6050
# File 'lib/models/porcelain.rb', line 6048

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



6050
6051
6052
# File 'lib/models/porcelain.rb', line 6050

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6052
6053
6054
# File 'lib/models/porcelain.rb', line 6052

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



6054
6055
6056
# File 'lib/models/porcelain.rb', line 6054

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6056
6057
6058
# File 'lib/models/porcelain.rb', line 6056

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6058
6059
6060
# File 'lib/models/porcelain.rb', line 6058

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



6060
6061
6062
# File 'lib/models/porcelain.rb', line 6060

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



6062
6063
6064
# File 'lib/models/porcelain.rb', line 6062

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6108
6109
6110
6111
6112
6113
6114
# File 'lib/models/porcelain.rb', line 6108

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end