Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
4981
4982
4983
4984
4985
4986
4987
4988
4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
# File 'lib/models/porcelain.rb', line 4956

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4916
4917
4918
# File 'lib/models/porcelain.rb', line 4916

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4918
4919
4920
# File 'lib/models/porcelain.rb', line 4918

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4920
4921
4922
# File 'lib/models/porcelain.rb', line 4920

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4922
4923
4924
# File 'lib/models/porcelain.rb', line 4922

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



4924
4925
4926
# File 'lib/models/porcelain.rb', line 4924

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4926
4927
4928
# File 'lib/models/porcelain.rb', line 4926

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4928
4929
4930
# File 'lib/models/porcelain.rb', line 4928

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4930
4931
4932
# File 'lib/models/porcelain.rb', line 4930

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4932
4933
4934
# File 'lib/models/porcelain.rb', line 4932

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4934
4935
4936
# File 'lib/models/porcelain.rb', line 4934

def name
  @name
end

#passwordObject

The password to authenticate with.



4936
4937
4938
# File 'lib/models/porcelain.rb', line 4936

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4938
4939
4940
# File 'lib/models/porcelain.rb', line 4938

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4940
4941
4942
# File 'lib/models/porcelain.rb', line 4940

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



4942
4943
4944
# File 'lib/models/porcelain.rb', line 4942

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4944
4945
4946
# File 'lib/models/porcelain.rb', line 4944

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



4946
4947
4948
# File 'lib/models/porcelain.rb', line 4946

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4948
4949
4950
# File 'lib/models/porcelain.rb', line 4948

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4950
4951
4952
# File 'lib/models/porcelain.rb', line 4950

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4952
4953
4954
# File 'lib/models/porcelain.rb', line 4952

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4954
4955
4956
# File 'lib/models/porcelain.rb', line 4954

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5000
5001
5002
5003
5004
5005
5006
# File 'lib/models/porcelain.rb', line 5000

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end