Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



4670
4671
4672
4673
4674
4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
4708
4709
4710
4711
4712
# File 'lib/models/porcelain.rb', line 4670

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4630
4631
4632
# File 'lib/models/porcelain.rb', line 4630

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4632
4633
4634
# File 'lib/models/porcelain.rb', line 4632

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4634
4635
4636
# File 'lib/models/porcelain.rb', line 4634

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4636
4637
4638
# File 'lib/models/porcelain.rb', line 4636

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4638
4639
4640
# File 'lib/models/porcelain.rb', line 4638

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4640
4641
4642
# File 'lib/models/porcelain.rb', line 4640

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4642
4643
4644
# File 'lib/models/porcelain.rb', line 4642

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4644
4645
4646
# File 'lib/models/porcelain.rb', line 4644

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4646
4647
4648
# File 'lib/models/porcelain.rb', line 4646

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4648
4649
4650
# File 'lib/models/porcelain.rb', line 4648

def name
  @name
end

#passwordObject

The password to authenticate with.



4650
4651
4652
# File 'lib/models/porcelain.rb', line 4650

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4652
4653
4654
# File 'lib/models/porcelain.rb', line 4652

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4654
4655
4656
# File 'lib/models/porcelain.rb', line 4654

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



4656
4657
4658
# File 'lib/models/porcelain.rb', line 4656

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4658
4659
4660
# File 'lib/models/porcelain.rb', line 4658

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



4660
4661
4662
# File 'lib/models/porcelain.rb', line 4660

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4662
4663
4664
# File 'lib/models/porcelain.rb', line 4662

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4664
4665
4666
# File 'lib/models/porcelain.rb', line 4664

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4666
4667
4668
# File 'lib/models/porcelain.rb', line 4666

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4668
4669
4670
# File 'lib/models/porcelain.rb', line 4668

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4714
4715
4716
4717
4718
4719
4720
# File 'lib/models/porcelain.rb', line 4714

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end