Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



4675
4676
4677
4678
4679
4680
4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
4703
4704
4705
4706
4707
4708
4709
4710
4711
4712
4713
4714
4715
4716
4717
# File 'lib/models/porcelain.rb', line 4675

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4635
4636
4637
# File 'lib/models/porcelain.rb', line 4635

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4637
4638
4639
# File 'lib/models/porcelain.rb', line 4637

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4639
4640
4641
# File 'lib/models/porcelain.rb', line 4639

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4641
4642
4643
# File 'lib/models/porcelain.rb', line 4641

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4643
4644
4645
# File 'lib/models/porcelain.rb', line 4643

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4645
4646
4647
# File 'lib/models/porcelain.rb', line 4645

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4647
4648
4649
# File 'lib/models/porcelain.rb', line 4647

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4649
4650
4651
# File 'lib/models/porcelain.rb', line 4649

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4651
4652
4653
# File 'lib/models/porcelain.rb', line 4651

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4653
4654
4655
# File 'lib/models/porcelain.rb', line 4653

def name
  @name
end

#passwordObject

The password to authenticate with.



4655
4656
4657
# File 'lib/models/porcelain.rb', line 4655

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4657
4658
4659
# File 'lib/models/porcelain.rb', line 4657

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4659
4660
4661
# File 'lib/models/porcelain.rb', line 4659

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



4661
4662
4663
# File 'lib/models/porcelain.rb', line 4661

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4663
4664
4665
# File 'lib/models/porcelain.rb', line 4663

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



4665
4666
4667
# File 'lib/models/porcelain.rb', line 4665

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4667
4668
4669
# File 'lib/models/porcelain.rb', line 4667

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4669
4670
4671
# File 'lib/models/porcelain.rb', line 4669

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4671
4672
4673
# File 'lib/models/porcelain.rb', line 4671

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4673
4674
4675
# File 'lib/models/porcelain.rb', line 4673

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4719
4720
4721
4722
4723
4724
4725
# File 'lib/models/porcelain.rb', line 4719

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end