Class: SDM::MTLSMysql
- Inherits:
-
Object
- Object
- SDM::MTLSMysql
- Defined in:
- lib/models/porcelain.rb
Overview
MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#require_native_auth ⇒ Object
Returns the value of attribute require_native_auth.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
Returns the value of attribute use_azure_single_server_usernames.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql
constructor
A new instance of MTLSMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql
Returns a new instance of MTLSMysql.
4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 |
# File 'lib/models/porcelain.rb', line 4555 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4515 4516 4517 |
# File 'lib/models/porcelain.rb', line 4515 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
4517 4518 4519 |
# File 'lib/models/porcelain.rb', line 4517 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
4519 4520 4521 |
# File 'lib/models/porcelain.rb', line 4519 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
4521 4522 4523 |
# File 'lib/models/porcelain.rb', line 4521 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
4523 4524 4525 |
# File 'lib/models/porcelain.rb', line 4523 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4525 4526 4527 |
# File 'lib/models/porcelain.rb', line 4525 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4527 4528 4529 |
# File 'lib/models/porcelain.rb', line 4527 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4529 4530 4531 |
# File 'lib/models/porcelain.rb', line 4529 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4531 4532 4533 |
# File 'lib/models/porcelain.rb', line 4531 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4533 4534 4535 |
# File 'lib/models/porcelain.rb', line 4533 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4535 4536 4537 |
# File 'lib/models/porcelain.rb', line 4535 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4537 4538 4539 |
# File 'lib/models/porcelain.rb', line 4537 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4539 4540 4541 |
# File 'lib/models/porcelain.rb', line 4539 def port_override @port_override end |
#require_native_auth ⇒ Object
Returns the value of attribute require_native_auth.
4541 4542 4543 |
# File 'lib/models/porcelain.rb', line 4541 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4543 4544 4545 |
# File 'lib/models/porcelain.rb', line 4543 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
4545 4546 4547 |
# File 'lib/models/porcelain.rb', line 4545 def server_name @server_name end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4547 4548 4549 |
# File 'lib/models/porcelain.rb', line 4547 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4549 4550 4551 |
# File 'lib/models/porcelain.rb', line 4549 def @tags end |
#use_azure_single_server_usernames ⇒ Object
Returns the value of attribute use_azure_single_server_usernames.
4551 4552 4553 |
# File 'lib/models/porcelain.rb', line 4551 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
Returns the value of attribute username.
4553 4554 4555 |
# File 'lib/models/porcelain.rb', line 4553 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/models/porcelain.rb', line 4599 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |