Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/models/porcelain.rb', line 4527

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4491
4492
4493
# File 'lib/models/porcelain.rb', line 4491

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



4493
4494
4495
# File 'lib/models/porcelain.rb', line 4493

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



4495
4496
4497
# File 'lib/models/porcelain.rb', line 4495

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



4497
4498
4499
# File 'lib/models/porcelain.rb', line 4497

def client_key
  @client_key
end

#databaseObject

Returns the value of attribute database.



4499
4500
4501
# File 'lib/models/porcelain.rb', line 4499

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4501
4502
4503
# File 'lib/models/porcelain.rb', line 4501

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4503
4504
4505
# File 'lib/models/porcelain.rb', line 4503

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4505
4506
4507
# File 'lib/models/porcelain.rb', line 4505

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4507
4508
4509
# File 'lib/models/porcelain.rb', line 4507

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4509
4510
4511
# File 'lib/models/porcelain.rb', line 4509

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4511
4512
4513
# File 'lib/models/porcelain.rb', line 4511

def password
  @password
end

#portObject

Returns the value of attribute port.



4513
4514
4515
# File 'lib/models/porcelain.rb', line 4513

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4515
4516
4517
# File 'lib/models/porcelain.rb', line 4515

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4517
4518
4519
# File 'lib/models/porcelain.rb', line 4517

def secret_store_id
  @secret_store_id
end

#server_nameObject

Returns the value of attribute server_name.



4519
4520
4521
# File 'lib/models/porcelain.rb', line 4519

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4521
4522
4523
# File 'lib/models/porcelain.rb', line 4521

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4523
4524
4525
# File 'lib/models/porcelain.rb', line 4523

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4525
4526
4527
# File 'lib/models/porcelain.rb', line 4525

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4567
4568
4569
4570
4571
4572
4573
# File 'lib/models/porcelain.rb', line 4567

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end