Class: SDM::MTLSMysql
- Inherits:
-
Object
- Object
- SDM::MTLSMysql
- Defined in:
- lib/models/porcelain.rb
Overview
MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSMysql
constructor
A new instance of MTLSMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSMysql
Returns a new instance of MTLSMysql.
4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/models/porcelain.rb', line 4211 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4177 4178 4179 |
# File 'lib/models/porcelain.rb', line 4177 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
4179 4180 4181 |
# File 'lib/models/porcelain.rb', line 4179 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
4181 4182 4183 |
# File 'lib/models/porcelain.rb', line 4181 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
4183 4184 4185 |
# File 'lib/models/porcelain.rb', line 4183 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
4185 4186 4187 |
# File 'lib/models/porcelain.rb', line 4185 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4187 4188 4189 |
# File 'lib/models/porcelain.rb', line 4187 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4189 4190 4191 |
# File 'lib/models/porcelain.rb', line 4189 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4191 4192 4193 |
# File 'lib/models/porcelain.rb', line 4191 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4193 4194 4195 |
# File 'lib/models/porcelain.rb', line 4193 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4195 4196 4197 |
# File 'lib/models/porcelain.rb', line 4195 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4197 4198 4199 |
# File 'lib/models/porcelain.rb', line 4197 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4199 4200 4201 |
# File 'lib/models/porcelain.rb', line 4199 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4201 4202 4203 |
# File 'lib/models/porcelain.rb', line 4201 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4203 4204 4205 |
# File 'lib/models/porcelain.rb', line 4203 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
4205 4206 4207 |
# File 'lib/models/porcelain.rb', line 4205 def server_name @server_name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4207 4208 4209 |
# File 'lib/models/porcelain.rb', line 4207 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4209 4210 4211 |
# File 'lib/models/porcelain.rb', line 4209 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4249 4250 4251 4252 4253 4254 4255 |
# File 'lib/models/porcelain.rb', line 4249 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |