Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
3888
3889
3890
3891
3892
3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
3908
3909
# File 'lib/models/porcelain.rb', line 3873

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  server_name: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3839
3840
3841
# File 'lib/models/porcelain.rb', line 3839

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3841
3842
3843
# File 'lib/models/porcelain.rb', line 3841

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3843
3844
3845
# File 'lib/models/porcelain.rb', line 3843

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3845
3846
3847
# File 'lib/models/porcelain.rb', line 3845

def client_key
  @client_key
end

#databaseObject

Returns the value of attribute database.



3847
3848
3849
# File 'lib/models/porcelain.rb', line 3847

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3849
3850
3851
# File 'lib/models/porcelain.rb', line 3849

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3851
3852
3853
# File 'lib/models/porcelain.rb', line 3851

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3853
3854
3855
# File 'lib/models/porcelain.rb', line 3853

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3855
3856
3857
# File 'lib/models/porcelain.rb', line 3855

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3857
3858
3859
# File 'lib/models/porcelain.rb', line 3857

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3859
3860
3861
# File 'lib/models/porcelain.rb', line 3859

def password
  @password
end

#portObject

Returns the value of attribute port.



3861
3862
3863
# File 'lib/models/porcelain.rb', line 3861

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3863
3864
3865
# File 'lib/models/porcelain.rb', line 3863

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3865
3866
3867
# File 'lib/models/porcelain.rb', line 3865

def secret_store_id
  @secret_store_id
end

#server_nameObject

Returns the value of attribute server_name.



3867
3868
3869
# File 'lib/models/porcelain.rb', line 3867

def server_name
  @server_name
end

#tagsObject

Tags is a map of key, value pairs.



3869
3870
3871
# File 'lib/models/porcelain.rb', line 3869

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3871
3872
3873
# File 'lib/models/porcelain.rb', line 3871

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3911
3912
3913
3914
3915
3916
3917
# File 'lib/models/porcelain.rb', line 3911

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end