Class: SDM::MTLSMysql
- Inherits:
-
Object
- Object
- SDM::MTLSMysql
- Defined in:
- lib/models/porcelain.rb
Overview
MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSMysql
constructor
A new instance of MTLSMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSMysql
Returns a new instance of MTLSMysql.
3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 |
# File 'lib/models/porcelain.rb', line 3874 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3840 3841 3842 |
# File 'lib/models/porcelain.rb', line 3840 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3842 3843 3844 |
# File 'lib/models/porcelain.rb', line 3842 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
3844 3845 3846 |
# File 'lib/models/porcelain.rb', line 3844 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
3846 3847 3848 |
# File 'lib/models/porcelain.rb', line 3846 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
3848 3849 3850 |
# File 'lib/models/porcelain.rb', line 3848 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3850 3851 3852 |
# File 'lib/models/porcelain.rb', line 3850 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3852 3853 3854 |
# File 'lib/models/porcelain.rb', line 3852 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3854 3855 3856 |
# File 'lib/models/porcelain.rb', line 3854 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3856 3857 3858 |
# File 'lib/models/porcelain.rb', line 3856 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3858 3859 3860 |
# File 'lib/models/porcelain.rb', line 3858 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3860 3861 3862 |
# File 'lib/models/porcelain.rb', line 3860 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3862 3863 3864 |
# File 'lib/models/porcelain.rb', line 3862 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3864 3865 3866 |
# File 'lib/models/porcelain.rb', line 3864 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3866 3867 3868 |
# File 'lib/models/porcelain.rb', line 3866 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
3868 3869 3870 |
# File 'lib/models/porcelain.rb', line 3868 def server_name @server_name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3870 3871 3872 |
# File 'lib/models/porcelain.rb', line 3870 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3872 3873 3874 |
# File 'lib/models/porcelain.rb', line 3872 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3912 3913 3914 3915 3916 3917 3918 |
# File 'lib/models/porcelain.rb', line 3912 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |