Class: SDM::MTLSMysql
- Inherits:
-
Object
- Object
- SDM::MTLSMysql
- Defined in:
- lib/models/porcelain.rb
Overview
MTLSMysql is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSMysql
constructor
A new instance of MTLSMysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSMysql
Returns a new instance of MTLSMysql.
3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 |
# File 'lib/models/porcelain.rb', line 3747 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3713 3714 3715 |
# File 'lib/models/porcelain.rb', line 3713 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3715 3716 3717 |
# File 'lib/models/porcelain.rb', line 3715 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
3717 3718 3719 |
# File 'lib/models/porcelain.rb', line 3717 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
3719 3720 3721 |
# File 'lib/models/porcelain.rb', line 3719 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
3721 3722 3723 |
# File 'lib/models/porcelain.rb', line 3721 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3723 3724 3725 |
# File 'lib/models/porcelain.rb', line 3723 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3725 3726 3727 |
# File 'lib/models/porcelain.rb', line 3725 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3727 3728 3729 |
# File 'lib/models/porcelain.rb', line 3727 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3729 3730 3731 |
# File 'lib/models/porcelain.rb', line 3729 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3731 3732 3733 |
# File 'lib/models/porcelain.rb', line 3731 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3733 3734 3735 |
# File 'lib/models/porcelain.rb', line 3733 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3735 3736 3737 |
# File 'lib/models/porcelain.rb', line 3735 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3737 3738 3739 |
# File 'lib/models/porcelain.rb', line 3737 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3739 3740 3741 |
# File 'lib/models/porcelain.rb', line 3739 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
3741 3742 3743 |
# File 'lib/models/porcelain.rb', line 3741 def server_name @server_name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3743 3744 3745 |
# File 'lib/models/porcelain.rb', line 3743 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3745 3746 3747 |
# File 'lib/models/porcelain.rb', line 3745 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3785 3786 3787 3788 3789 3790 3791 |
# File 'lib/models/porcelain.rb', line 3785 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |