Class: SDM::MTLSMysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ MTLSMysql

Returns a new instance of MTLSMysql.



10527
10528
10529
10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
10547
10548
10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
10569
10570
10571
# File 'lib/models/porcelain.rb', line 10527

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10485
10486
10487
# File 'lib/models/porcelain.rb', line 10485

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10487
10488
10489
# File 'lib/models/porcelain.rb', line 10487

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10489
10490
10491
# File 'lib/models/porcelain.rb', line 10489

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10491
10492
10493
# File 'lib/models/porcelain.rb', line 10491

def client_key
  @client_key
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10493
10494
10495
# File 'lib/models/porcelain.rb', line 10493

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10495
10496
10497
# File 'lib/models/porcelain.rb', line 10495

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10497
10498
10499
# File 'lib/models/porcelain.rb', line 10497

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10499
10500
10501
# File 'lib/models/porcelain.rb', line 10499

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10501
10502
10503
# File 'lib/models/porcelain.rb', line 10501

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10503
10504
10505
# File 'lib/models/porcelain.rb', line 10503

def name
  @name
end

#passwordObject

The password to authenticate with.



10505
10506
10507
# File 'lib/models/porcelain.rb', line 10505

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10507
10508
10509
# File 'lib/models/porcelain.rb', line 10507

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10509
10510
10511
# File 'lib/models/porcelain.rb', line 10509

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10511
10512
10513
# File 'lib/models/porcelain.rb', line 10511

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10513
10514
10515
# File 'lib/models/porcelain.rb', line 10513

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10515
10516
10517
# File 'lib/models/porcelain.rb', line 10515

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10517
10518
10519
# File 'lib/models/porcelain.rb', line 10517

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10519
10520
10521
# File 'lib/models/porcelain.rb', line 10519

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10521
10522
10523
# File 'lib/models/porcelain.rb', line 10521

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10523
10524
10525
# File 'lib/models/porcelain.rb', line 10523

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10525
10526
10527
# File 'lib/models/porcelain.rb', line 10525

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10573
10574
10575
10576
10577
10578
10579
# File 'lib/models/porcelain.rb', line 10573

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end