Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



11000
11001
11002
11003
11004
11005
11006
11007
11008
11009
11010
11011
11012
11013
11014
11015
11016
11017
11018
11019
11020
11021
11022
11023
11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
11036
11037
11038
11039
11040
11041
11042
# File 'lib/models/porcelain.rb', line 11000

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10960
10961
10962
# File 'lib/models/porcelain.rb', line 10960

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10962
10963
10964
# File 'lib/models/porcelain.rb', line 10962

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10964
10965
10966
# File 'lib/models/porcelain.rb', line 10964

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10966
10967
10968
# File 'lib/models/porcelain.rb', line 10966

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10968
10969
10970
# File 'lib/models/porcelain.rb', line 10968

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10970
10971
10972
# File 'lib/models/porcelain.rb', line 10970

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10972
10973
10974
# File 'lib/models/porcelain.rb', line 10972

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10974
10975
10976
# File 'lib/models/porcelain.rb', line 10974

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10976
10977
10978
# File 'lib/models/porcelain.rb', line 10976

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10978
10979
10980
# File 'lib/models/porcelain.rb', line 10978

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10980
10981
10982
# File 'lib/models/porcelain.rb', line 10980

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10982
10983
10984
# File 'lib/models/porcelain.rb', line 10982

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10984
10985
10986
# File 'lib/models/porcelain.rb', line 10984

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10986
10987
10988
# File 'lib/models/porcelain.rb', line 10986

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10988
10989
10990
# File 'lib/models/porcelain.rb', line 10988

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10990
10991
10992
# File 'lib/models/porcelain.rb', line 10990

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10992
10993
10994
# File 'lib/models/porcelain.rb', line 10992

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10994
10995
10996
# File 'lib/models/porcelain.rb', line 10994

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10996
10997
10998
# File 'lib/models/porcelain.rb', line 10996

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10998
10999
11000
# File 'lib/models/porcelain.rb', line 10998

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11044
11045
11046
11047
11048
11049
11050
# File 'lib/models/porcelain.rb', line 11044

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end