Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



10772
10773
10774
10775
10776
10777
10778
10779
10780
10781
10782
10783
10784
10785
10786
10787
10788
10789
10790
10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
10802
10803
10804
10805
10806
10807
10808
10809
10810
10811
10812
10813
10814
# File 'lib/models/porcelain.rb', line 10772

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10732
10733
10734
# File 'lib/models/porcelain.rb', line 10732

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10734
10735
10736
# File 'lib/models/porcelain.rb', line 10734

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10736
10737
10738
# File 'lib/models/porcelain.rb', line 10736

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10738
10739
10740
# File 'lib/models/porcelain.rb', line 10738

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10740
10741
10742
# File 'lib/models/porcelain.rb', line 10740

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10742
10743
10744
# File 'lib/models/porcelain.rb', line 10742

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10744
10745
10746
# File 'lib/models/porcelain.rb', line 10744

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10746
10747
10748
# File 'lib/models/porcelain.rb', line 10746

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10748
10749
10750
# File 'lib/models/porcelain.rb', line 10748

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10750
10751
10752
# File 'lib/models/porcelain.rb', line 10750

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10752
10753
10754
# File 'lib/models/porcelain.rb', line 10752

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10754
10755
10756
# File 'lib/models/porcelain.rb', line 10754

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10756
10757
10758
# File 'lib/models/porcelain.rb', line 10756

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10758
10759
10760
# File 'lib/models/porcelain.rb', line 10758

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10760
10761
10762
# File 'lib/models/porcelain.rb', line 10760

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10762
10763
10764
# File 'lib/models/porcelain.rb', line 10762

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10764
10765
10766
# File 'lib/models/porcelain.rb', line 10764

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10766
10767
10768
# File 'lib/models/porcelain.rb', line 10766

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10768
10769
10770
# File 'lib/models/porcelain.rb', line 10768

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10770
10771
10772
# File 'lib/models/porcelain.rb', line 10770

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10816
10817
10818
10819
10820
10821
10822
# File 'lib/models/porcelain.rb', line 10816

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end