Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



10418
10419
10420
10421
10422
10423
10424
10425
10426
10427
10428
10429
10430
10431
10432
10433
10434
10435
10436
10437
10438
10439
10440
10441
10442
10443
10444
10445
10446
10447
10448
10449
10450
10451
10452
10453
10454
10455
10456
10457
10458
10459
10460
# File 'lib/models/porcelain.rb', line 10418

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10378
10379
10380
# File 'lib/models/porcelain.rb', line 10378

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10380
10381
10382
# File 'lib/models/porcelain.rb', line 10380

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10382
10383
10384
# File 'lib/models/porcelain.rb', line 10382

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10384
10385
10386
# File 'lib/models/porcelain.rb', line 10384

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10386
10387
10388
# File 'lib/models/porcelain.rb', line 10386

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10388
10389
10390
# File 'lib/models/porcelain.rb', line 10388

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10390
10391
10392
# File 'lib/models/porcelain.rb', line 10390

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10392
10393
10394
# File 'lib/models/porcelain.rb', line 10392

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10394
10395
10396
# File 'lib/models/porcelain.rb', line 10394

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10396
10397
10398
# File 'lib/models/porcelain.rb', line 10396

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10398
10399
10400
# File 'lib/models/porcelain.rb', line 10398

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10400
10401
10402
# File 'lib/models/porcelain.rb', line 10400

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10402
10403
10404
# File 'lib/models/porcelain.rb', line 10402

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10404
10405
10406
# File 'lib/models/porcelain.rb', line 10404

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10406
10407
10408
# File 'lib/models/porcelain.rb', line 10406

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10408
10409
10410
# File 'lib/models/porcelain.rb', line 10408

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10410
10411
10412
# File 'lib/models/porcelain.rb', line 10410

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10412
10413
10414
# File 'lib/models/porcelain.rb', line 10412

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10414
10415
10416
# File 'lib/models/porcelain.rb', line 10414

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10416
10417
10418
# File 'lib/models/porcelain.rb', line 10416

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10462
10463
10464
10465
10466
10467
10468
# File 'lib/models/porcelain.rb', line 10462

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end