Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
10148
10149
10150
10151
10152
10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
# File 'lib/models/porcelain.rb', line 10124

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10084
10085
10086
# File 'lib/models/porcelain.rb', line 10084

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10086
10087
10088
# File 'lib/models/porcelain.rb', line 10086

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10088
10089
10090
# File 'lib/models/porcelain.rb', line 10088

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10090
10091
10092
# File 'lib/models/porcelain.rb', line 10090

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10092
10093
10094
# File 'lib/models/porcelain.rb', line 10092

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10094
10095
10096
# File 'lib/models/porcelain.rb', line 10094

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10096
10097
10098
# File 'lib/models/porcelain.rb', line 10096

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10098
10099
10100
# File 'lib/models/porcelain.rb', line 10098

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10100
10101
10102
# File 'lib/models/porcelain.rb', line 10100

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10102
10103
10104
# File 'lib/models/porcelain.rb', line 10102

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10104
10105
10106
# File 'lib/models/porcelain.rb', line 10104

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10106
10107
10108
# File 'lib/models/porcelain.rb', line 10106

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10108
10109
10110
# File 'lib/models/porcelain.rb', line 10108

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10110
10111
10112
# File 'lib/models/porcelain.rb', line 10110

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10112
10113
10114
# File 'lib/models/porcelain.rb', line 10112

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10114
10115
10116
# File 'lib/models/porcelain.rb', line 10114

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10116
10117
10118
# File 'lib/models/porcelain.rb', line 10116

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10118
10119
10120
# File 'lib/models/porcelain.rb', line 10118

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10120
10121
10122
# File 'lib/models/porcelain.rb', line 10120

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10122
10123
10124
# File 'lib/models/porcelain.rb', line 10122

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10168
10169
10170
10171
10172
10173
10174
# File 'lib/models/porcelain.rb', line 10168

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end