Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



10060
10061
10062
10063
10064
10065
10066
10067
10068
10069
10070
10071
10072
10073
10074
10075
10076
10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
10090
10091
10092
10093
10094
10095
10096
10097
10098
10099
10100
10101
10102
# File 'lib/models/porcelain.rb', line 10060

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10020
10021
10022
# File 'lib/models/porcelain.rb', line 10020

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



10022
10023
10024
# File 'lib/models/porcelain.rb', line 10022

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



10024
10025
10026
# File 'lib/models/porcelain.rb', line 10024

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



10026
10027
10028
# File 'lib/models/porcelain.rb', line 10026

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10028
10029
10030
# File 'lib/models/porcelain.rb', line 10028

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10030
10031
10032
# File 'lib/models/porcelain.rb', line 10030

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10032
10033
10034
# File 'lib/models/porcelain.rb', line 10032

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10034
10035
10036
# File 'lib/models/porcelain.rb', line 10034

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10036
10037
10038
# File 'lib/models/porcelain.rb', line 10036

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10038
10039
10040
# File 'lib/models/porcelain.rb', line 10038

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10040
10041
10042
# File 'lib/models/porcelain.rb', line 10040

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10042
10043
10044
# File 'lib/models/porcelain.rb', line 10042

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10044
10045
10046
# File 'lib/models/porcelain.rb', line 10044

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10046
10047
10048
# File 'lib/models/porcelain.rb', line 10046

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10048
10049
10050
# File 'lib/models/porcelain.rb', line 10048

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10050
10051
10052
# File 'lib/models/porcelain.rb', line 10050

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



10052
10053
10054
# File 'lib/models/porcelain.rb', line 10052

def server_name
  @server_name
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10054
10055
10056
# File 'lib/models/porcelain.rb', line 10054

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10056
10057
10058
# File 'lib/models/porcelain.rb', line 10056

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10058
10059
10060
# File 'lib/models/porcelain.rb', line 10058

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10104
10105
10106
10107
10108
10109
10110
# File 'lib/models/porcelain.rb', line 10104

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end