Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



8248
8249
8250
8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
8286
8287
8288
8289
8290
# File 'lib/models/porcelain.rb', line 8248

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8208
8209
8210
# File 'lib/models/porcelain.rb', line 8208

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



8210
8211
8212
# File 'lib/models/porcelain.rb', line 8210

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



8212
8213
8214
# File 'lib/models/porcelain.rb', line 8212

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



8214
8215
8216
# File 'lib/models/porcelain.rb', line 8214

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8216
8217
8218
# File 'lib/models/porcelain.rb', line 8216

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8218
8219
8220
# File 'lib/models/porcelain.rb', line 8218

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8220
8221
8222
# File 'lib/models/porcelain.rb', line 8220

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8222
8223
8224
# File 'lib/models/porcelain.rb', line 8222

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8224
8225
8226
# File 'lib/models/porcelain.rb', line 8224

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8226
8227
8228
# File 'lib/models/porcelain.rb', line 8226

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8228
8229
8230
# File 'lib/models/porcelain.rb', line 8228

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



8230
8231
8232
# File 'lib/models/porcelain.rb', line 8230

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8232
8233
8234
# File 'lib/models/porcelain.rb', line 8232

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8234
8235
8236
# File 'lib/models/porcelain.rb', line 8234

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8236
8237
8238
# File 'lib/models/porcelain.rb', line 8236

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8238
8239
8240
# File 'lib/models/porcelain.rb', line 8238

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



8240
8241
8242
# File 'lib/models/porcelain.rb', line 8240

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8242
8243
8244
# File 'lib/models/porcelain.rb', line 8242

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8244
8245
8246
# File 'lib/models/porcelain.rb', line 8244

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8246
8247
8248
# File 'lib/models/porcelain.rb', line 8246

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8292
8293
8294
8295
8296
8297
8298
# File 'lib/models/porcelain.rb', line 8292

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end