Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
8115
8116
8117
8118
# File 'lib/models/porcelain.rb', line 8076

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8036
8037
8038
# File 'lib/models/porcelain.rb', line 8036

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



8038
8039
8040
# File 'lib/models/porcelain.rb', line 8038

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



8040
8041
8042
# File 'lib/models/porcelain.rb', line 8040

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



8042
8043
8044
# File 'lib/models/porcelain.rb', line 8042

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8044
8045
8046
# File 'lib/models/porcelain.rb', line 8044

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8046
8047
8048
# File 'lib/models/porcelain.rb', line 8046

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8048
8049
8050
# File 'lib/models/porcelain.rb', line 8048

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8050
8051
8052
# File 'lib/models/porcelain.rb', line 8050

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8052
8053
8054
# File 'lib/models/porcelain.rb', line 8052

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8054
8055
8056
# File 'lib/models/porcelain.rb', line 8054

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8056
8057
8058
# File 'lib/models/porcelain.rb', line 8056

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



8058
8059
8060
# File 'lib/models/porcelain.rb', line 8058

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8060
8061
8062
# File 'lib/models/porcelain.rb', line 8060

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8062
8063
8064
# File 'lib/models/porcelain.rb', line 8062

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8064
8065
8066
# File 'lib/models/porcelain.rb', line 8064

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8066
8067
8068
# File 'lib/models/porcelain.rb', line 8066

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



8068
8069
8070
# File 'lib/models/porcelain.rb', line 8068

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8070
8071
8072
# File 'lib/models/porcelain.rb', line 8070

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8072
8073
8074
# File 'lib/models/porcelain.rb', line 8072

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8074
8075
8076
# File 'lib/models/porcelain.rb', line 8074

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8120
8121
8122
8123
8124
8125
8126
# File 'lib/models/porcelain.rb', line 8120

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end