Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
7965
7966
7967
7968
7969
7970
7971
# File 'lib/models/porcelain.rb', line 7929

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7889
7890
7891
# File 'lib/models/porcelain.rb', line 7889

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7891
7892
7893
# File 'lib/models/porcelain.rb', line 7891

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7893
7894
7895
# File 'lib/models/porcelain.rb', line 7893

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7895
7896
7897
# File 'lib/models/porcelain.rb', line 7895

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7897
7898
7899
# File 'lib/models/porcelain.rb', line 7897

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7899
7900
7901
# File 'lib/models/porcelain.rb', line 7899

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7901
7902
7903
# File 'lib/models/porcelain.rb', line 7901

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7903
7904
7905
# File 'lib/models/porcelain.rb', line 7903

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7905
7906
7907
# File 'lib/models/porcelain.rb', line 7905

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7907
7908
7909
# File 'lib/models/porcelain.rb', line 7907

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



7909
7910
7911
# File 'lib/models/porcelain.rb', line 7909

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



7911
7912
7913
# File 'lib/models/porcelain.rb', line 7911

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7913
7914
7915
# File 'lib/models/porcelain.rb', line 7913

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7915
7916
7917
# File 'lib/models/porcelain.rb', line 7915

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7917
7918
7919
# File 'lib/models/porcelain.rb', line 7917

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7919
7920
7921
# File 'lib/models/porcelain.rb', line 7919

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



7921
7922
7923
# File 'lib/models/porcelain.rb', line 7921

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7923
7924
7925
# File 'lib/models/porcelain.rb', line 7923

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7925
7926
7927
# File 'lib/models/porcelain.rb', line 7925

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7927
7928
7929
# File 'lib/models/porcelain.rb', line 7927

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7973
7974
7975
7976
7977
7978
7979
# File 'lib/models/porcelain.rb', line 7973

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end