Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
7641
7642
7643
# File 'lib/models/porcelain.rb', line 7601

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7561
7562
7563
# File 'lib/models/porcelain.rb', line 7561

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7563
7564
7565
# File 'lib/models/porcelain.rb', line 7563

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7565
7566
7567
# File 'lib/models/porcelain.rb', line 7565

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7567
7568
7569
# File 'lib/models/porcelain.rb', line 7567

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7569
7570
7571
# File 'lib/models/porcelain.rb', line 7569

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7571
7572
7573
# File 'lib/models/porcelain.rb', line 7571

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7573
7574
7575
# File 'lib/models/porcelain.rb', line 7573

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7575
7576
7577
# File 'lib/models/porcelain.rb', line 7575

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7577
7578
7579
# File 'lib/models/porcelain.rb', line 7577

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7579
7580
7581
# File 'lib/models/porcelain.rb', line 7579

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



7581
7582
7583
# File 'lib/models/porcelain.rb', line 7581

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



7583
7584
7585
# File 'lib/models/porcelain.rb', line 7583

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7585
7586
7587
# File 'lib/models/porcelain.rb', line 7585

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7587
7588
7589
# File 'lib/models/porcelain.rb', line 7587

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7589
7590
7591
# File 'lib/models/porcelain.rb', line 7589

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7591
7592
7593
# File 'lib/models/porcelain.rb', line 7591

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



7593
7594
7595
# File 'lib/models/porcelain.rb', line 7593

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7595
7596
7597
# File 'lib/models/porcelain.rb', line 7595

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7597
7598
7599
# File 'lib/models/porcelain.rb', line 7597

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7599
7600
7601
# File 'lib/models/porcelain.rb', line 7599

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7645
7646
7647
7648
7649
7650
7651
# File 'lib/models/porcelain.rb', line 7645

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end