Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
# File 'lib/models/porcelain.rb', line 7598

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7558
7559
7560
# File 'lib/models/porcelain.rb', line 7558

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7560
7561
7562
# File 'lib/models/porcelain.rb', line 7560

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7562
7563
7564
# File 'lib/models/porcelain.rb', line 7562

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7564
7565
7566
# File 'lib/models/porcelain.rb', line 7564

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7566
7567
7568
# File 'lib/models/porcelain.rb', line 7566

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7568
7569
7570
# File 'lib/models/porcelain.rb', line 7568

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7570
7571
7572
# File 'lib/models/porcelain.rb', line 7570

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7572
7573
7574
# File 'lib/models/porcelain.rb', line 7572

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7574
7575
7576
# File 'lib/models/porcelain.rb', line 7574

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7576
7577
7578
# File 'lib/models/porcelain.rb', line 7576

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



7578
7579
7580
# File 'lib/models/porcelain.rb', line 7578

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



7580
7581
7582
# File 'lib/models/porcelain.rb', line 7580

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7582
7583
7584
# File 'lib/models/porcelain.rb', line 7582

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7584
7585
7586
# File 'lib/models/porcelain.rb', line 7584

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7586
7587
7588
# File 'lib/models/porcelain.rb', line 7586

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7588
7589
7590
# File 'lib/models/porcelain.rb', line 7588

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



7590
7591
7592
# File 'lib/models/porcelain.rb', line 7590

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7592
7593
7594
# File 'lib/models/porcelain.rb', line 7592

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7594
7595
7596
# File 'lib/models/porcelain.rb', line 7594

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7596
7597
7598
# File 'lib/models/porcelain.rb', line 7596

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7642
7643
7644
7645
7646
7647
7648
# File 'lib/models/porcelain.rb', line 7642

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end