Class: SDM::MTLSPostgres
- Inherits:
-
Object
- Object
- SDM::MTLSPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Server name for TLS verification (unverified by StrongDM if empty).
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
constructor
A new instance of MTLSPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
Returns a new instance of MTLSPostgres.
7522 7523 7524 7525 7526 7527 7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 7560 7561 7562 7563 7564 |
# File 'lib/models/porcelain.rb', line 7522 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7482 7483 7484 |
# File 'lib/models/porcelain.rb', line 7482 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
7484 7485 7486 |
# File 'lib/models/porcelain.rb', line 7484 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
7486 7487 7488 |
# File 'lib/models/porcelain.rb', line 7486 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
7488 7489 7490 |
# File 'lib/models/porcelain.rb', line 7488 def client_key @client_key end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7490 7491 7492 |
# File 'lib/models/porcelain.rb', line 7490 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7492 7493 7494 |
# File 'lib/models/porcelain.rb', line 7492 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7494 7495 7496 |
# File 'lib/models/porcelain.rb', line 7494 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7496 7497 7498 |
# File 'lib/models/porcelain.rb', line 7496 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7498 7499 7500 |
# File 'lib/models/porcelain.rb', line 7498 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7500 7501 7502 |
# File 'lib/models/porcelain.rb', line 7500 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
7502 7503 7504 |
# File 'lib/models/porcelain.rb', line 7502 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
7504 7505 7506 |
# File 'lib/models/porcelain.rb', line 7504 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7506 7507 7508 |
# File 'lib/models/porcelain.rb', line 7506 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7508 7509 7510 |
# File 'lib/models/porcelain.rb', line 7508 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7510 7511 7512 |
# File 'lib/models/porcelain.rb', line 7510 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7512 7513 7514 |
# File 'lib/models/porcelain.rb', line 7512 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Server name for TLS verification (unverified by StrongDM if empty)
7514 7515 7516 |
# File 'lib/models/porcelain.rb', line 7514 def server_name @server_name end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7516 7517 7518 |
# File 'lib/models/porcelain.rb', line 7516 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7518 7519 7520 |
# File 'lib/models/porcelain.rb', line 7518 def @tags end |
#username ⇒ Object
The username to authenticate with.
7520 7521 7522 |
# File 'lib/models/porcelain.rb', line 7520 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7566 7567 7568 7569 7570 7571 7572 |
# File 'lib/models/porcelain.rb', line 7566 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |