Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



7452
7453
7454
7455
7456
7457
7458
7459
7460
7461
7462
7463
7464
7465
7466
7467
7468
7469
7470
7471
7472
7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
7483
7484
7485
7486
7487
7488
7489
7490
7491
7492
7493
7494
# File 'lib/models/porcelain.rb', line 7452

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7412
7413
7414
# File 'lib/models/porcelain.rb', line 7412

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



7414
7415
7416
# File 'lib/models/porcelain.rb', line 7414

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



7416
7417
7418
# File 'lib/models/porcelain.rb', line 7416

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



7418
7419
7420
# File 'lib/models/porcelain.rb', line 7418

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7420
7421
7422
# File 'lib/models/porcelain.rb', line 7420

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7422
7423
7424
# File 'lib/models/porcelain.rb', line 7422

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7424
7425
7426
# File 'lib/models/porcelain.rb', line 7424

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7426
7427
7428
# File 'lib/models/porcelain.rb', line 7426

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7428
7429
7430
# File 'lib/models/porcelain.rb', line 7428

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7430
7431
7432
# File 'lib/models/porcelain.rb', line 7430

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



7432
7433
7434
# File 'lib/models/porcelain.rb', line 7432

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



7434
7435
7436
# File 'lib/models/porcelain.rb', line 7434

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7436
7437
7438
# File 'lib/models/porcelain.rb', line 7436

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7438
7439
7440
# File 'lib/models/porcelain.rb', line 7438

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7440
7441
7442
# File 'lib/models/porcelain.rb', line 7440

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7442
7443
7444
# File 'lib/models/porcelain.rb', line 7442

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



7444
7445
7446
# File 'lib/models/porcelain.rb', line 7444

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7446
7447
7448
# File 'lib/models/porcelain.rb', line 7446

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7448
7449
7450
# File 'lib/models/porcelain.rb', line 7448

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7450
7451
7452
# File 'lib/models/porcelain.rb', line 7450

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7496
7497
7498
7499
7500
7501
7502
# File 'lib/models/porcelain.rb', line 7496

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end