Class: SDM::MTLSPostgres
- Inherits:
-
Object
- Object
- SDM::MTLSPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Server name for TLS verification (unverified by StrongDM if empty).
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
constructor
A new instance of MTLSPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
Returns a new instance of MTLSPostgres.
7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 7397 7398 7399 7400 7401 7402 7403 7404 7405 7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 7424 7425 7426 7427 |
# File 'lib/models/porcelain.rb', line 7385 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7345 7346 7347 |
# File 'lib/models/porcelain.rb', line 7345 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
7347 7348 7349 |
# File 'lib/models/porcelain.rb', line 7347 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
7349 7350 7351 |
# File 'lib/models/porcelain.rb', line 7349 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
7351 7352 7353 |
# File 'lib/models/porcelain.rb', line 7351 def client_key @client_key end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7353 7354 7355 |
# File 'lib/models/porcelain.rb', line 7353 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7355 7356 7357 |
# File 'lib/models/porcelain.rb', line 7355 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7357 7358 7359 |
# File 'lib/models/porcelain.rb', line 7357 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7359 7360 7361 |
# File 'lib/models/porcelain.rb', line 7359 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7361 7362 7363 |
# File 'lib/models/porcelain.rb', line 7361 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7363 7364 7365 |
# File 'lib/models/porcelain.rb', line 7363 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
7365 7366 7367 |
# File 'lib/models/porcelain.rb', line 7365 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
7367 7368 7369 |
# File 'lib/models/porcelain.rb', line 7367 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7369 7370 7371 |
# File 'lib/models/porcelain.rb', line 7369 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7371 7372 7373 |
# File 'lib/models/porcelain.rb', line 7371 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7373 7374 7375 |
# File 'lib/models/porcelain.rb', line 7373 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7375 7376 7377 |
# File 'lib/models/porcelain.rb', line 7375 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Server name for TLS verification (unverified by StrongDM if empty)
7377 7378 7379 |
# File 'lib/models/porcelain.rb', line 7377 def server_name @server_name end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7379 7380 7381 |
# File 'lib/models/porcelain.rb', line 7379 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7381 7382 7383 |
# File 'lib/models/porcelain.rb', line 7381 def @tags end |
#username ⇒ Object
The username to authenticate with.
7383 7384 7385 |
# File 'lib/models/porcelain.rb', line 7383 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7429 7430 7431 7432 7433 7434 7435 |
# File 'lib/models/porcelain.rb', line 7429 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |