Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
6878
6879
6880
6881
6882
6883
# File 'lib/models/porcelain.rb', line 6841

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6801
6802
6803
# File 'lib/models/porcelain.rb', line 6801

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6803
6804
6805
# File 'lib/models/porcelain.rb', line 6803

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6805
6806
6807
# File 'lib/models/porcelain.rb', line 6805

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6807
6808
6809
# File 'lib/models/porcelain.rb', line 6807

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6809
6810
6811
# File 'lib/models/porcelain.rb', line 6809

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6811
6812
6813
# File 'lib/models/porcelain.rb', line 6811

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6813
6814
6815
# File 'lib/models/porcelain.rb', line 6813

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6815
6816
6817
# File 'lib/models/porcelain.rb', line 6815

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6817
6818
6819
# File 'lib/models/porcelain.rb', line 6817

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6819
6820
6821
# File 'lib/models/porcelain.rb', line 6819

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



6821
6822
6823
# File 'lib/models/porcelain.rb', line 6821

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



6823
6824
6825
# File 'lib/models/porcelain.rb', line 6823

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6825
6826
6827
# File 'lib/models/porcelain.rb', line 6825

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6827
6828
6829
# File 'lib/models/porcelain.rb', line 6827

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6829
6830
6831
# File 'lib/models/porcelain.rb', line 6829

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6831
6832
6833
# File 'lib/models/porcelain.rb', line 6831

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



6833
6834
6835
# File 'lib/models/porcelain.rb', line 6833

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6835
6836
6837
# File 'lib/models/porcelain.rb', line 6835

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6837
6838
6839
# File 'lib/models/porcelain.rb', line 6837

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6839
6840
6841
# File 'lib/models/porcelain.rb', line 6839

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6885
6886
6887
6888
6889
6890
6891
# File 'lib/models/porcelain.rb', line 6885

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end