Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
6783
6784
6785
6786
6787
6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
# File 'lib/models/porcelain.rb', line 6770

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6730
6731
6732
# File 'lib/models/porcelain.rb', line 6730

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



6732
6733
6734
# File 'lib/models/porcelain.rb', line 6732

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



6734
6735
6736
# File 'lib/models/porcelain.rb', line 6734

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



6736
6737
6738
# File 'lib/models/porcelain.rb', line 6736

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6738
6739
6740
# File 'lib/models/porcelain.rb', line 6738

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6740
6741
6742
# File 'lib/models/porcelain.rb', line 6740

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6742
6743
6744
# File 'lib/models/porcelain.rb', line 6742

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6744
6745
6746
# File 'lib/models/porcelain.rb', line 6744

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6746
6747
6748
# File 'lib/models/porcelain.rb', line 6746

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6748
6749
6750
# File 'lib/models/porcelain.rb', line 6748

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



6750
6751
6752
# File 'lib/models/porcelain.rb', line 6750

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



6752
6753
6754
# File 'lib/models/porcelain.rb', line 6752

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6754
6755
6756
# File 'lib/models/porcelain.rb', line 6754

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6756
6757
6758
# File 'lib/models/porcelain.rb', line 6756

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6758
6759
6760
# File 'lib/models/porcelain.rb', line 6758

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6760
6761
6762
# File 'lib/models/porcelain.rb', line 6760

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



6762
6763
6764
# File 'lib/models/porcelain.rb', line 6762

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6764
6765
6766
# File 'lib/models/porcelain.rb', line 6764

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6766
6767
6768
# File 'lib/models/porcelain.rb', line 6766

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6768
6769
6770
# File 'lib/models/porcelain.rb', line 6768

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6814
6815
6816
6817
6818
6819
6820
# File 'lib/models/porcelain.rb', line 6814

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end