Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



4935
4936
4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
4971
4972
4973
4974
4975
# File 'lib/models/porcelain.rb', line 4935

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4897
4898
4899
# File 'lib/models/porcelain.rb', line 4897

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4899
4900
4901
# File 'lib/models/porcelain.rb', line 4899

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4901
4902
4903
# File 'lib/models/porcelain.rb', line 4901

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4903
4904
4905
# File 'lib/models/porcelain.rb', line 4903

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4905
4906
4907
# File 'lib/models/porcelain.rb', line 4905

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4907
4908
4909
# File 'lib/models/porcelain.rb', line 4907

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4909
4910
4911
# File 'lib/models/porcelain.rb', line 4909

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4911
4912
4913
# File 'lib/models/porcelain.rb', line 4911

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4913
4914
4915
# File 'lib/models/porcelain.rb', line 4913

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4915
4916
4917
# File 'lib/models/porcelain.rb', line 4915

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4917
4918
4919
# File 'lib/models/porcelain.rb', line 4917

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4919
4920
4921
# File 'lib/models/porcelain.rb', line 4919

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4921
4922
4923
# File 'lib/models/porcelain.rb', line 4921

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4923
4924
4925
# File 'lib/models/porcelain.rb', line 4923

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4925
4926
4927
# File 'lib/models/porcelain.rb', line 4925

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



4927
4928
4929
# File 'lib/models/porcelain.rb', line 4927

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4929
4930
4931
# File 'lib/models/porcelain.rb', line 4929

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4931
4932
4933
# File 'lib/models/porcelain.rb', line 4931

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4933
4934
4935
# File 'lib/models/porcelain.rb', line 4933

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4977
4978
4979
4980
4981
4982
4983
# File 'lib/models/porcelain.rb', line 4977

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end