Class: SDM::MTLSPostgres
- Inherits:
-
Object
- Object
- SDM::MTLSPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
-
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
-
#client_key ⇒ Object
The key to authenticate TLS connections with.
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Server name for TLS verification (unverified by StrongDM if empty).
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
constructor
A new instance of MTLSPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
Returns a new instance of MTLSPostgres.
4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 4792 4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 |
# File 'lib/models/porcelain.rb', line 4771 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
4733 4734 4735 |
# File 'lib/models/porcelain.rb', line 4733 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
The CA to authenticate TLS connections with.
4735 4736 4737 |
# File 'lib/models/porcelain.rb', line 4735 def @certificate_authority end |
#client_certificate ⇒ Object
The certificate to authenticate TLS connections with.
4737 4738 4739 |
# File 'lib/models/porcelain.rb', line 4737 def client_certificate @client_certificate end |
#client_key ⇒ Object
The key to authenticate TLS connections with.
4739 4740 4741 |
# File 'lib/models/porcelain.rb', line 4739 def client_key @client_key end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
4741 4742 4743 |
# File 'lib/models/porcelain.rb', line 4741 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4743 4744 4745 |
# File 'lib/models/porcelain.rb', line 4743 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4745 4746 4747 |
# File 'lib/models/porcelain.rb', line 4745 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
4747 4748 4749 |
# File 'lib/models/porcelain.rb', line 4747 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4749 4750 4751 |
# File 'lib/models/porcelain.rb', line 4749 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4751 4752 4753 |
# File 'lib/models/porcelain.rb', line 4751 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
4753 4754 4755 |
# File 'lib/models/porcelain.rb', line 4753 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
4755 4756 4757 |
# File 'lib/models/porcelain.rb', line 4755 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
4757 4758 4759 |
# File 'lib/models/porcelain.rb', line 4757 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
4759 4760 4761 |
# File 'lib/models/porcelain.rb', line 4759 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4761 4762 4763 |
# File 'lib/models/porcelain.rb', line 4761 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Server name for TLS verification (unverified by StrongDM if empty)
4763 4764 4765 |
# File 'lib/models/porcelain.rb', line 4763 def server_name @server_name end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4765 4766 4767 |
# File 'lib/models/porcelain.rb', line 4765 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4767 4768 4769 |
# File 'lib/models/porcelain.rb', line 4767 def @tags end |
#username ⇒ Object
The username to authenticate with.
4769 4770 4771 |
# File 'lib/models/porcelain.rb', line 4769 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4813 4814 4815 4816 4817 4818 4819 |
# File 'lib/models/porcelain.rb', line 4813 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |