Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
# File 'lib/models/porcelain.rb', line 4763

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4725
4726
4727
# File 'lib/models/porcelain.rb', line 4725

def bind_interface
  @bind_interface
end

#certificate_authorityObject

The CA to authenticate TLS connections with.



4727
4728
4729
# File 'lib/models/porcelain.rb', line 4727

def certificate_authority
  @certificate_authority
end

#client_certificateObject

The certificate to authenticate TLS connections with.



4729
4730
4731
# File 'lib/models/porcelain.rb', line 4729

def client_certificate
  @client_certificate
end

#client_keyObject

The key to authenticate TLS connections with.



4731
4732
4733
# File 'lib/models/porcelain.rb', line 4731

def client_key
  @client_key
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4733
4734
4735
# File 'lib/models/porcelain.rb', line 4733

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4735
4736
4737
# File 'lib/models/porcelain.rb', line 4735

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4737
4738
4739
# File 'lib/models/porcelain.rb', line 4737

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4739
4740
4741
# File 'lib/models/porcelain.rb', line 4739

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4741
4742
4743
# File 'lib/models/porcelain.rb', line 4741

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4743
4744
4745
# File 'lib/models/porcelain.rb', line 4743

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



4745
4746
4747
# File 'lib/models/porcelain.rb', line 4745

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



4747
4748
4749
# File 'lib/models/porcelain.rb', line 4747

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4749
4750
4751
# File 'lib/models/porcelain.rb', line 4749

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4751
4752
4753
# File 'lib/models/porcelain.rb', line 4751

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4753
4754
4755
# File 'lib/models/porcelain.rb', line 4753

def secret_store_id
  @secret_store_id
end

#server_nameObject

Server name for TLS verification (unverified by StrongDM if empty)



4755
4756
4757
# File 'lib/models/porcelain.rb', line 4755

def server_name
  @server_name
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4757
4758
4759
# File 'lib/models/porcelain.rb', line 4757

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4759
4760
4761
# File 'lib/models/porcelain.rb', line 4759

def tags
  @tags
end

#usernameObject

The username to authenticate with.



4761
4762
4763
# File 'lib/models/porcelain.rb', line 4761

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4805
4806
4807
4808
4809
4810
4811
# File 'lib/models/porcelain.rb', line 4805

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end