Class: SDM::MTLSPostgres
- Inherits:
-
Object
- Object
- SDM::MTLSPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
constructor
A new instance of MTLSPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
Returns a new instance of MTLSPostgres.
4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 4677 4678 4679 4680 4681 4682 4683 4684 4685 4686 4687 4688 |
# File 'lib/models/porcelain.rb', line 4648 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4610 4611 4612 |
# File 'lib/models/porcelain.rb', line 4610 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
4612 4613 4614 |
# File 'lib/models/porcelain.rb', line 4612 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
4614 4615 4616 |
# File 'lib/models/porcelain.rb', line 4614 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
4616 4617 4618 |
# File 'lib/models/porcelain.rb', line 4616 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
4618 4619 4620 |
# File 'lib/models/porcelain.rb', line 4618 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4620 4621 4622 |
# File 'lib/models/porcelain.rb', line 4620 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4622 4623 4624 |
# File 'lib/models/porcelain.rb', line 4622 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4624 4625 4626 |
# File 'lib/models/porcelain.rb', line 4624 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4626 4627 4628 |
# File 'lib/models/porcelain.rb', line 4626 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4628 4629 4630 |
# File 'lib/models/porcelain.rb', line 4628 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
4630 4631 4632 |
# File 'lib/models/porcelain.rb', line 4630 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
4632 4633 4634 |
# File 'lib/models/porcelain.rb', line 4632 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4634 4635 4636 |
# File 'lib/models/porcelain.rb', line 4634 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4636 4637 4638 |
# File 'lib/models/porcelain.rb', line 4636 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4638 4639 4640 |
# File 'lib/models/porcelain.rb', line 4638 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
4640 4641 4642 |
# File 'lib/models/porcelain.rb', line 4640 def server_name @server_name end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4642 4643 4644 |
# File 'lib/models/porcelain.rb', line 4642 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4644 4645 4646 |
# File 'lib/models/porcelain.rb', line 4644 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4646 4647 4648 |
# File 'lib/models/porcelain.rb', line 4646 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4690 4691 4692 4693 4694 4695 4696 |
# File 'lib/models/porcelain.rb', line 4690 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |