Class: SDM::MTLSPostgres
- Inherits:
-
Object
- Object
- SDM::MTLSPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
constructor
A new instance of MTLSPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres
Returns a new instance of MTLSPostgres.
4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 |
# File 'lib/models/porcelain.rb', line 4616 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4578 4579 4580 |
# File 'lib/models/porcelain.rb', line 4578 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
4580 4581 4582 |
# File 'lib/models/porcelain.rb', line 4580 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
4582 4583 4584 |
# File 'lib/models/porcelain.rb', line 4582 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
4584 4585 4586 |
# File 'lib/models/porcelain.rb', line 4584 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
4586 4587 4588 |
# File 'lib/models/porcelain.rb', line 4586 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4588 4589 4590 |
# File 'lib/models/porcelain.rb', line 4588 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4590 4591 4592 |
# File 'lib/models/porcelain.rb', line 4590 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4592 4593 4594 |
# File 'lib/models/porcelain.rb', line 4592 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4594 4595 4596 |
# File 'lib/models/porcelain.rb', line 4594 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4596 4597 4598 |
# File 'lib/models/porcelain.rb', line 4596 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
4598 4599 4600 |
# File 'lib/models/porcelain.rb', line 4598 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
4600 4601 4602 |
# File 'lib/models/porcelain.rb', line 4600 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4602 4603 4604 |
# File 'lib/models/porcelain.rb', line 4602 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4604 4605 4606 |
# File 'lib/models/porcelain.rb', line 4604 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4606 4607 4608 |
# File 'lib/models/porcelain.rb', line 4606 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
4608 4609 4610 |
# File 'lib/models/porcelain.rb', line 4608 def server_name @server_name end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4610 4611 4612 |
# File 'lib/models/porcelain.rb', line 4610 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4612 4613 4614 |
# File 'lib/models/porcelain.rb', line 4612 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4614 4615 4616 |
# File 'lib/models/porcelain.rb', line 4614 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4658 4659 4660 4661 4662 4663 4664 |
# File 'lib/models/porcelain.rb', line 4658 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |