Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



4296
4297
4298
4299
4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
4317
4318
4319
4320
4321
4322
4323
4324
4325
4326
4327
4328
4329
4330
4331
4332
4333
4334
# File 'lib/models/porcelain.rb', line 4296

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  server_name: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4260
4261
4262
# File 'lib/models/porcelain.rb', line 4260

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



4262
4263
4264
# File 'lib/models/porcelain.rb', line 4262

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



4264
4265
4266
# File 'lib/models/porcelain.rb', line 4264

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



4266
4267
4268
# File 'lib/models/porcelain.rb', line 4266

def client_key
  @client_key
end

#databaseObject

Returns the value of attribute database.



4268
4269
4270
# File 'lib/models/porcelain.rb', line 4268

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4270
4271
4272
# File 'lib/models/porcelain.rb', line 4270

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4272
4273
4274
# File 'lib/models/porcelain.rb', line 4272

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4274
4275
4276
# File 'lib/models/porcelain.rb', line 4274

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4276
4277
4278
# File 'lib/models/porcelain.rb', line 4276

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4278
4279
4280
# File 'lib/models/porcelain.rb', line 4278

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



4280
4281
4282
# File 'lib/models/porcelain.rb', line 4280

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



4282
4283
4284
# File 'lib/models/porcelain.rb', line 4282

def password
  @password
end

#portObject

Returns the value of attribute port.



4284
4285
4286
# File 'lib/models/porcelain.rb', line 4284

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4286
4287
4288
# File 'lib/models/porcelain.rb', line 4286

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4288
4289
4290
# File 'lib/models/porcelain.rb', line 4288

def secret_store_id
  @secret_store_id
end

#server_nameObject

Returns the value of attribute server_name.



4290
4291
4292
# File 'lib/models/porcelain.rb', line 4290

def server_name
  @server_name
end

#tagsObject

Tags is a map of key, value pairs.



4292
4293
4294
# File 'lib/models/porcelain.rb', line 4292

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4294
4295
4296
# File 'lib/models/porcelain.rb', line 4294

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4336
4337
4338
4339
4340
4341
4342
# File 'lib/models/porcelain.rb', line 4336

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end