Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



3958
3959
3960
3961
3962
3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
# File 'lib/models/porcelain.rb', line 3958

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  server_name: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3922
3923
3924
# File 'lib/models/porcelain.rb', line 3922

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3924
3925
3926
# File 'lib/models/porcelain.rb', line 3924

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3926
3927
3928
# File 'lib/models/porcelain.rb', line 3926

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3928
3929
3930
# File 'lib/models/porcelain.rb', line 3928

def client_key
  @client_key
end

#databaseObject

Returns the value of attribute database.



3930
3931
3932
# File 'lib/models/porcelain.rb', line 3930

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3932
3933
3934
# File 'lib/models/porcelain.rb', line 3932

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3934
3935
3936
# File 'lib/models/porcelain.rb', line 3934

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3936
3937
3938
# File 'lib/models/porcelain.rb', line 3936

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3938
3939
3940
# File 'lib/models/porcelain.rb', line 3938

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3940
3941
3942
# File 'lib/models/porcelain.rb', line 3940

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



3942
3943
3944
# File 'lib/models/porcelain.rb', line 3942

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



3944
3945
3946
# File 'lib/models/porcelain.rb', line 3944

def password
  @password
end

#portObject

Returns the value of attribute port.



3946
3947
3948
# File 'lib/models/porcelain.rb', line 3946

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3948
3949
3950
# File 'lib/models/porcelain.rb', line 3948

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3950
3951
3952
# File 'lib/models/porcelain.rb', line 3950

def secret_store_id
  @secret_store_id
end

#server_nameObject

Returns the value of attribute server_name.



3952
3953
3954
# File 'lib/models/porcelain.rb', line 3952

def server_name
  @server_name
end

#tagsObject

Tags is a map of key, value pairs.



3954
3955
3956
# File 'lib/models/porcelain.rb', line 3954

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3956
3957
3958
# File 'lib/models/porcelain.rb', line 3956

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3998
3999
4000
4001
4002
4003
4004
# File 'lib/models/porcelain.rb', line 3998

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end