Class: SDM::MTLSPostgres
- Inherits:
-
Object
- Object
- SDM::MTLSPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres
constructor
A new instance of MTLSPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres
Returns a new instance of MTLSPostgres.
3959 3960 3961 3962 3963 3964 3965 3966 3967 3968 3969 3970 3971 3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 3991 3992 3993 3994 3995 3996 3997 |
# File 'lib/models/porcelain.rb', line 3959 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3923 3924 3925 |
# File 'lib/models/porcelain.rb', line 3923 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3925 3926 3927 |
# File 'lib/models/porcelain.rb', line 3925 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
3927 3928 3929 |
# File 'lib/models/porcelain.rb', line 3927 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
3929 3930 3931 |
# File 'lib/models/porcelain.rb', line 3929 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
3931 3932 3933 |
# File 'lib/models/porcelain.rb', line 3931 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3933 3934 3935 |
# File 'lib/models/porcelain.rb', line 3933 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3935 3936 3937 |
# File 'lib/models/porcelain.rb', line 3935 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3937 3938 3939 |
# File 'lib/models/porcelain.rb', line 3937 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3939 3940 3941 |
# File 'lib/models/porcelain.rb', line 3939 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3941 3942 3943 |
# File 'lib/models/porcelain.rb', line 3941 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3943 3944 3945 |
# File 'lib/models/porcelain.rb', line 3943 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3945 3946 3947 |
# File 'lib/models/porcelain.rb', line 3945 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3947 3948 3949 |
# File 'lib/models/porcelain.rb', line 3947 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3949 3950 3951 |
# File 'lib/models/porcelain.rb', line 3949 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3951 3952 3953 |
# File 'lib/models/porcelain.rb', line 3951 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
3953 3954 3955 |
# File 'lib/models/porcelain.rb', line 3953 def server_name @server_name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3955 3956 3957 |
# File 'lib/models/porcelain.rb', line 3955 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3957 3958 3959 |
# File 'lib/models/porcelain.rb', line 3957 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3999 4000 4001 4002 4003 4004 4005 |
# File 'lib/models/porcelain.rb', line 3999 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |