Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



3847
3848
3849
3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
# File 'lib/models/porcelain.rb', line 3847

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  server_name: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3811
3812
3813
# File 'lib/models/porcelain.rb', line 3811

def bind_interface
  @bind_interface
end

#certificate_authorityObject

Returns the value of attribute certificate_authority.



3813
3814
3815
# File 'lib/models/porcelain.rb', line 3813

def certificate_authority
  @certificate_authority
end

#client_certificateObject

Returns the value of attribute client_certificate.



3815
3816
3817
# File 'lib/models/porcelain.rb', line 3815

def client_certificate
  @client_certificate
end

#client_keyObject

Returns the value of attribute client_key.



3817
3818
3819
# File 'lib/models/porcelain.rb', line 3817

def client_key
  @client_key
end

#databaseObject

Returns the value of attribute database.



3819
3820
3821
# File 'lib/models/porcelain.rb', line 3819

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3821
3822
3823
# File 'lib/models/porcelain.rb', line 3821

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3823
3824
3825
# File 'lib/models/porcelain.rb', line 3823

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3825
3826
3827
# File 'lib/models/porcelain.rb', line 3825

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3827
3828
3829
# File 'lib/models/porcelain.rb', line 3827

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3829
3830
3831
# File 'lib/models/porcelain.rb', line 3829

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



3831
3832
3833
# File 'lib/models/porcelain.rb', line 3831

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



3833
3834
3835
# File 'lib/models/porcelain.rb', line 3833

def password
  @password
end

#portObject

Returns the value of attribute port.



3835
3836
3837
# File 'lib/models/porcelain.rb', line 3835

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3837
3838
3839
# File 'lib/models/porcelain.rb', line 3837

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3839
3840
3841
# File 'lib/models/porcelain.rb', line 3839

def secret_store_id
  @secret_store_id
end

#server_nameObject

Returns the value of attribute server_name.



3841
3842
3843
# File 'lib/models/porcelain.rb', line 3841

def server_name
  @server_name
end

#tagsObject

Tags is a map of key, value pairs.



3843
3844
3845
# File 'lib/models/porcelain.rb', line 3843

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3845
3846
3847
# File 'lib/models/porcelain.rb', line 3845

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3887
3888
3889
3890
3891
3892
3893
# File 'lib/models/porcelain.rb', line 3887

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end