Class: SDM::MTLSPostgres
- Inherits:
-
Object
- Object
- SDM::MTLSPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres
constructor
A new instance of MTLSPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres
Returns a new instance of MTLSPostgres.
3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 |
# File 'lib/models/porcelain.rb', line 3832 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3796 3797 3798 |
# File 'lib/models/porcelain.rb', line 3796 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3798 3799 3800 |
# File 'lib/models/porcelain.rb', line 3798 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
3800 3801 3802 |
# File 'lib/models/porcelain.rb', line 3800 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
3802 3803 3804 |
# File 'lib/models/porcelain.rb', line 3802 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
3804 3805 3806 |
# File 'lib/models/porcelain.rb', line 3804 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3806 3807 3808 |
# File 'lib/models/porcelain.rb', line 3806 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3808 3809 3810 |
# File 'lib/models/porcelain.rb', line 3808 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3810 3811 3812 |
# File 'lib/models/porcelain.rb', line 3810 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3812 3813 3814 |
# File 'lib/models/porcelain.rb', line 3812 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3814 3815 3816 |
# File 'lib/models/porcelain.rb', line 3814 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3816 3817 3818 |
# File 'lib/models/porcelain.rb', line 3816 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3818 3819 3820 |
# File 'lib/models/porcelain.rb', line 3818 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3820 3821 3822 |
# File 'lib/models/porcelain.rb', line 3820 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3822 3823 3824 |
# File 'lib/models/porcelain.rb', line 3822 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3824 3825 3826 |
# File 'lib/models/porcelain.rb', line 3824 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
3826 3827 3828 |
# File 'lib/models/porcelain.rb', line 3826 def server_name @server_name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3828 3829 3830 |
# File 'lib/models/porcelain.rb', line 3828 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3830 3831 3832 |
# File 'lib/models/porcelain.rb', line 3830 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3872 3873 3874 3875 3876 3877 3878 |
# File 'lib/models/porcelain.rb', line 3872 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |