Class: SDM::MTLSPostgres
- Inherits:
-
Object
- Object
- SDM::MTLSPostgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
-
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
-
#client_key ⇒ Object
Returns the value of attribute client_key.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_name ⇒ Object
Returns the value of attribute server_name.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres
constructor
A new instance of MTLSPostgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil) ⇒ MTLSPostgres
Returns a new instance of MTLSPostgres.
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 3436 3437 3438 3439 3440 3441 3442 |
# File 'lib/models/porcelain.rb', line 3404 def initialize( bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, server_name: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @certificate_authority = == nil ? "" : @client_certificate = client_certificate == nil ? "" : client_certificate @client_key = client_key == nil ? "" : client_key @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_name = server_name == nil ? "" : server_name @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
3368 3369 3370 |
# File 'lib/models/porcelain.rb', line 3368 def bind_interface @bind_interface end |
#certificate_authority ⇒ Object
Returns the value of attribute certificate_authority.
3370 3371 3372 |
# File 'lib/models/porcelain.rb', line 3370 def @certificate_authority end |
#client_certificate ⇒ Object
Returns the value of attribute client_certificate.
3372 3373 3374 |
# File 'lib/models/porcelain.rb', line 3372 def client_certificate @client_certificate end |
#client_key ⇒ Object
Returns the value of attribute client_key.
3374 3375 3376 |
# File 'lib/models/porcelain.rb', line 3374 def client_key @client_key end |
#database ⇒ Object
Returns the value of attribute database.
3376 3377 3378 |
# File 'lib/models/porcelain.rb', line 3376 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3378 3379 3380 |
# File 'lib/models/porcelain.rb', line 3378 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3380 3381 3382 |
# File 'lib/models/porcelain.rb', line 3380 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3382 3383 3384 |
# File 'lib/models/porcelain.rb', line 3382 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3384 3385 3386 |
# File 'lib/models/porcelain.rb', line 3384 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3386 3387 3388 |
# File 'lib/models/porcelain.rb', line 3386 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
3388 3389 3390 |
# File 'lib/models/porcelain.rb', line 3388 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
3390 3391 3392 |
# File 'lib/models/porcelain.rb', line 3390 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3392 3393 3394 |
# File 'lib/models/porcelain.rb', line 3392 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3394 3395 3396 |
# File 'lib/models/porcelain.rb', line 3394 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3396 3397 3398 |
# File 'lib/models/porcelain.rb', line 3396 def secret_store_id @secret_store_id end |
#server_name ⇒ Object
Returns the value of attribute server_name.
3398 3399 3400 |
# File 'lib/models/porcelain.rb', line 3398 def server_name @server_name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3400 3401 3402 |
# File 'lib/models/porcelain.rb', line 3400 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
3402 3403 3404 |
# File 'lib/models/porcelain.rb', line 3402 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3444 3445 3446 3447 3448 3449 3450 |
# File 'lib/models/porcelain.rb', line 3444 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |