Class: SDM::MTLSPostgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, certificate_authority: nil, client_certificate: nil, client_key: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_name: nil, subdomain: nil, tags: nil, username: nil) ⇒ MTLSPostgres

Returns a new instance of MTLSPostgres.



11060
11061
11062
11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
11079
11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
11093
11094
11095
11096
11097
11098
11099
11100
11101
11102
# File 'lib/models/porcelain.rb', line 11060

def initialize(
  bind_interface: nil,
  certificate_authority: nil,
  client_certificate: nil,
  client_key: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_name: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @certificate_authority = certificate_authority == nil ? "" : certificate_authority
  @client_certificate = client_certificate == nil ? "" : client_certificate
  @client_key = client_key == nil ? "" : client_key
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_name = server_name == nil ? "" : server_name
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11020
11021
11022
# File 'lib/models/porcelain.rb', line 11020

def bind_interface
  @bind_interface
end

#certificate_authority ⇒ Object

The CA to authenticate TLS connections with.



11022
11023
11024
# File 'lib/models/porcelain.rb', line 11022

def certificate_authority
  @certificate_authority
end

#client_certificate ⇒ Object

The certificate to authenticate TLS connections with.



11024
11025
11026
# File 'lib/models/porcelain.rb', line 11024

def client_certificate
  @client_certificate
end

#client_key ⇒ Object

The key to authenticate TLS connections with.



11026
11027
11028
# File 'lib/models/porcelain.rb', line 11026

def client_key
  @client_key
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11028
11029
11030
# File 'lib/models/porcelain.rb', line 11028

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



11030
11031
11032
# File 'lib/models/porcelain.rb', line 11030

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



11032
11033
11034
# File 'lib/models/porcelain.rb', line 11032

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



11034
11035
11036
# File 'lib/models/porcelain.rb', line 11034

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



11036
11037
11038
# File 'lib/models/porcelain.rb', line 11036

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



11038
11039
11040
# File 'lib/models/porcelain.rb', line 11038

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11040
11041
11042
# File 'lib/models/porcelain.rb', line 11040

def override_database
  @override_database
end

#password ⇒ Object

The password to authenticate with.



11042
11043
11044
# File 'lib/models/porcelain.rb', line 11042

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



11044
11045
11046
# File 'lib/models/porcelain.rb', line 11044

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11046
11047
11048
# File 'lib/models/porcelain.rb', line 11046

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



11048
11049
11050
# File 'lib/models/porcelain.rb', line 11048

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



11050
11051
11052
# File 'lib/models/porcelain.rb', line 11050

def secret_store_id
  @secret_store_id
end

#server_name ⇒ Object

Server name for TLS verification (unverified by StrongDM if empty)



11052
11053
11054
# File 'lib/models/porcelain.rb', line 11052

def server_name
  @server_name
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11054
11055
11056
# File 'lib/models/porcelain.rb', line 11054

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



11056
11057
11058
# File 'lib/models/porcelain.rb', line 11056

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



11058
11059
11060
# File 'lib/models/porcelain.rb', line 11058

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11104
11105
11106
11107
11108
11109
11110
# File 'lib/models/porcelain.rb', line 11104

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end