Class: SDM::ManagedSecret

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ManagedSecret contains details about managed secret

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config: nil, expires_at: nil, id: nil, last_rotated_at: nil, name: nil, policy: nil, secret_engine_id: nil, secret_store_path: nil, tags: nil, value: nil) ⇒ ManagedSecret

Returns a new instance of ManagedSecret.



9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
9521
9522
# File 'lib/models/porcelain.rb', line 9500

def initialize(
  config: nil,
  expires_at: nil,
  id: nil,
  last_rotated_at: nil,
  name: nil,
  policy: nil,
  secret_engine_id: nil,
  secret_store_path: nil,
  tags: nil,
  value: nil
)
  @config = config == nil ? "" : config
  @expires_at = expires_at == nil ? nil : expires_at
  @id = id == nil ? "" : id
  @last_rotated_at = last_rotated_at == nil ? nil : last_rotated_at
  @name = name == nil ? "" : name
  @policy = policy == nil ? nil : policy
  @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id
  @secret_store_path = secret_store_path == nil ? "" : secret_store_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @value = value == nil ? "" : value
end

Instance Attribute Details

#configObject

public part of the secret value



9480
9481
9482
# File 'lib/models/porcelain.rb', line 9480

def config
  @config
end

#expires_atObject

Timestamp of when secret is going to be rotated



9482
9483
9484
# File 'lib/models/porcelain.rb', line 9482

def expires_at
  @expires_at
end

#idObject

Unique identifier of the Managed Secret.



9484
9485
9486
# File 'lib/models/porcelain.rb', line 9484

def id
  @id
end

#last_rotated_atObject

Timestamp of when secret was last rotated



9486
9487
9488
# File 'lib/models/porcelain.rb', line 9486

def last_rotated_at
  @last_rotated_at
end

#nameObject

Unique human-readable name of the Managed Secret.



9488
9489
9490
# File 'lib/models/porcelain.rb', line 9488

def name
  @name
end

#policyObject

Password and rotation policy for the secret



9490
9491
9492
# File 'lib/models/porcelain.rb', line 9490

def policy
  @policy
end

#secret_engine_idObject

An ID of a Secret Engine linked with the Managed Secret.



9492
9493
9494
# File 'lib/models/porcelain.rb', line 9492

def secret_engine_id
  @secret_engine_id
end

#secret_store_pathObject

Path in a secret store.



9494
9495
9496
# File 'lib/models/porcelain.rb', line 9494

def secret_store_path
  @secret_store_path
end

#tagsObject

Tags is a map of key, value pairs.



9496
9497
9498
# File 'lib/models/porcelain.rb', line 9496

def tags
  @tags
end

#valueObject

Sensitive value of the secret.



9498
9499
9500
# File 'lib/models/porcelain.rb', line 9498

def value
  @value
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9524
9525
9526
9527
9528
9529
9530
# File 'lib/models/porcelain.rb', line 9524

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end