Class: SDM::ManagedSecret

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ManagedSecret contains details about managed secret

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config: nil, expires_at: nil, id: nil, last_rotated_at: nil, name: nil, policy: nil, secret_engine_id: nil, secret_store_path: nil, tags: nil, value: nil) ⇒ ManagedSecret

Returns a new instance of ManagedSecret.



8321
8322
8323
8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
8335
8336
8337
8338
8339
8340
8341
8342
8343
# File 'lib/models/porcelain.rb', line 8321

def initialize(
  config: nil,
  expires_at: nil,
  id: nil,
  last_rotated_at: nil,
  name: nil,
  policy: nil,
  secret_engine_id: nil,
  secret_store_path: nil,
  tags: nil,
  value: nil
)
  @config = config == nil ? "" : config
  @expires_at = expires_at == nil ? nil : expires_at
  @id = id == nil ? "" : id
  @last_rotated_at = last_rotated_at == nil ? nil : last_rotated_at
  @name = name == nil ? "" : name
  @policy = policy == nil ? nil : policy
  @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id
  @secret_store_path = secret_store_path == nil ? "" : secret_store_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @value = value == nil ? "" : value
end

Instance Attribute Details

#configObject

public part of the secret value



8301
8302
8303
# File 'lib/models/porcelain.rb', line 8301

def config
  @config
end

#expires_atObject

Timestamp of when secret is going to be rotated



8303
8304
8305
# File 'lib/models/porcelain.rb', line 8303

def expires_at
  @expires_at
end

#idObject

Unique identifier of the Managed Secret.



8305
8306
8307
# File 'lib/models/porcelain.rb', line 8305

def id
  @id
end

#last_rotated_atObject

Timestamp of when secret was last rotated



8307
8308
8309
# File 'lib/models/porcelain.rb', line 8307

def last_rotated_at
  @last_rotated_at
end

#nameObject

Unique human-readable name of the Managed Secret.



8309
8310
8311
# File 'lib/models/porcelain.rb', line 8309

def name
  @name
end

#policyObject

Password and rotation policy for the secret



8311
8312
8313
# File 'lib/models/porcelain.rb', line 8311

def policy
  @policy
end

#secret_engine_idObject

An ID of a Secret Engine linked with the Managed Secret.



8313
8314
8315
# File 'lib/models/porcelain.rb', line 8313

def secret_engine_id
  @secret_engine_id
end

#secret_store_pathObject

Path in a secret store.



8315
8316
8317
# File 'lib/models/porcelain.rb', line 8315

def secret_store_path
  @secret_store_path
end

#tagsObject

Tags is a map of key, value pairs.



8317
8318
8319
# File 'lib/models/porcelain.rb', line 8317

def tags
  @tags
end

#valueObject

Sensitive value of the secret.



8319
8320
8321
# File 'lib/models/porcelain.rb', line 8319

def value
  @value
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8345
8346
8347
8348
8349
8350
8351
# File 'lib/models/porcelain.rb', line 8345

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end