Class: SDM::ManagedSecret
- Inherits:
-
Object
- Object
- SDM::ManagedSecret
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecret contains details about managed secret
Instance Attribute Summary collapse
-
#config ⇒ Object
public part of the secret value.
-
#expires_at ⇒ Object
Timestamp of when secret is going to be rotated.
-
#id ⇒ Object
Unique identifier of the Managed Secret.
-
#last_rotated_at ⇒ Object
Timestamp of when secret was last rotated.
-
#name ⇒ Object
Unique human-readable name of the Managed Secret.
-
#policy ⇒ Object
Password and rotation policy for the secret.
-
#secret_engine_id ⇒ Object
An ID of a Secret Engine linked with the Managed Secret.
-
#secret_store_path ⇒ Object
Path in a secret store.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#value ⇒ Object
Sensitive value of the secret.
Instance Method Summary collapse
-
#initialize(config: nil, expires_at: nil, id: nil, last_rotated_at: nil, name: nil, policy: nil, secret_engine_id: nil, secret_store_path: nil, tags: nil, value: nil) ⇒ ManagedSecret
constructor
A new instance of ManagedSecret.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(config: nil, expires_at: nil, id: nil, last_rotated_at: nil, name: nil, policy: nil, secret_engine_id: nil, secret_store_path: nil, tags: nil, value: nil) ⇒ ManagedSecret
Returns a new instance of ManagedSecret.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 |
# File 'lib/models/porcelain.rb', line 8152 def initialize( config: nil, expires_at: nil, id: nil, last_rotated_at: nil, name: nil, policy: nil, secret_engine_id: nil, secret_store_path: nil, tags: nil, value: nil ) @config = config == nil ? "" : config @expires_at = expires_at == nil ? nil : expires_at @id = id == nil ? "" : id @last_rotated_at = last_rotated_at == nil ? nil : last_rotated_at @name = name == nil ? "" : name @policy = policy == nil ? nil : policy @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id @secret_store_path = secret_store_path == nil ? "" : secret_store_path @tags = == nil ? SDM::() : @value = value == nil ? "" : value end |
Instance Attribute Details
#config ⇒ Object
public part of the secret value
8132 8133 8134 |
# File 'lib/models/porcelain.rb', line 8132 def config @config end |
#expires_at ⇒ Object
Timestamp of when secret is going to be rotated
8134 8135 8136 |
# File 'lib/models/porcelain.rb', line 8134 def expires_at @expires_at end |
#id ⇒ Object
Unique identifier of the Managed Secret.
8136 8137 8138 |
# File 'lib/models/porcelain.rb', line 8136 def id @id end |
#last_rotated_at ⇒ Object
Timestamp of when secret was last rotated
8138 8139 8140 |
# File 'lib/models/porcelain.rb', line 8138 def last_rotated_at @last_rotated_at end |
#name ⇒ Object
Unique human-readable name of the Managed Secret.
8140 8141 8142 |
# File 'lib/models/porcelain.rb', line 8140 def name @name end |
#policy ⇒ Object
Password and rotation policy for the secret
8142 8143 8144 |
# File 'lib/models/porcelain.rb', line 8142 def policy @policy end |
#secret_engine_id ⇒ Object
An ID of a Secret Engine linked with the Managed Secret.
8144 8145 8146 |
# File 'lib/models/porcelain.rb', line 8144 def secret_engine_id @secret_engine_id end |
#secret_store_path ⇒ Object
Path in a secret store.
8146 8147 8148 |
# File 'lib/models/porcelain.rb', line 8146 def secret_store_path @secret_store_path end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8148 8149 8150 |
# File 'lib/models/porcelain.rb', line 8148 def @tags end |
#value ⇒ Object
Sensitive value of the secret.
8150 8151 8152 |
# File 'lib/models/porcelain.rb', line 8150 def value @value end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8176 8177 8178 8179 8180 8181 8182 |
# File 'lib/models/porcelain.rb', line 8176 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |