Class: SDM::ManagedSecretDeleteRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretDeleteRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretDeleteRequest specified the ID of a Managed Secret to be deleted.
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to delete.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretDeleteRequest
constructor
A new instance of ManagedSecretDeleteRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretDeleteRequest
Returns a new instance of ManagedSecretDeleteRequest.
8240 8241 8242 8243 8244 |
# File 'lib/models/porcelain.rb', line 8240 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to delete.
8238 8239 8240 |
# File 'lib/models/porcelain.rb', line 8238 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8246 8247 8248 8249 8250 8251 8252 |
# File 'lib/models/porcelain.rb', line 8246 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |