Class: SDM::ManagedSecretGetRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretGetRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretGetRequest specifies which Managed Secret to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretGetRequest
constructor
A new instance of ManagedSecretGetRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretGetRequest
Returns a new instance of ManagedSecretGetRequest.
8438 8439 8440 8441 8442 |
# File 'lib/models/porcelain.rb', line 8438 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
8436 8437 8438 |
# File 'lib/models/porcelain.rb', line 8436 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8444 8445 8446 8447 8448 8449 8450 |
# File 'lib/models/porcelain.rb', line 8444 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |