Class: SDM::ManagedSecretLog
- Inherits:
-
Object
- Object
- SDM::ManagedSecretLog
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretLog contains details about action performed against a managed secret
Instance Attribute Summary collapse
-
#account_id ⇒ Object
An ID of the account the action was performed by.
-
#action ⇒ Object
The action performed by the account against the managed secret.
-
#created_at ⇒ Object
Timestamp of when action was performed.
-
#debug ⇒ Object
Any debug logs associated with the action.
-
#id ⇒ Object
Unique identifier of the Managed Secret Log.
-
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
-
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
Instance Method Summary collapse
-
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
constructor
A new instance of ManagedSecretLog.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
Returns a new instance of ManagedSecretLog.
11311 11312 11313 11314 11315 11316 11317 11318 11319 11320 11321 11322 11323 11324 11325 11326 11327 |
# File 'lib/models/porcelain.rb', line 11311 def initialize( account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil ) @account_id = account_id == nil ? "" : account_id @action = action == nil ? "" : action @created_at = created_at == nil ? nil : created_at @debug = debug == nil ? "" : debug @id = id == nil ? "" : id @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id end |
Instance Attribute Details
#account_id ⇒ Object
An ID of the account the action was performed by.
11297 11298 11299 |
# File 'lib/models/porcelain.rb', line 11297 def account_id @account_id end |
#action ⇒ Object
The action performed by the account against the managed secret.
11299 11300 11301 |
# File 'lib/models/porcelain.rb', line 11299 def action @action end |
#created_at ⇒ Object
Timestamp of when action was performed.
11301 11302 11303 |
# File 'lib/models/porcelain.rb', line 11301 def created_at @created_at end |
#debug ⇒ Object
Any debug logs associated with the action.
11303 11304 11305 |
# File 'lib/models/porcelain.rb', line 11303 def debug @debug end |
#id ⇒ Object
Unique identifier of the Managed Secret Log.
11305 11306 11307 |
# File 'lib/models/porcelain.rb', line 11305 def id @id end |
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
11307 11308 11309 |
# File 'lib/models/porcelain.rb', line 11307 def managed_secret_id @managed_secret_id end |
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
11309 11310 11311 |
# File 'lib/models/porcelain.rb', line 11309 def secret_engine_id @secret_engine_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11329 11330 11331 11332 11333 11334 11335 |
# File 'lib/models/porcelain.rb', line 11329 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |