Class: SDM::ManagedSecretLog
- Inherits:
-
Object
- Object
- SDM::ManagedSecretLog
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretLog contains details about action performed against a managed secret
Instance Attribute Summary collapse
-
#account_id ⇒ Object
An ID of the account the action was performed by.
-
#action ⇒ Object
The action performed by the account against the managed secret.
-
#created_at ⇒ Object
Timestamp of when action was performed.
-
#debug ⇒ Object
Any debug logs associated with the action.
-
#id ⇒ Object
Unique identifier of the Managed Secret Log.
-
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
-
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
Instance Method Summary collapse
-
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
constructor
A new instance of ManagedSecretLog.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
Returns a new instance of ManagedSecretLog.
11195 11196 11197 11198 11199 11200 11201 11202 11203 11204 11205 11206 11207 11208 11209 11210 11211 |
# File 'lib/models/porcelain.rb', line 11195 def initialize( account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil ) @account_id = account_id == nil ? "" : account_id @action = action == nil ? "" : action @created_at = created_at == nil ? nil : created_at @debug = debug == nil ? "" : debug @id = id == nil ? "" : id @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id end |
Instance Attribute Details
#account_id ⇒ Object
An ID of the account the action was performed by.
11181 11182 11183 |
# File 'lib/models/porcelain.rb', line 11181 def account_id @account_id end |
#action ⇒ Object
The action performed by the account against the managed secret.
11183 11184 11185 |
# File 'lib/models/porcelain.rb', line 11183 def action @action end |
#created_at ⇒ Object
Timestamp of when action was performed.
11185 11186 11187 |
# File 'lib/models/porcelain.rb', line 11185 def created_at @created_at end |
#debug ⇒ Object
Any debug logs associated with the action.
11187 11188 11189 |
# File 'lib/models/porcelain.rb', line 11187 def debug @debug end |
#id ⇒ Object
Unique identifier of the Managed Secret Log.
11189 11190 11191 |
# File 'lib/models/porcelain.rb', line 11189 def id @id end |
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
11191 11192 11193 |
# File 'lib/models/porcelain.rb', line 11191 def managed_secret_id @managed_secret_id end |
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
11193 11194 11195 |
# File 'lib/models/porcelain.rb', line 11193 def secret_engine_id @secret_engine_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11213 11214 11215 11216 11217 11218 11219 |
# File 'lib/models/porcelain.rb', line 11213 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |