Class: SDM::ManagedSecretLog
- Inherits:
-
Object
- Object
- SDM::ManagedSecretLog
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretLog contains details about action performed against a managed secret
Instance Attribute Summary collapse
-
#account_id ⇒ Object
An ID of the account the action was performed by.
-
#action ⇒ Object
The action performed by the account against the managed secret.
-
#created_at ⇒ Object
Timestamp of when action was performed.
-
#debug ⇒ Object
Any debug logs associated with the action.
-
#id ⇒ Object
Unique identifier of the Managed Secret Log.
-
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
-
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
Instance Method Summary collapse
-
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
constructor
A new instance of ManagedSecretLog.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
Returns a new instance of ManagedSecretLog.
11099 11100 11101 11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 |
# File 'lib/models/porcelain.rb', line 11099 def initialize( account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil ) @account_id = account_id == nil ? "" : account_id @action = action == nil ? "" : action @created_at = created_at == nil ? nil : created_at @debug = debug == nil ? "" : debug @id = id == nil ? "" : id @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id end |
Instance Attribute Details
#account_id ⇒ Object
An ID of the account the action was performed by.
11085 11086 11087 |
# File 'lib/models/porcelain.rb', line 11085 def account_id @account_id end |
#action ⇒ Object
The action performed by the account against the managed secret.
11087 11088 11089 |
# File 'lib/models/porcelain.rb', line 11087 def action @action end |
#created_at ⇒ Object
Timestamp of when action was performed.
11089 11090 11091 |
# File 'lib/models/porcelain.rb', line 11089 def created_at @created_at end |
#debug ⇒ Object
Any debug logs associated with the action.
11091 11092 11093 |
# File 'lib/models/porcelain.rb', line 11091 def debug @debug end |
#id ⇒ Object
Unique identifier of the Managed Secret Log.
11093 11094 11095 |
# File 'lib/models/porcelain.rb', line 11093 def id @id end |
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
11095 11096 11097 |
# File 'lib/models/porcelain.rb', line 11095 def managed_secret_id @managed_secret_id end |
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
11097 11098 11099 |
# File 'lib/models/porcelain.rb', line 11097 def secret_engine_id @secret_engine_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11117 11118 11119 11120 11121 11122 11123 |
# File 'lib/models/porcelain.rb', line 11117 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |