Class: SDM::ManagedSecretLog
- Inherits:
-
Object
- Object
- SDM::ManagedSecretLog
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretLog contains details about action performed against a managed secret
Instance Attribute Summary collapse
-
#account_id ⇒ Object
An ID of the account the action was performed by.
-
#action ⇒ Object
The action performed by the account against the managed secret.
-
#created_at ⇒ Object
Timestamp of when action was performed.
-
#debug ⇒ Object
Any debug logs associated with the action.
-
#id ⇒ Object
Unique identifier of the Managed Secret Log.
-
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
-
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
Instance Method Summary collapse
-
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
constructor
A new instance of ManagedSecretLog.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
Returns a new instance of ManagedSecretLog.
10725 10726 10727 10728 10729 10730 10731 10732 10733 10734 10735 10736 10737 10738 10739 10740 10741 |
# File 'lib/models/porcelain.rb', line 10725 def initialize( account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil ) @account_id = account_id == nil ? "" : account_id @action = action == nil ? "" : action @created_at = created_at == nil ? nil : created_at @debug = debug == nil ? "" : debug @id = id == nil ? "" : id @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id end |
Instance Attribute Details
#account_id ⇒ Object
An ID of the account the action was performed by.
10711 10712 10713 |
# File 'lib/models/porcelain.rb', line 10711 def account_id @account_id end |
#action ⇒ Object
The action performed by the account against the managed secret.
10713 10714 10715 |
# File 'lib/models/porcelain.rb', line 10713 def action @action end |
#created_at ⇒ Object
Timestamp of when action was performed.
10715 10716 10717 |
# File 'lib/models/porcelain.rb', line 10715 def created_at @created_at end |
#debug ⇒ Object
Any debug logs associated with the action.
10717 10718 10719 |
# File 'lib/models/porcelain.rb', line 10717 def debug @debug end |
#id ⇒ Object
Unique identifier of the Managed Secret Log.
10719 10720 10721 |
# File 'lib/models/porcelain.rb', line 10719 def id @id end |
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
10721 10722 10723 |
# File 'lib/models/porcelain.rb', line 10721 def managed_secret_id @managed_secret_id end |
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
10723 10724 10725 |
# File 'lib/models/porcelain.rb', line 10723 def secret_engine_id @secret_engine_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10743 10744 10745 10746 10747 10748 10749 |
# File 'lib/models/porcelain.rb', line 10743 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |