Class: SDM::ManagedSecretLog

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ManagedSecretLog contains details about action performed against a managed secret

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog

Returns a new instance of ManagedSecretLog.



10431
10432
10433
10434
10435
10436
10437
10438
10439
10440
10441
10442
10443
10444
10445
10446
10447
# File 'lib/models/porcelain.rb', line 10431

def initialize(
  account_id: nil,
  action: nil,
  created_at: nil,
  debug: nil,
  id: nil,
  managed_secret_id: nil,
  secret_engine_id: nil
)
  @account_id =  == nil ? "" : 
  @action = action == nil ? "" : action
  @created_at = created_at == nil ? nil : created_at
  @debug = debug == nil ? "" : debug
  @id = id == nil ? "" : id
  @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id
  @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id
end

Instance Attribute Details

#account_idObject

An ID of the account the action was performed by.



10417
10418
10419
# File 'lib/models/porcelain.rb', line 10417

def 
  @account_id
end

#actionObject

The action performed by the account against the managed secret.



10419
10420
10421
# File 'lib/models/porcelain.rb', line 10419

def action
  @action
end

#created_atObject

Timestamp of when action was performed.



10421
10422
10423
# File 'lib/models/porcelain.rb', line 10421

def created_at
  @created_at
end

#debugObject

Any debug logs associated with the action.



10423
10424
10425
# File 'lib/models/porcelain.rb', line 10423

def debug
  @debug
end

#idObject

Unique identifier of the Managed Secret Log.



10425
10426
10427
# File 'lib/models/porcelain.rb', line 10425

def id
  @id
end

#managed_secret_idObject

An ID of the Managed Secret the action was performed against.



10427
10428
10429
# File 'lib/models/porcelain.rb', line 10427

def managed_secret_id
  @managed_secret_id
end

#secret_engine_idObject

An ID of the Secret Engine linked with the Managed Secret.



10429
10430
10431
# File 'lib/models/porcelain.rb', line 10429

def secret_engine_id
  @secret_engine_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10449
10450
10451
10452
10453
10454
10455
# File 'lib/models/porcelain.rb', line 10449

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end