Class: SDM::ManagedSecretLog

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ManagedSecretLog contains details about action performed against a managed secret

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog

Returns a new instance of ManagedSecretLog.



10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
# File 'lib/models/porcelain.rb', line 10367

def initialize(
  account_id: nil,
  action: nil,
  created_at: nil,
  debug: nil,
  id: nil,
  managed_secret_id: nil,
  secret_engine_id: nil
)
  @account_id =  == nil ? "" : 
  @action = action == nil ? "" : action
  @created_at = created_at == nil ? nil : created_at
  @debug = debug == nil ? "" : debug
  @id = id == nil ? "" : id
  @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id
  @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id
end

Instance Attribute Details

#account_idObject

An ID of the account the action was performed by.



10353
10354
10355
# File 'lib/models/porcelain.rb', line 10353

def 
  @account_id
end

#actionObject

The action performed by the account against the managed secret.



10355
10356
10357
# File 'lib/models/porcelain.rb', line 10355

def action
  @action
end

#created_atObject

Timestamp of when action was performed.



10357
10358
10359
# File 'lib/models/porcelain.rb', line 10357

def created_at
  @created_at
end

#debugObject

Any debug logs associated with the action.



10359
10360
10361
# File 'lib/models/porcelain.rb', line 10359

def debug
  @debug
end

#idObject

Unique identifier of the Managed Secret Log.



10361
10362
10363
# File 'lib/models/porcelain.rb', line 10361

def id
  @id
end

#managed_secret_idObject

An ID of the Managed Secret the action was performed against.



10363
10364
10365
# File 'lib/models/porcelain.rb', line 10363

def managed_secret_id
  @managed_secret_id
end

#secret_engine_idObject

An ID of the Secret Engine linked with the Managed Secret.



10365
10366
10367
# File 'lib/models/porcelain.rb', line 10365

def secret_engine_id
  @secret_engine_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10385
10386
10387
10388
10389
10390
10391
# File 'lib/models/porcelain.rb', line 10385

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end