Class: SDM::ManagedSecretLog

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ManagedSecretLog contains details about action performed against a managed secret

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog

Returns a new instance of ManagedSecretLog.



8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
# File 'lib/models/porcelain.rb', line 8540

def initialize(
  account_id: nil,
  action: nil,
  created_at: nil,
  debug: nil,
  id: nil,
  managed_secret_id: nil,
  secret_engine_id: nil
)
  @account_id =  == nil ? "" : 
  @action = action == nil ? "" : action
  @created_at = created_at == nil ? nil : created_at
  @debug = debug == nil ? "" : debug
  @id = id == nil ? "" : id
  @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id
  @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id
end

Instance Attribute Details

#account_idObject

An ID of the account the action was performed by.



8526
8527
8528
# File 'lib/models/porcelain.rb', line 8526

def 
  @account_id
end

#actionObject

The action performed by the account against the managed secret.



8528
8529
8530
# File 'lib/models/porcelain.rb', line 8528

def action
  @action
end

#created_atObject

Timestamp of when action was performed.



8530
8531
8532
# File 'lib/models/porcelain.rb', line 8530

def created_at
  @created_at
end

#debugObject

Any debug logs associated with the action.



8532
8533
8534
# File 'lib/models/porcelain.rb', line 8532

def debug
  @debug
end

#idObject

Unique identifier of the Managed Secret Log.



8534
8535
8536
# File 'lib/models/porcelain.rb', line 8534

def id
  @id
end

#managed_secret_idObject

An ID of the Managed Secret the action was performed against.



8536
8537
8538
# File 'lib/models/porcelain.rb', line 8536

def managed_secret_id
  @managed_secret_id
end

#secret_engine_idObject

An ID of the Secret Engine linked with the Managed Secret.



8538
8539
8540
# File 'lib/models/porcelain.rb', line 8538

def secret_engine_id
  @secret_engine_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8558
8559
8560
8561
8562
8563
8564
# File 'lib/models/porcelain.rb', line 8558

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end