Class: SDM::ManagedSecretLog
- Inherits:
-
Object
- Object
- SDM::ManagedSecretLog
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretLog contains details about action performed against a managed secret
Instance Attribute Summary collapse
-
#account_id ⇒ Object
An ID of the account the action was performed by.
-
#action ⇒ Object
The action performed by the account against the managed secret.
-
#created_at ⇒ Object
Timestamp of when action was performed.
-
#debug ⇒ Object
Any debug logs associated with the action.
-
#id ⇒ Object
Unique identifier of the Managed Secret Log.
-
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
-
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
Instance Method Summary collapse
-
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
constructor
A new instance of ManagedSecretLog.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
Returns a new instance of ManagedSecretLog.
8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 8252 |
# File 'lib/models/porcelain.rb', line 8236 def initialize( account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil ) @account_id = account_id == nil ? "" : account_id @action = action == nil ? "" : action @created_at = created_at == nil ? nil : created_at @debug = debug == nil ? "" : debug @id = id == nil ? "" : id @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id end |
Instance Attribute Details
#account_id ⇒ Object
An ID of the account the action was performed by.
8222 8223 8224 |
# File 'lib/models/porcelain.rb', line 8222 def account_id @account_id end |
#action ⇒ Object
The action performed by the account against the managed secret.
8224 8225 8226 |
# File 'lib/models/porcelain.rb', line 8224 def action @action end |
#created_at ⇒ Object
Timestamp of when action was performed.
8226 8227 8228 |
# File 'lib/models/porcelain.rb', line 8226 def created_at @created_at end |
#debug ⇒ Object
Any debug logs associated with the action.
8228 8229 8230 |
# File 'lib/models/porcelain.rb', line 8228 def debug @debug end |
#id ⇒ Object
Unique identifier of the Managed Secret Log.
8230 8231 8232 |
# File 'lib/models/porcelain.rb', line 8230 def id @id end |
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
8232 8233 8234 |
# File 'lib/models/porcelain.rb', line 8232 def managed_secret_id @managed_secret_id end |
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
8234 8235 8236 |
# File 'lib/models/porcelain.rb', line 8234 def secret_engine_id @secret_engine_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8254 8255 8256 8257 8258 8259 8260 |
# File 'lib/models/porcelain.rb', line 8254 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |