Class: SDM::ManagedSecretLog
- Inherits:
-
Object
- Object
- SDM::ManagedSecretLog
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretLog contains details about action performed against a managed secret
Instance Attribute Summary collapse
-
#account_id ⇒ Object
An ID of the account the action was performed by.
-
#action ⇒ Object
The action performed by the account against the managed secret.
-
#created_at ⇒ Object
Timestamp of when action was performed.
-
#debug ⇒ Object
Any debug logs associated with the action.
-
#id ⇒ Object
Unique identifier of the Managed Secret Log.
-
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
-
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
Instance Method Summary collapse
-
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
constructor
A new instance of ManagedSecretLog.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil) ⇒ ManagedSecretLog
Returns a new instance of ManagedSecretLog.
11371 11372 11373 11374 11375 11376 11377 11378 11379 11380 11381 11382 11383 11384 11385 11386 11387 |
# File 'lib/models/porcelain.rb', line 11371 def initialize( account_id: nil, action: nil, created_at: nil, debug: nil, id: nil, managed_secret_id: nil, secret_engine_id: nil ) @account_id = account_id == nil ? "" : account_id @action = action == nil ? "" : action @created_at = created_at == nil ? nil : created_at @debug = debug == nil ? "" : debug @id = id == nil ? "" : id @managed_secret_id = managed_secret_id == nil ? "" : managed_secret_id @secret_engine_id = secret_engine_id == nil ? "" : secret_engine_id end |
Instance Attribute Details
#account_id ⇒ Object
An ID of the account the action was performed by.
11357 11358 11359 |
# File 'lib/models/porcelain.rb', line 11357 def account_id @account_id end |
#action ⇒ Object
The action performed by the account against the managed secret.
11359 11360 11361 |
# File 'lib/models/porcelain.rb', line 11359 def action @action end |
#created_at ⇒ Object
Timestamp of when action was performed.
11361 11362 11363 |
# File 'lib/models/porcelain.rb', line 11361 def created_at @created_at end |
#debug ⇒ Object
Any debug logs associated with the action.
11363 11364 11365 |
# File 'lib/models/porcelain.rb', line 11363 def debug @debug end |
#id ⇒ Object
Unique identifier of the Managed Secret Log.
11365 11366 11367 |
# File 'lib/models/porcelain.rb', line 11365 def id @id end |
#managed_secret_id ⇒ Object
An ID of the Managed Secret the action was performed against.
11367 11368 11369 |
# File 'lib/models/porcelain.rb', line 11367 def managed_secret_id @managed_secret_id end |
#secret_engine_id ⇒ Object
An ID of the Secret Engine linked with the Managed Secret.
11369 11370 11371 |
# File 'lib/models/porcelain.rb', line 11369 def secret_engine_id @secret_engine_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11389 11390 11391 11392 11393 11394 11395 |
# File 'lib/models/porcelain.rb', line 11389 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |