Class: SDM::ManagedSecretPasswordPolicy
- Inherits:
-
Object
- Object
- SDM::ManagedSecretPasswordPolicy
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_repeat ⇒ Object
If set to true allows for consecutive characters to repeat itself.
-
#exclude_characters ⇒ Object
Characters to exclude when generating password.
-
#exclude_upper_case ⇒ Object
If set to true do not include upper case letters when generating password.
-
#length ⇒ Object
Password length.
-
#num_digits ⇒ Object
Numbers of digits to use when generating password.
-
#num_symbols ⇒ Object
Number of symbols to use when generating password.
Instance Method Summary collapse
-
#initialize(allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil) ⇒ ManagedSecretPasswordPolicy
constructor
A new instance of ManagedSecretPasswordPolicy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil) ⇒ ManagedSecretPasswordPolicy
Returns a new instance of ManagedSecretPasswordPolicy.
11181 11182 11183 11184 11185 11186 11187 11188 11189 11190 11191 11192 11193 11194 11195 |
# File 'lib/models/porcelain.rb', line 11181 def initialize( allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil ) @allow_repeat = allow_repeat == nil ? false : allow_repeat @exclude_characters = exclude_characters == nil ? "" : exclude_characters @exclude_upper_case = exclude_upper_case == nil ? false : exclude_upper_case @length = length == nil ? 0 : length @num_digits = num_digits == nil ? 0 : num_digits @num_symbols = num_symbols == nil ? 0 : num_symbols end |
Instance Attribute Details
#allow_repeat ⇒ Object
If set to true allows for consecutive characters to repeat itself
11169 11170 11171 |
# File 'lib/models/porcelain.rb', line 11169 def allow_repeat @allow_repeat end |
#exclude_characters ⇒ Object
Characters to exclude when generating password
11171 11172 11173 |
# File 'lib/models/porcelain.rb', line 11171 def exclude_characters @exclude_characters end |
#exclude_upper_case ⇒ Object
If set to true do not include upper case letters when generating password
11173 11174 11175 |
# File 'lib/models/porcelain.rb', line 11173 def exclude_upper_case @exclude_upper_case end |
#length ⇒ Object
Password length
11175 11176 11177 |
# File 'lib/models/porcelain.rb', line 11175 def length @length end |
#num_digits ⇒ Object
Numbers of digits to use when generating password
11177 11178 11179 |
# File 'lib/models/porcelain.rb', line 11177 def num_digits @num_digits end |
#num_symbols ⇒ Object
Number of symbols to use when generating password
11179 11180 11181 |
# File 'lib/models/porcelain.rb', line 11179 def num_symbols @num_symbols end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11197 11198 11199 11200 11201 11202 11203 |
# File 'lib/models/porcelain.rb', line 11197 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |