Class: SDM::ManagedSecretPasswordPolicy
- Inherits:
-
Object
- Object
- SDM::ManagedSecretPasswordPolicy
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_repeat ⇒ Object
If set to true allows for consecutive characters to repeat itself.
-
#exclude_characters ⇒ Object
Characters to exclude when generating password.
-
#exclude_upper_case ⇒ Object
If set to true do not include upper case letters when generating password.
-
#length ⇒ Object
Password length.
-
#num_digits ⇒ Object
Numbers of digits to use when generating password.
-
#num_symbols ⇒ Object
Number of symbols to use when generating password.
Instance Method Summary collapse
-
#initialize(allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil) ⇒ ManagedSecretPasswordPolicy
constructor
A new instance of ManagedSecretPasswordPolicy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil) ⇒ ManagedSecretPasswordPolicy
Returns a new instance of ManagedSecretPasswordPolicy.
8465 8466 8467 8468 8469 8470 8471 8472 8473 8474 8475 8476 8477 8478 8479 |
# File 'lib/models/porcelain.rb', line 8465 def initialize( allow_repeat: nil, exclude_characters: nil, exclude_upper_case: nil, length: nil, num_digits: nil, num_symbols: nil ) @allow_repeat = allow_repeat == nil ? false : allow_repeat @exclude_characters = exclude_characters == nil ? "" : exclude_characters @exclude_upper_case = exclude_upper_case == nil ? false : exclude_upper_case @length = length == nil ? 0 : length @num_digits = num_digits == nil ? 0 : num_digits @num_symbols = num_symbols == nil ? 0 : num_symbols end |
Instance Attribute Details
#allow_repeat ⇒ Object
If set to true allows for consecutive characters to repeat itself
8453 8454 8455 |
# File 'lib/models/porcelain.rb', line 8453 def allow_repeat @allow_repeat end |
#exclude_characters ⇒ Object
Characters to exclude when generating password
8455 8456 8457 |
# File 'lib/models/porcelain.rb', line 8455 def exclude_characters @exclude_characters end |
#exclude_upper_case ⇒ Object
If set to true do not include upper case letters when generating password
8457 8458 8459 |
# File 'lib/models/porcelain.rb', line 8457 def exclude_upper_case @exclude_upper_case end |
#length ⇒ Object
Password length
8459 8460 8461 |
# File 'lib/models/porcelain.rb', line 8459 def length @length end |
#num_digits ⇒ Object
Numbers of digits to use when generating password
8461 8462 8463 |
# File 'lib/models/porcelain.rb', line 8461 def num_digits @num_digits end |
#num_symbols ⇒ Object
Number of symbols to use when generating password
8463 8464 8465 |
# File 'lib/models/porcelain.rb', line 8463 def num_symbols @num_symbols end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8481 8482 8483 8484 8485 8486 8487 |
# File 'lib/models/porcelain.rb', line 8481 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |