Class: SDM::ManagedSecretRetrieveRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretRetrieveRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretRetrieveRequest specifies which Managed Secret to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
-
#public_key ⇒ Object
Public key to encrypt a sensitive value with.
Instance Method Summary collapse
-
#initialize(id: nil, public_key: nil) ⇒ ManagedSecretRetrieveRequest
constructor
A new instance of ManagedSecretRetrieveRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, public_key: nil) ⇒ ManagedSecretRetrieveRequest
Returns a new instance of ManagedSecretRetrieveRequest.
8693 8694 8695 8696 8697 8698 8699 |
# File 'lib/models/porcelain.rb', line 8693 def initialize( id: nil, public_key: nil ) @id = id == nil ? "" : id @public_key = public_key == nil ? "" : public_key end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
8689 8690 8691 |
# File 'lib/models/porcelain.rb', line 8689 def id @id end |
#public_key ⇒ Object
Public key to encrypt a sensitive value with
8691 8692 8693 |
# File 'lib/models/porcelain.rb', line 8691 def public_key @public_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8701 8702 8703 8704 8705 8706 8707 |
# File 'lib/models/porcelain.rb', line 8701 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |