Class: SDM::ManagedSecretRetrieveRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretRetrieveRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretRetrieveRequest specifies which Managed Secret to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
-
#public_key ⇒ Object
Public key to encrypt a sensitive value with.
Instance Method Summary collapse
-
#initialize(id: nil, public_key: nil) ⇒ ManagedSecretRetrieveRequest
constructor
A new instance of ManagedSecretRetrieveRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, public_key: nil) ⇒ ManagedSecretRetrieveRequest
Returns a new instance of ManagedSecretRetrieveRequest.
8678 8679 8680 8681 8682 8683 8684 |
# File 'lib/models/porcelain.rb', line 8678 def initialize( id: nil, public_key: nil ) @id = id == nil ? "" : id @public_key = public_key == nil ? "" : public_key end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
8674 8675 8676 |
# File 'lib/models/porcelain.rb', line 8674 def id @id end |
#public_key ⇒ Object
Public key to encrypt a sensitive value with
8676 8677 8678 |
# File 'lib/models/porcelain.rb', line 8676 def public_key @public_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8686 8687 8688 8689 8690 8691 8692 |
# File 'lib/models/porcelain.rb', line 8686 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |