Class: SDM::ManagedSecretRetrieveRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretRetrieveRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretRetrieveRequest specifies which Managed Secret to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
-
#public_key ⇒ Object
Public key to encrypt a sensitive value with.
Instance Method Summary collapse
-
#initialize(id: nil, public_key: nil) ⇒ ManagedSecretRetrieveRequest
constructor
A new instance of ManagedSecretRetrieveRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, public_key: nil) ⇒ ManagedSecretRetrieveRequest
Returns a new instance of ManagedSecretRetrieveRequest.
8374 8375 8376 8377 8378 8379 8380 |
# File 'lib/models/porcelain.rb', line 8374 def initialize( id: nil, public_key: nil ) @id = id == nil ? "" : id @public_key = public_key == nil ? "" : public_key end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
8370 8371 8372 |
# File 'lib/models/porcelain.rb', line 8370 def id @id end |
#public_key ⇒ Object
Public key to encrypt a sensitive value with
8372 8373 8374 |
# File 'lib/models/porcelain.rb', line 8372 def public_key @public_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8382 8383 8384 8385 8386 8387 8388 |
# File 'lib/models/porcelain.rb', line 8382 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |