Class: SDM::ManagedSecretRetrieveRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretRetrieveRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretRetrieveRequest specifies which Managed Secret to retrieve
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
-
#public_key ⇒ Object
Public key to encrypt a sensitive value with.
Instance Method Summary collapse
-
#initialize(id: nil, public_key: nil) ⇒ ManagedSecretRetrieveRequest
constructor
A new instance of ManagedSecretRetrieveRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil, public_key: nil) ⇒ ManagedSecretRetrieveRequest
Returns a new instance of ManagedSecretRetrieveRequest.
8510 8511 8512 8513 8514 8515 8516 |
# File 'lib/models/porcelain.rb', line 8510 def initialize( id: nil, public_key: nil ) @id = id == nil ? "" : id @public_key = public_key == nil ? "" : public_key end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to retrieve.
8506 8507 8508 |
# File 'lib/models/porcelain.rb', line 8506 def id @id end |
#public_key ⇒ Object
Public key to encrypt a sensitive value with
8508 8509 8510 |
# File 'lib/models/porcelain.rb', line 8508 def public_key @public_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8518 8519 8520 8521 8522 8523 8524 |
# File 'lib/models/porcelain.rb', line 8518 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |