Class: SDM::ManagedSecretRotateRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretRotateRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretRotateRequest specifies Managed Secret to rotate
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to rotate.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretRotateRequest
constructor
A new instance of ManagedSecretRotateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretRotateRequest
Returns a new instance of ManagedSecretRotateRequest.
11460 11461 11462 11463 11464 |
# File 'lib/models/porcelain.rb', line 11460 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to rotate.
11458 11459 11460 |
# File 'lib/models/porcelain.rb', line 11458 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11466 11467 11468 11469 11470 11471 11472 |
# File 'lib/models/porcelain.rb', line 11466 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |