Class: SDM::ManagedSecretRotateRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretRotateRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretRotateRequest specifies Managed Secret to rotate
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to rotate.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretRotateRequest
constructor
A new instance of ManagedSecretRotateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretRotateRequest
Returns a new instance of ManagedSecretRotateRequest.
10984 10985 10986 10987 10988 |
# File 'lib/models/porcelain.rb', line 10984 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to rotate.
10982 10983 10984 |
# File 'lib/models/porcelain.rb', line 10982 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10990 10991 10992 10993 10994 10995 10996 |
# File 'lib/models/porcelain.rb', line 10990 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |