Class: SDM::ManagedSecretRotateRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretRotateRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretRotateRequest specifies Managed Secret to rotate
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to rotate.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretRotateRequest
constructor
A new instance of ManagedSecretRotateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretRotateRequest
Returns a new instance of ManagedSecretRotateRequest.
8572 8573 8574 8575 8576 |
# File 'lib/models/porcelain.rb', line 8572 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to rotate.
8570 8571 8572 |
# File 'lib/models/porcelain.rb', line 8570 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8578 8579 8580 8581 8582 8583 8584 |
# File 'lib/models/porcelain.rb', line 8578 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |