Class: SDM::ManagedSecretValidateRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretValidateRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretValidateRequest specifies which Managed Secret to validate
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
constructor
A new instance of ManagedSecretValidateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
Returns a new instance of ManagedSecretValidateRequest.
11391 11392 11393 11394 11395 |
# File 'lib/models/porcelain.rb', line 11391 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
11389 11390 11391 |
# File 'lib/models/porcelain.rb', line 11389 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11397 11398 11399 11400 11401 11402 11403 |
# File 'lib/models/porcelain.rb', line 11397 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |