Class: SDM::ManagedSecretValidateRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretValidateRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretValidateRequest specifies which Managed Secret to validate
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
constructor
A new instance of ManagedSecretValidateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
Returns a new instance of ManagedSecretValidateRequest.
11091 11092 11093 11094 11095 |
# File 'lib/models/porcelain.rb', line 11091 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
11089 11090 11091 |
# File 'lib/models/porcelain.rb', line 11089 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11097 11098 11099 11100 11101 11102 11103 |
# File 'lib/models/porcelain.rb', line 11097 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |