Class: SDM::ManagedSecretValidateRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretValidateRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretValidateRequest specifies which Managed Secret to validate
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
constructor
A new instance of ManagedSecretValidateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
Returns a new instance of ManagedSecretValidateRequest.
11017 11018 11019 11020 11021 |
# File 'lib/models/porcelain.rb', line 11017 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
11015 11016 11017 |
# File 'lib/models/porcelain.rb', line 11015 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11023 11024 11025 11026 11027 11028 11029 |
# File 'lib/models/porcelain.rb', line 11023 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |