Class: SDM::ManagedSecretValidateRequest
- Inherits:
-
Object
- Object
- SDM::ManagedSecretValidateRequest
- Defined in:
- lib/models/porcelain.rb
Overview
ManagedSecretValidateRequest specifies which Managed Secret to validate
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
constructor
A new instance of ManagedSecretValidateRequest.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(id: nil) ⇒ ManagedSecretValidateRequest
Returns a new instance of ManagedSecretValidateRequest.
11663 11664 11665 11666 11667 |
# File 'lib/models/porcelain.rb', line 11663 def initialize( id: nil ) @id = id == nil ? "" : id end |
Instance Attribute Details
#id ⇒ Object
The unique identifier of the Managed Secret to validate.
11661 11662 11663 |
# File 'lib/models/porcelain.rb', line 11661 def id @id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11669 11670 11671 11672 11673 11674 11675 |
# File 'lib/models/porcelain.rb', line 11669 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |