Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/models/porcelain.rb', line 11495

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11461
11462
11463
# File 'lib/models/porcelain.rb', line 11461

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11463
11464
11465
# File 'lib/models/porcelain.rb', line 11463

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11465
11466
11467
# File 'lib/models/porcelain.rb', line 11465

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11467
11468
11469
# File 'lib/models/porcelain.rb', line 11467

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11469
11470
11471
# File 'lib/models/porcelain.rb', line 11469

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11471
11472
11473
# File 'lib/models/porcelain.rb', line 11471

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11473
11474
11475
# File 'lib/models/porcelain.rb', line 11473

def name
  @name
end

#passwordObject

The password to authenticate with.



11475
11476
11477
# File 'lib/models/porcelain.rb', line 11475

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11477
11478
11479
# File 'lib/models/porcelain.rb', line 11477

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11479
11480
11481
# File 'lib/models/porcelain.rb', line 11479

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11481
11482
11483
# File 'lib/models/porcelain.rb', line 11481

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11483
11484
11485
# File 'lib/models/porcelain.rb', line 11483

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11485
11486
11487
# File 'lib/models/porcelain.rb', line 11485

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11487
11488
11489
# File 'lib/models/porcelain.rb', line 11487

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11489
11490
11491
# File 'lib/models/porcelain.rb', line 11489

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11491
11492
11493
# File 'lib/models/porcelain.rb', line 11491

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11493
11494
11495
# File 'lib/models/porcelain.rb', line 11493

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11533
11534
11535
11536
11537
11538
11539
# File 'lib/models/porcelain.rb', line 11533

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end