Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



11175
11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
11191
11192
11193
11194
11195
11196
11197
11198
11199
11200
11201
11202
11203
11204
11205
11206
11207
11208
11209
11210
11211
# File 'lib/models/porcelain.rb', line 11175

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11141
11142
11143
# File 'lib/models/porcelain.rb', line 11141

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11143
11144
11145
# File 'lib/models/porcelain.rb', line 11143

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11145
11146
11147
# File 'lib/models/porcelain.rb', line 11145

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11147
11148
11149
# File 'lib/models/porcelain.rb', line 11147

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11149
11150
11151
# File 'lib/models/porcelain.rb', line 11149

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11151
11152
11153
# File 'lib/models/porcelain.rb', line 11151

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11153
11154
11155
# File 'lib/models/porcelain.rb', line 11153

def name
  @name
end

#passwordObject

The password to authenticate with.



11155
11156
11157
# File 'lib/models/porcelain.rb', line 11155

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11157
11158
11159
# File 'lib/models/porcelain.rb', line 11157

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11159
11160
11161
# File 'lib/models/porcelain.rb', line 11159

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11161
11162
11163
# File 'lib/models/porcelain.rb', line 11161

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11163
11164
11165
# File 'lib/models/porcelain.rb', line 11163

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11165
11166
11167
# File 'lib/models/porcelain.rb', line 11165

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11167
11168
11169
# File 'lib/models/porcelain.rb', line 11167

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11169
11170
11171
# File 'lib/models/porcelain.rb', line 11169

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11171
11172
11173
# File 'lib/models/porcelain.rb', line 11171

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11173
11174
11175
# File 'lib/models/porcelain.rb', line 11173

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11213
11214
11215
11216
11217
11218
11219
# File 'lib/models/porcelain.rb', line 11213

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end