Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



11093
11094
11095
11096
11097
11098
11099
11100
11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
11113
11114
11115
11116
11117
11118
11119
11120
11121
11122
11123
11124
11125
11126
11127
11128
11129
# File 'lib/models/porcelain.rb', line 11093

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11059
11060
11061
# File 'lib/models/porcelain.rb', line 11059

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11061
11062
11063
# File 'lib/models/porcelain.rb', line 11061

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11063
11064
11065
# File 'lib/models/porcelain.rb', line 11063

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11065
11066
11067
# File 'lib/models/porcelain.rb', line 11065

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11067
11068
11069
# File 'lib/models/porcelain.rb', line 11067

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11069
11070
11071
# File 'lib/models/porcelain.rb', line 11069

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11071
11072
11073
# File 'lib/models/porcelain.rb', line 11071

def name
  @name
end

#passwordObject

The password to authenticate with.



11073
11074
11075
# File 'lib/models/porcelain.rb', line 11073

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11075
11076
11077
# File 'lib/models/porcelain.rb', line 11075

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11077
11078
11079
# File 'lib/models/porcelain.rb', line 11077

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11079
11080
11081
# File 'lib/models/porcelain.rb', line 11079

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11081
11082
11083
# File 'lib/models/porcelain.rb', line 11081

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11083
11084
11085
# File 'lib/models/porcelain.rb', line 11083

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11085
11086
11087
# File 'lib/models/porcelain.rb', line 11085

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11087
11088
11089
# File 'lib/models/porcelain.rb', line 11087

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11089
11090
11091
# File 'lib/models/porcelain.rb', line 11089

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11091
11092
11093
# File 'lib/models/porcelain.rb', line 11091

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11131
11132
11133
11134
11135
11136
11137
# File 'lib/models/porcelain.rb', line 11131

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end