Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



10807
10808
10809
10810
10811
10812
10813
10814
10815
10816
10817
10818
10819
10820
10821
10822
10823
10824
10825
10826
10827
10828
10829
10830
10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
# File 'lib/models/porcelain.rb', line 10807

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10773
10774
10775
# File 'lib/models/porcelain.rb', line 10773

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10775
10776
10777
# File 'lib/models/porcelain.rb', line 10775

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10777
10778
10779
# File 'lib/models/porcelain.rb', line 10777

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10779
10780
10781
# File 'lib/models/porcelain.rb', line 10779

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10781
10782
10783
# File 'lib/models/porcelain.rb', line 10781

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10783
10784
10785
# File 'lib/models/porcelain.rb', line 10783

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10785
10786
10787
# File 'lib/models/porcelain.rb', line 10785

def name
  @name
end

#passwordObject

The password to authenticate with.



10787
10788
10789
# File 'lib/models/porcelain.rb', line 10787

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10789
10790
10791
# File 'lib/models/porcelain.rb', line 10789

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10791
10792
10793
# File 'lib/models/porcelain.rb', line 10791

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10793
10794
10795
# File 'lib/models/porcelain.rb', line 10793

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10795
10796
10797
# File 'lib/models/porcelain.rb', line 10795

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10797
10798
10799
# File 'lib/models/porcelain.rb', line 10797

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10799
10800
10801
# File 'lib/models/porcelain.rb', line 10799

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10801
10802
10803
# File 'lib/models/porcelain.rb', line 10801

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10803
10804
10805
# File 'lib/models/porcelain.rb', line 10803

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10805
10806
10807
# File 'lib/models/porcelain.rb', line 10805

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10845
10846
10847
10848
10849
10850
10851
# File 'lib/models/porcelain.rb', line 10845

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end