Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/models/porcelain.rb', line 10111

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10077
10078
10079
# File 'lib/models/porcelain.rb', line 10077

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10079
10080
10081
# File 'lib/models/porcelain.rb', line 10079

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10081
10082
10083
# File 'lib/models/porcelain.rb', line 10081

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10083
10084
10085
# File 'lib/models/porcelain.rb', line 10083

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10085
10086
10087
# File 'lib/models/porcelain.rb', line 10085

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10087
10088
10089
# File 'lib/models/porcelain.rb', line 10087

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10089
10090
10091
# File 'lib/models/porcelain.rb', line 10089

def name
  @name
end

#passwordObject

The password to authenticate with.



10091
10092
10093
# File 'lib/models/porcelain.rb', line 10091

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10093
10094
10095
# File 'lib/models/porcelain.rb', line 10093

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10095
10096
10097
# File 'lib/models/porcelain.rb', line 10095

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10097
10098
10099
# File 'lib/models/porcelain.rb', line 10097

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10099
10100
10101
# File 'lib/models/porcelain.rb', line 10099

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10101
10102
10103
# File 'lib/models/porcelain.rb', line 10101

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10103
10104
10105
# File 'lib/models/porcelain.rb', line 10103

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10105
10106
10107
# File 'lib/models/porcelain.rb', line 10105

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10107
10108
10109
# File 'lib/models/porcelain.rb', line 10107

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10109
10110
10111
# File 'lib/models/porcelain.rb', line 10109

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10149
10150
10151
10152
10153
10154
10155
# File 'lib/models/porcelain.rb', line 10149

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end