Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



8763
8764
8765
8766
8767
8768
8769
8770
8771
8772
8773
8774
8775
8776
8777
8778
8779
8780
8781
8782
8783
8784
8785
8786
8787
8788
8789
8790
8791
8792
8793
8794
8795
8796
8797
8798
8799
# File 'lib/models/porcelain.rb', line 8763

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8729
8730
8731
# File 'lib/models/porcelain.rb', line 8729

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



8731
8732
8733
# File 'lib/models/porcelain.rb', line 8731

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8733
8734
8735
# File 'lib/models/porcelain.rb', line 8733

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8735
8736
8737
# File 'lib/models/porcelain.rb', line 8735

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8737
8738
8739
# File 'lib/models/porcelain.rb', line 8737

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8739
8740
8741
# File 'lib/models/porcelain.rb', line 8739

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8741
8742
8743
# File 'lib/models/porcelain.rb', line 8741

def name
  @name
end

#passwordObject

The password to authenticate with.



8743
8744
8745
# File 'lib/models/porcelain.rb', line 8743

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8745
8746
8747
# File 'lib/models/porcelain.rb', line 8745

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8747
8748
8749
# File 'lib/models/porcelain.rb', line 8747

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8749
8750
8751
# File 'lib/models/porcelain.rb', line 8749

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8751
8752
8753
# File 'lib/models/porcelain.rb', line 8751

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8753
8754
8755
# File 'lib/models/porcelain.rb', line 8753

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8755
8756
8757
# File 'lib/models/porcelain.rb', line 8755

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8757
8758
8759
# File 'lib/models/porcelain.rb', line 8757

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8759
8760
8761
# File 'lib/models/porcelain.rb', line 8759

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8761
8762
8763
# File 'lib/models/porcelain.rb', line 8761

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8801
8802
8803
8804
8805
8806
8807
# File 'lib/models/porcelain.rb', line 8801

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end