Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
8629
8630
8631
8632
8633
8634
8635
8636
8637
8638
8639
8640
8641
8642
8643
8644
8645
8646
8647
8648
8649
8650
8651
8652
# File 'lib/models/porcelain.rb', line 8616

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8582
8583
8584
# File 'lib/models/porcelain.rb', line 8582

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



8584
8585
8586
# File 'lib/models/porcelain.rb', line 8584

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8586
8587
8588
# File 'lib/models/porcelain.rb', line 8586

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8588
8589
8590
# File 'lib/models/porcelain.rb', line 8588

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8590
8591
8592
# File 'lib/models/porcelain.rb', line 8590

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8592
8593
8594
# File 'lib/models/porcelain.rb', line 8592

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8594
8595
8596
# File 'lib/models/porcelain.rb', line 8594

def name
  @name
end

#passwordObject

The password to authenticate with.



8596
8597
8598
# File 'lib/models/porcelain.rb', line 8596

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8598
8599
8600
# File 'lib/models/porcelain.rb', line 8598

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8600
8601
8602
# File 'lib/models/porcelain.rb', line 8600

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8602
8603
8604
# File 'lib/models/porcelain.rb', line 8602

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8604
8605
8606
# File 'lib/models/porcelain.rb', line 8604

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8606
8607
8608
# File 'lib/models/porcelain.rb', line 8606

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8608
8609
8610
# File 'lib/models/porcelain.rb', line 8608

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8610
8611
8612
# File 'lib/models/porcelain.rb', line 8610

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8612
8613
8614
# File 'lib/models/porcelain.rb', line 8612

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8614
8615
8616
# File 'lib/models/porcelain.rb', line 8614

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8654
8655
8656
8657
8658
8659
8660
# File 'lib/models/porcelain.rb', line 8654

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end