Class: SDM::Maria
- Inherits:
-
Object
- Object
- SDM::Maria
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria
constructor
A new instance of Maria.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria
Returns a new instance of Maria.
7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 7791 7792 7793 7794 7795 7796 7797 7798 7799 7800 7801 |
# File 'lib/models/porcelain.rb', line 7765 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7731 7732 7733 |
# File 'lib/models/porcelain.rb', line 7731 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests.
7733 7734 7735 |
# File 'lib/models/porcelain.rb', line 7733 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7735 7736 7737 |
# File 'lib/models/porcelain.rb', line 7735 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7737 7738 7739 |
# File 'lib/models/porcelain.rb', line 7737 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7739 7740 7741 |
# File 'lib/models/porcelain.rb', line 7739 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7741 7742 7743 |
# File 'lib/models/porcelain.rb', line 7741 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7743 7744 7745 |
# File 'lib/models/porcelain.rb', line 7743 def name @name end |
#password ⇒ Object
The password to authenticate with.
7745 7746 7747 |
# File 'lib/models/porcelain.rb', line 7745 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7747 7748 7749 |
# File 'lib/models/porcelain.rb', line 7747 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7749 7750 7751 |
# File 'lib/models/porcelain.rb', line 7749 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7751 7752 7753 |
# File 'lib/models/porcelain.rb', line 7751 def proxy_cluster_id @proxy_cluster_id end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
7753 7754 7755 |
# File 'lib/models/porcelain.rb', line 7753 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7755 7756 7757 |
# File 'lib/models/porcelain.rb', line 7755 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7757 7758 7759 |
# File 'lib/models/porcelain.rb', line 7757 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7759 7760 7761 |
# File 'lib/models/porcelain.rb', line 7759 def @tags end |
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address
7761 7762 7763 |
# File 'lib/models/porcelain.rb', line 7761 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
The username to authenticate with.
7763 7764 7765 |
# File 'lib/models/porcelain.rb', line 7763 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7803 7804 7805 7806 7807 7808 7809 |
# File 'lib/models/porcelain.rb', line 7803 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |