Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
7772
7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
7794
# File 'lib/models/porcelain.rb', line 7758

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7724
7725
7726
# File 'lib/models/porcelain.rb', line 7724

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7726
7727
7728
# File 'lib/models/porcelain.rb', line 7726

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7728
7729
7730
# File 'lib/models/porcelain.rb', line 7728

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7730
7731
7732
# File 'lib/models/porcelain.rb', line 7730

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7732
7733
7734
# File 'lib/models/porcelain.rb', line 7732

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7734
7735
7736
# File 'lib/models/porcelain.rb', line 7734

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7736
7737
7738
# File 'lib/models/porcelain.rb', line 7736

def name
  @name
end

#passwordObject

The password to authenticate with.



7738
7739
7740
# File 'lib/models/porcelain.rb', line 7738

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7740
7741
7742
# File 'lib/models/porcelain.rb', line 7740

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7742
7743
7744
# File 'lib/models/porcelain.rb', line 7742

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7744
7745
7746
# File 'lib/models/porcelain.rb', line 7744

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7746
7747
7748
# File 'lib/models/porcelain.rb', line 7746

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7748
7749
7750
# File 'lib/models/porcelain.rb', line 7748

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7750
7751
7752
# File 'lib/models/porcelain.rb', line 7750

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7752
7753
7754
# File 'lib/models/porcelain.rb', line 7752

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7754
7755
7756
# File 'lib/models/porcelain.rb', line 7754

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7756
7757
7758
# File 'lib/models/porcelain.rb', line 7756

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7796
7797
7798
7799
7800
7801
7802
# File 'lib/models/porcelain.rb', line 7796

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end