Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



7687
7688
7689
7690
7691
7692
7693
7694
7695
7696
7697
7698
7699
7700
7701
7702
7703
7704
7705
7706
7707
7708
7709
7710
7711
7712
7713
7714
7715
7716
7717
7718
7719
7720
7721
7722
7723
# File 'lib/models/porcelain.rb', line 7687

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7653
7654
7655
# File 'lib/models/porcelain.rb', line 7653

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7655
7656
7657
# File 'lib/models/porcelain.rb', line 7655

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7657
7658
7659
# File 'lib/models/porcelain.rb', line 7657

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7659
7660
7661
# File 'lib/models/porcelain.rb', line 7659

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7661
7662
7663
# File 'lib/models/porcelain.rb', line 7661

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7663
7664
7665
# File 'lib/models/porcelain.rb', line 7663

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7665
7666
7667
# File 'lib/models/porcelain.rb', line 7665

def name
  @name
end

#passwordObject

The password to authenticate with.



7667
7668
7669
# File 'lib/models/porcelain.rb', line 7667

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7669
7670
7671
# File 'lib/models/porcelain.rb', line 7669

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7671
7672
7673
# File 'lib/models/porcelain.rb', line 7671

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7673
7674
7675
# File 'lib/models/porcelain.rb', line 7673

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7675
7676
7677
# File 'lib/models/porcelain.rb', line 7675

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7677
7678
7679
# File 'lib/models/porcelain.rb', line 7677

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7679
7680
7681
# File 'lib/models/porcelain.rb', line 7679

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7681
7682
7683
# File 'lib/models/porcelain.rb', line 7681

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7683
7684
7685
# File 'lib/models/porcelain.rb', line 7683

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7685
7686
7687
# File 'lib/models/porcelain.rb', line 7685

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7725
7726
7727
7728
7729
7730
7731
# File 'lib/models/porcelain.rb', line 7725

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end