Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
# File 'lib/models/porcelain.rb', line 7611

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7577
7578
7579
# File 'lib/models/porcelain.rb', line 7577

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7579
7580
7581
# File 'lib/models/porcelain.rb', line 7579

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7581
7582
7583
# File 'lib/models/porcelain.rb', line 7581

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7583
7584
7585
# File 'lib/models/porcelain.rb', line 7583

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7585
7586
7587
# File 'lib/models/porcelain.rb', line 7585

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7587
7588
7589
# File 'lib/models/porcelain.rb', line 7587

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7589
7590
7591
# File 'lib/models/porcelain.rb', line 7589

def name
  @name
end

#passwordObject

The password to authenticate with.



7591
7592
7593
# File 'lib/models/porcelain.rb', line 7591

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7593
7594
7595
# File 'lib/models/porcelain.rb', line 7593

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7595
7596
7597
# File 'lib/models/porcelain.rb', line 7595

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7597
7598
7599
# File 'lib/models/porcelain.rb', line 7597

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7599
7600
7601
# File 'lib/models/porcelain.rb', line 7599

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7601
7602
7603
# File 'lib/models/porcelain.rb', line 7601

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7603
7604
7605
# File 'lib/models/porcelain.rb', line 7603

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7605
7606
7607
# File 'lib/models/porcelain.rb', line 7605

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7607
7608
7609
# File 'lib/models/porcelain.rb', line 7607

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7609
7610
7611
# File 'lib/models/porcelain.rb', line 7609

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7649
7650
7651
7652
7653
7654
7655
# File 'lib/models/porcelain.rb', line 7649

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end