Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



7541
7542
7543
7544
7545
7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
# File 'lib/models/porcelain.rb', line 7541

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7507
7508
7509
# File 'lib/models/porcelain.rb', line 7507

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7509
7510
7511
# File 'lib/models/porcelain.rb', line 7509

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7511
7512
7513
# File 'lib/models/porcelain.rb', line 7511

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7513
7514
7515
# File 'lib/models/porcelain.rb', line 7513

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7515
7516
7517
# File 'lib/models/porcelain.rb', line 7515

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7517
7518
7519
# File 'lib/models/porcelain.rb', line 7517

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7519
7520
7521
# File 'lib/models/porcelain.rb', line 7519

def name
  @name
end

#passwordObject

The password to authenticate with.



7521
7522
7523
# File 'lib/models/porcelain.rb', line 7521

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7523
7524
7525
# File 'lib/models/porcelain.rb', line 7523

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7525
7526
7527
# File 'lib/models/porcelain.rb', line 7525

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7527
7528
7529
# File 'lib/models/porcelain.rb', line 7527

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7529
7530
7531
# File 'lib/models/porcelain.rb', line 7529

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7531
7532
7533
# File 'lib/models/porcelain.rb', line 7531

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7533
7534
7535
# File 'lib/models/porcelain.rb', line 7533

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7535
7536
7537
# File 'lib/models/porcelain.rb', line 7535

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7537
7538
7539
# File 'lib/models/porcelain.rb', line 7537

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7539
7540
7541
# File 'lib/models/porcelain.rb', line 7539

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7579
7580
7581
7582
7583
7584
7585
# File 'lib/models/porcelain.rb', line 7579

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end