Class: SDM::Maria
- Inherits:
-
Object
- Object
- SDM::Maria
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria
constructor
A new instance of Maria.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria
Returns a new instance of Maria.
7541 7542 7543 7544 7545 7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 7560 7561 7562 7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 |
# File 'lib/models/porcelain.rb', line 7541 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7507 7508 7509 |
# File 'lib/models/porcelain.rb', line 7507 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests.
7509 7510 7511 |
# File 'lib/models/porcelain.rb', line 7509 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7511 7512 7513 |
# File 'lib/models/porcelain.rb', line 7511 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7513 7514 7515 |
# File 'lib/models/porcelain.rb', line 7513 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7515 7516 7517 |
# File 'lib/models/porcelain.rb', line 7515 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7517 7518 7519 |
# File 'lib/models/porcelain.rb', line 7517 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7519 7520 7521 |
# File 'lib/models/porcelain.rb', line 7519 def name @name end |
#password ⇒ Object
The password to authenticate with.
7521 7522 7523 |
# File 'lib/models/porcelain.rb', line 7521 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7523 7524 7525 |
# File 'lib/models/porcelain.rb', line 7523 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7525 7526 7527 |
# File 'lib/models/porcelain.rb', line 7525 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7527 7528 7529 |
# File 'lib/models/porcelain.rb', line 7527 def proxy_cluster_id @proxy_cluster_id end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
7529 7530 7531 |
# File 'lib/models/porcelain.rb', line 7529 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7531 7532 7533 |
# File 'lib/models/porcelain.rb', line 7531 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7533 7534 7535 |
# File 'lib/models/porcelain.rb', line 7533 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7535 7536 7537 |
# File 'lib/models/porcelain.rb', line 7535 def @tags end |
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address
7537 7538 7539 |
# File 'lib/models/porcelain.rb', line 7537 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
The username to authenticate with.
7539 7540 7541 |
# File 'lib/models/porcelain.rb', line 7539 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7579 7580 7581 7582 7583 7584 7585 |
# File 'lib/models/porcelain.rb', line 7579 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |