Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
6878
6879
6880
6881
6882
6883
6884
6885
6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
# File 'lib/models/porcelain.rb', line 6859

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6825
6826
6827
# File 'lib/models/porcelain.rb', line 6825

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



6827
6828
6829
# File 'lib/models/porcelain.rb', line 6827

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6829
6830
6831
# File 'lib/models/porcelain.rb', line 6829

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6831
6832
6833
# File 'lib/models/porcelain.rb', line 6831

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6833
6834
6835
# File 'lib/models/porcelain.rb', line 6833

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6835
6836
6837
# File 'lib/models/porcelain.rb', line 6835

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6837
6838
6839
# File 'lib/models/porcelain.rb', line 6837

def name
  @name
end

#passwordObject

The password to authenticate with.



6839
6840
6841
# File 'lib/models/porcelain.rb', line 6839

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6841
6842
6843
# File 'lib/models/porcelain.rb', line 6841

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6843
6844
6845
# File 'lib/models/porcelain.rb', line 6843

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6845
6846
6847
# File 'lib/models/porcelain.rb', line 6845

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



6847
6848
6849
# File 'lib/models/porcelain.rb', line 6847

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6849
6850
6851
# File 'lib/models/porcelain.rb', line 6849

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6851
6852
6853
# File 'lib/models/porcelain.rb', line 6851

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6853
6854
6855
# File 'lib/models/porcelain.rb', line 6853

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



6855
6856
6857
# File 'lib/models/porcelain.rb', line 6855

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



6857
6858
6859
# File 'lib/models/porcelain.rb', line 6857

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6897
6898
6899
6900
6901
6902
6903
# File 'lib/models/porcelain.rb', line 6897

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end