Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
6600
6601
6602
6603
6604
6605
6606
6607
6608
6609
6610
6611
6612
6613
6614
# File 'lib/models/porcelain.rb', line 6580

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6548
6549
6550
# File 'lib/models/porcelain.rb', line 6548

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



6550
6551
6552
# File 'lib/models/porcelain.rb', line 6550

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6552
6553
6554
# File 'lib/models/porcelain.rb', line 6552

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6554
6555
6556
# File 'lib/models/porcelain.rb', line 6554

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6556
6557
6558
# File 'lib/models/porcelain.rb', line 6556

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6558
6559
6560
# File 'lib/models/porcelain.rb', line 6558

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6560
6561
6562
# File 'lib/models/porcelain.rb', line 6560

def name
  @name
end

#passwordObject

The password to authenticate with.



6562
6563
6564
# File 'lib/models/porcelain.rb', line 6562

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6564
6565
6566
# File 'lib/models/porcelain.rb', line 6564

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6566
6567
6568
# File 'lib/models/porcelain.rb', line 6566

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



6568
6569
6570
# File 'lib/models/porcelain.rb', line 6568

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6570
6571
6572
# File 'lib/models/porcelain.rb', line 6570

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6572
6573
6574
# File 'lib/models/porcelain.rb', line 6572

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6574
6575
6576
# File 'lib/models/porcelain.rb', line 6574

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



6576
6577
6578
# File 'lib/models/porcelain.rb', line 6576

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



6578
6579
6580
# File 'lib/models/porcelain.rb', line 6578

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6616
6617
6618
6619
6620
6621
6622
# File 'lib/models/porcelain.rb', line 6616

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end