Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
5856
5857
5858
5859
5860
5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
# File 'lib/models/porcelain.rb', line 5840

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5808
5809
5810
# File 'lib/models/porcelain.rb', line 5808

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



5810
5811
5812
# File 'lib/models/porcelain.rb', line 5810

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5812
5813
5814
# File 'lib/models/porcelain.rb', line 5812

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5814
5815
5816
# File 'lib/models/porcelain.rb', line 5814

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5816
5817
5818
# File 'lib/models/porcelain.rb', line 5816

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5818
5819
5820
# File 'lib/models/porcelain.rb', line 5818

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5820
5821
5822
# File 'lib/models/porcelain.rb', line 5820

def name
  @name
end

#passwordObject

The password to authenticate with.



5822
5823
5824
# File 'lib/models/porcelain.rb', line 5822

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5824
5825
5826
# File 'lib/models/porcelain.rb', line 5824

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5826
5827
5828
# File 'lib/models/porcelain.rb', line 5826

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



5828
5829
5830
# File 'lib/models/porcelain.rb', line 5828

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5830
5831
5832
# File 'lib/models/porcelain.rb', line 5830

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5832
5833
5834
# File 'lib/models/porcelain.rb', line 5832

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5834
5835
5836
# File 'lib/models/porcelain.rb', line 5834

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



5836
5837
5838
# File 'lib/models/porcelain.rb', line 5836

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



5838
5839
5840
# File 'lib/models/porcelain.rb', line 5838

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5876
5877
5878
5879
5880
5881
5882
# File 'lib/models/porcelain.rb', line 5876

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end