Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
5053
5054
# File 'lib/models/porcelain.rb', line 5020

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4988
4989
4990
# File 'lib/models/porcelain.rb', line 4988

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4990
4991
4992
# File 'lib/models/porcelain.rb', line 4990

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4992
4993
4994
# File 'lib/models/porcelain.rb', line 4992

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4994
4995
4996
# File 'lib/models/porcelain.rb', line 4994

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4996
4997
4998
# File 'lib/models/porcelain.rb', line 4996

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4998
4999
5000
# File 'lib/models/porcelain.rb', line 4998

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5000
5001
5002
# File 'lib/models/porcelain.rb', line 5000

def name
  @name
end

#passwordObject

The password to authenticate with.



5002
5003
5004
# File 'lib/models/porcelain.rb', line 5002

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5004
5005
5006
# File 'lib/models/porcelain.rb', line 5004

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5006
5007
5008
# File 'lib/models/porcelain.rb', line 5006

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



5008
5009
5010
# File 'lib/models/porcelain.rb', line 5008

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5010
5011
5012
# File 'lib/models/porcelain.rb', line 5010

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5012
5013
5014
# File 'lib/models/porcelain.rb', line 5012

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5014
5015
5016
# File 'lib/models/porcelain.rb', line 5014

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



5016
5017
5018
# File 'lib/models/porcelain.rb', line 5016

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



5018
5019
5020
# File 'lib/models/porcelain.rb', line 5018

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5056
5057
5058
5059
5060
5061
5062
# File 'lib/models/porcelain.rb', line 5056

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end