Class: SDM::Maria
- Inherits:
-
Object
- Object
- SDM::Maria
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#require_native_auth ⇒ Object
Returns the value of attribute require_native_auth.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
Returns the value of attribute use_azure_single_server_usernames.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria
constructor
A new instance of Maria.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria
Returns a new instance of Maria.
4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 4767 |
# File 'lib/models/porcelain.rb', line 4733 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4701 4702 4703 |
# File 'lib/models/porcelain.rb', line 4701 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4703 4704 4705 |
# File 'lib/models/porcelain.rb', line 4703 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4705 4706 4707 |
# File 'lib/models/porcelain.rb', line 4705 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4707 4708 4709 |
# File 'lib/models/porcelain.rb', line 4707 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4709 4710 4711 |
# File 'lib/models/porcelain.rb', line 4709 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4711 4712 4713 |
# File 'lib/models/porcelain.rb', line 4711 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4713 4714 4715 |
# File 'lib/models/porcelain.rb', line 4713 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4715 4716 4717 |
# File 'lib/models/porcelain.rb', line 4715 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4717 4718 4719 |
# File 'lib/models/porcelain.rb', line 4717 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4719 4720 4721 |
# File 'lib/models/porcelain.rb', line 4719 def port_override @port_override end |
#require_native_auth ⇒ Object
Returns the value of attribute require_native_auth.
4721 4722 4723 |
# File 'lib/models/porcelain.rb', line 4721 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4723 4724 4725 |
# File 'lib/models/porcelain.rb', line 4723 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4725 4726 4727 |
# File 'lib/models/porcelain.rb', line 4725 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4727 4728 4729 |
# File 'lib/models/porcelain.rb', line 4727 def @tags end |
#use_azure_single_server_usernames ⇒ Object
Returns the value of attribute use_azure_single_server_usernames.
4729 4730 4731 |
# File 'lib/models/porcelain.rb', line 4729 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
Returns the value of attribute username.
4731 4732 4733 |
# File 'lib/models/porcelain.rb', line 4731 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4769 4770 4771 4772 4773 4774 4775 |
# File 'lib/models/porcelain.rb', line 4769 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |