Class: SDM::Maria
- Inherits:
-
Object
- Object
- SDM::Maria
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Maria
constructor
A new instance of Maria.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Maria
Returns a new instance of Maria.
4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 |
# File 'lib/models/porcelain.rb', line 4697 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4669 4670 4671 |
# File 'lib/models/porcelain.rb', line 4669 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4671 4672 4673 |
# File 'lib/models/porcelain.rb', line 4671 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4673 4674 4675 |
# File 'lib/models/porcelain.rb', line 4673 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4675 4676 4677 |
# File 'lib/models/porcelain.rb', line 4675 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4677 4678 4679 |
# File 'lib/models/porcelain.rb', line 4677 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4679 4680 4681 |
# File 'lib/models/porcelain.rb', line 4679 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4681 4682 4683 |
# File 'lib/models/porcelain.rb', line 4681 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4683 4684 4685 |
# File 'lib/models/porcelain.rb', line 4683 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4685 4686 4687 |
# File 'lib/models/porcelain.rb', line 4685 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4687 4688 4689 |
# File 'lib/models/porcelain.rb', line 4687 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4689 4690 4691 |
# File 'lib/models/porcelain.rb', line 4689 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4691 4692 4693 |
# File 'lib/models/porcelain.rb', line 4691 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4693 4694 4695 |
# File 'lib/models/porcelain.rb', line 4693 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4695 4696 4697 |
# File 'lib/models/porcelain.rb', line 4695 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4729 4730 4731 4732 4733 4734 4735 |
# File 'lib/models/porcelain.rb', line 4729 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |