Class: SDM::Maria
- Inherits:
-
Object
- Object
- SDM::Maria
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Maria
constructor
A new instance of Maria.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Maria
Returns a new instance of Maria.
4373 4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 |
# File 'lib/models/porcelain.rb', line 4373 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4347 4348 4349 |
# File 'lib/models/porcelain.rb', line 4347 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4349 4350 4351 |
# File 'lib/models/porcelain.rb', line 4349 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4351 4352 4353 |
# File 'lib/models/porcelain.rb', line 4351 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4353 4354 4355 |
# File 'lib/models/porcelain.rb', line 4353 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4355 4356 4357 |
# File 'lib/models/porcelain.rb', line 4355 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4357 4358 4359 |
# File 'lib/models/porcelain.rb', line 4357 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4359 4360 4361 |
# File 'lib/models/porcelain.rb', line 4359 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4361 4362 4363 |
# File 'lib/models/porcelain.rb', line 4361 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4363 4364 4365 |
# File 'lib/models/porcelain.rb', line 4363 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4365 4366 4367 |
# File 'lib/models/porcelain.rb', line 4365 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4367 4368 4369 |
# File 'lib/models/porcelain.rb', line 4367 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4369 4370 4371 |
# File 'lib/models/porcelain.rb', line 4369 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4371 4372 4373 |
# File 'lib/models/porcelain.rb', line 4371 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4403 4404 4405 4406 4407 4408 4409 |
# File 'lib/models/porcelain.rb', line 4403 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |