Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
3925
3926
3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
# File 'lib/models/porcelain.rb', line 3909

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



3883
3884
3885
# File 'lib/models/porcelain.rb', line 3883

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



3885
3886
3887
# File 'lib/models/porcelain.rb', line 3885

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3887
3888
3889
# File 'lib/models/porcelain.rb', line 3887

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3889
3890
3891
# File 'lib/models/porcelain.rb', line 3889

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3891
3892
3893
# File 'lib/models/porcelain.rb', line 3891

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3893
3894
3895
# File 'lib/models/porcelain.rb', line 3893

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3895
3896
3897
# File 'lib/models/porcelain.rb', line 3895

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3897
3898
3899
# File 'lib/models/porcelain.rb', line 3897

def password
  @password
end

#portObject

Returns the value of attribute port.



3899
3900
3901
# File 'lib/models/porcelain.rb', line 3899

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3901
3902
3903
# File 'lib/models/porcelain.rb', line 3901

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3903
3904
3905
# File 'lib/models/porcelain.rb', line 3903

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3905
3906
3907
# File 'lib/models/porcelain.rb', line 3905

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3907
3908
3909
# File 'lib/models/porcelain.rb', line 3907

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3939
3940
3941
3942
3943
3944
3945
# File 'lib/models/porcelain.rb', line 3939

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end