Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



3210
3211
3212
3213
3214
3215
3216
3217
3218
3219
3220
3221
3222
3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
3235
3236
# File 'lib/models/porcelain.rb', line 3210

def initialize(
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#databaseObject

Returns the value of attribute database.



3186
3187
3188
# File 'lib/models/porcelain.rb', line 3186

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3188
3189
3190
# File 'lib/models/porcelain.rb', line 3188

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3190
3191
3192
# File 'lib/models/porcelain.rb', line 3190

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3192
3193
3194
# File 'lib/models/porcelain.rb', line 3192

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3194
3195
3196
# File 'lib/models/porcelain.rb', line 3194

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3196
3197
3198
# File 'lib/models/porcelain.rb', line 3196

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3198
3199
3200
# File 'lib/models/porcelain.rb', line 3198

def password
  @password
end

#portObject

Returns the value of attribute port.



3200
3201
3202
# File 'lib/models/porcelain.rb', line 3200

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3202
3203
3204
# File 'lib/models/porcelain.rb', line 3202

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3204
3205
3206
# File 'lib/models/porcelain.rb', line 3204

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3206
3207
3208
# File 'lib/models/porcelain.rb', line 3206

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



3208
3209
3210
# File 'lib/models/porcelain.rb', line 3208

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3238
3239
3240
3241
3242
3243
3244
# File 'lib/models/porcelain.rb', line 3238

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end