Class: SDM::Maria
- Inherits:
-
Object
- Object
- SDM::Maria
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Maria
constructor
A new instance of Maria.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Maria
Returns a new instance of Maria.
4169 4170 4171 4172 4173 4174 4175 4176 4177 4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 |
# File 'lib/models/porcelain.rb', line 4169 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
4145 4146 4147 |
# File 'lib/models/porcelain.rb', line 4145 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4147 4148 4149 |
# File 'lib/models/porcelain.rb', line 4147 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4149 4150 4151 |
# File 'lib/models/porcelain.rb', line 4149 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4151 4152 4153 |
# File 'lib/models/porcelain.rb', line 4151 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4153 4154 4155 |
# File 'lib/models/porcelain.rb', line 4153 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4155 4156 4157 |
# File 'lib/models/porcelain.rb', line 4155 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4157 4158 4159 |
# File 'lib/models/porcelain.rb', line 4157 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4159 4160 4161 |
# File 'lib/models/porcelain.rb', line 4159 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4161 4162 4163 |
# File 'lib/models/porcelain.rb', line 4161 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4163 4164 4165 |
# File 'lib/models/porcelain.rb', line 4163 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4165 4166 4167 |
# File 'lib/models/porcelain.rb', line 4165 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4167 4168 4169 |
# File 'lib/models/porcelain.rb', line 4167 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4221 4222 4223 4224 4225 4226 4227 |
# File 'lib/models/porcelain.rb', line 4221 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |