Class: SDM::Maria

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Maria

Returns a new instance of Maria.



11767
11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
11784
11785
11786
11787
11788
11789
11790
11791
11792
11793
11794
11795
11796
11797
11798
11799
11800
11801
11802
11803
# File 'lib/models/porcelain.rb', line 11767

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11733
11734
11735
# File 'lib/models/porcelain.rb', line 11733

def bind_interface
  @bind_interface
end

#database ⇒ Object

The database for healthchecks. Does not affect client requests.



11735
11736
11737
# File 'lib/models/porcelain.rb', line 11735

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



11737
11738
11739
# File 'lib/models/porcelain.rb', line 11737

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



11739
11740
11741
# File 'lib/models/porcelain.rb', line 11739

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



11741
11742
11743
# File 'lib/models/porcelain.rb', line 11741

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



11743
11744
11745
# File 'lib/models/porcelain.rb', line 11743

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



11745
11746
11747
# File 'lib/models/porcelain.rb', line 11745

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



11747
11748
11749
# File 'lib/models/porcelain.rb', line 11747

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



11749
11750
11751
# File 'lib/models/porcelain.rb', line 11749

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11751
11752
11753
# File 'lib/models/porcelain.rb', line 11751

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



11753
11754
11755
# File 'lib/models/porcelain.rb', line 11753

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_auth ⇒ Object

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11755
11756
11757
# File 'lib/models/porcelain.rb', line 11755

def require_native_auth
  @require_native_auth
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



11757
11758
11759
# File 'lib/models/porcelain.rb', line 11757

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11759
11760
11761
# File 'lib/models/porcelain.rb', line 11759

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



11761
11762
11763
# File 'lib/models/porcelain.rb', line 11761

def tags
  @tags
end

#use_azure_single_server_usernames ⇒ Object

If true, appends the hostname to the username when hitting a database.azure.com address



11763
11764
11765
# File 'lib/models/porcelain.rb', line 11763

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#username ⇒ Object

The username to authenticate with.



11765
11766
11767
# File 'lib/models/porcelain.rb', line 11765

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11805
11806
11807
11808
11809
11810
11811
# File 'lib/models/porcelain.rb', line 11805

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end