Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



11780
11781
11782
11783
11784
11785
11786
11787
11788
11789
11790
11791
11792
11793
11794
11795
11796
11797
11798
11799
11800
11801
11802
11803
11804
11805
11806
# File 'lib/models/porcelain.rb', line 11780

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11756
11757
11758
# File 'lib/models/porcelain.rb', line 11756

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11758
11759
11760
# File 'lib/models/porcelain.rb', line 11758

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11760
11761
11762
# File 'lib/models/porcelain.rb', line 11760

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11762
11763
11764
# File 'lib/models/porcelain.rb', line 11762

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11764
11765
11766
# File 'lib/models/porcelain.rb', line 11764

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11766
11767
11768
# File 'lib/models/porcelain.rb', line 11766

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11768
11769
11770
# File 'lib/models/porcelain.rb', line 11768

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11770
11771
11772
# File 'lib/models/porcelain.rb', line 11770

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11772
11773
11774
# File 'lib/models/porcelain.rb', line 11772

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11774
11775
11776
# File 'lib/models/porcelain.rb', line 11774

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11776
11777
11778
# File 'lib/models/porcelain.rb', line 11776

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11778
11779
11780
# File 'lib/models/porcelain.rb', line 11778

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11808
11809
11810
11811
11812
11813
11814
# File 'lib/models/porcelain.rb', line 11808

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end