Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



11248
11249
11250
11251
11252
11253
11254
11255
11256
11257
11258
11259
11260
11261
11262
11263
11264
11265
11266
11267
11268
11269
11270
11271
11272
11273
11274
# File 'lib/models/porcelain.rb', line 11248

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11224
11225
11226
# File 'lib/models/porcelain.rb', line 11224

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11226
11227
11228
# File 'lib/models/porcelain.rb', line 11226

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11228
11229
11230
# File 'lib/models/porcelain.rb', line 11228

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11230
11231
11232
# File 'lib/models/porcelain.rb', line 11230

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11232
11233
11234
# File 'lib/models/porcelain.rb', line 11232

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11234
11235
11236
# File 'lib/models/porcelain.rb', line 11234

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11236
11237
11238
# File 'lib/models/porcelain.rb', line 11236

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11238
11239
11240
# File 'lib/models/porcelain.rb', line 11238

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11240
11241
11242
# File 'lib/models/porcelain.rb', line 11240

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11242
11243
11244
# File 'lib/models/porcelain.rb', line 11242

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11244
11245
11246
# File 'lib/models/porcelain.rb', line 11244

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11246
11247
11248
# File 'lib/models/porcelain.rb', line 11246

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11276
11277
11278
11279
11280
11281
11282
# File 'lib/models/porcelain.rb', line 11276

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end