Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
11191
11192
# File 'lib/models/porcelain.rb', line 11166

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11142
11143
11144
# File 'lib/models/porcelain.rb', line 11142

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11144
11145
11146
# File 'lib/models/porcelain.rb', line 11144

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11146
11147
11148
# File 'lib/models/porcelain.rb', line 11146

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11148
11149
11150
# File 'lib/models/porcelain.rb', line 11148

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11150
11151
11152
# File 'lib/models/porcelain.rb', line 11150

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11152
11153
11154
# File 'lib/models/porcelain.rb', line 11152

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11154
11155
11156
# File 'lib/models/porcelain.rb', line 11154

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11156
11157
11158
# File 'lib/models/porcelain.rb', line 11156

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11158
11159
11160
# File 'lib/models/porcelain.rb', line 11158

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11160
11161
11162
# File 'lib/models/porcelain.rb', line 11160

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11162
11163
11164
# File 'lib/models/porcelain.rb', line 11162

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11164
11165
11166
# File 'lib/models/porcelain.rb', line 11164

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11194
11195
11196
11197
11198
11199
11200
# File 'lib/models/porcelain.rb', line 11194

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end