Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
10906
# File 'lib/models/porcelain.rb', line 10880

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10856
10857
10858
# File 'lib/models/porcelain.rb', line 10856

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10858
10859
10860
# File 'lib/models/porcelain.rb', line 10858

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10860
10861
10862
# File 'lib/models/porcelain.rb', line 10860

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10862
10863
10864
# File 'lib/models/porcelain.rb', line 10862

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10864
10865
10866
# File 'lib/models/porcelain.rb', line 10864

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10866
10867
10868
# File 'lib/models/porcelain.rb', line 10866

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10868
10869
10870
# File 'lib/models/porcelain.rb', line 10868

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10870
10871
10872
# File 'lib/models/porcelain.rb', line 10870

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10872
10873
10874
# File 'lib/models/porcelain.rb', line 10872

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10874
10875
10876
# File 'lib/models/porcelain.rb', line 10874

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10876
10877
10878
# File 'lib/models/porcelain.rb', line 10876

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10878
10879
10880
# File 'lib/models/porcelain.rb', line 10878

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10908
10909
10910
10911
10912
10913
10914
# File 'lib/models/porcelain.rb', line 10908

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end