Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
10195
10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
# File 'lib/models/porcelain.rb', line 10184

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10160
10161
10162
# File 'lib/models/porcelain.rb', line 10160

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10162
10163
10164
# File 'lib/models/porcelain.rb', line 10162

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10164
10165
10166
# File 'lib/models/porcelain.rb', line 10164

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10166
10167
10168
# File 'lib/models/porcelain.rb', line 10166

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10168
10169
10170
# File 'lib/models/porcelain.rb', line 10168

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10170
10171
10172
# File 'lib/models/porcelain.rb', line 10170

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10172
10173
10174
# File 'lib/models/porcelain.rb', line 10172

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10174
10175
10176
# File 'lib/models/porcelain.rb', line 10174

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10176
10177
10178
# File 'lib/models/porcelain.rb', line 10176

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10178
10179
10180
# File 'lib/models/porcelain.rb', line 10178

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10180
10181
10182
# File 'lib/models/porcelain.rb', line 10180

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10182
10183
10184
# File 'lib/models/porcelain.rb', line 10182

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10212
10213
10214
10215
10216
10217
10218
# File 'lib/models/porcelain.rb', line 10212

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end