Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
# File 'lib/models/porcelain.rb', line 8836

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8812
8813
8814
# File 'lib/models/porcelain.rb', line 8812

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8814
8815
8816
# File 'lib/models/porcelain.rb', line 8814

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8816
8817
8818
# File 'lib/models/porcelain.rb', line 8816

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8818
8819
8820
# File 'lib/models/porcelain.rb', line 8818

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8820
8821
8822
# File 'lib/models/porcelain.rb', line 8820

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8822
8823
8824
# File 'lib/models/porcelain.rb', line 8822

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8824
8825
8826
# File 'lib/models/porcelain.rb', line 8824

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8826
8827
8828
# File 'lib/models/porcelain.rb', line 8826

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8828
8829
8830
# File 'lib/models/porcelain.rb', line 8828

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8830
8831
8832
# File 'lib/models/porcelain.rb', line 8830

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8832
8833
8834
# File 'lib/models/porcelain.rb', line 8832

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8834
8835
8836
# File 'lib/models/porcelain.rb', line 8834

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8864
8865
8866
8867
8868
8869
8870
# File 'lib/models/porcelain.rb', line 8864

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end