Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
# File 'lib/models/porcelain.rb', line 8825

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8801
8802
8803
# File 'lib/models/porcelain.rb', line 8801

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8803
8804
8805
# File 'lib/models/porcelain.rb', line 8803

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8805
8806
8807
# File 'lib/models/porcelain.rb', line 8805

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8807
8808
8809
# File 'lib/models/porcelain.rb', line 8807

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8809
8810
8811
# File 'lib/models/porcelain.rb', line 8809

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8811
8812
8813
# File 'lib/models/porcelain.rb', line 8811

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8813
8814
8815
# File 'lib/models/porcelain.rb', line 8813

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8815
8816
8817
# File 'lib/models/porcelain.rb', line 8815

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8817
8818
8819
# File 'lib/models/porcelain.rb', line 8817

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8819
8820
8821
# File 'lib/models/porcelain.rb', line 8819

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8821
8822
8823
# File 'lib/models/porcelain.rb', line 8821

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8823
8824
8825
# File 'lib/models/porcelain.rb', line 8823

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8853
8854
8855
8856
8857
8858
8859
# File 'lib/models/porcelain.rb', line 8853

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end