Class: SDM::Memcached
- Inherits:
-
Object
- Object
- SDM::Memcached
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached
constructor
A new instance of Memcached.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached
Returns a new instance of Memcached.
8689 8690 8691 8692 8693 8694 8695 8696 8697 8698 8699 8700 8701 8702 8703 8704 8705 8706 8707 8708 8709 8710 8711 8712 8713 8714 8715 |
# File 'lib/models/porcelain.rb', line 8689 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8665 8666 8667 |
# File 'lib/models/porcelain.rb', line 8665 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8667 8668 8669 |
# File 'lib/models/porcelain.rb', line 8667 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8669 8670 8671 |
# File 'lib/models/porcelain.rb', line 8669 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8671 8672 8673 |
# File 'lib/models/porcelain.rb', line 8671 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8673 8674 8675 |
# File 'lib/models/porcelain.rb', line 8673 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8675 8676 8677 |
# File 'lib/models/porcelain.rb', line 8675 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8677 8678 8679 |
# File 'lib/models/porcelain.rb', line 8677 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8679 8680 8681 |
# File 'lib/models/porcelain.rb', line 8679 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8681 8682 8683 |
# File 'lib/models/porcelain.rb', line 8681 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8683 8684 8685 |
# File 'lib/models/porcelain.rb', line 8683 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8685 8686 8687 |
# File 'lib/models/porcelain.rb', line 8685 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8687 8688 8689 |
# File 'lib/models/porcelain.rb', line 8687 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8717 8718 8719 8720 8721 8722 8723 |
# File 'lib/models/porcelain.rb', line 8717 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |