Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
# File 'lib/models/porcelain.rb', line 7838

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7814
7815
7816
# File 'lib/models/porcelain.rb', line 7814

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7816
7817
7818
# File 'lib/models/porcelain.rb', line 7816

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7818
7819
7820
# File 'lib/models/porcelain.rb', line 7818

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7820
7821
7822
# File 'lib/models/porcelain.rb', line 7820

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7822
7823
7824
# File 'lib/models/porcelain.rb', line 7822

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7824
7825
7826
# File 'lib/models/porcelain.rb', line 7824

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7826
7827
7828
# File 'lib/models/porcelain.rb', line 7826

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7828
7829
7830
# File 'lib/models/porcelain.rb', line 7828

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7830
7831
7832
# File 'lib/models/porcelain.rb', line 7830

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7832
7833
7834
# File 'lib/models/porcelain.rb', line 7832

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7834
7835
7836
# File 'lib/models/porcelain.rb', line 7834

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7836
7837
7838
# File 'lib/models/porcelain.rb', line 7836

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7866
7867
7868
7869
7870
7871
7872
# File 'lib/models/porcelain.rb', line 7866

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end