Class: SDM::Memcached
- Inherits:
-
Object
- Object
- SDM::Memcached
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached
constructor
A new instance of Memcached.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached
Returns a new instance of Memcached.
7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 7783 7784 7785 7786 7787 7788 7789 7790 |
# File 'lib/models/porcelain.rb', line 7764 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7740 7741 7742 |
# File 'lib/models/porcelain.rb', line 7740 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7742 7743 7744 |
# File 'lib/models/porcelain.rb', line 7742 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7744 7745 7746 |
# File 'lib/models/porcelain.rb', line 7744 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7746 7747 7748 |
# File 'lib/models/porcelain.rb', line 7746 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7748 7749 7750 |
# File 'lib/models/porcelain.rb', line 7748 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7750 7751 7752 |
# File 'lib/models/porcelain.rb', line 7750 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7752 7753 7754 |
# File 'lib/models/porcelain.rb', line 7752 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7754 7755 7756 |
# File 'lib/models/porcelain.rb', line 7754 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7756 7757 7758 |
# File 'lib/models/porcelain.rb', line 7756 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7758 7759 7760 |
# File 'lib/models/porcelain.rb', line 7758 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7760 7761 7762 |
# File 'lib/models/porcelain.rb', line 7760 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7762 7763 7764 |
# File 'lib/models/porcelain.rb', line 7762 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7792 7793 7794 7795 7796 7797 7798 |
# File 'lib/models/porcelain.rb', line 7792 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |