Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
# File 'lib/models/porcelain.rb', line 7614

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7590
7591
7592
# File 'lib/models/porcelain.rb', line 7590

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7592
7593
7594
# File 'lib/models/porcelain.rb', line 7592

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7594
7595
7596
# File 'lib/models/porcelain.rb', line 7594

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7596
7597
7598
# File 'lib/models/porcelain.rb', line 7596

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7598
7599
7600
# File 'lib/models/porcelain.rb', line 7598

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7600
7601
7602
# File 'lib/models/porcelain.rb', line 7600

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7602
7603
7604
# File 'lib/models/porcelain.rb', line 7602

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7604
7605
7606
# File 'lib/models/porcelain.rb', line 7604

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7606
7607
7608
# File 'lib/models/porcelain.rb', line 7606

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7608
7609
7610
# File 'lib/models/porcelain.rb', line 7608

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7610
7611
7612
# File 'lib/models/porcelain.rb', line 7610

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7612
7613
7614
# File 'lib/models/porcelain.rb', line 7612

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7642
7643
7644
7645
7646
7647
7648
# File 'lib/models/porcelain.rb', line 7642

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end