Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



7252
7253
7254
7255
7256
7257
7258
7259
7260
7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
# File 'lib/models/porcelain.rb', line 7252

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7228
7229
7230
# File 'lib/models/porcelain.rb', line 7228

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7230
7231
7232
# File 'lib/models/porcelain.rb', line 7230

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7232
7233
7234
# File 'lib/models/porcelain.rb', line 7232

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7234
7235
7236
# File 'lib/models/porcelain.rb', line 7234

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7236
7237
7238
# File 'lib/models/porcelain.rb', line 7236

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7238
7239
7240
# File 'lib/models/porcelain.rb', line 7238

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7240
7241
7242
# File 'lib/models/porcelain.rb', line 7240

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7242
7243
7244
# File 'lib/models/porcelain.rb', line 7242

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7244
7245
7246
# File 'lib/models/porcelain.rb', line 7244

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7246
7247
7248
# File 'lib/models/porcelain.rb', line 7246

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7248
7249
7250
# File 'lib/models/porcelain.rb', line 7248

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7250
7251
7252
# File 'lib/models/porcelain.rb', line 7250

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7280
7281
7282
7283
7284
7285
7286
# File 'lib/models/porcelain.rb', line 7280

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end