Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
# File 'lib/models/porcelain.rb', line 7003

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6979
6980
6981
# File 'lib/models/porcelain.rb', line 6979

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6981
6982
6983
# File 'lib/models/porcelain.rb', line 6981

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6983
6984
6985
# File 'lib/models/porcelain.rb', line 6983

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6985
6986
6987
# File 'lib/models/porcelain.rb', line 6985

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6987
6988
6989
# File 'lib/models/porcelain.rb', line 6987

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6989
6990
6991
# File 'lib/models/porcelain.rb', line 6989

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6991
6992
6993
# File 'lib/models/porcelain.rb', line 6991

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6993
6994
6995
# File 'lib/models/porcelain.rb', line 6993

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6995
6996
6997
# File 'lib/models/porcelain.rb', line 6995

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6997
6998
6999
# File 'lib/models/porcelain.rb', line 6997

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6999
7000
7001
# File 'lib/models/porcelain.rb', line 6999

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7001
7002
7003
# File 'lib/models/porcelain.rb', line 7001

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7031
7032
7033
7034
7035
7036
7037
# File 'lib/models/porcelain.rb', line 7031

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end