Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



6932
6933
6934
6935
6936
6937
6938
6939
6940
6941
6942
6943
6944
6945
6946
6947
6948
6949
6950
6951
6952
6953
6954
6955
6956
6957
6958
# File 'lib/models/porcelain.rb', line 6932

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6908
6909
6910
# File 'lib/models/porcelain.rb', line 6908

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6910
6911
6912
# File 'lib/models/porcelain.rb', line 6910

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6912
6913
6914
# File 'lib/models/porcelain.rb', line 6912

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6914
6915
6916
# File 'lib/models/porcelain.rb', line 6914

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6916
6917
6918
# File 'lib/models/porcelain.rb', line 6916

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6918
6919
6920
# File 'lib/models/porcelain.rb', line 6918

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6920
6921
6922
# File 'lib/models/porcelain.rb', line 6920

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6922
6923
6924
# File 'lib/models/porcelain.rb', line 6922

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6924
6925
6926
# File 'lib/models/porcelain.rb', line 6924

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6926
6927
6928
# File 'lib/models/porcelain.rb', line 6926

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6928
6929
6930
# File 'lib/models/porcelain.rb', line 6928

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6930
6931
6932
# File 'lib/models/porcelain.rb', line 6930

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6960
6961
6962
6963
6964
6965
6966
# File 'lib/models/porcelain.rb', line 6960

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end