Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



6649
6650
6651
6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
6673
# File 'lib/models/porcelain.rb', line 6649

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6627
6628
6629
# File 'lib/models/porcelain.rb', line 6627

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6629
6630
6631
# File 'lib/models/porcelain.rb', line 6629

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6631
6632
6633
# File 'lib/models/porcelain.rb', line 6631

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6633
6634
6635
# File 'lib/models/porcelain.rb', line 6633

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6635
6636
6637
# File 'lib/models/porcelain.rb', line 6635

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6637
6638
6639
# File 'lib/models/porcelain.rb', line 6637

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6639
6640
6641
# File 'lib/models/porcelain.rb', line 6639

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6641
6642
6643
# File 'lib/models/porcelain.rb', line 6641

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6643
6644
6645
# File 'lib/models/porcelain.rb', line 6643

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6645
6646
6647
# File 'lib/models/porcelain.rb', line 6645

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6647
6648
6649
# File 'lib/models/porcelain.rb', line 6647

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6675
6676
6677
6678
6679
6680
6681
# File 'lib/models/porcelain.rb', line 6675

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end