Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
# File 'lib/models/porcelain.rb', line 5089

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5067
5068
5069
# File 'lib/models/porcelain.rb', line 5067

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5069
5070
5071
# File 'lib/models/porcelain.rb', line 5069

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5071
5072
5073
# File 'lib/models/porcelain.rb', line 5071

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5073
5074
5075
# File 'lib/models/porcelain.rb', line 5073

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5075
5076
5077
# File 'lib/models/porcelain.rb', line 5075

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5077
5078
5079
# File 'lib/models/porcelain.rb', line 5077

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5079
5080
5081
# File 'lib/models/porcelain.rb', line 5079

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5081
5082
5083
# File 'lib/models/porcelain.rb', line 5081

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5083
5084
5085
# File 'lib/models/porcelain.rb', line 5083

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5085
5086
5087
# File 'lib/models/porcelain.rb', line 5085

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5087
5088
5089
# File 'lib/models/porcelain.rb', line 5087

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5115
5116
5117
5118
5119
5120
5121
# File 'lib/models/porcelain.rb', line 5115

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end