Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



4922
4923
4924
4925
4926
4927
4928
4929
4930
4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
# File 'lib/models/porcelain.rb', line 4922

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4900
4901
4902
# File 'lib/models/porcelain.rb', line 4900

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4902
4903
4904
# File 'lib/models/porcelain.rb', line 4902

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4904
4905
4906
# File 'lib/models/porcelain.rb', line 4904

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4906
4907
4908
# File 'lib/models/porcelain.rb', line 4906

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4908
4909
4910
# File 'lib/models/porcelain.rb', line 4908

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4910
4911
4912
# File 'lib/models/porcelain.rb', line 4910

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4912
4913
4914
# File 'lib/models/porcelain.rb', line 4912

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4914
4915
4916
# File 'lib/models/porcelain.rb', line 4914

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4916
4917
4918
# File 'lib/models/porcelain.rb', line 4916

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4918
4919
4920
# File 'lib/models/porcelain.rb', line 4918

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4920
4921
4922
# File 'lib/models/porcelain.rb', line 4920

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4948
4949
4950
4951
4952
4953
4954
# File 'lib/models/porcelain.rb', line 4948

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end