Class: SDM::Memcached
- Inherits:
-
Object
- Object
- SDM::Memcached
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached
constructor
A new instance of Memcached.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached
Returns a new instance of Memcached.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/models/porcelain.rb', line 4762 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4740 4741 4742 |
# File 'lib/models/porcelain.rb', line 4740 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4742 4743 4744 |
# File 'lib/models/porcelain.rb', line 4742 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4744 4745 4746 |
# File 'lib/models/porcelain.rb', line 4744 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4746 4747 4748 |
# File 'lib/models/porcelain.rb', line 4746 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4748 4749 4750 |
# File 'lib/models/porcelain.rb', line 4748 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4750 4751 4752 |
# File 'lib/models/porcelain.rb', line 4750 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4752 4753 4754 |
# File 'lib/models/porcelain.rb', line 4752 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4754 4755 4756 |
# File 'lib/models/porcelain.rb', line 4754 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4756 4757 4758 |
# File 'lib/models/porcelain.rb', line 4756 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4758 4759 4760 |
# File 'lib/models/porcelain.rb', line 4758 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4760 4761 4762 |
# File 'lib/models/porcelain.rb', line 4760 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4788 4789 4790 4791 4792 4793 4794 |
# File 'lib/models/porcelain.rb', line 4788 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |