Class: SDM::Memcached
- Inherits:
-
Object
- Object
- SDM::Memcached
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached
constructor
A new instance of Memcached.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached
Returns a new instance of Memcached.
4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 |
# File 'lib/models/porcelain.rb', line 4592 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4570 4571 4572 |
# File 'lib/models/porcelain.rb', line 4570 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4572 4573 4574 |
# File 'lib/models/porcelain.rb', line 4572 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4574 4575 4576 |
# File 'lib/models/porcelain.rb', line 4574 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4576 4577 4578 |
# File 'lib/models/porcelain.rb', line 4576 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4578 4579 4580 |
# File 'lib/models/porcelain.rb', line 4578 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4580 4581 4582 |
# File 'lib/models/porcelain.rb', line 4580 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4582 4583 4584 |
# File 'lib/models/porcelain.rb', line 4582 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4584 4585 4586 |
# File 'lib/models/porcelain.rb', line 4584 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4586 4587 4588 |
# File 'lib/models/porcelain.rb', line 4586 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4588 4589 4590 |
# File 'lib/models/porcelain.rb', line 4588 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4590 4591 4592 |
# File 'lib/models/porcelain.rb', line 4590 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4618 4619 4620 4621 4622 4623 4624 |
# File 'lib/models/porcelain.rb', line 4618 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |