Class: SDM::Memcached
- Inherits:
-
Object
- Object
- SDM::Memcached
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Memcached
constructor
A new instance of Memcached.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Memcached
Returns a new instance of Memcached.
4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 |
# File 'lib/models/porcelain.rb', line 4096 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4076 4077 4078 |
# File 'lib/models/porcelain.rb', line 4076 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4078 4079 4080 |
# File 'lib/models/porcelain.rb', line 4078 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4080 4081 4082 |
# File 'lib/models/porcelain.rb', line 4080 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4082 4083 4084 |
# File 'lib/models/porcelain.rb', line 4082 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4084 4085 4086 |
# File 'lib/models/porcelain.rb', line 4084 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4086 4087 4088 |
# File 'lib/models/porcelain.rb', line 4086 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4088 4089 4090 |
# File 'lib/models/porcelain.rb', line 4088 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4090 4091 4092 |
# File 'lib/models/porcelain.rb', line 4090 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4092 4093 4094 |
# File 'lib/models/porcelain.rb', line 4092 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4094 4095 4096 |
# File 'lib/models/porcelain.rb', line 4094 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4120 4121 4122 4123 4124 4125 4126 |
# File 'lib/models/porcelain.rb', line 4120 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |