Class: SDM::Memcached
- Inherits:
-
Object
- Object
- SDM::Memcached
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Memcached
constructor
A new instance of Memcached.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Memcached
Returns a new instance of Memcached.
4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/models/porcelain.rb', line 4250 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4232 4233 4234 |
# File 'lib/models/porcelain.rb', line 4232 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4234 4235 4236 |
# File 'lib/models/porcelain.rb', line 4234 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4236 4237 4238 |
# File 'lib/models/porcelain.rb', line 4236 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4238 4239 4240 |
# File 'lib/models/porcelain.rb', line 4238 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4240 4241 4242 |
# File 'lib/models/porcelain.rb', line 4240 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4242 4243 4244 |
# File 'lib/models/porcelain.rb', line 4242 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4244 4245 4246 |
# File 'lib/models/porcelain.rb', line 4244 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4246 4247 4248 |
# File 'lib/models/porcelain.rb', line 4246 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4248 4249 4250 |
# File 'lib/models/porcelain.rb', line 4248 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/models/porcelain.rb', line 4290 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |