Class: SDM::Memcached

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Memcached

Returns a new instance of Memcached.



11548
11549
11550
11551
11552
11553
11554
11555
11556
11557
11558
11559
11560
11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
11572
11573
11574
# File 'lib/models/porcelain.rb', line 11548

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11524
11525
11526
# File 'lib/models/porcelain.rb', line 11524

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11526
11527
11528
# File 'lib/models/porcelain.rb', line 11526

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11528
11529
11530
# File 'lib/models/porcelain.rb', line 11528

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11530
11531
11532
# File 'lib/models/porcelain.rb', line 11530

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11532
11533
11534
# File 'lib/models/porcelain.rb', line 11532

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11534
11535
11536
# File 'lib/models/porcelain.rb', line 11534

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11536
11537
11538
# File 'lib/models/porcelain.rb', line 11536

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11538
11539
11540
# File 'lib/models/porcelain.rb', line 11538

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11540
11541
11542
# File 'lib/models/porcelain.rb', line 11540

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11542
11543
11544
# File 'lib/models/porcelain.rb', line 11542

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11544
11545
11546
# File 'lib/models/porcelain.rb', line 11544

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11546
11547
11548
# File 'lib/models/porcelain.rb', line 11546

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11576
11577
11578
11579
11580
11581
11582
# File 'lib/models/porcelain.rb', line 11576

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end