Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



11641
11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
11658
11659
11660
11661
11662
11663
11664
11665
11666
11667
11668
11669
11670
11671
11672
11673
11674
11675
11676
11677
# File 'lib/models/porcelain.rb', line 11641

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11607
11608
11609
# File 'lib/models/porcelain.rb', line 11607

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11609
11610
11611
# File 'lib/models/porcelain.rb', line 11609

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11611
11612
11613
# File 'lib/models/porcelain.rb', line 11611

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11613
11614
11615
# File 'lib/models/porcelain.rb', line 11613

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11615
11616
11617
# File 'lib/models/porcelain.rb', line 11615

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11617
11618
11619
# File 'lib/models/porcelain.rb', line 11617

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11619
11620
11621
# File 'lib/models/porcelain.rb', line 11619

def name
  @name
end

#passwordObject

The password to authenticate with.



11621
11622
11623
# File 'lib/models/porcelain.rb', line 11621

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11623
11624
11625
# File 'lib/models/porcelain.rb', line 11623

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11625
11626
11627
# File 'lib/models/porcelain.rb', line 11625

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11627
11628
11629
# File 'lib/models/porcelain.rb', line 11627

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11629
11630
11631
# File 'lib/models/porcelain.rb', line 11629

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11631
11632
11633
# File 'lib/models/porcelain.rb', line 11631

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11633
11634
11635
# File 'lib/models/porcelain.rb', line 11633

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11635
11636
11637
# File 'lib/models/porcelain.rb', line 11635

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11637
11638
11639
# File 'lib/models/porcelain.rb', line 11637

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11639
11640
11641
# File 'lib/models/porcelain.rb', line 11639

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11679
11680
11681
11682
11683
11684
11685
# File 'lib/models/porcelain.rb', line 11679

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end