Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



10257
10258
10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
10281
10282
10283
10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
# File 'lib/models/porcelain.rb', line 10257

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10223
10224
10225
# File 'lib/models/porcelain.rb', line 10223

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



10225
10226
10227
# File 'lib/models/porcelain.rb', line 10225

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10227
10228
10229
# File 'lib/models/porcelain.rb', line 10227

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10229
10230
10231
# File 'lib/models/porcelain.rb', line 10229

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10231
10232
10233
# File 'lib/models/porcelain.rb', line 10231

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10233
10234
10235
# File 'lib/models/porcelain.rb', line 10233

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10235
10236
10237
# File 'lib/models/porcelain.rb', line 10235

def name
  @name
end

#passwordObject

The password to authenticate with.



10237
10238
10239
# File 'lib/models/porcelain.rb', line 10237

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10239
10240
10241
# File 'lib/models/porcelain.rb', line 10239

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10241
10242
10243
# File 'lib/models/porcelain.rb', line 10241

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10243
10244
10245
# File 'lib/models/porcelain.rb', line 10243

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



10245
10246
10247
# File 'lib/models/porcelain.rb', line 10245

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10247
10248
10249
# File 'lib/models/porcelain.rb', line 10247

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10249
10250
10251
# File 'lib/models/porcelain.rb', line 10249

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10251
10252
10253
# File 'lib/models/porcelain.rb', line 10251

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



10253
10254
10255
# File 'lib/models/porcelain.rb', line 10253

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



10255
10256
10257
# File 'lib/models/porcelain.rb', line 10255

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10295
10296
10297
10298
10299
10300
10301
# File 'lib/models/porcelain.rb', line 10295

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end