Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



8909
8910
8911
8912
8913
8914
8915
8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
8933
8934
8935
8936
8937
8938
8939
8940
8941
8942
8943
8944
8945
# File 'lib/models/porcelain.rb', line 8909

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8875
8876
8877
# File 'lib/models/porcelain.rb', line 8875

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



8877
8878
8879
# File 'lib/models/porcelain.rb', line 8877

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8879
8880
8881
# File 'lib/models/porcelain.rb', line 8879

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8881
8882
8883
# File 'lib/models/porcelain.rb', line 8881

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8883
8884
8885
# File 'lib/models/porcelain.rb', line 8883

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8885
8886
8887
# File 'lib/models/porcelain.rb', line 8885

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8887
8888
8889
# File 'lib/models/porcelain.rb', line 8887

def name
  @name
end

#passwordObject

The password to authenticate with.



8889
8890
8891
# File 'lib/models/porcelain.rb', line 8889

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8891
8892
8893
# File 'lib/models/porcelain.rb', line 8891

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8893
8894
8895
# File 'lib/models/porcelain.rb', line 8893

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8895
8896
8897
# File 'lib/models/porcelain.rb', line 8895

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8897
8898
8899
# File 'lib/models/porcelain.rb', line 8897

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8899
8900
8901
# File 'lib/models/porcelain.rb', line 8899

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8901
8902
8903
# File 'lib/models/porcelain.rb', line 8901

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8903
8904
8905
# File 'lib/models/porcelain.rb', line 8903

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8905
8906
8907
# File 'lib/models/porcelain.rb', line 8905

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8907
8908
8909
# File 'lib/models/porcelain.rb', line 8907

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8947
8948
8949
8950
8951
8952
8953
# File 'lib/models/porcelain.rb', line 8947

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end