Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
# File 'lib/models/porcelain.rb', line 7911

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7877
7878
7879
# File 'lib/models/porcelain.rb', line 7877

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7879
7880
7881
# File 'lib/models/porcelain.rb', line 7879

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7881
7882
7883
# File 'lib/models/porcelain.rb', line 7881

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7883
7884
7885
# File 'lib/models/porcelain.rb', line 7883

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7885
7886
7887
# File 'lib/models/porcelain.rb', line 7885

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7887
7888
7889
# File 'lib/models/porcelain.rb', line 7887

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7889
7890
7891
# File 'lib/models/porcelain.rb', line 7889

def name
  @name
end

#passwordObject

The password to authenticate with.



7891
7892
7893
# File 'lib/models/porcelain.rb', line 7891

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7893
7894
7895
# File 'lib/models/porcelain.rb', line 7893

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7895
7896
7897
# File 'lib/models/porcelain.rb', line 7895

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7897
7898
7899
# File 'lib/models/porcelain.rb', line 7897

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7899
7900
7901
# File 'lib/models/porcelain.rb', line 7899

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7901
7902
7903
# File 'lib/models/porcelain.rb', line 7901

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7903
7904
7905
# File 'lib/models/porcelain.rb', line 7903

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7905
7906
7907
# File 'lib/models/porcelain.rb', line 7905

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7907
7908
7909
# File 'lib/models/porcelain.rb', line 7907

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7909
7910
7911
# File 'lib/models/porcelain.rb', line 7909

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7949
7950
7951
7952
7953
7954
7955
# File 'lib/models/porcelain.rb', line 7949

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end