Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



7686
7687
7688
7689
7690
7691
7692
7693
7694
7695
7696
7697
7698
7699
7700
7701
7702
7703
7704
7705
7706
7707
7708
7709
7710
7711
7712
7713
7714
7715
7716
7717
7718
7719
7720
7721
7722
# File 'lib/models/porcelain.rb', line 7686

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7652
7653
7654
# File 'lib/models/porcelain.rb', line 7652

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7654
7655
7656
# File 'lib/models/porcelain.rb', line 7654

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7656
7657
7658
# File 'lib/models/porcelain.rb', line 7656

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7658
7659
7660
# File 'lib/models/porcelain.rb', line 7658

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7660
7661
7662
# File 'lib/models/porcelain.rb', line 7660

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7662
7663
7664
# File 'lib/models/porcelain.rb', line 7662

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7664
7665
7666
# File 'lib/models/porcelain.rb', line 7664

def name
  @name
end

#passwordObject

The password to authenticate with.



7666
7667
7668
# File 'lib/models/porcelain.rb', line 7666

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7668
7669
7670
# File 'lib/models/porcelain.rb', line 7668

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7670
7671
7672
# File 'lib/models/porcelain.rb', line 7670

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7672
7673
7674
# File 'lib/models/porcelain.rb', line 7672

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7674
7675
7676
# File 'lib/models/porcelain.rb', line 7674

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7676
7677
7678
# File 'lib/models/porcelain.rb', line 7676

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7678
7679
7680
# File 'lib/models/porcelain.rb', line 7678

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7680
7681
7682
# File 'lib/models/porcelain.rb', line 7680

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7682
7683
7684
# File 'lib/models/porcelain.rb', line 7682

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7684
7685
7686
# File 'lib/models/porcelain.rb', line 7684

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7724
7725
7726
7727
7728
7729
7730
# File 'lib/models/porcelain.rb', line 7724

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end