Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



7323
7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
# File 'lib/models/porcelain.rb', line 7323

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7289
7290
7291
# File 'lib/models/porcelain.rb', line 7289

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7291
7292
7293
# File 'lib/models/porcelain.rb', line 7291

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7293
7294
7295
# File 'lib/models/porcelain.rb', line 7293

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7295
7296
7297
# File 'lib/models/porcelain.rb', line 7295

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7297
7298
7299
# File 'lib/models/porcelain.rb', line 7297

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7299
7300
7301
# File 'lib/models/porcelain.rb', line 7299

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7301
7302
7303
# File 'lib/models/porcelain.rb', line 7301

def name
  @name
end

#passwordObject

The password to authenticate with.



7303
7304
7305
# File 'lib/models/porcelain.rb', line 7303

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7305
7306
7307
# File 'lib/models/porcelain.rb', line 7305

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7307
7308
7309
# File 'lib/models/porcelain.rb', line 7307

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7309
7310
7311
# File 'lib/models/porcelain.rb', line 7309

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7311
7312
7313
# File 'lib/models/porcelain.rb', line 7311

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7313
7314
7315
# File 'lib/models/porcelain.rb', line 7313

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7315
7316
7317
# File 'lib/models/porcelain.rb', line 7315

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7317
7318
7319
# File 'lib/models/porcelain.rb', line 7317

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7319
7320
7321
# File 'lib/models/porcelain.rb', line 7319

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7321
7322
7323
# File 'lib/models/porcelain.rb', line 7321

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7361
7362
7363
7364
7365
7366
7367
# File 'lib/models/porcelain.rb', line 7361

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end