Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
# File 'lib/models/porcelain.rb', line 7005

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6971
6972
6973
# File 'lib/models/porcelain.rb', line 6971

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



6973
6974
6975
# File 'lib/models/porcelain.rb', line 6973

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6975
6976
6977
# File 'lib/models/porcelain.rb', line 6975

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6977
6978
6979
# File 'lib/models/porcelain.rb', line 6977

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6979
6980
6981
# File 'lib/models/porcelain.rb', line 6979

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6981
6982
6983
# File 'lib/models/porcelain.rb', line 6981

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6983
6984
6985
# File 'lib/models/porcelain.rb', line 6983

def name
  @name
end

#passwordObject

The password to authenticate with.



6985
6986
6987
# File 'lib/models/porcelain.rb', line 6985

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6987
6988
6989
# File 'lib/models/porcelain.rb', line 6987

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6989
6990
6991
# File 'lib/models/porcelain.rb', line 6989

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



6991
6992
6993
# File 'lib/models/porcelain.rb', line 6991

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



6993
6994
6995
# File 'lib/models/porcelain.rb', line 6993

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6995
6996
6997
# File 'lib/models/porcelain.rb', line 6995

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6997
6998
6999
# File 'lib/models/porcelain.rb', line 6997

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6999
7000
7001
# File 'lib/models/porcelain.rb', line 6999

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7001
7002
7003
# File 'lib/models/porcelain.rb', line 7001

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7003
7004
7005
# File 'lib/models/porcelain.rb', line 7003

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7043
7044
7045
7046
7047
7048
7049
# File 'lib/models/porcelain.rb', line 7043

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end