Class: SDM::Memsql
- Inherits:
-
Object
- Object
- SDM::Memsql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql
constructor
A new instance of Memsql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql
Returns a new instance of Memsql.
6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 6742 6743 6744 6745 6746 6747 6748 6749 6750 6751 6752 |
# File 'lib/models/porcelain.rb', line 6718 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6686 6687 6688 |
# File 'lib/models/porcelain.rb', line 6686 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests.
6688 6689 6690 |
# File 'lib/models/porcelain.rb', line 6688 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6690 6691 6692 |
# File 'lib/models/porcelain.rb', line 6690 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6692 6693 6694 |
# File 'lib/models/porcelain.rb', line 6692 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6694 6695 6696 |
# File 'lib/models/porcelain.rb', line 6694 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6696 6697 6698 |
# File 'lib/models/porcelain.rb', line 6696 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6698 6699 6700 |
# File 'lib/models/porcelain.rb', line 6698 def name @name end |
#password ⇒ Object
The password to authenticate with.
6700 6701 6702 |
# File 'lib/models/porcelain.rb', line 6700 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6702 6703 6704 |
# File 'lib/models/porcelain.rb', line 6702 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6704 6705 6706 |
# File 'lib/models/porcelain.rb', line 6704 def port_override @port_override end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
6706 6707 6708 |
# File 'lib/models/porcelain.rb', line 6706 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6708 6709 6710 |
# File 'lib/models/porcelain.rb', line 6708 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6710 6711 6712 |
# File 'lib/models/porcelain.rb', line 6710 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6712 6713 6714 |
# File 'lib/models/porcelain.rb', line 6712 def @tags end |
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address
6714 6715 6716 |
# File 'lib/models/porcelain.rb', line 6714 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
The username to authenticate with.
6716 6717 6718 |
# File 'lib/models/porcelain.rb', line 6716 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/models/porcelain.rb', line 6754 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |