Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



4986
4987
4988
4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
5013
5014
5015
5016
5017
5018
5019
5020
# File 'lib/models/porcelain.rb', line 4986

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



4954
4955
4956
# File 'lib/models/porcelain.rb', line 4954

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



4956
4957
4958
# File 'lib/models/porcelain.rb', line 4956

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4958
4959
4960
# File 'lib/models/porcelain.rb', line 4958

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4960
4961
4962
# File 'lib/models/porcelain.rb', line 4960

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



4962
4963
4964
# File 'lib/models/porcelain.rb', line 4962

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4964
4965
4966
# File 'lib/models/porcelain.rb', line 4964

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4966
4967
4968
# File 'lib/models/porcelain.rb', line 4966

def name
  @name
end

#passwordObject

The password to authenticate with.



4968
4969
4970
# File 'lib/models/porcelain.rb', line 4968

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



4970
4971
4972
# File 'lib/models/porcelain.rb', line 4970

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



4972
4973
4974
# File 'lib/models/porcelain.rb', line 4972

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



4974
4975
4976
# File 'lib/models/porcelain.rb', line 4974

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4976
4977
4978
# File 'lib/models/porcelain.rb', line 4976

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4978
4979
4980
# File 'lib/models/porcelain.rb', line 4978

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4980
4981
4982
# File 'lib/models/porcelain.rb', line 4980

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



4982
4983
4984
# File 'lib/models/porcelain.rb', line 4982

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



4984
4985
4986
# File 'lib/models/porcelain.rb', line 4984

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5022
5023
5024
5025
5026
5027
5028
# File 'lib/models/porcelain.rb', line 5022

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end