Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
# File 'lib/models/porcelain.rb', line 4871

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4839
4840
4841
# File 'lib/models/porcelain.rb', line 4839

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4841
4842
4843
# File 'lib/models/porcelain.rb', line 4841

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4843
4844
4845
# File 'lib/models/porcelain.rb', line 4843

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4845
4846
4847
# File 'lib/models/porcelain.rb', line 4845

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4847
4848
4849
# File 'lib/models/porcelain.rb', line 4847

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4849
4850
4851
# File 'lib/models/porcelain.rb', line 4849

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4851
4852
4853
# File 'lib/models/porcelain.rb', line 4851

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4853
4854
4855
# File 'lib/models/porcelain.rb', line 4853

def password
  @password
end

#portObject

Returns the value of attribute port.



4855
4856
4857
# File 'lib/models/porcelain.rb', line 4855

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4857
4858
4859
# File 'lib/models/porcelain.rb', line 4857

def port_override
  @port_override
end

#require_native_authObject

Returns the value of attribute require_native_auth.



4859
4860
4861
# File 'lib/models/porcelain.rb', line 4859

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4861
4862
4863
# File 'lib/models/porcelain.rb', line 4861

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



4863
4864
4865
# File 'lib/models/porcelain.rb', line 4863

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



4865
4866
4867
# File 'lib/models/porcelain.rb', line 4865

def tags
  @tags
end

#use_azure_single_server_usernamesObject

Returns the value of attribute use_azure_single_server_usernames.



4867
4868
4869
# File 'lib/models/porcelain.rb', line 4867

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

Returns the value of attribute username.



4869
4870
4871
# File 'lib/models/porcelain.rb', line 4869

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4907
4908
4909
4910
4911
4912
4913
# File 'lib/models/porcelain.rb', line 4907

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end