Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



4495
4496
4497
4498
4499
4500
4501
4502
4503
4504
4505
4506
4507
4508
4509
4510
4511
4512
4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
# File 'lib/models/porcelain.rb', line 4495

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4469
4470
4471
# File 'lib/models/porcelain.rb', line 4469

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4471
4472
4473
# File 'lib/models/porcelain.rb', line 4471

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4473
4474
4475
# File 'lib/models/porcelain.rb', line 4473

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4475
4476
4477
# File 'lib/models/porcelain.rb', line 4475

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4477
4478
4479
# File 'lib/models/porcelain.rb', line 4477

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4479
4480
4481
# File 'lib/models/porcelain.rb', line 4479

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4481
4482
4483
# File 'lib/models/porcelain.rb', line 4481

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4483
4484
4485
# File 'lib/models/porcelain.rb', line 4483

def password
  @password
end

#portObject

Returns the value of attribute port.



4485
4486
4487
# File 'lib/models/porcelain.rb', line 4485

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4487
4488
4489
# File 'lib/models/porcelain.rb', line 4487

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4489
4490
4491
# File 'lib/models/porcelain.rb', line 4489

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4491
4492
4493
# File 'lib/models/porcelain.rb', line 4491

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4493
4494
4495
# File 'lib/models/porcelain.rb', line 4493

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4525
4526
4527
4528
4529
4530
4531
# File 'lib/models/porcelain.rb', line 4525

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end