Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
# File 'lib/models/porcelain.rb', line 4157

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4131
4132
4133
# File 'lib/models/porcelain.rb', line 4131

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4133
4134
4135
# File 'lib/models/porcelain.rb', line 4133

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4135
4136
4137
# File 'lib/models/porcelain.rb', line 4135

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4137
4138
4139
# File 'lib/models/porcelain.rb', line 4137

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4139
4140
4141
# File 'lib/models/porcelain.rb', line 4139

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4141
4142
4143
# File 'lib/models/porcelain.rb', line 4141

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4143
4144
4145
# File 'lib/models/porcelain.rb', line 4143

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4145
4146
4147
# File 'lib/models/porcelain.rb', line 4145

def password
  @password
end

#portObject

Returns the value of attribute port.



4147
4148
4149
# File 'lib/models/porcelain.rb', line 4147

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4149
4150
4151
# File 'lib/models/porcelain.rb', line 4149

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4151
4152
4153
# File 'lib/models/porcelain.rb', line 4151

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4153
4154
4155
# File 'lib/models/porcelain.rb', line 4153

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4155
4156
4157
# File 'lib/models/porcelain.rb', line 4155

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4187
4188
4189
4190
4191
4192
4193
# File 'lib/models/porcelain.rb', line 4187

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end