Class: SDM::Memsql
- Inherits:
-
Object
- Object
- SDM::Memsql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Memsql
constructor
A new instance of Memsql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Memsql
Returns a new instance of Memsql.
4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 4168 4169 4170 4171 4172 4173 4174 4175 4176 4177 4178 4179 4180 4181 4182 4183 4184 4185 4186 |
# File 'lib/models/porcelain.rb', line 4158 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4132 4133 4134 |
# File 'lib/models/porcelain.rb', line 4132 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4134 4135 4136 |
# File 'lib/models/porcelain.rb', line 4134 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4136 4137 4138 |
# File 'lib/models/porcelain.rb', line 4136 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4138 4139 4140 |
# File 'lib/models/porcelain.rb', line 4138 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4140 4141 4142 |
# File 'lib/models/porcelain.rb', line 4140 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4142 4143 4144 |
# File 'lib/models/porcelain.rb', line 4142 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4144 4145 4146 |
# File 'lib/models/porcelain.rb', line 4144 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4146 4147 4148 |
# File 'lib/models/porcelain.rb', line 4146 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4148 4149 4150 |
# File 'lib/models/porcelain.rb', line 4148 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4150 4151 4152 |
# File 'lib/models/porcelain.rb', line 4150 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4152 4153 4154 |
# File 'lib/models/porcelain.rb', line 4152 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4154 4155 4156 |
# File 'lib/models/porcelain.rb', line 4154 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4156 4157 4158 |
# File 'lib/models/porcelain.rb', line 4156 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4188 4189 4190 4191 4192 4193 4194 |
# File 'lib/models/porcelain.rb', line 4188 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |