Class: SDM::Memsql
- Inherits:
-
Object
- Object
- SDM::Memsql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Memsql
constructor
A new instance of Memsql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Memsql
Returns a new instance of Memsql.
4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/models/porcelain.rb', line 4050 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4024 4025 4026 |
# File 'lib/models/porcelain.rb', line 4024 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4026 4027 4028 |
# File 'lib/models/porcelain.rb', line 4026 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4028 4029 4030 |
# File 'lib/models/porcelain.rb', line 4028 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4030 4031 4032 |
# File 'lib/models/porcelain.rb', line 4030 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4032 4033 4034 |
# File 'lib/models/porcelain.rb', line 4032 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4034 4035 4036 |
# File 'lib/models/porcelain.rb', line 4034 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4036 4037 4038 |
# File 'lib/models/porcelain.rb', line 4036 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4038 4039 4040 |
# File 'lib/models/porcelain.rb', line 4038 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4040 4041 4042 |
# File 'lib/models/porcelain.rb', line 4040 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4042 4043 4044 |
# File 'lib/models/porcelain.rb', line 4042 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4044 4045 4046 |
# File 'lib/models/porcelain.rb', line 4044 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4046 4047 4048 |
# File 'lib/models/porcelain.rb', line 4046 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4048 4049 4050 |
# File 'lib/models/porcelain.rb', line 4048 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4080 4081 4082 4083 4084 4085 4086 |
# File 'lib/models/porcelain.rb', line 4080 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |