Class: SDM::Memsql
- Inherits:
-
Object
- Object
- SDM::Memsql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Memsql
constructor
A new instance of Memsql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Memsql
Returns a new instance of Memsql.
4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 |
# File 'lib/models/porcelain.rb', line 4324 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
4300 4301 4302 |
# File 'lib/models/porcelain.rb', line 4300 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4302 4303 4304 |
# File 'lib/models/porcelain.rb', line 4302 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4304 4305 4306 |
# File 'lib/models/porcelain.rb', line 4304 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4306 4307 4308 |
# File 'lib/models/porcelain.rb', line 4306 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4308 4309 4310 |
# File 'lib/models/porcelain.rb', line 4308 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4310 4311 4312 |
# File 'lib/models/porcelain.rb', line 4310 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4312 4313 4314 |
# File 'lib/models/porcelain.rb', line 4312 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4314 4315 4316 |
# File 'lib/models/porcelain.rb', line 4314 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4316 4317 4318 |
# File 'lib/models/porcelain.rb', line 4316 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4318 4319 4320 |
# File 'lib/models/porcelain.rb', line 4318 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4320 4321 4322 |
# File 'lib/models/porcelain.rb', line 4320 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4322 4323 4324 |
# File 'lib/models/porcelain.rb', line 4322 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/models/porcelain.rb', line 4376 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |