Class: SDM::Memsql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Memsql

Returns a new instance of Memsql.



11913
11914
11915
11916
11917
11918
11919
11920
11921
11922
11923
11924
11925
11926
11927
11928
11929
11930
11931
11932
11933
11934
11935
11936
11937
11938
11939
11940
11941
11942
11943
11944
11945
11946
11947
11948
11949
# File 'lib/models/porcelain.rb', line 11913

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11879
11880
11881
# File 'lib/models/porcelain.rb', line 11879

def bind_interface
  @bind_interface
end

#database ⇒ Object

The database for healthchecks. Does not affect client requests.



11881
11882
11883
# File 'lib/models/porcelain.rb', line 11881

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



11883
11884
11885
# File 'lib/models/porcelain.rb', line 11883

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



11885
11886
11887
# File 'lib/models/porcelain.rb', line 11885

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



11887
11888
11889
# File 'lib/models/porcelain.rb', line 11887

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



11889
11890
11891
# File 'lib/models/porcelain.rb', line 11889

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



11891
11892
11893
# File 'lib/models/porcelain.rb', line 11891

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



11893
11894
11895
# File 'lib/models/porcelain.rb', line 11893

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



11895
11896
11897
# File 'lib/models/porcelain.rb', line 11895

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11897
11898
11899
# File 'lib/models/porcelain.rb', line 11897

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



11899
11900
11901
# File 'lib/models/porcelain.rb', line 11899

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_auth ⇒ Object

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11901
11902
11903
# File 'lib/models/porcelain.rb', line 11901

def require_native_auth
  @require_native_auth
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



11903
11904
11905
# File 'lib/models/porcelain.rb', line 11903

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11905
11906
11907
# File 'lib/models/porcelain.rb', line 11905

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



11907
11908
11909
# File 'lib/models/porcelain.rb', line 11907

def tags
  @tags
end

#use_azure_single_server_usernames ⇒ Object

If true, appends the hostname to the username when hitting a database.azure.com address



11909
11910
11911
# File 'lib/models/porcelain.rb', line 11909

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#username ⇒ Object

The username to authenticate with.



11911
11912
11913
# File 'lib/models/porcelain.rb', line 11911

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11951
11952
11953
11954
11955
11956
11957
# File 'lib/models/porcelain.rb', line 11951

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end