Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to use for IAM (MONGODB-AWS) authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
11936 11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 11962 11963 11964 11965 11966 11967 11968 11969 11970 11971 11972 |
# File 'lib/models/porcelain.rb', line 11936 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
11902 11903 11904 |
# File 'lib/models/porcelain.rb', line 11902 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
11904 11905 11906 |
# File 'lib/models/porcelain.rb', line 11904 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11906 11907 11908 |
# File 'lib/models/porcelain.rb', line 11906 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11908 11909 11910 |
# File 'lib/models/porcelain.rb', line 11908 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11910 11911 11912 |
# File 'lib/models/porcelain.rb', line 11910 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11912 11913 11914 |
# File 'lib/models/porcelain.rb', line 11912 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11914 11915 11916 |
# File 'lib/models/porcelain.rb', line 11914 def name @name end |
#password ⇒ Object
The password to authenticate with.
11916 11917 11918 |
# File 'lib/models/porcelain.rb', line 11916 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11918 11919 11920 |
# File 'lib/models/porcelain.rb', line 11918 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
11920 11921 11922 |
# File 'lib/models/porcelain.rb', line 11920 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11922 11923 11924 |
# File 'lib/models/porcelain.rb', line 11922 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to use for IAM (MONGODB-AWS) authentication.
11924 11925 11926 |
# File 'lib/models/porcelain.rb', line 11924 def region @region end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11926 11927 11928 |
# File 'lib/models/porcelain.rb', line 11926 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
11928 11929 11930 |
# File 'lib/models/porcelain.rb', line 11928 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11930 11931 11932 |
# File 'lib/models/porcelain.rb', line 11930 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
11932 11933 11934 |
# File 'lib/models/porcelain.rb', line 11932 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
11934 11935 11936 |
# File 'lib/models/porcelain.rb', line 11934 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11974 11975 11976 11977 11978 11979 11980 |
# File 'lib/models/porcelain.rb', line 11974 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |