Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
11829
11830
11831
11832
11833
11834
11835
11836
11837
11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
11848
11849
11850
11851
11852
# File 'lib/models/porcelain.rb', line 11818

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11786
11787
11788
# File 'lib/models/porcelain.rb', line 11786

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11788
11789
11790
# File 'lib/models/porcelain.rb', line 11788

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11790
11791
11792
# File 'lib/models/porcelain.rb', line 11790

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11792
11793
11794
# File 'lib/models/porcelain.rb', line 11792

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11794
11795
11796
# File 'lib/models/porcelain.rb', line 11794

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11796
11797
11798
# File 'lib/models/porcelain.rb', line 11796

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11798
11799
11800
# File 'lib/models/porcelain.rb', line 11798

def name
  @name
end

#passwordObject

The password to authenticate with.



11800
11801
11802
# File 'lib/models/porcelain.rb', line 11800

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11802
11803
11804
# File 'lib/models/porcelain.rb', line 11802

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11804
11805
11806
# File 'lib/models/porcelain.rb', line 11804

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11806
11807
11808
# File 'lib/models/porcelain.rb', line 11806

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11808
11809
11810
# File 'lib/models/porcelain.rb', line 11808

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11810
11811
11812
# File 'lib/models/porcelain.rb', line 11810

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11812
11813
11814
# File 'lib/models/porcelain.rb', line 11812

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11814
11815
11816
# File 'lib/models/porcelain.rb', line 11814

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11816
11817
11818
# File 'lib/models/porcelain.rb', line 11816

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11854
11855
11856
11857
11858
11859
11860
# File 'lib/models/porcelain.rb', line 11854

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end