Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



11034
11035
11036
11037
11038
11039
11040
11041
11042
11043
11044
11045
11046
11047
11048
11049
11050
11051
11052
11053
11054
11055
11056
11057
11058
11059
11060
11061
11062
11063
11064
11065
11066
11067
11068
# File 'lib/models/porcelain.rb', line 11034

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11002
11003
11004
# File 'lib/models/porcelain.rb', line 11002

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11004
11005
11006
# File 'lib/models/porcelain.rb', line 11004

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11006
11007
11008
# File 'lib/models/porcelain.rb', line 11006

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11008
11009
11010
# File 'lib/models/porcelain.rb', line 11008

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11010
11011
11012
# File 'lib/models/porcelain.rb', line 11010

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11012
11013
11014
# File 'lib/models/porcelain.rb', line 11012

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11014
11015
11016
# File 'lib/models/porcelain.rb', line 11014

def name
  @name
end

#passwordObject

The password to authenticate with.



11016
11017
11018
# File 'lib/models/porcelain.rb', line 11016

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11018
11019
11020
# File 'lib/models/porcelain.rb', line 11018

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11020
11021
11022
# File 'lib/models/porcelain.rb', line 11020

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11022
11023
11024
# File 'lib/models/porcelain.rb', line 11022

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11024
11025
11026
# File 'lib/models/porcelain.rb', line 11024

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11026
11027
11028
# File 'lib/models/porcelain.rb', line 11026

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11028
11029
11030
# File 'lib/models/porcelain.rb', line 11028

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11030
11031
11032
# File 'lib/models/porcelain.rb', line 11030

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11032
11033
11034
# File 'lib/models/porcelain.rb', line 11032

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11070
11071
11072
11073
11074
11075
11076
# File 'lib/models/porcelain.rb', line 11070

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end