Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



10338
10339
10340
10341
10342
10343
10344
10345
10346
10347
10348
10349
10350
10351
10352
10353
10354
10355
10356
10357
10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
# File 'lib/models/porcelain.rb', line 10338

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



10306
10307
10308
# File 'lib/models/porcelain.rb', line 10306

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10308
10309
10310
# File 'lib/models/porcelain.rb', line 10308

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10310
10311
10312
# File 'lib/models/porcelain.rb', line 10310

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10312
10313
10314
# File 'lib/models/porcelain.rb', line 10312

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10314
10315
10316
# File 'lib/models/porcelain.rb', line 10314

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10316
10317
10318
# File 'lib/models/porcelain.rb', line 10316

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10318
10319
10320
# File 'lib/models/porcelain.rb', line 10318

def name
  @name
end

#passwordObject

The password to authenticate with.



10320
10321
10322
# File 'lib/models/porcelain.rb', line 10320

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10322
10323
10324
# File 'lib/models/porcelain.rb', line 10322

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10324
10325
10326
# File 'lib/models/porcelain.rb', line 10324

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10326
10327
10328
# File 'lib/models/porcelain.rb', line 10326

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10328
10329
10330
# File 'lib/models/porcelain.rb', line 10328

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10330
10331
10332
# File 'lib/models/porcelain.rb', line 10330

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10332
10333
10334
# File 'lib/models/porcelain.rb', line 10332

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



10334
10335
10336
# File 'lib/models/porcelain.rb', line 10334

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



10336
10337
10338
# File 'lib/models/porcelain.rb', line 10336

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10374
10375
10376
10377
10378
10379
10380
# File 'lib/models/porcelain.rb', line 10374

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end