Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
9162 9163 9164 9165 9166 9167 9168 9169 9170 9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 9195 9196 |
# File 'lib/models/porcelain.rb', line 9162 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
9130 9131 9132 |
# File 'lib/models/porcelain.rb', line 9130 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9132 9133 9134 |
# File 'lib/models/porcelain.rb', line 9132 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9134 9135 9136 |
# File 'lib/models/porcelain.rb', line 9134 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9136 9137 9138 |
# File 'lib/models/porcelain.rb', line 9136 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9138 9139 9140 |
# File 'lib/models/porcelain.rb', line 9138 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9140 9141 9142 |
# File 'lib/models/porcelain.rb', line 9140 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9142 9143 9144 |
# File 'lib/models/porcelain.rb', line 9142 def name @name end |
#password ⇒ Object
The password to authenticate with.
9144 9145 9146 |
# File 'lib/models/porcelain.rb', line 9144 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9146 9147 9148 |
# File 'lib/models/porcelain.rb', line 9146 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9148 9149 9150 |
# File 'lib/models/porcelain.rb', line 9148 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9150 9151 9152 |
# File 'lib/models/porcelain.rb', line 9150 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9152 9153 9154 |
# File 'lib/models/porcelain.rb', line 9152 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9154 9155 9156 |
# File 'lib/models/porcelain.rb', line 9154 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9156 9157 9158 |
# File 'lib/models/porcelain.rb', line 9156 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9158 9159 9160 |
# File 'lib/models/porcelain.rb', line 9158 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9160 9161 9162 |
# File 'lib/models/porcelain.rb', line 9160 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9198 9199 9200 9201 9202 9203 9204 |
# File 'lib/models/porcelain.rb', line 9198 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |