Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



9147
9148
9149
9150
9151
9152
9153
9154
9155
9156
9157
9158
9159
9160
9161
9162
9163
9164
9165
9166
9167
9168
9169
9170
9171
9172
9173
9174
9175
9176
9177
9178
9179
9180
9181
# File 'lib/models/porcelain.rb', line 9147

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



9115
9116
9117
# File 'lib/models/porcelain.rb', line 9115

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9117
9118
9119
# File 'lib/models/porcelain.rb', line 9117

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9119
9120
9121
# File 'lib/models/porcelain.rb', line 9119

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9121
9122
9123
# File 'lib/models/porcelain.rb', line 9121

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9123
9124
9125
# File 'lib/models/porcelain.rb', line 9123

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9125
9126
9127
# File 'lib/models/porcelain.rb', line 9125

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9127
9128
9129
# File 'lib/models/porcelain.rb', line 9127

def name
  @name
end

#passwordObject

The password to authenticate with.



9129
9130
9131
# File 'lib/models/porcelain.rb', line 9129

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9131
9132
9133
# File 'lib/models/porcelain.rb', line 9131

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9133
9134
9135
# File 'lib/models/porcelain.rb', line 9133

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9135
9136
9137
# File 'lib/models/porcelain.rb', line 9135

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9137
9138
9139
# File 'lib/models/porcelain.rb', line 9137

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9139
9140
9141
# File 'lib/models/porcelain.rb', line 9139

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9141
9142
9143
# File 'lib/models/porcelain.rb', line 9141

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9143
9144
9145
# File 'lib/models/porcelain.rb', line 9143

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9145
9146
9147
# File 'lib/models/porcelain.rb', line 9145

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9183
9184
9185
9186
9187
9188
9189
# File 'lib/models/porcelain.rb', line 9183

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end