Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 |
# File 'lib/models/porcelain.rb', line 8843 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
8811 8812 8813 |
# File 'lib/models/porcelain.rb', line 8811 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8813 8814 8815 |
# File 'lib/models/porcelain.rb', line 8813 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8815 8816 8817 |
# File 'lib/models/porcelain.rb', line 8815 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8817 8818 8819 |
# File 'lib/models/porcelain.rb', line 8817 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8819 8820 8821 |
# File 'lib/models/porcelain.rb', line 8819 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8821 8822 8823 |
# File 'lib/models/porcelain.rb', line 8821 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8823 8824 8825 |
# File 'lib/models/porcelain.rb', line 8823 def name @name end |
#password ⇒ Object
The password to authenticate with.
8825 8826 8827 |
# File 'lib/models/porcelain.rb', line 8825 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8827 8828 8829 |
# File 'lib/models/porcelain.rb', line 8827 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8829 8830 8831 |
# File 'lib/models/porcelain.rb', line 8829 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8831 8832 8833 |
# File 'lib/models/porcelain.rb', line 8831 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8833 8834 8835 |
# File 'lib/models/porcelain.rb', line 8833 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8835 8836 8837 |
# File 'lib/models/porcelain.rb', line 8835 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8837 8838 8839 |
# File 'lib/models/porcelain.rb', line 8837 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8839 8840 8841 |
# File 'lib/models/porcelain.rb', line 8839 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8841 8842 8843 |
# File 'lib/models/porcelain.rb', line 8841 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8879 8880 8881 8882 8883 8884 8885 |
# File 'lib/models/porcelain.rb', line 8879 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |