Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 |
# File 'lib/models/porcelain.rb', line 7701 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
7669 7670 7671 |
# File 'lib/models/porcelain.rb', line 7669 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7671 7672 7673 |
# File 'lib/models/porcelain.rb', line 7671 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7673 7674 7675 |
# File 'lib/models/porcelain.rb', line 7673 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7675 7676 7677 |
# File 'lib/models/porcelain.rb', line 7675 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7677 7678 7679 |
# File 'lib/models/porcelain.rb', line 7677 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7679 7680 7681 |
# File 'lib/models/porcelain.rb', line 7679 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7681 7682 7683 |
# File 'lib/models/porcelain.rb', line 7681 def name @name end |
#password ⇒ Object
The password to authenticate with.
7683 7684 7685 |
# File 'lib/models/porcelain.rb', line 7683 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7685 7686 7687 |
# File 'lib/models/porcelain.rb', line 7685 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7687 7688 7689 |
# File 'lib/models/porcelain.rb', line 7687 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7689 7690 7691 |
# File 'lib/models/porcelain.rb', line 7689 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7691 7692 7693 |
# File 'lib/models/porcelain.rb', line 7691 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7693 7694 7695 |
# File 'lib/models/porcelain.rb', line 7693 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7695 7696 7697 |
# File 'lib/models/porcelain.rb', line 7695 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7697 7698 7699 |
# File 'lib/models/porcelain.rb', line 7697 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7699 7700 7701 |
# File 'lib/models/porcelain.rb', line 7699 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7737 7738 7739 7740 7741 7742 7743 |
# File 'lib/models/porcelain.rb', line 7737 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |