Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 7186 7187 7188 7189 7190 7191 |
# File 'lib/models/porcelain.rb', line 7157 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
7125 7126 7127 |
# File 'lib/models/porcelain.rb', line 7125 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7127 7128 7129 |
# File 'lib/models/porcelain.rb', line 7127 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7129 7130 7131 |
# File 'lib/models/porcelain.rb', line 7129 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7131 7132 7133 |
# File 'lib/models/porcelain.rb', line 7131 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7133 7134 7135 |
# File 'lib/models/porcelain.rb', line 7133 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7135 7136 7137 |
# File 'lib/models/porcelain.rb', line 7135 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7137 7138 7139 |
# File 'lib/models/porcelain.rb', line 7137 def name @name end |
#password ⇒ Object
The password to authenticate with.
7139 7140 7141 |
# File 'lib/models/porcelain.rb', line 7139 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7141 7142 7143 |
# File 'lib/models/porcelain.rb', line 7141 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7143 7144 7145 |
# File 'lib/models/porcelain.rb', line 7143 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7145 7146 7147 |
# File 'lib/models/porcelain.rb', line 7145 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7147 7148 7149 |
# File 'lib/models/porcelain.rb', line 7147 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7149 7150 7151 |
# File 'lib/models/porcelain.rb', line 7149 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7151 7152 7153 |
# File 'lib/models/porcelain.rb', line 7151 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7153 7154 7155 |
# File 'lib/models/porcelain.rb', line 7153 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7155 7156 7157 |
# File 'lib/models/porcelain.rb', line 7155 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7193 7194 7195 7196 7197 7198 7199 |
# File 'lib/models/porcelain.rb', line 7193 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |