Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
# File 'lib/models/porcelain.rb', line 7086

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7054
7055
7056
# File 'lib/models/porcelain.rb', line 7054

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7056
7057
7058
# File 'lib/models/porcelain.rb', line 7056

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7058
7059
7060
# File 'lib/models/porcelain.rb', line 7058

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7060
7061
7062
# File 'lib/models/porcelain.rb', line 7060

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7062
7063
7064
# File 'lib/models/porcelain.rb', line 7062

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7064
7065
7066
# File 'lib/models/porcelain.rb', line 7064

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7066
7067
7068
# File 'lib/models/porcelain.rb', line 7066

def name
  @name
end

#passwordObject

The password to authenticate with.



7068
7069
7070
# File 'lib/models/porcelain.rb', line 7068

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7070
7071
7072
# File 'lib/models/porcelain.rb', line 7070

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7072
7073
7074
# File 'lib/models/porcelain.rb', line 7072

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7074
7075
7076
# File 'lib/models/porcelain.rb', line 7074

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7076
7077
7078
# File 'lib/models/porcelain.rb', line 7076

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7078
7079
7080
# File 'lib/models/porcelain.rb', line 7078

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7080
7081
7082
# File 'lib/models/porcelain.rb', line 7080

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7082
7083
7084
# File 'lib/models/porcelain.rb', line 7082

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7084
7085
7086
# File 'lib/models/porcelain.rb', line 7084

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7122
7123
7124
7125
7126
7127
7128
# File 'lib/models/porcelain.rb', line 7122

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end