Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
# File 'lib/models/porcelain.rb', line 6795

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



6765
6766
6767
# File 'lib/models/porcelain.rb', line 6765

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6767
6768
6769
# File 'lib/models/porcelain.rb', line 6767

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6769
6770
6771
# File 'lib/models/porcelain.rb', line 6769

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6771
6772
6773
# File 'lib/models/porcelain.rb', line 6771

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6773
6774
6775
# File 'lib/models/porcelain.rb', line 6773

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6775
6776
6777
# File 'lib/models/porcelain.rb', line 6775

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6777
6778
6779
# File 'lib/models/porcelain.rb', line 6777

def name
  @name
end

#passwordObject

The password to authenticate with.



6779
6780
6781
# File 'lib/models/porcelain.rb', line 6779

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6781
6782
6783
# File 'lib/models/porcelain.rb', line 6781

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6783
6784
6785
# File 'lib/models/porcelain.rb', line 6783

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6785
6786
6787
# File 'lib/models/porcelain.rb', line 6785

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6787
6788
6789
# File 'lib/models/porcelain.rb', line 6787

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6789
6790
6791
# File 'lib/models/porcelain.rb', line 6789

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



6791
6792
6793
# File 'lib/models/porcelain.rb', line 6791

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



6793
6794
6795
# File 'lib/models/porcelain.rb', line 6793

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6829
6830
6831
6832
6833
6834
6835
# File 'lib/models/porcelain.rb', line 6829

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end