Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
6458 6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 6469 6470 6471 6472 6473 6474 6475 6476 6477 6478 6479 6480 6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 |
# File 'lib/models/porcelain.rb', line 6458 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
6428 6429 6430 |
# File 'lib/models/porcelain.rb', line 6428 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6430 6431 6432 |
# File 'lib/models/porcelain.rb', line 6430 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6432 6433 6434 |
# File 'lib/models/porcelain.rb', line 6432 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6434 6435 6436 |
# File 'lib/models/porcelain.rb', line 6434 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6436 6437 6438 |
# File 'lib/models/porcelain.rb', line 6436 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6438 6439 6440 |
# File 'lib/models/porcelain.rb', line 6438 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6440 6441 6442 |
# File 'lib/models/porcelain.rb', line 6440 def name @name end |
#password ⇒ Object
The password to authenticate with.
6442 6443 6444 |
# File 'lib/models/porcelain.rb', line 6442 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6444 6445 6446 |
# File 'lib/models/porcelain.rb', line 6444 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6446 6447 6448 |
# File 'lib/models/porcelain.rb', line 6446 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6448 6449 6450 |
# File 'lib/models/porcelain.rb', line 6448 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6450 6451 6452 |
# File 'lib/models/porcelain.rb', line 6450 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6452 6453 6454 |
# File 'lib/models/porcelain.rb', line 6452 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
6454 6455 6456 |
# File 'lib/models/porcelain.rb', line 6454 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
6456 6457 6458 |
# File 'lib/models/porcelain.rb', line 6456 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6492 6493 6494 6495 6496 6497 6498 |
# File 'lib/models/porcelain.rb', line 6492 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |