Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
6056 6057 6058 6059 6060 6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 6088 |
# File 'lib/models/porcelain.rb', line 6056 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
6026 6027 6028 |
# File 'lib/models/porcelain.rb', line 6026 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6028 6029 6030 |
# File 'lib/models/porcelain.rb', line 6028 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6030 6031 6032 |
# File 'lib/models/porcelain.rb', line 6030 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6032 6033 6034 |
# File 'lib/models/porcelain.rb', line 6032 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6034 6035 6036 |
# File 'lib/models/porcelain.rb', line 6034 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6036 6037 6038 |
# File 'lib/models/porcelain.rb', line 6036 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6038 6039 6040 |
# File 'lib/models/porcelain.rb', line 6038 def name @name end |
#password ⇒ Object
The password to authenticate with.
6040 6041 6042 |
# File 'lib/models/porcelain.rb', line 6040 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6042 6043 6044 |
# File 'lib/models/porcelain.rb', line 6042 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6044 6045 6046 |
# File 'lib/models/porcelain.rb', line 6044 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6046 6047 6048 |
# File 'lib/models/porcelain.rb', line 6046 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6048 6049 6050 |
# File 'lib/models/porcelain.rb', line 6048 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6050 6051 6052 |
# File 'lib/models/porcelain.rb', line 6050 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
6052 6053 6054 |
# File 'lib/models/porcelain.rb', line 6052 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
6054 6055 6056 |
# File 'lib/models/porcelain.rb', line 6054 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6090 6091 6092 6093 6094 6095 6096 |
# File 'lib/models/porcelain.rb', line 6090 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |