Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
5236 5237 5238 5239 5240 5241 5242 5243 5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 5266 5267 5268 |
# File 'lib/models/porcelain.rb', line 5236 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
5206 5207 5208 |
# File 'lib/models/porcelain.rb', line 5206 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5208 5209 5210 |
# File 'lib/models/porcelain.rb', line 5208 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5210 5211 5212 |
# File 'lib/models/porcelain.rb', line 5210 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5212 5213 5214 |
# File 'lib/models/porcelain.rb', line 5212 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5214 5215 5216 |
# File 'lib/models/porcelain.rb', line 5214 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5216 5217 5218 |
# File 'lib/models/porcelain.rb', line 5216 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5218 5219 5220 |
# File 'lib/models/porcelain.rb', line 5218 def name @name end |
#password ⇒ Object
The password to authenticate with.
5220 5221 5222 |
# File 'lib/models/porcelain.rb', line 5220 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5222 5223 5224 |
# File 'lib/models/porcelain.rb', line 5222 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5224 5225 5226 |
# File 'lib/models/porcelain.rb', line 5224 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5226 5227 5228 |
# File 'lib/models/porcelain.rb', line 5226 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5228 5229 5230 |
# File 'lib/models/porcelain.rb', line 5228 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5230 5231 5232 |
# File 'lib/models/porcelain.rb', line 5230 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5232 5233 5234 |
# File 'lib/models/porcelain.rb', line 5232 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5234 5235 5236 |
# File 'lib/models/porcelain.rb', line 5234 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5270 5271 5272 5273 5274 5275 5276 |
# File 'lib/models/porcelain.rb', line 5270 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |