Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 5101 5102 5103 5104 |
# File 'lib/models/porcelain.rb', line 5072 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
5042 5043 5044 |
# File 'lib/models/porcelain.rb', line 5042 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5044 5045 5046 |
# File 'lib/models/porcelain.rb', line 5044 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5046 5047 5048 |
# File 'lib/models/porcelain.rb', line 5046 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5048 5049 5050 |
# File 'lib/models/porcelain.rb', line 5048 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5050 5051 5052 |
# File 'lib/models/porcelain.rb', line 5050 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5052 5053 5054 |
# File 'lib/models/porcelain.rb', line 5052 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5054 5055 5056 |
# File 'lib/models/porcelain.rb', line 5054 def name @name end |
#password ⇒ Object
The password to authenticate with.
5056 5057 5058 |
# File 'lib/models/porcelain.rb', line 5056 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5058 5059 5060 |
# File 'lib/models/porcelain.rb', line 5058 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5060 5061 5062 |
# File 'lib/models/porcelain.rb', line 5060 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5062 5063 5064 |
# File 'lib/models/porcelain.rb', line 5062 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5064 5065 5066 |
# File 'lib/models/porcelain.rb', line 5064 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5066 5067 5068 |
# File 'lib/models/porcelain.rb', line 5066 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5068 5069 5070 |
# File 'lib/models/porcelain.rb', line 5068 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5070 5071 5072 |
# File 'lib/models/porcelain.rb', line 5070 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5106 5107 5108 5109 5110 5111 5112 |
# File 'lib/models/porcelain.rb', line 5106 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |