Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
# File 'lib/models/porcelain.rb', line 5069

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5039
5040
5041
# File 'lib/models/porcelain.rb', line 5039

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5041
5042
5043
# File 'lib/models/porcelain.rb', line 5041

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5043
5044
5045
# File 'lib/models/porcelain.rb', line 5043

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5045
5046
5047
# File 'lib/models/porcelain.rb', line 5045

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5047
5048
5049
# File 'lib/models/porcelain.rb', line 5047

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5049
5050
5051
# File 'lib/models/porcelain.rb', line 5049

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5051
5052
5053
# File 'lib/models/porcelain.rb', line 5051

def name
  @name
end

#passwordObject

The password to authenticate with.



5053
5054
5055
# File 'lib/models/porcelain.rb', line 5053

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5055
5056
5057
# File 'lib/models/porcelain.rb', line 5055

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5057
5058
5059
# File 'lib/models/porcelain.rb', line 5057

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5059
5060
5061
# File 'lib/models/porcelain.rb', line 5059

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5061
5062
5063
# File 'lib/models/porcelain.rb', line 5061

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5063
5064
5065
# File 'lib/models/porcelain.rb', line 5063

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5065
5066
5067
# File 'lib/models/porcelain.rb', line 5065

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5067
5068
5069
# File 'lib/models/porcelain.rb', line 5067

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5103
5104
5105
5106
5107
5108
5109
# File 'lib/models/porcelain.rb', line 5103

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end