Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 |
# File 'lib/models/porcelain.rb', line 4948 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4918 4919 4920 |
# File 'lib/models/porcelain.rb', line 4918 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4920 4921 4922 |
# File 'lib/models/porcelain.rb', line 4920 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4922 4923 4924 |
# File 'lib/models/porcelain.rb', line 4922 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4924 4925 4926 |
# File 'lib/models/porcelain.rb', line 4924 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4926 4927 4928 |
# File 'lib/models/porcelain.rb', line 4926 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4928 4929 4930 |
# File 'lib/models/porcelain.rb', line 4928 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4930 4931 4932 |
# File 'lib/models/porcelain.rb', line 4930 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4932 4933 4934 |
# File 'lib/models/porcelain.rb', line 4932 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4934 4935 4936 |
# File 'lib/models/porcelain.rb', line 4934 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4936 4937 4938 |
# File 'lib/models/porcelain.rb', line 4936 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4938 4939 4940 |
# File 'lib/models/porcelain.rb', line 4938 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4940 4941 4942 |
# File 'lib/models/porcelain.rb', line 4940 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4942 4943 4944 |
# File 'lib/models/porcelain.rb', line 4942 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4944 4945 4946 |
# File 'lib/models/porcelain.rb', line 4944 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4946 4947 4948 |
# File 'lib/models/porcelain.rb', line 4946 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4982 4983 4984 4985 4986 4987 4988 |
# File 'lib/models/porcelain.rb', line 4982 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |