Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



4564
4565
4566
4567
4568
4569
4570
4571
4572
4573
4574
4575
4576
4577
4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
4593
4594
# File 'lib/models/porcelain.rb', line 4564

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4536
4537
4538
# File 'lib/models/porcelain.rb', line 4536

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4538
4539
4540
# File 'lib/models/porcelain.rb', line 4538

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4540
4541
4542
# File 'lib/models/porcelain.rb', line 4540

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4542
4543
4544
# File 'lib/models/porcelain.rb', line 4542

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4544
4545
4546
# File 'lib/models/porcelain.rb', line 4544

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4546
4547
4548
# File 'lib/models/porcelain.rb', line 4546

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4548
4549
4550
# File 'lib/models/porcelain.rb', line 4548

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4550
4551
4552
# File 'lib/models/porcelain.rb', line 4550

def password
  @password
end

#portObject

Returns the value of attribute port.



4552
4553
4554
# File 'lib/models/porcelain.rb', line 4552

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4554
4555
4556
# File 'lib/models/porcelain.rb', line 4554

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4556
4557
4558
# File 'lib/models/porcelain.rb', line 4556

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4558
4559
4560
# File 'lib/models/porcelain.rb', line 4558

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4560
4561
4562
# File 'lib/models/porcelain.rb', line 4560

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4562
4563
4564
# File 'lib/models/porcelain.rb', line 4562

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4596
4597
4598
4599
4600
4601
4602
# File 'lib/models/porcelain.rb', line 4596

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end