Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
# File 'lib/models/porcelain.rb', line 4226

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4198
4199
4200
# File 'lib/models/porcelain.rb', line 4198

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4200
4201
4202
# File 'lib/models/porcelain.rb', line 4200

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4202
4203
4204
# File 'lib/models/porcelain.rb', line 4202

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4204
4205
4206
# File 'lib/models/porcelain.rb', line 4204

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4206
4207
4208
# File 'lib/models/porcelain.rb', line 4206

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4208
4209
4210
# File 'lib/models/porcelain.rb', line 4208

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4210
4211
4212
# File 'lib/models/porcelain.rb', line 4210

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4212
4213
4214
# File 'lib/models/porcelain.rb', line 4212

def password
  @password
end

#portObject

Returns the value of attribute port.



4214
4215
4216
# File 'lib/models/porcelain.rb', line 4214

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4216
4217
4218
# File 'lib/models/porcelain.rb', line 4216

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4218
4219
4220
# File 'lib/models/porcelain.rb', line 4218

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4220
4221
4222
# File 'lib/models/porcelain.rb', line 4220

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4222
4223
4224
# File 'lib/models/porcelain.rb', line 4222

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4224
4225
4226
# File 'lib/models/porcelain.rb', line 4224

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4258
4259
4260
4261
4262
4263
4264
# File 'lib/models/porcelain.rb', line 4258

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end