Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
# File 'lib/models/porcelain.rb', line 4227

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4199
4200
4201
# File 'lib/models/porcelain.rb', line 4199

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4201
4202
4203
# File 'lib/models/porcelain.rb', line 4201

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4203
4204
4205
# File 'lib/models/porcelain.rb', line 4203

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4205
4206
4207
# File 'lib/models/porcelain.rb', line 4205

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4207
4208
4209
# File 'lib/models/porcelain.rb', line 4207

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4209
4210
4211
# File 'lib/models/porcelain.rb', line 4209

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4211
4212
4213
# File 'lib/models/porcelain.rb', line 4211

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4213
4214
4215
# File 'lib/models/porcelain.rb', line 4213

def password
  @password
end

#portObject

Returns the value of attribute port.



4215
4216
4217
# File 'lib/models/porcelain.rb', line 4215

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4217
4218
4219
# File 'lib/models/porcelain.rb', line 4217

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4219
4220
4221
# File 'lib/models/porcelain.rb', line 4219

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4221
4222
4223
# File 'lib/models/porcelain.rb', line 4221

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4223
4224
4225
# File 'lib/models/porcelain.rb', line 4223

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4225
4226
4227
# File 'lib/models/porcelain.rb', line 4225

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4259
4260
4261
4262
4263
4264
4265
# File 'lib/models/porcelain.rb', line 4259

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end