Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 |
# File 'lib/models/porcelain.rb', line 4115 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4087 4088 4089 |
# File 'lib/models/porcelain.rb', line 4087 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4089 4090 4091 |
# File 'lib/models/porcelain.rb', line 4089 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4091 4092 4093 |
# File 'lib/models/porcelain.rb', line 4091 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4093 4094 4095 |
# File 'lib/models/porcelain.rb', line 4093 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4095 4096 4097 |
# File 'lib/models/porcelain.rb', line 4095 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4097 4098 4099 |
# File 'lib/models/porcelain.rb', line 4097 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4099 4100 4101 |
# File 'lib/models/porcelain.rb', line 4099 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4101 4102 4103 |
# File 'lib/models/porcelain.rb', line 4101 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4103 4104 4105 |
# File 'lib/models/porcelain.rb', line 4103 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4105 4106 4107 |
# File 'lib/models/porcelain.rb', line 4105 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4107 4108 4109 |
# File 'lib/models/porcelain.rb', line 4107 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4109 4110 4111 |
# File 'lib/models/porcelain.rb', line 4109 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4111 4112 4113 |
# File 'lib/models/porcelain.rb', line 4111 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4113 4114 4115 |
# File 'lib/models/porcelain.rb', line 4113 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4147 4148 4149 4150 4151 4152 4153 |
# File 'lib/models/porcelain.rb', line 4147 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |