Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 |
# File 'lib/models/porcelain.rb', line 3759 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
3731 3732 3733 |
# File 'lib/models/porcelain.rb', line 3731 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
3733 3734 3735 |
# File 'lib/models/porcelain.rb', line 3733 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3735 3736 3737 |
# File 'lib/models/porcelain.rb', line 3735 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3737 3738 3739 |
# File 'lib/models/porcelain.rb', line 3737 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3739 3740 3741 |
# File 'lib/models/porcelain.rb', line 3739 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3741 3742 3743 |
# File 'lib/models/porcelain.rb', line 3741 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3743 3744 3745 |
# File 'lib/models/porcelain.rb', line 3743 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3745 3746 3747 |
# File 'lib/models/porcelain.rb', line 3745 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3747 3748 3749 |
# File 'lib/models/porcelain.rb', line 3747 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3749 3750 3751 |
# File 'lib/models/porcelain.rb', line 3749 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3751 3752 3753 |
# File 'lib/models/porcelain.rb', line 3751 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3753 3754 3755 |
# File 'lib/models/porcelain.rb', line 3753 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
3755 3756 3757 |
# File 'lib/models/porcelain.rb', line 3755 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
3757 3758 3759 |
# File 'lib/models/porcelain.rb', line 3757 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3791 3792 3793 3794 3795 3796 3797 |
# File 'lib/models/porcelain.rb', line 3791 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |