Class: SDM::MongoHost
- Inherits:
-
Object
- Object
- SDM::MongoHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
constructor
A new instance of MongoHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost
Returns a new instance of MongoHost.
4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 |
# File 'lib/models/porcelain.rb', line 4412 def initialize( auth_database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) if auth_database != nil @auth_database = auth_database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end if username != nil @username = username end end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4386 4387 4388 |
# File 'lib/models/porcelain.rb', line 4386 def auth_database @auth_database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4388 4389 4390 |
# File 'lib/models/porcelain.rb', line 4388 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4390 4391 4392 |
# File 'lib/models/porcelain.rb', line 4390 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4392 4393 4394 |
# File 'lib/models/porcelain.rb', line 4392 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4394 4395 4396 |
# File 'lib/models/porcelain.rb', line 4394 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4396 4397 4398 |
# File 'lib/models/porcelain.rb', line 4396 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4398 4399 4400 |
# File 'lib/models/porcelain.rb', line 4398 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4400 4401 4402 |
# File 'lib/models/porcelain.rb', line 4400 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4402 4403 4404 |
# File 'lib/models/porcelain.rb', line 4402 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4404 4405 4406 |
# File 'lib/models/porcelain.rb', line 4404 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4406 4407 4408 |
# File 'lib/models/porcelain.rb', line 4406 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4408 4409 4410 |
# File 'lib/models/porcelain.rb', line 4408 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4410 4411 4412 |
# File 'lib/models/porcelain.rb', line 4410 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/models/porcelain.rb', line 4468 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |