Class: SDM::MongoHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoHost

Returns a new instance of MongoHost.



11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
11418
11419
11420
11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
# File 'lib/models/porcelain.rb', line 11401

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11369
11370
11371
# File 'lib/models/porcelain.rb', line 11369

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11371
11372
11373
# File 'lib/models/porcelain.rb', line 11371

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11373
11374
11375
# File 'lib/models/porcelain.rb', line 11373

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11375
11376
11377
# File 'lib/models/porcelain.rb', line 11375

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11377
11378
11379
# File 'lib/models/porcelain.rb', line 11377

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11379
11380
11381
# File 'lib/models/porcelain.rb', line 11379

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11381
11382
11383
# File 'lib/models/porcelain.rb', line 11381

def name
  @name
end

#passwordObject

The password to authenticate with.



11383
11384
11385
# File 'lib/models/porcelain.rb', line 11383

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11385
11386
11387
# File 'lib/models/porcelain.rb', line 11385

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11387
11388
11389
# File 'lib/models/porcelain.rb', line 11387

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11389
11390
11391
# File 'lib/models/porcelain.rb', line 11389

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11391
11392
11393
# File 'lib/models/porcelain.rb', line 11391

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11393
11394
11395
# File 'lib/models/porcelain.rb', line 11393

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11395
11396
11397
# File 'lib/models/porcelain.rb', line 11395

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11397
11398
11399
# File 'lib/models/porcelain.rb', line 11397

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11399
11400
11401
# File 'lib/models/porcelain.rb', line 11399

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11437
11438
11439
11440
11441
11442
11443
# File 'lib/models/porcelain.rb', line 11437

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end