Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



11978
11979
11980
11981
11982
11983
11984
11985
11986
11987
11988
11989
11990
11991
11992
11993
11994
11995
11996
11997
11998
11999
12000
12001
12002
12003
12004
12005
12006
12007
12008
12009
12010
12011
12012
# File 'lib/models/porcelain.rb', line 11978

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11946
11947
11948
# File 'lib/models/porcelain.rb', line 11946

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11948
11949
11950
# File 'lib/models/porcelain.rb', line 11948

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11950
11951
11952
# File 'lib/models/porcelain.rb', line 11950

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11952
11953
11954
# File 'lib/models/porcelain.rb', line 11952

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11954
11955
11956
# File 'lib/models/porcelain.rb', line 11954

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11956
11957
11958
# File 'lib/models/porcelain.rb', line 11956

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11958
11959
11960
# File 'lib/models/porcelain.rb', line 11958

def name
  @name
end

#passwordObject

The password to authenticate with.



11960
11961
11962
# File 'lib/models/porcelain.rb', line 11960

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11962
11963
11964
# File 'lib/models/porcelain.rb', line 11962

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11964
11965
11966
# File 'lib/models/porcelain.rb', line 11964

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11966
11967
11968
# File 'lib/models/porcelain.rb', line 11966

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11968
11969
11970
# File 'lib/models/porcelain.rb', line 11968

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11970
11971
11972
# File 'lib/models/porcelain.rb', line 11970

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11972
11973
11974
# File 'lib/models/porcelain.rb', line 11972

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11974
11975
11976
# File 'lib/models/porcelain.rb', line 11974

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11976
11977
11978
# File 'lib/models/porcelain.rb', line 11976

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12014
12015
12016
12017
12018
12019
12020
# File 'lib/models/porcelain.rb', line 12014

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end