Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



11114
11115
11116
11117
11118
11119
11120
11121
11122
11123
11124
11125
11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
# File 'lib/models/porcelain.rb', line 11114

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11082
11083
11084
# File 'lib/models/porcelain.rb', line 11082

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11084
11085
11086
# File 'lib/models/porcelain.rb', line 11084

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11086
11087
11088
# File 'lib/models/porcelain.rb', line 11086

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11088
11089
11090
# File 'lib/models/porcelain.rb', line 11088

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11090
11091
11092
# File 'lib/models/porcelain.rb', line 11090

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11092
11093
11094
# File 'lib/models/porcelain.rb', line 11092

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11094
11095
11096
# File 'lib/models/porcelain.rb', line 11094

def name
  @name
end

#passwordObject

The password to authenticate with.



11096
11097
11098
# File 'lib/models/porcelain.rb', line 11096

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11098
11099
11100
# File 'lib/models/porcelain.rb', line 11098

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11100
11101
11102
# File 'lib/models/porcelain.rb', line 11100

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11102
11103
11104
# File 'lib/models/porcelain.rb', line 11102

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11104
11105
11106
# File 'lib/models/porcelain.rb', line 11104

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11106
11107
11108
# File 'lib/models/porcelain.rb', line 11106

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11108
11109
11110
# File 'lib/models/porcelain.rb', line 11108

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11110
11111
11112
# File 'lib/models/porcelain.rb', line 11110

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11112
11113
11114
# File 'lib/models/porcelain.rb', line 11112

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11150
11151
11152
11153
11154
11155
11156
# File 'lib/models/porcelain.rb', line 11150

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end