Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
11050 11051 11052 11053 11054 11055 11056 11057 11058 11059 11060 11061 11062 11063 11064 11065 11066 11067 11068 11069 11070 11071 11072 11073 11074 11075 11076 11077 11078 11079 11080 11081 11082 11083 11084 |
# File 'lib/models/porcelain.rb', line 11050 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
11018 11019 11020 |
# File 'lib/models/porcelain.rb', line 11018 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
11020 11021 11022 |
# File 'lib/models/porcelain.rb', line 11020 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11022 11023 11024 |
# File 'lib/models/porcelain.rb', line 11022 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11024 11025 11026 |
# File 'lib/models/porcelain.rb', line 11024 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11026 11027 11028 |
# File 'lib/models/porcelain.rb', line 11026 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11028 11029 11030 |
# File 'lib/models/porcelain.rb', line 11028 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11030 11031 11032 |
# File 'lib/models/porcelain.rb', line 11030 def name @name end |
#password ⇒ Object
The password to authenticate with.
11032 11033 11034 |
# File 'lib/models/porcelain.rb', line 11032 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11034 11035 11036 |
# File 'lib/models/porcelain.rb', line 11034 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
11036 11037 11038 |
# File 'lib/models/porcelain.rb', line 11036 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11038 11039 11040 |
# File 'lib/models/porcelain.rb', line 11038 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11040 11041 11042 |
# File 'lib/models/porcelain.rb', line 11040 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
11042 11043 11044 |
# File 'lib/models/porcelain.rb', line 11042 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11044 11045 11046 |
# File 'lib/models/porcelain.rb', line 11044 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
11046 11047 11048 |
# File 'lib/models/porcelain.rb', line 11046 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
11048 11049 11050 |
# File 'lib/models/porcelain.rb', line 11048 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11086 11087 11088 11089 11090 11091 11092 |
# File 'lib/models/porcelain.rb', line 11086 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |