Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
9325
9326
9327
9328
9329
9330
9331
9332
9333
9334
9335
9336
9337
9338
9339
9340
9341
9342
# File 'lib/models/porcelain.rb', line 9308

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



9276
9277
9278
# File 'lib/models/porcelain.rb', line 9276

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9278
9279
9280
# File 'lib/models/porcelain.rb', line 9278

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9280
9281
9282
# File 'lib/models/porcelain.rb', line 9280

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9282
9283
9284
# File 'lib/models/porcelain.rb', line 9282

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9284
9285
9286
# File 'lib/models/porcelain.rb', line 9284

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9286
9287
9288
# File 'lib/models/porcelain.rb', line 9286

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9288
9289
9290
# File 'lib/models/porcelain.rb', line 9288

def name
  @name
end

#passwordObject

The password to authenticate with.



9290
9291
9292
# File 'lib/models/porcelain.rb', line 9290

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9292
9293
9294
# File 'lib/models/porcelain.rb', line 9292

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9294
9295
9296
# File 'lib/models/porcelain.rb', line 9294

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9296
9297
9298
# File 'lib/models/porcelain.rb', line 9296

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9298
9299
9300
# File 'lib/models/porcelain.rb', line 9298

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9300
9301
9302
# File 'lib/models/porcelain.rb', line 9300

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9302
9303
9304
# File 'lib/models/porcelain.rb', line 9302

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9304
9305
9306
# File 'lib/models/porcelain.rb', line 9304

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9306
9307
9308
# File 'lib/models/porcelain.rb', line 9306

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9344
9345
9346
9347
9348
9349
9350
# File 'lib/models/porcelain.rb', line 9344

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end