Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
9242 9243 9244 9245 9246 9247 9248 9249 9250 9251 9252 9253 9254 9255 9256 9257 9258 9259 9260 9261 9262 9263 9264 9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 9275 9276 |
# File 'lib/models/porcelain.rb', line 9242 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
9210 9211 9212 |
# File 'lib/models/porcelain.rb', line 9210 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9212 9213 9214 |
# File 'lib/models/porcelain.rb', line 9212 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9214 9215 9216 |
# File 'lib/models/porcelain.rb', line 9214 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9216 9217 9218 |
# File 'lib/models/porcelain.rb', line 9216 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9218 9219 9220 |
# File 'lib/models/porcelain.rb', line 9218 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9220 9221 9222 |
# File 'lib/models/porcelain.rb', line 9220 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9222 9223 9224 |
# File 'lib/models/porcelain.rb', line 9222 def name @name end |
#password ⇒ Object
The password to authenticate with.
9224 9225 9226 |
# File 'lib/models/porcelain.rb', line 9224 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9226 9227 9228 |
# File 'lib/models/porcelain.rb', line 9226 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9228 9229 9230 |
# File 'lib/models/porcelain.rb', line 9228 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9230 9231 9232 |
# File 'lib/models/porcelain.rb', line 9230 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9232 9233 9234 |
# File 'lib/models/porcelain.rb', line 9232 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9234 9235 9236 |
# File 'lib/models/porcelain.rb', line 9234 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9236 9237 9238 |
# File 'lib/models/porcelain.rb', line 9236 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9238 9239 9240 |
# File 'lib/models/porcelain.rb', line 9238 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9240 9241 9242 |
# File 'lib/models/porcelain.rb', line 9240 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9278 9279 9280 9281 9282 9283 9284 |
# File 'lib/models/porcelain.rb', line 9278 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |