Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
9227 9228 9229 9230 9231 9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 9247 9248 9249 9250 9251 9252 9253 9254 9255 9256 9257 9258 9259 9260 9261 |
# File 'lib/models/porcelain.rb', line 9227 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
9195 9196 9197 |
# File 'lib/models/porcelain.rb', line 9195 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9197 9198 9199 |
# File 'lib/models/porcelain.rb', line 9197 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9199 9200 9201 |
# File 'lib/models/porcelain.rb', line 9199 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9201 9202 9203 |
# File 'lib/models/porcelain.rb', line 9201 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9203 9204 9205 |
# File 'lib/models/porcelain.rb', line 9203 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9205 9206 9207 |
# File 'lib/models/porcelain.rb', line 9205 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9207 9208 9209 |
# File 'lib/models/porcelain.rb', line 9207 def name @name end |
#password ⇒ Object
The password to authenticate with.
9209 9210 9211 |
# File 'lib/models/porcelain.rb', line 9209 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9211 9212 9213 |
# File 'lib/models/porcelain.rb', line 9211 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9213 9214 9215 |
# File 'lib/models/porcelain.rb', line 9213 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9215 9216 9217 |
# File 'lib/models/porcelain.rb', line 9215 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9217 9218 9219 |
# File 'lib/models/porcelain.rb', line 9217 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9219 9220 9221 |
# File 'lib/models/porcelain.rb', line 9219 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9221 9222 9223 |
# File 'lib/models/porcelain.rb', line 9221 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9223 9224 9225 |
# File 'lib/models/porcelain.rb', line 9223 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9225 9226 9227 |
# File 'lib/models/porcelain.rb', line 9225 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9263 9264 9265 9266 9267 9268 9269 |
# File 'lib/models/porcelain.rb', line 9263 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |