Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Overview
MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
9059 9060 9061 9062 9063 9064 9065 9066 9067 9068 9069 9070 9071 9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/models/porcelain.rb', line 9059 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
9027 9028 9029 |
# File 'lib/models/porcelain.rb', line 9027 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9029 9030 9031 |
# File 'lib/models/porcelain.rb', line 9029 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9031 9032 9033 |
# File 'lib/models/porcelain.rb', line 9031 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9033 9034 9035 |
# File 'lib/models/porcelain.rb', line 9033 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9035 9036 9037 |
# File 'lib/models/porcelain.rb', line 9035 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9037 9038 9039 |
# File 'lib/models/porcelain.rb', line 9037 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9039 9040 9041 |
# File 'lib/models/porcelain.rb', line 9039 def name @name end |
#password ⇒ Object
The password to authenticate with.
9041 9042 9043 |
# File 'lib/models/porcelain.rb', line 9041 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9043 9044 9045 |
# File 'lib/models/porcelain.rb', line 9043 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9045 9046 9047 |
# File 'lib/models/porcelain.rb', line 9045 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9047 9048 9049 |
# File 'lib/models/porcelain.rb', line 9047 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9049 9050 9051 |
# File 'lib/models/porcelain.rb', line 9049 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9051 9052 9053 |
# File 'lib/models/porcelain.rb', line 9051 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9053 9054 9055 |
# File 'lib/models/porcelain.rb', line 9053 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9055 9056 9057 |
# File 'lib/models/porcelain.rb', line 9055 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9057 9058 9059 |
# File 'lib/models/porcelain.rb', line 9057 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9095 9096 9097 9098 9099 9100 9101 |
# File 'lib/models/porcelain.rb', line 9095 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |