Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



7847
7848
7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
# File 'lib/models/porcelain.rb', line 7847

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7815
7816
7817
# File 'lib/models/porcelain.rb', line 7815

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7817
7818
7819
# File 'lib/models/porcelain.rb', line 7817

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7819
7820
7821
# File 'lib/models/porcelain.rb', line 7819

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7821
7822
7823
# File 'lib/models/porcelain.rb', line 7821

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7823
7824
7825
# File 'lib/models/porcelain.rb', line 7823

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7825
7826
7827
# File 'lib/models/porcelain.rb', line 7825

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7827
7828
7829
# File 'lib/models/porcelain.rb', line 7827

def name
  @name
end

#passwordObject

The password to authenticate with.



7829
7830
7831
# File 'lib/models/porcelain.rb', line 7829

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7831
7832
7833
# File 'lib/models/porcelain.rb', line 7831

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7833
7834
7835
# File 'lib/models/porcelain.rb', line 7833

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7835
7836
7837
# File 'lib/models/porcelain.rb', line 7835

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7837
7838
7839
# File 'lib/models/porcelain.rb', line 7837

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7839
7840
7841
# File 'lib/models/porcelain.rb', line 7839

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7841
7842
7843
# File 'lib/models/porcelain.rb', line 7841

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7843
7844
7845
# File 'lib/models/porcelain.rb', line 7843

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7845
7846
7847
# File 'lib/models/porcelain.rb', line 7845

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7883
7884
7885
7886
7887
7888
7889
# File 'lib/models/porcelain.rb', line 7883

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end