Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



7237
7238
7239
7240
7241
7242
7243
7244
7245
7246
7247
7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
7258
7259
7260
7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
# File 'lib/models/porcelain.rb', line 7237

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7205
7206
7207
# File 'lib/models/porcelain.rb', line 7205

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7207
7208
7209
# File 'lib/models/porcelain.rb', line 7207

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7209
7210
7211
# File 'lib/models/porcelain.rb', line 7209

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7211
7212
7213
# File 'lib/models/porcelain.rb', line 7211

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7213
7214
7215
# File 'lib/models/porcelain.rb', line 7213

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7215
7216
7217
# File 'lib/models/porcelain.rb', line 7215

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7217
7218
7219
# File 'lib/models/porcelain.rb', line 7217

def name
  @name
end

#passwordObject

The password to authenticate with.



7219
7220
7221
# File 'lib/models/porcelain.rb', line 7219

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7221
7222
7223
# File 'lib/models/porcelain.rb', line 7221

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7223
7224
7225
# File 'lib/models/porcelain.rb', line 7223

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7225
7226
7227
# File 'lib/models/porcelain.rb', line 7225

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7227
7228
7229
# File 'lib/models/porcelain.rb', line 7227

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7229
7230
7231
# File 'lib/models/porcelain.rb', line 7229

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7231
7232
7233
# File 'lib/models/porcelain.rb', line 7231

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7233
7234
7235
# File 'lib/models/porcelain.rb', line 7233

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7235
7236
7237
# File 'lib/models/porcelain.rb', line 7235

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7273
7274
7275
7276
7277
7278
7279
# File 'lib/models/porcelain.rb', line 7273

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end