Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
7200
# File 'lib/models/porcelain.rb', line 7166

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7134
7135
7136
# File 'lib/models/porcelain.rb', line 7134

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7136
7137
7138
# File 'lib/models/porcelain.rb', line 7136

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7138
7139
7140
# File 'lib/models/porcelain.rb', line 7138

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7140
7141
7142
# File 'lib/models/porcelain.rb', line 7140

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7142
7143
7144
# File 'lib/models/porcelain.rb', line 7142

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7144
7145
7146
# File 'lib/models/porcelain.rb', line 7144

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7146
7147
7148
# File 'lib/models/porcelain.rb', line 7146

def name
  @name
end

#passwordObject

The password to authenticate with.



7148
7149
7150
# File 'lib/models/porcelain.rb', line 7148

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7150
7151
7152
# File 'lib/models/porcelain.rb', line 7150

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7152
7153
7154
# File 'lib/models/porcelain.rb', line 7152

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7154
7155
7156
# File 'lib/models/porcelain.rb', line 7154

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7156
7157
7158
# File 'lib/models/porcelain.rb', line 7156

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7158
7159
7160
# File 'lib/models/porcelain.rb', line 7158

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7160
7161
7162
# File 'lib/models/porcelain.rb', line 7160

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7162
7163
7164
# File 'lib/models/porcelain.rb', line 7162

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7164
7165
7166
# File 'lib/models/porcelain.rb', line 7164

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7202
7203
7204
7205
7206
7207
7208
# File 'lib/models/porcelain.rb', line 7202

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end