Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
6150
6151
6152
6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
6163
6164
6165
6166
6167
# File 'lib/models/porcelain.rb', line 6133

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



6101
6102
6103
# File 'lib/models/porcelain.rb', line 6101

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6103
6104
6105
# File 'lib/models/porcelain.rb', line 6103

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6105
6106
6107
# File 'lib/models/porcelain.rb', line 6105

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6107
6108
6109
# File 'lib/models/porcelain.rb', line 6107

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6109
6110
6111
# File 'lib/models/porcelain.rb', line 6109

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6111
6112
6113
# File 'lib/models/porcelain.rb', line 6111

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6113
6114
6115
# File 'lib/models/porcelain.rb', line 6113

def name
  @name
end

#passwordObject

The password to authenticate with.



6115
6116
6117
# File 'lib/models/porcelain.rb', line 6115

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6117
6118
6119
# File 'lib/models/porcelain.rb', line 6117

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6119
6120
6121
# File 'lib/models/porcelain.rb', line 6119

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



6121
6122
6123
# File 'lib/models/porcelain.rb', line 6121

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6123
6124
6125
# File 'lib/models/porcelain.rb', line 6123

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6125
6126
6127
# File 'lib/models/porcelain.rb', line 6125

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6127
6128
6129
# File 'lib/models/porcelain.rb', line 6127

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



6129
6130
6131
# File 'lib/models/porcelain.rb', line 6129

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



6131
6132
6133
# File 'lib/models/porcelain.rb', line 6131

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6169
6170
6171
6172
6173
6174
6175
# File 'lib/models/porcelain.rb', line 6169

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end