Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
5464 5465 5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 |
# File 'lib/models/porcelain.rb', line 5464 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
5432 5433 5434 |
# File 'lib/models/porcelain.rb', line 5432 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5434 5435 5436 |
# File 'lib/models/porcelain.rb', line 5434 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5436 5437 5438 |
# File 'lib/models/porcelain.rb', line 5436 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5438 5439 5440 |
# File 'lib/models/porcelain.rb', line 5438 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5440 5441 5442 |
# File 'lib/models/porcelain.rb', line 5440 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5442 5443 5444 |
# File 'lib/models/porcelain.rb', line 5442 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5444 5445 5446 |
# File 'lib/models/porcelain.rb', line 5444 def name @name end |
#password ⇒ Object
The password to authenticate with.
5446 5447 5448 |
# File 'lib/models/porcelain.rb', line 5446 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5448 5449 5450 |
# File 'lib/models/porcelain.rb', line 5448 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5450 5451 5452 |
# File 'lib/models/porcelain.rb', line 5450 def port_override @port_override end |
#replica_set ⇒ Object
The name of the mongo replicaset.
5452 5453 5454 |
# File 'lib/models/porcelain.rb', line 5452 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5454 5455 5456 |
# File 'lib/models/porcelain.rb', line 5454 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5456 5457 5458 |
# File 'lib/models/porcelain.rb', line 5456 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5458 5459 5460 |
# File 'lib/models/porcelain.rb', line 5458 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5460 5461 5462 |
# File 'lib/models/porcelain.rb', line 5460 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5462 5463 5464 |
# File 'lib/models/porcelain.rb', line 5462 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/models/porcelain.rb', line 5500 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |