Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
5438
5439
5440
5441
5442
5443
5444
5445
5446
5447
5448
5449
5450
5451
5452
5453
5454
5455
5456
5457
5458
5459
5460
5461
# File 'lib/models/porcelain.rb', line 5427

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5395
5396
5397
# File 'lib/models/porcelain.rb', line 5395

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5397
5398
5399
# File 'lib/models/porcelain.rb', line 5397

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5399
5400
5401
# File 'lib/models/porcelain.rb', line 5399

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5401
5402
5403
# File 'lib/models/porcelain.rb', line 5401

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5403
5404
5405
# File 'lib/models/porcelain.rb', line 5403

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5405
5406
5407
# File 'lib/models/porcelain.rb', line 5405

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5407
5408
5409
# File 'lib/models/porcelain.rb', line 5407

def name
  @name
end

#passwordObject

The password to authenticate with.



5409
5410
5411
# File 'lib/models/porcelain.rb', line 5409

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5411
5412
5413
# File 'lib/models/porcelain.rb', line 5411

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5413
5414
5415
# File 'lib/models/porcelain.rb', line 5413

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



5415
5416
5417
# File 'lib/models/porcelain.rb', line 5415

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5417
5418
5419
# File 'lib/models/porcelain.rb', line 5417

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5419
5420
5421
# File 'lib/models/porcelain.rb', line 5419

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5421
5422
5423
# File 'lib/models/porcelain.rb', line 5421

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5423
5424
5425
# File 'lib/models/porcelain.rb', line 5423

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5425
5426
5427
# File 'lib/models/porcelain.rb', line 5425

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5463
5464
5465
5466
5467
5468
5469
# File 'lib/models/porcelain.rb', line 5463

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end