Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



5313
5314
5315
5316
5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
5347
# File 'lib/models/porcelain.rb', line 5313

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5281
5282
5283
# File 'lib/models/porcelain.rb', line 5281

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5283
5284
5285
# File 'lib/models/porcelain.rb', line 5283

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5285
5286
5287
# File 'lib/models/porcelain.rb', line 5285

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5287
5288
5289
# File 'lib/models/porcelain.rb', line 5287

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5289
5290
5291
# File 'lib/models/porcelain.rb', line 5289

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5291
5292
5293
# File 'lib/models/porcelain.rb', line 5291

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5293
5294
5295
# File 'lib/models/porcelain.rb', line 5293

def name
  @name
end

#passwordObject

The password to authenticate with.



5295
5296
5297
# File 'lib/models/porcelain.rb', line 5295

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5297
5298
5299
# File 'lib/models/porcelain.rb', line 5297

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5299
5300
5301
# File 'lib/models/porcelain.rb', line 5299

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



5301
5302
5303
# File 'lib/models/porcelain.rb', line 5301

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5303
5304
5305
# File 'lib/models/porcelain.rb', line 5303

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5305
5306
5307
# File 'lib/models/porcelain.rb', line 5305

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5307
5308
5309
# File 'lib/models/porcelain.rb', line 5307

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5309
5310
5311
# File 'lib/models/porcelain.rb', line 5309

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5311
5312
5313
# File 'lib/models/porcelain.rb', line 5311

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5349
5350
5351
5352
5353
5354
5355
# File 'lib/models/porcelain.rb', line 5349

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end