Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 |
# File 'lib/models/porcelain.rb', line 5149 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
5117 5118 5119 |
# File 'lib/models/porcelain.rb', line 5117 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5119 5120 5121 |
# File 'lib/models/porcelain.rb', line 5119 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5121 5122 5123 |
# File 'lib/models/porcelain.rb', line 5121 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5123 5124 5125 |
# File 'lib/models/porcelain.rb', line 5123 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5125 5126 5127 |
# File 'lib/models/porcelain.rb', line 5125 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5127 5128 5129 |
# File 'lib/models/porcelain.rb', line 5127 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5129 5130 5131 |
# File 'lib/models/porcelain.rb', line 5129 def name @name end |
#password ⇒ Object
The password to authenticate with.
5131 5132 5133 |
# File 'lib/models/porcelain.rb', line 5131 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5133 5134 5135 |
# File 'lib/models/porcelain.rb', line 5133 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5135 5136 5137 |
# File 'lib/models/porcelain.rb', line 5135 def port_override @port_override end |
#replica_set ⇒ Object
The name of the mongo replicaset.
5137 5138 5139 |
# File 'lib/models/porcelain.rb', line 5137 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5139 5140 5141 |
# File 'lib/models/porcelain.rb', line 5139 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5141 5142 5143 |
# File 'lib/models/porcelain.rb', line 5141 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5143 5144 5145 |
# File 'lib/models/porcelain.rb', line 5143 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5145 5146 5147 |
# File 'lib/models/porcelain.rb', line 5145 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5147 5148 5149 |
# File 'lib/models/porcelain.rb', line 5147 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5185 5186 5187 5188 5189 5190 5191 |
# File 'lib/models/porcelain.rb', line 5185 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |