Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



5146
5147
5148
5149
5150
5151
5152
5153
5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/models/porcelain.rb', line 5146

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5114
5115
5116
# File 'lib/models/porcelain.rb', line 5114

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5116
5117
5118
# File 'lib/models/porcelain.rb', line 5116

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5118
5119
5120
# File 'lib/models/porcelain.rb', line 5118

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5120
5121
5122
# File 'lib/models/porcelain.rb', line 5120

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5122
5123
5124
# File 'lib/models/porcelain.rb', line 5122

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5124
5125
5126
# File 'lib/models/porcelain.rb', line 5124

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5126
5127
5128
# File 'lib/models/porcelain.rb', line 5126

def name
  @name
end

#passwordObject

The password to authenticate with.



5128
5129
5130
# File 'lib/models/porcelain.rb', line 5128

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5130
5131
5132
# File 'lib/models/porcelain.rb', line 5130

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5132
5133
5134
# File 'lib/models/porcelain.rb', line 5132

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



5134
5135
5136
# File 'lib/models/porcelain.rb', line 5134

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5136
5137
5138
# File 'lib/models/porcelain.rb', line 5136

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5138
5139
5140
# File 'lib/models/porcelain.rb', line 5138

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5140
5141
5142
# File 'lib/models/porcelain.rb', line 5140

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5142
5143
5144
# File 'lib/models/porcelain.rb', line 5142

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5144
5145
5146
# File 'lib/models/porcelain.rb', line 5144

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5182
5183
5184
5185
5186
5187
5188
# File 'lib/models/porcelain.rb', line 5182

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end