Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
5038
5039
5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
5053
5054
5055
5056
5057
5058
# File 'lib/models/porcelain.rb', line 5024

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4992
4993
4994
# File 'lib/models/porcelain.rb', line 4992

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4994
4995
4996
# File 'lib/models/porcelain.rb', line 4994

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4996
4997
4998
# File 'lib/models/porcelain.rb', line 4996

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4998
4999
5000
# File 'lib/models/porcelain.rb', line 4998

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5000
5001
5002
# File 'lib/models/porcelain.rb', line 5000

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5002
5003
5004
# File 'lib/models/porcelain.rb', line 5002

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5004
5005
5006
# File 'lib/models/porcelain.rb', line 5004

def name
  @name
end

#passwordObject

Returns the value of attribute password.



5006
5007
5008
# File 'lib/models/porcelain.rb', line 5006

def password
  @password
end

#portObject

Returns the value of attribute port.



5008
5009
5010
# File 'lib/models/porcelain.rb', line 5008

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5010
5011
5012
# File 'lib/models/porcelain.rb', line 5010

def port_override
  @port_override
end

#replica_setObject

Returns the value of attribute replica_set.



5012
5013
5014
# File 'lib/models/porcelain.rb', line 5012

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5014
5015
5016
# File 'lib/models/porcelain.rb', line 5014

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5016
5017
5018
# File 'lib/models/porcelain.rb', line 5016

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5018
5019
5020
# File 'lib/models/porcelain.rb', line 5018

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



5020
5021
5022
# File 'lib/models/porcelain.rb', line 5020

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



5022
5023
5024
# File 'lib/models/porcelain.rb', line 5022

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5060
5061
5062
5063
5064
5065
5066
# File 'lib/models/porcelain.rb', line 5060

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end