Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 |
# File 'lib/models/porcelain.rb', line 4976 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4944 4945 4946 |
# File 'lib/models/porcelain.rb', line 4944 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4946 4947 4948 |
# File 'lib/models/porcelain.rb', line 4946 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4948 4949 4950 |
# File 'lib/models/porcelain.rb', line 4948 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4950 4951 4952 |
# File 'lib/models/porcelain.rb', line 4950 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4952 4953 4954 |
# File 'lib/models/porcelain.rb', line 4952 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4954 4955 4956 |
# File 'lib/models/porcelain.rb', line 4954 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4956 4957 4958 |
# File 'lib/models/porcelain.rb', line 4956 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4958 4959 4960 |
# File 'lib/models/porcelain.rb', line 4958 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4960 4961 4962 |
# File 'lib/models/porcelain.rb', line 4960 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4962 4963 4964 |
# File 'lib/models/porcelain.rb', line 4962 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4964 4965 4966 |
# File 'lib/models/porcelain.rb', line 4964 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4966 4967 4968 |
# File 'lib/models/porcelain.rb', line 4966 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
4968 4969 4970 |
# File 'lib/models/porcelain.rb', line 4968 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4970 4971 4972 |
# File 'lib/models/porcelain.rb', line 4970 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4972 4973 4974 |
# File 'lib/models/porcelain.rb', line 4972 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4974 4975 4976 |
# File 'lib/models/porcelain.rb', line 4974 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5012 5013 5014 5015 5016 5017 5018 |
# File 'lib/models/porcelain.rb', line 5012 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |