Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 |
# File 'lib/models/porcelain.rb', line 4636 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4606 4607 4608 |
# File 'lib/models/porcelain.rb', line 4606 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4608 4609 4610 |
# File 'lib/models/porcelain.rb', line 4608 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4610 4611 4612 |
# File 'lib/models/porcelain.rb', line 4610 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4612 4613 4614 |
# File 'lib/models/porcelain.rb', line 4612 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4614 4615 4616 |
# File 'lib/models/porcelain.rb', line 4614 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4616 4617 4618 |
# File 'lib/models/porcelain.rb', line 4616 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4618 4619 4620 |
# File 'lib/models/porcelain.rb', line 4618 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4620 4621 4622 |
# File 'lib/models/porcelain.rb', line 4620 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4622 4623 4624 |
# File 'lib/models/porcelain.rb', line 4622 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4624 4625 4626 |
# File 'lib/models/porcelain.rb', line 4624 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4626 4627 4628 |
# File 'lib/models/porcelain.rb', line 4626 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4628 4629 4630 |
# File 'lib/models/porcelain.rb', line 4628 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4630 4631 4632 |
# File 'lib/models/porcelain.rb', line 4630 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4632 4633 4634 |
# File 'lib/models/porcelain.rb', line 4632 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4634 4635 4636 |
# File 'lib/models/porcelain.rb', line 4634 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/models/porcelain.rb', line 4670 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |