Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 |
# File 'lib/models/porcelain.rb', line 4299 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4269 4270 4271 |
# File 'lib/models/porcelain.rb', line 4269 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4271 4272 4273 |
# File 'lib/models/porcelain.rb', line 4271 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4273 4274 4275 |
# File 'lib/models/porcelain.rb', line 4273 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4275 4276 4277 |
# File 'lib/models/porcelain.rb', line 4275 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4277 4278 4279 |
# File 'lib/models/porcelain.rb', line 4277 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4279 4280 4281 |
# File 'lib/models/porcelain.rb', line 4279 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4281 4282 4283 |
# File 'lib/models/porcelain.rb', line 4281 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4283 4284 4285 |
# File 'lib/models/porcelain.rb', line 4283 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4285 4286 4287 |
# File 'lib/models/porcelain.rb', line 4285 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4287 4288 4289 |
# File 'lib/models/porcelain.rb', line 4287 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4289 4290 4291 |
# File 'lib/models/porcelain.rb', line 4289 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4291 4292 4293 |
# File 'lib/models/porcelain.rb', line 4291 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4293 4294 4295 |
# File 'lib/models/porcelain.rb', line 4293 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4295 4296 4297 |
# File 'lib/models/porcelain.rb', line 4295 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4297 4298 4299 |
# File 'lib/models/porcelain.rb', line 4297 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4333 4334 4335 4336 4337 4338 4339 |
# File 'lib/models/porcelain.rb', line 4333 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |