Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
4197
4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
4217
4218
4219
# File 'lib/models/porcelain.rb', line 4187

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4157
4158
4159
# File 'lib/models/porcelain.rb', line 4157

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4159
4160
4161
# File 'lib/models/porcelain.rb', line 4159

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4161
4162
4163
# File 'lib/models/porcelain.rb', line 4161

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4163
4164
4165
# File 'lib/models/porcelain.rb', line 4163

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4165
4166
4167
# File 'lib/models/porcelain.rb', line 4165

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4167
4168
4169
# File 'lib/models/porcelain.rb', line 4167

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4169
4170
4171
# File 'lib/models/porcelain.rb', line 4169

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4171
4172
4173
# File 'lib/models/porcelain.rb', line 4171

def password
  @password
end

#portObject

Returns the value of attribute port.



4173
4174
4175
# File 'lib/models/porcelain.rb', line 4173

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4175
4176
4177
# File 'lib/models/porcelain.rb', line 4175

def port_override
  @port_override
end

#replica_setObject

Returns the value of attribute replica_set.



4177
4178
4179
# File 'lib/models/porcelain.rb', line 4177

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4179
4180
4181
# File 'lib/models/porcelain.rb', line 4179

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4181
4182
4183
# File 'lib/models/porcelain.rb', line 4181

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4183
4184
4185
# File 'lib/models/porcelain.rb', line 4183

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4185
4186
4187
# File 'lib/models/porcelain.rb', line 4185

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4221
4222
4223
4224
4225
4226
4227
# File 'lib/models/porcelain.rb', line 4221

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end