Class: SDM::MongoLegacyHost
- Inherits:
-
Object
- Object
- SDM::MongoLegacyHost
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
constructor
A new instance of MongoLegacyHost.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost
Returns a new instance of MongoLegacyHost.
4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 |
# File 'lib/models/porcelain.rb', line 4092 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4062 4063 4064 |
# File 'lib/models/porcelain.rb', line 4062 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4064 4065 4066 |
# File 'lib/models/porcelain.rb', line 4064 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4066 4067 4068 |
# File 'lib/models/porcelain.rb', line 4066 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4068 4069 4070 |
# File 'lib/models/porcelain.rb', line 4068 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4070 4071 4072 |
# File 'lib/models/porcelain.rb', line 4070 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4072 4073 4074 |
# File 'lib/models/porcelain.rb', line 4072 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4074 4075 4076 |
# File 'lib/models/porcelain.rb', line 4074 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4076 4077 4078 |
# File 'lib/models/porcelain.rb', line 4076 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4078 4079 4080 |
# File 'lib/models/porcelain.rb', line 4078 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4080 4081 4082 |
# File 'lib/models/porcelain.rb', line 4080 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4082 4083 4084 |
# File 'lib/models/porcelain.rb', line 4082 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4084 4085 4086 |
# File 'lib/models/porcelain.rb', line 4084 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4086 4087 4088 |
# File 'lib/models/porcelain.rb', line 4086 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4088 4089 4090 |
# File 'lib/models/porcelain.rb', line 4088 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4090 4091 4092 |
# File 'lib/models/porcelain.rb', line 4090 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4126 4127 4128 4129 4130 4131 4132 |
# File 'lib/models/porcelain.rb', line 4126 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |