Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



3831
3832
3833
3834
3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
3860
3861
3862
3863
# File 'lib/models/porcelain.rb', line 3831

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



3801
3802
3803
# File 'lib/models/porcelain.rb', line 3801

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



3803
3804
3805
# File 'lib/models/porcelain.rb', line 3803

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



3805
3806
3807
# File 'lib/models/porcelain.rb', line 3805

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



3807
3808
3809
# File 'lib/models/porcelain.rb', line 3807

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



3809
3810
3811
# File 'lib/models/porcelain.rb', line 3809

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



3811
3812
3813
# File 'lib/models/porcelain.rb', line 3811

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



3813
3814
3815
# File 'lib/models/porcelain.rb', line 3813

def name
  @name
end

#passwordObject

Returns the value of attribute password.



3815
3816
3817
# File 'lib/models/porcelain.rb', line 3815

def password
  @password
end

#portObject

Returns the value of attribute port.



3817
3818
3819
# File 'lib/models/porcelain.rb', line 3817

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



3819
3820
3821
# File 'lib/models/porcelain.rb', line 3819

def port_override
  @port_override
end

#replica_setObject

Returns the value of attribute replica_set.



3821
3822
3823
# File 'lib/models/porcelain.rb', line 3821

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



3823
3824
3825
# File 'lib/models/porcelain.rb', line 3823

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



3825
3826
3827
# File 'lib/models/porcelain.rb', line 3825

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



3827
3828
3829
# File 'lib/models/porcelain.rb', line 3827

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



3829
3830
3831
# File 'lib/models/porcelain.rb', line 3829

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



3865
3866
3867
3868
3869
3870
3871
# File 'lib/models/porcelain.rb', line 3865

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end