Class: SDM::MongoLegacyHost

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyHost is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyHost

Returns a new instance of MongoLegacyHost.



12078
12079
12080
12081
12082
12083
12084
12085
12086
12087
12088
12089
12090
12091
12092
12093
12094
12095
12096
12097
12098
12099
12100
12101
12102
12103
12104
12105
12106
12107
12108
12109
12110
12111
12112
# File 'lib/models/porcelain.rb', line 12078

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_database ⇒ Object

The authentication database to use.



12046
12047
12048
# File 'lib/models/porcelain.rb', line 12046

def auth_database
  @auth_database
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12048
12049
12050
# File 'lib/models/porcelain.rb', line 12048

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12050
12051
12052
# File 'lib/models/porcelain.rb', line 12050

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12052
12053
12054
# File 'lib/models/porcelain.rb', line 12052

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



12054
12055
12056
# File 'lib/models/porcelain.rb', line 12054

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



12056
12057
12058
# File 'lib/models/porcelain.rb', line 12056

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12058
12059
12060
# File 'lib/models/porcelain.rb', line 12058

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



12060
12061
12062
# File 'lib/models/porcelain.rb', line 12060

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



12062
12063
12064
# File 'lib/models/porcelain.rb', line 12062

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12064
12065
12066
# File 'lib/models/porcelain.rb', line 12064

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12066
12067
12068
# File 'lib/models/porcelain.rb', line 12066

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12068
12069
12070
# File 'lib/models/porcelain.rb', line 12068

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12070
12071
12072
# File 'lib/models/porcelain.rb', line 12070

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12072
12073
12074
# File 'lib/models/porcelain.rb', line 12072

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



12074
12075
12076
# File 'lib/models/porcelain.rb', line 12074

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



12076
12077
12078
# File 'lib/models/porcelain.rb', line 12076

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12114
12115
12116
12117
12118
12119
12120
# File 'lib/models/porcelain.rb', line 12114

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end