Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



12100
12101
12102
12103
12104
12105
12106
12107
12108
12109
12110
12111
12112
12113
12114
12115
12116
12117
12118
12119
12120
12121
12122
12123
12124
12125
12126
12127
12128
12129
12130
12131
12132
12133
12134
12135
12136
# File 'lib/models/porcelain.rb', line 12100

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



12066
12067
12068
# File 'lib/models/porcelain.rb', line 12066

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12068
12069
12070
# File 'lib/models/porcelain.rb', line 12068

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



12070
12071
12072
# File 'lib/models/porcelain.rb', line 12070

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12072
12073
12074
# File 'lib/models/porcelain.rb', line 12072

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12074
12075
12076
# File 'lib/models/porcelain.rb', line 12074

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12076
12077
12078
# File 'lib/models/porcelain.rb', line 12076

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12078
12079
12080
# File 'lib/models/porcelain.rb', line 12078

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12080
12081
12082
# File 'lib/models/porcelain.rb', line 12080

def name
  @name
end

#passwordObject

The password to authenticate with.



12082
12083
12084
# File 'lib/models/porcelain.rb', line 12082

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12084
12085
12086
# File 'lib/models/porcelain.rb', line 12084

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12086
12087
12088
# File 'lib/models/porcelain.rb', line 12086

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12088
12089
12090
# File 'lib/models/porcelain.rb', line 12088

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12090
12091
12092
# File 'lib/models/porcelain.rb', line 12090

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12092
12093
12094
# File 'lib/models/porcelain.rb', line 12092

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12094
12095
12096
# File 'lib/models/porcelain.rb', line 12094

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



12096
12097
12098
# File 'lib/models/porcelain.rb', line 12096

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



12098
12099
12100
# File 'lib/models/porcelain.rb', line 12098

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12138
12139
12140
12141
12142
12143
12144
# File 'lib/models/porcelain.rb', line 12138

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end