Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



11564
11565
11566
11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
11581
11582
11583
11584
11585
11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
# File 'lib/models/porcelain.rb', line 11564

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11530
11531
11532
# File 'lib/models/porcelain.rb', line 11530

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11532
11533
11534
# File 'lib/models/porcelain.rb', line 11532

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



11534
11535
11536
# File 'lib/models/porcelain.rb', line 11534

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11536
11537
11538
# File 'lib/models/porcelain.rb', line 11536

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11538
11539
11540
# File 'lib/models/porcelain.rb', line 11538

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11540
11541
11542
# File 'lib/models/porcelain.rb', line 11540

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11542
11543
11544
# File 'lib/models/porcelain.rb', line 11542

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11544
11545
11546
# File 'lib/models/porcelain.rb', line 11544

def name
  @name
end

#passwordObject

The password to authenticate with.



11546
11547
11548
# File 'lib/models/porcelain.rb', line 11546

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11548
11549
11550
# File 'lib/models/porcelain.rb', line 11548

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11550
11551
11552
# File 'lib/models/porcelain.rb', line 11550

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11552
11553
11554
# File 'lib/models/porcelain.rb', line 11552

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11554
11555
11556
# File 'lib/models/porcelain.rb', line 11554

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11556
11557
11558
# File 'lib/models/porcelain.rb', line 11556

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11558
11559
11560
# File 'lib/models/porcelain.rb', line 11558

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11560
11561
11562
# File 'lib/models/porcelain.rb', line 11560

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11562
11563
11564
# File 'lib/models/porcelain.rb', line 11562

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11602
11603
11604
11605
11606
11607
11608
# File 'lib/models/porcelain.rb', line 11602

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end