Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



11196
11197
11198
11199
11200
11201
11202
11203
11204
11205
11206
11207
11208
11209
11210
11211
11212
11213
11214
11215
11216
11217
11218
11219
11220
11221
11222
11223
11224
11225
11226
11227
11228
11229
11230
11231
11232
# File 'lib/models/porcelain.rb', line 11196

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11162
11163
11164
# File 'lib/models/porcelain.rb', line 11162

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11164
11165
11166
# File 'lib/models/porcelain.rb', line 11164

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



11166
11167
11168
# File 'lib/models/porcelain.rb', line 11166

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11168
11169
11170
# File 'lib/models/porcelain.rb', line 11168

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11170
11171
11172
# File 'lib/models/porcelain.rb', line 11170

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11172
11173
11174
# File 'lib/models/porcelain.rb', line 11172

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11174
11175
11176
# File 'lib/models/porcelain.rb', line 11174

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11176
11177
11178
# File 'lib/models/porcelain.rb', line 11176

def name
  @name
end

#passwordObject

The password to authenticate with.



11178
11179
11180
# File 'lib/models/porcelain.rb', line 11178

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11180
11181
11182
# File 'lib/models/porcelain.rb', line 11180

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11182
11183
11184
# File 'lib/models/porcelain.rb', line 11182

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11184
11185
11186
# File 'lib/models/porcelain.rb', line 11184

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11186
11187
11188
# File 'lib/models/porcelain.rb', line 11186

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11188
11189
11190
# File 'lib/models/porcelain.rb', line 11188

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11190
11191
11192
# File 'lib/models/porcelain.rb', line 11190

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11192
11193
11194
# File 'lib/models/porcelain.rb', line 11192

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11194
11195
11196
# File 'lib/models/porcelain.rb', line 11194

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11234
11235
11236
11237
11238
11239
11240
# File 'lib/models/porcelain.rb', line 11234

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end