Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



9569
9570
9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
9596
9597
9598
9599
9600
9601
9602
9603
9604
9605
9606
9607
# File 'lib/models/porcelain.rb', line 9569

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



9533
9534
9535
# File 'lib/models/porcelain.rb', line 9533

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9535
9536
9537
# File 'lib/models/porcelain.rb', line 9535

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



9537
9538
9539
# File 'lib/models/porcelain.rb', line 9537

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9539
9540
9541
# File 'lib/models/porcelain.rb', line 9539

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9541
9542
9543
# File 'lib/models/porcelain.rb', line 9541

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9543
9544
9545
# File 'lib/models/porcelain.rb', line 9543

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9545
9546
9547
# File 'lib/models/porcelain.rb', line 9545

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9547
9548
9549
# File 'lib/models/porcelain.rb', line 9547

def name
  @name
end

#passwordObject

The password to authenticate with.



9549
9550
9551
# File 'lib/models/porcelain.rb', line 9549

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9551
9552
9553
# File 'lib/models/porcelain.rb', line 9551

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9553
9554
9555
# File 'lib/models/porcelain.rb', line 9553

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9555
9556
9557
# File 'lib/models/porcelain.rb', line 9555

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



9557
9558
9559
# File 'lib/models/porcelain.rb', line 9557

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9559
9560
9561
# File 'lib/models/porcelain.rb', line 9559

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9561
9562
9563
# File 'lib/models/porcelain.rb', line 9561

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9563
9564
9565
# File 'lib/models/porcelain.rb', line 9563

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9565
9566
9567
# File 'lib/models/porcelain.rb', line 9565

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9567
9568
9569
# File 'lib/models/porcelain.rb', line 9567

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9609
9610
9611
9612
9613
9614
9615
# File 'lib/models/porcelain.rb', line 9609

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end