Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Overview
MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
9143 9144 9145 9146 9147 9148 9149 9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 9163 9164 9165 9166 9167 9168 9169 9170 9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 |
# File 'lib/models/porcelain.rb', line 9143 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
9107 9108 9109 |
# File 'lib/models/porcelain.rb', line 9107 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9109 9110 9111 |
# File 'lib/models/porcelain.rb', line 9109 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
9111 9112 9113 |
# File 'lib/models/porcelain.rb', line 9111 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9113 9114 9115 |
# File 'lib/models/porcelain.rb', line 9113 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9115 9116 9117 |
# File 'lib/models/porcelain.rb', line 9115 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9117 9118 9119 |
# File 'lib/models/porcelain.rb', line 9117 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9119 9120 9121 |
# File 'lib/models/porcelain.rb', line 9119 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9121 9122 9123 |
# File 'lib/models/porcelain.rb', line 9121 def name @name end |
#password ⇒ Object
The password to authenticate with.
9123 9124 9125 |
# File 'lib/models/porcelain.rb', line 9123 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9125 9126 9127 |
# File 'lib/models/porcelain.rb', line 9125 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9127 9128 9129 |
# File 'lib/models/porcelain.rb', line 9127 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9129 9130 9131 |
# File 'lib/models/porcelain.rb', line 9129 def proxy_cluster_id @proxy_cluster_id end |
#replica_set ⇒ Object
The name of the mongo replicaset.
9131 9132 9133 |
# File 'lib/models/porcelain.rb', line 9131 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9133 9134 9135 |
# File 'lib/models/porcelain.rb', line 9133 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9135 9136 9137 |
# File 'lib/models/porcelain.rb', line 9135 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9137 9138 9139 |
# File 'lib/models/porcelain.rb', line 9137 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9139 9140 9141 |
# File 'lib/models/porcelain.rb', line 9139 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9141 9142 9143 |
# File 'lib/models/porcelain.rb', line 9141 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9183 9184 9185 9186 9187 9188 9189 |
# File 'lib/models/porcelain.rb', line 9183 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |