Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



9007
9008
9009
9010
9011
9012
9013
9014
9015
9016
9017
9018
9019
9020
9021
9022
9023
9024
9025
9026
9027
9028
9029
9030
9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
# File 'lib/models/porcelain.rb', line 9007

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



8971
8972
8973
# File 'lib/models/porcelain.rb', line 8971

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8973
8974
8975
# File 'lib/models/porcelain.rb', line 8973

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



8975
8976
8977
# File 'lib/models/porcelain.rb', line 8975

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8977
8978
8979
# File 'lib/models/porcelain.rb', line 8977

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8979
8980
8981
# File 'lib/models/porcelain.rb', line 8979

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8981
8982
8983
# File 'lib/models/porcelain.rb', line 8981

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8983
8984
8985
# File 'lib/models/porcelain.rb', line 8983

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8985
8986
8987
# File 'lib/models/porcelain.rb', line 8985

def name
  @name
end

#passwordObject

The password to authenticate with.



8987
8988
8989
# File 'lib/models/porcelain.rb', line 8987

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8989
8990
8991
# File 'lib/models/porcelain.rb', line 8989

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8991
8992
8993
# File 'lib/models/porcelain.rb', line 8991

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8993
8994
8995
# File 'lib/models/porcelain.rb', line 8993

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



8995
8996
8997
# File 'lib/models/porcelain.rb', line 8995

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8997
8998
8999
# File 'lib/models/porcelain.rb', line 8997

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8999
9000
9001
# File 'lib/models/porcelain.rb', line 8999

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9001
9002
9003
# File 'lib/models/porcelain.rb', line 9001

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9003
9004
9005
# File 'lib/models/porcelain.rb', line 9003

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9005
9006
9007
# File 'lib/models/porcelain.rb', line 9005

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9047
9048
9049
9050
9051
9052
9053
# File 'lib/models/porcelain.rb', line 9047

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end