Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



8156
8157
8158
8159
8160
8161
8162
8163
8164
8165
8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
8180
8181
8182
8183
8184
8185
8186
8187
8188
8189
8190
8191
8192
8193
8194
# File 'lib/models/porcelain.rb', line 8156

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



8120
8121
8122
# File 'lib/models/porcelain.rb', line 8120

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8122
8123
8124
# File 'lib/models/porcelain.rb', line 8122

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



8124
8125
8126
# File 'lib/models/porcelain.rb', line 8124

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8126
8127
8128
# File 'lib/models/porcelain.rb', line 8126

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8128
8129
8130
# File 'lib/models/porcelain.rb', line 8128

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8130
8131
8132
# File 'lib/models/porcelain.rb', line 8130

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8132
8133
8134
# File 'lib/models/porcelain.rb', line 8132

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8134
8135
8136
# File 'lib/models/porcelain.rb', line 8134

def name
  @name
end

#passwordObject

The password to authenticate with.



8136
8137
8138
# File 'lib/models/porcelain.rb', line 8136

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8138
8139
8140
# File 'lib/models/porcelain.rb', line 8138

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8140
8141
8142
# File 'lib/models/porcelain.rb', line 8140

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8142
8143
8144
# File 'lib/models/porcelain.rb', line 8142

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



8144
8145
8146
# File 'lib/models/porcelain.rb', line 8144

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8146
8147
8148
# File 'lib/models/porcelain.rb', line 8146

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8148
8149
8150
# File 'lib/models/porcelain.rb', line 8148

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8150
8151
8152
# File 'lib/models/porcelain.rb', line 8150

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8152
8153
8154
# File 'lib/models/porcelain.rb', line 8152

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8154
8155
8156
# File 'lib/models/porcelain.rb', line 8154

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8196
8197
8198
8199
8200
8201
8202
# File 'lib/models/porcelain.rb', line 8196

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end