Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
8115
8116
8117
8118
8119
8120
# File 'lib/models/porcelain.rb', line 8082

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



8046
8047
8048
# File 'lib/models/porcelain.rb', line 8046

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8048
8049
8050
# File 'lib/models/porcelain.rb', line 8048

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



8050
8051
8052
# File 'lib/models/porcelain.rb', line 8050

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8052
8053
8054
# File 'lib/models/porcelain.rb', line 8052

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8054
8055
8056
# File 'lib/models/porcelain.rb', line 8054

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8056
8057
8058
# File 'lib/models/porcelain.rb', line 8056

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8058
8059
8060
# File 'lib/models/porcelain.rb', line 8058

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8060
8061
8062
# File 'lib/models/porcelain.rb', line 8060

def name
  @name
end

#passwordObject

The password to authenticate with.



8062
8063
8064
# File 'lib/models/porcelain.rb', line 8062

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8064
8065
8066
# File 'lib/models/porcelain.rb', line 8064

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8066
8067
8068
# File 'lib/models/porcelain.rb', line 8066

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8068
8069
8070
# File 'lib/models/porcelain.rb', line 8068

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



8070
8071
8072
# File 'lib/models/porcelain.rb', line 8070

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8072
8073
8074
# File 'lib/models/porcelain.rb', line 8072

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8074
8075
8076
# File 'lib/models/porcelain.rb', line 8074

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8076
8077
8078
# File 'lib/models/porcelain.rb', line 8076

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8078
8079
8080
# File 'lib/models/porcelain.rb', line 8078

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8080
8081
8082
# File 'lib/models/porcelain.rb', line 8080

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8122
8123
8124
8125
8126
8127
8128
# File 'lib/models/porcelain.rb', line 8122

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end