Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Overview
MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
8002 8003 8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 8025 8026 8027 8028 8029 8030 8031 8032 8033 8034 8035 8036 8037 8038 8039 8040 |
# File 'lib/models/porcelain.rb', line 8002 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
7966 7967 7968 |
# File 'lib/models/porcelain.rb', line 7966 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7968 7969 7970 |
# File 'lib/models/porcelain.rb', line 7968 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
7970 7971 7972 |
# File 'lib/models/porcelain.rb', line 7970 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7972 7973 7974 |
# File 'lib/models/porcelain.rb', line 7972 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7974 7975 7976 |
# File 'lib/models/porcelain.rb', line 7974 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7976 7977 7978 |
# File 'lib/models/porcelain.rb', line 7976 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7978 7979 7980 |
# File 'lib/models/porcelain.rb', line 7978 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7980 7981 7982 |
# File 'lib/models/porcelain.rb', line 7980 def name @name end |
#password ⇒ Object
The password to authenticate with.
7982 7983 7984 |
# File 'lib/models/porcelain.rb', line 7982 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7984 7985 7986 |
# File 'lib/models/porcelain.rb', line 7984 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7986 7987 7988 |
# File 'lib/models/porcelain.rb', line 7986 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7988 7989 7990 |
# File 'lib/models/porcelain.rb', line 7988 def proxy_cluster_id @proxy_cluster_id end |
#replica_set ⇒ Object
The name of the mongo replicaset.
7990 7991 7992 |
# File 'lib/models/porcelain.rb', line 7990 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7992 7993 7994 |
# File 'lib/models/porcelain.rb', line 7992 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7994 7995 7996 |
# File 'lib/models/porcelain.rb', line 7994 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7996 7997 7998 |
# File 'lib/models/porcelain.rb', line 7996 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7998 7999 8000 |
# File 'lib/models/porcelain.rb', line 7998 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8000 8001 8002 |
# File 'lib/models/porcelain.rb', line 8000 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8042 8043 8044 8045 8046 8047 8048 |
# File 'lib/models/porcelain.rb', line 8042 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |