Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



7321
7322
7323
7324
7325
7326
7327
7328
7329
7330
7331
7332
7333
7334
7335
7336
7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
# File 'lib/models/porcelain.rb', line 7321

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7285
7286
7287
# File 'lib/models/porcelain.rb', line 7285

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7287
7288
7289
# File 'lib/models/porcelain.rb', line 7287

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



7289
7290
7291
# File 'lib/models/porcelain.rb', line 7289

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7291
7292
7293
# File 'lib/models/porcelain.rb', line 7291

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7293
7294
7295
# File 'lib/models/porcelain.rb', line 7293

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7295
7296
7297
# File 'lib/models/porcelain.rb', line 7295

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7297
7298
7299
# File 'lib/models/porcelain.rb', line 7297

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7299
7300
7301
# File 'lib/models/porcelain.rb', line 7299

def name
  @name
end

#passwordObject

The password to authenticate with.



7301
7302
7303
# File 'lib/models/porcelain.rb', line 7301

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7303
7304
7305
# File 'lib/models/porcelain.rb', line 7303

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7305
7306
7307
# File 'lib/models/porcelain.rb', line 7305

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7307
7308
7309
# File 'lib/models/porcelain.rb', line 7307

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



7309
7310
7311
# File 'lib/models/porcelain.rb', line 7309

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7311
7312
7313
# File 'lib/models/porcelain.rb', line 7311

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7313
7314
7315
# File 'lib/models/porcelain.rb', line 7313

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7315
7316
7317
# File 'lib/models/porcelain.rb', line 7315

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7317
7318
7319
# File 'lib/models/porcelain.rb', line 7317

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7319
7320
7321
# File 'lib/models/porcelain.rb', line 7319

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7361
7362
7363
7364
7365
7366
7367
# File 'lib/models/porcelain.rb', line 7361

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end