Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



7250
7251
7252
7253
7254
7255
7256
7257
7258
7259
7260
7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
7284
7285
7286
7287
7288
# File 'lib/models/porcelain.rb', line 7250

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7214
7215
7216
# File 'lib/models/porcelain.rb', line 7214

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7216
7217
7218
# File 'lib/models/porcelain.rb', line 7216

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



7218
7219
7220
# File 'lib/models/porcelain.rb', line 7218

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7220
7221
7222
# File 'lib/models/porcelain.rb', line 7220

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7222
7223
7224
# File 'lib/models/porcelain.rb', line 7222

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7224
7225
7226
# File 'lib/models/porcelain.rb', line 7224

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7226
7227
7228
# File 'lib/models/porcelain.rb', line 7226

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7228
7229
7230
# File 'lib/models/porcelain.rb', line 7228

def name
  @name
end

#passwordObject

The password to authenticate with.



7230
7231
7232
# File 'lib/models/porcelain.rb', line 7230

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7232
7233
7234
# File 'lib/models/porcelain.rb', line 7232

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7234
7235
7236
# File 'lib/models/porcelain.rb', line 7234

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7236
7237
7238
# File 'lib/models/porcelain.rb', line 7236

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



7238
7239
7240
# File 'lib/models/porcelain.rb', line 7238

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7240
7241
7242
# File 'lib/models/porcelain.rb', line 7240

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7242
7243
7244
# File 'lib/models/porcelain.rb', line 7242

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7244
7245
7246
# File 'lib/models/porcelain.rb', line 7244

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7246
7247
7248
# File 'lib/models/porcelain.rb', line 7246

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7248
7249
7250
# File 'lib/models/porcelain.rb', line 7248

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7290
7291
7292
7293
7294
7295
7296
# File 'lib/models/porcelain.rb', line 7290

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end