Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Overview
MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 6976 6977 6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 |
# File 'lib/models/porcelain.rb', line 6951 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
6917 6918 6919 |
# File 'lib/models/porcelain.rb', line 6917 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6919 6920 6921 |
# File 'lib/models/porcelain.rb', line 6919 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
6921 6922 6923 |
# File 'lib/models/porcelain.rb', line 6921 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6923 6924 6925 |
# File 'lib/models/porcelain.rb', line 6923 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6925 6926 6927 |
# File 'lib/models/porcelain.rb', line 6925 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6927 6928 6929 |
# File 'lib/models/porcelain.rb', line 6927 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6929 6930 6931 |
# File 'lib/models/porcelain.rb', line 6929 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6931 6932 6933 |
# File 'lib/models/porcelain.rb', line 6931 def name @name end |
#password ⇒ Object
The password to authenticate with.
6933 6934 6935 |
# File 'lib/models/porcelain.rb', line 6933 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6935 6936 6937 |
# File 'lib/models/porcelain.rb', line 6935 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6937 6938 6939 |
# File 'lib/models/porcelain.rb', line 6937 def port_override @port_override end |
#replica_set ⇒ Object
The name of the mongo replicaset.
6939 6940 6941 |
# File 'lib/models/porcelain.rb', line 6939 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6941 6942 6943 |
# File 'lib/models/porcelain.rb', line 6941 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6943 6944 6945 |
# File 'lib/models/porcelain.rb', line 6943 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6945 6946 6947 |
# File 'lib/models/porcelain.rb', line 6945 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
6947 6948 6949 |
# File 'lib/models/porcelain.rb', line 6947 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
6949 6950 6951 |
# File 'lib/models/porcelain.rb', line 6949 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6989 6990 6991 6992 6993 6994 6995 |
# File 'lib/models/porcelain.rb', line 6989 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |