Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 6638 6639 6640 6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 6651 6652 |
# File 'lib/models/porcelain.rb', line 6616 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
6582 6583 6584 |
# File 'lib/models/porcelain.rb', line 6582 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6584 6585 6586 |
# File 'lib/models/porcelain.rb', line 6584 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
6586 6587 6588 |
# File 'lib/models/porcelain.rb', line 6586 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6588 6589 6590 |
# File 'lib/models/porcelain.rb', line 6588 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6590 6591 6592 |
# File 'lib/models/porcelain.rb', line 6590 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6592 6593 6594 |
# File 'lib/models/porcelain.rb', line 6592 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6594 6595 6596 |
# File 'lib/models/porcelain.rb', line 6594 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6596 6597 6598 |
# File 'lib/models/porcelain.rb', line 6596 def name @name end |
#password ⇒ Object
The password to authenticate with.
6598 6599 6600 |
# File 'lib/models/porcelain.rb', line 6598 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6600 6601 6602 |
# File 'lib/models/porcelain.rb', line 6600 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6602 6603 6604 |
# File 'lib/models/porcelain.rb', line 6602 def port_override @port_override end |
#replica_set ⇒ Object
The name of the mongo replicaset.
6604 6605 6606 |
# File 'lib/models/porcelain.rb', line 6604 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6606 6607 6608 |
# File 'lib/models/porcelain.rb', line 6606 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6608 6609 6610 |
# File 'lib/models/porcelain.rb', line 6608 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6610 6611 6612 |
# File 'lib/models/porcelain.rb', line 6610 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
6612 6613 6614 |
# File 'lib/models/porcelain.rb', line 6612 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
6614 6615 6616 |
# File 'lib/models/porcelain.rb', line 6614 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6654 6655 6656 6657 6658 6659 6660 |
# File 'lib/models/porcelain.rb', line 6654 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |