Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/models/porcelain.rb', line 5394 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
5360 5361 5362 |
# File 'lib/models/porcelain.rb', line 5360 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5362 5363 5364 |
# File 'lib/models/porcelain.rb', line 5362 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
5364 5365 5366 |
# File 'lib/models/porcelain.rb', line 5364 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5366 5367 5368 |
# File 'lib/models/porcelain.rb', line 5366 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5368 5369 5370 |
# File 'lib/models/porcelain.rb', line 5368 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5370 5371 5372 |
# File 'lib/models/porcelain.rb', line 5370 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5372 5373 5374 |
# File 'lib/models/porcelain.rb', line 5372 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5374 5375 5376 |
# File 'lib/models/porcelain.rb', line 5374 def name @name end |
#password ⇒ Object
The password to authenticate with.
5376 5377 5378 |
# File 'lib/models/porcelain.rb', line 5376 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5378 5379 5380 |
# File 'lib/models/porcelain.rb', line 5378 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5380 5381 5382 |
# File 'lib/models/porcelain.rb', line 5380 def port_override @port_override end |
#replica_set ⇒ Object
The name of the mongo replicaset.
5382 5383 5384 |
# File 'lib/models/porcelain.rb', line 5382 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5384 5385 5386 |
# File 'lib/models/porcelain.rb', line 5384 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5386 5387 5388 |
# File 'lib/models/porcelain.rb', line 5386 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5388 5389 5390 |
# File 'lib/models/porcelain.rb', line 5388 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5390 5391 5392 |
# File 'lib/models/porcelain.rb', line 5390 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5392 5393 5394 |
# File 'lib/models/porcelain.rb', line 5392 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5432 5433 5434 5435 5436 5437 5438 |
# File 'lib/models/porcelain.rb', line 5432 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |