Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
5246
5247
5248
5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
5264
5265
5266
# File 'lib/models/porcelain.rb', line 5230

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5196
5197
5198
# File 'lib/models/porcelain.rb', line 5196

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5198
5199
5200
# File 'lib/models/porcelain.rb', line 5198

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



5200
5201
5202
# File 'lib/models/porcelain.rb', line 5200

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5202
5203
5204
# File 'lib/models/porcelain.rb', line 5202

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5204
5205
5206
# File 'lib/models/porcelain.rb', line 5204

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5206
5207
5208
# File 'lib/models/porcelain.rb', line 5206

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5208
5209
5210
# File 'lib/models/porcelain.rb', line 5208

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5210
5211
5212
# File 'lib/models/porcelain.rb', line 5210

def name
  @name
end

#passwordObject

The password to authenticate with.



5212
5213
5214
# File 'lib/models/porcelain.rb', line 5212

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5214
5215
5216
# File 'lib/models/porcelain.rb', line 5214

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5216
5217
5218
# File 'lib/models/porcelain.rb', line 5216

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



5218
5219
5220
# File 'lib/models/porcelain.rb', line 5218

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5220
5221
5222
# File 'lib/models/porcelain.rb', line 5220

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5222
5223
5224
# File 'lib/models/porcelain.rb', line 5222

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5224
5225
5226
# File 'lib/models/porcelain.rb', line 5224

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5226
5227
5228
# File 'lib/models/porcelain.rb', line 5226

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5228
5229
5230
# File 'lib/models/porcelain.rb', line 5228

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5268
5269
5270
5271
5272
5273
5274
# File 'lib/models/porcelain.rb', line 5268

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end