Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 |
# File 'lib/models/porcelain.rb', line 5056 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
5022 5023 5024 |
# File 'lib/models/porcelain.rb', line 5022 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
5024 5025 5026 |
# File 'lib/models/porcelain.rb', line 5024 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
5026 5027 5028 |
# File 'lib/models/porcelain.rb', line 5026 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5028 5029 5030 |
# File 'lib/models/porcelain.rb', line 5028 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5030 5031 5032 |
# File 'lib/models/porcelain.rb', line 5030 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5032 5033 5034 |
# File 'lib/models/porcelain.rb', line 5032 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5034 5035 5036 |
# File 'lib/models/porcelain.rb', line 5034 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5036 5037 5038 |
# File 'lib/models/porcelain.rb', line 5036 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5038 5039 5040 |
# File 'lib/models/porcelain.rb', line 5038 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5040 5041 5042 |
# File 'lib/models/porcelain.rb', line 5040 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5042 5043 5044 |
# File 'lib/models/porcelain.rb', line 5042 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
5044 5045 5046 |
# File 'lib/models/porcelain.rb', line 5044 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5046 5047 5048 |
# File 'lib/models/porcelain.rb', line 5046 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5048 5049 5050 |
# File 'lib/models/porcelain.rb', line 5048 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5050 5051 5052 |
# File 'lib/models/porcelain.rb', line 5050 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5052 5053 5054 |
# File 'lib/models/porcelain.rb', line 5052 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5054 5055 5056 |
# File 'lib/models/porcelain.rb', line 5054 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/models/porcelain.rb', line 5094 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |