Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 |
# File 'lib/models/porcelain.rb', line 4712 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4680 4681 4682 |
# File 'lib/models/porcelain.rb', line 4680 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4682 4683 4684 |
# File 'lib/models/porcelain.rb', line 4682 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
4684 4685 4686 |
# File 'lib/models/porcelain.rb', line 4684 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4686 4687 4688 |
# File 'lib/models/porcelain.rb', line 4686 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4688 4689 4690 |
# File 'lib/models/porcelain.rb', line 4688 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4690 4691 4692 |
# File 'lib/models/porcelain.rb', line 4690 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4692 4693 4694 |
# File 'lib/models/porcelain.rb', line 4692 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4694 4695 4696 |
# File 'lib/models/porcelain.rb', line 4694 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4696 4697 4698 |
# File 'lib/models/porcelain.rb', line 4696 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4698 4699 4700 |
# File 'lib/models/porcelain.rb', line 4698 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4700 4701 4702 |
# File 'lib/models/porcelain.rb', line 4700 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4702 4703 4704 |
# File 'lib/models/porcelain.rb', line 4702 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4704 4705 4706 |
# File 'lib/models/porcelain.rb', line 4704 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4706 4707 4708 |
# File 'lib/models/porcelain.rb', line 4706 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4708 4709 4710 |
# File 'lib/models/porcelain.rb', line 4708 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4710 4711 4712 |
# File 'lib/models/porcelain.rb', line 4710 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4748 4749 4750 4751 4752 4753 4754 |
# File 'lib/models/porcelain.rb', line 4748 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |