Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 |
# File 'lib/models/porcelain.rb', line 4374 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4342 4343 4344 |
# File 'lib/models/porcelain.rb', line 4342 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4344 4345 4346 |
# File 'lib/models/porcelain.rb', line 4344 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
4346 4347 4348 |
# File 'lib/models/porcelain.rb', line 4346 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4348 4349 4350 |
# File 'lib/models/porcelain.rb', line 4348 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4350 4351 4352 |
# File 'lib/models/porcelain.rb', line 4350 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4352 4353 4354 |
# File 'lib/models/porcelain.rb', line 4352 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4354 4355 4356 |
# File 'lib/models/porcelain.rb', line 4354 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4356 4357 4358 |
# File 'lib/models/porcelain.rb', line 4356 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4358 4359 4360 |
# File 'lib/models/porcelain.rb', line 4358 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4360 4361 4362 |
# File 'lib/models/porcelain.rb', line 4360 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4362 4363 4364 |
# File 'lib/models/porcelain.rb', line 4362 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4364 4365 4366 |
# File 'lib/models/porcelain.rb', line 4364 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4366 4367 4368 |
# File 'lib/models/porcelain.rb', line 4366 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4368 4369 4370 |
# File 'lib/models/porcelain.rb', line 4368 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4370 4371 4372 |
# File 'lib/models/porcelain.rb', line 4370 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4372 4373 4374 |
# File 'lib/models/porcelain.rb', line 4372 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4410 4411 4412 4413 4414 4415 4416 |
# File 'lib/models/porcelain.rb', line 4410 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |