Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
4301
# File 'lib/models/porcelain.rb', line 4267

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4235
4236
4237
# File 'lib/models/porcelain.rb', line 4235

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4237
4238
4239
# File 'lib/models/porcelain.rb', line 4237

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Returns the value of attribute connect_to_replica.



4239
4240
4241
# File 'lib/models/porcelain.rb', line 4239

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4241
4242
4243
# File 'lib/models/porcelain.rb', line 4241

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4243
4244
4245
# File 'lib/models/porcelain.rb', line 4243

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4245
4246
4247
# File 'lib/models/porcelain.rb', line 4245

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4247
4248
4249
# File 'lib/models/porcelain.rb', line 4247

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4249
4250
4251
# File 'lib/models/porcelain.rb', line 4249

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4251
4252
4253
# File 'lib/models/porcelain.rb', line 4251

def password
  @password
end

#portObject

Returns the value of attribute port.



4253
4254
4255
# File 'lib/models/porcelain.rb', line 4253

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4255
4256
4257
# File 'lib/models/porcelain.rb', line 4255

def port_override
  @port_override
end

#replica_setObject

Returns the value of attribute replica_set.



4257
4258
4259
# File 'lib/models/porcelain.rb', line 4257

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4259
4260
4261
# File 'lib/models/porcelain.rb', line 4259

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4261
4262
4263
# File 'lib/models/porcelain.rb', line 4261

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4263
4264
4265
# File 'lib/models/porcelain.rb', line 4263

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4265
4266
4267
# File 'lib/models/porcelain.rb', line 4265

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4303
4304
4305
4306
4307
4308
4309
# File 'lib/models/porcelain.rb', line 4303

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end