Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 3939 3940 3941 |
# File 'lib/models/porcelain.rb', line 3907 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
3875 3876 3877 |
# File 'lib/models/porcelain.rb', line 3875 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
3877 3878 3879 |
# File 'lib/models/porcelain.rb', line 3877 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
3879 3880 3881 |
# File 'lib/models/porcelain.rb', line 3879 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3881 3882 3883 |
# File 'lib/models/porcelain.rb', line 3881 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3883 3884 3885 |
# File 'lib/models/porcelain.rb', line 3883 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3885 3886 3887 |
# File 'lib/models/porcelain.rb', line 3885 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3887 3888 3889 |
# File 'lib/models/porcelain.rb', line 3887 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3889 3890 3891 |
# File 'lib/models/porcelain.rb', line 3889 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3891 3892 3893 |
# File 'lib/models/porcelain.rb', line 3891 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3893 3894 3895 |
# File 'lib/models/porcelain.rb', line 3893 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3895 3896 3897 |
# File 'lib/models/porcelain.rb', line 3895 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
3897 3898 3899 |
# File 'lib/models/porcelain.rb', line 3897 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3899 3900 3901 |
# File 'lib/models/porcelain.rb', line 3899 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3901 3902 3903 |
# File 'lib/models/porcelain.rb', line 3901 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
3903 3904 3905 |
# File 'lib/models/porcelain.rb', line 3903 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
3905 3906 3907 |
# File 'lib/models/porcelain.rb', line 3905 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3943 3944 3945 3946 3947 3948 3949 |
# File 'lib/models/porcelain.rb', line 3943 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |