Class: SDM::MongoLegacyReplicaset
- Inherits:
-
Object
- Object
- SDM::MongoLegacyReplicaset
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
constructor
A new instance of MongoLegacyReplicaset.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset
Returns a new instance of MongoLegacyReplicaset.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 |
# File 'lib/models/porcelain.rb', line 4606 def initialize( auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) if auth_database != nil @auth_database = auth_database end if connect_to_replica != nil @connect_to_replica = connect_to_replica end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if replica_set != nil @replica_set = replica_set end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end if username != nil @username = username end end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4576 4577 4578 |
# File 'lib/models/porcelain.rb', line 4576 def auth_database @auth_database end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
4578 4579 4580 |
# File 'lib/models/porcelain.rb', line 4578 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4580 4581 4582 |
# File 'lib/models/porcelain.rb', line 4580 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4582 4583 4584 |
# File 'lib/models/porcelain.rb', line 4582 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4584 4585 4586 |
# File 'lib/models/porcelain.rb', line 4584 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4586 4587 4588 |
# File 'lib/models/porcelain.rb', line 4586 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4588 4589 4590 |
# File 'lib/models/porcelain.rb', line 4588 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4590 4591 4592 |
# File 'lib/models/porcelain.rb', line 4590 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4592 4593 4594 |
# File 'lib/models/porcelain.rb', line 4592 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4594 4595 4596 |
# File 'lib/models/porcelain.rb', line 4594 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4596 4597 4598 |
# File 'lib/models/porcelain.rb', line 4596 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4598 4599 4600 |
# File 'lib/models/porcelain.rb', line 4598 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4600 4601 4602 |
# File 'lib/models/porcelain.rb', line 4600 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4602 4603 4604 |
# File 'lib/models/porcelain.rb', line 4602 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4604 4605 4606 |
# File 'lib/models/porcelain.rb', line 4604 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/models/porcelain.rb', line 4670 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |