Class: SDM::MongoLegacyReplicaset

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoLegacyReplicaset is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoLegacyReplicaset

Returns a new instance of MongoLegacyReplicaset.



12160
12161
12162
12163
12164
12165
12166
12167
12168
12169
12170
12171
12172
12173
12174
12175
12176
12177
12178
12179
12180
12181
12182
12183
12184
12185
12186
12187
12188
12189
12190
12191
12192
12193
12194
12195
12196
# File 'lib/models/porcelain.rb', line 12160

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_database ⇒ Object

The authentication database to use.



12126
12127
12128
# File 'lib/models/porcelain.rb', line 12126

def auth_database
  @auth_database
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12128
12129
12130
# File 'lib/models/porcelain.rb', line 12128

def bind_interface
  @bind_interface
end

#connect_to_replica ⇒ Object

Set to connect to a replica instead of the primary node.



12130
12131
12132
# File 'lib/models/porcelain.rb', line 12130

def connect_to_replica
  @connect_to_replica
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12132
12133
12134
# File 'lib/models/porcelain.rb', line 12132

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12134
12135
12136
# File 'lib/models/porcelain.rb', line 12134

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



12136
12137
12138
# File 'lib/models/porcelain.rb', line 12136

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



12138
12139
12140
# File 'lib/models/porcelain.rb', line 12138

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12140
12141
12142
# File 'lib/models/porcelain.rb', line 12140

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



12142
12143
12144
# File 'lib/models/porcelain.rb', line 12142

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



12144
12145
12146
# File 'lib/models/porcelain.rb', line 12144

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12146
12147
12148
# File 'lib/models/porcelain.rb', line 12146

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12148
12149
12150
# File 'lib/models/porcelain.rb', line 12148

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12150
12151
12152
# File 'lib/models/porcelain.rb', line 12150

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12152
12153
12154
# File 'lib/models/porcelain.rb', line 12152

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12154
12155
12156
# File 'lib/models/porcelain.rb', line 12154

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



12156
12157
12158
# File 'lib/models/porcelain.rb', line 12156

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



12158
12159
12160
# File 'lib/models/porcelain.rb', line 12158

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12198
12199
12200
12201
12202
12203
12204
# File 'lib/models/porcelain.rb', line 12198

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end