Class: SDM::MongoReplicaSet
- Inherits:
-
Object
- Object
- SDM::MongoReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to use for IAM (MONGODB-AWS) authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
constructor
A new instance of MongoReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
Returns a new instance of MongoReplicaSet.
12185 12186 12187 12188 12189 12190 12191 12192 12193 12194 12195 12196 12197 12198 12199 12200 12201 12202 12203 12204 12205 12206 12207 12208 12209 12210 12211 12212 12213 12214 12215 12216 12217 12218 12219 12220 12221 12222 12223 |
# File 'lib/models/porcelain.rb', line 12185 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
12149 12150 12151 |
# File 'lib/models/porcelain.rb', line 12149 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
12151 12152 12153 |
# File 'lib/models/porcelain.rb', line 12151 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
12153 12154 12155 |
# File 'lib/models/porcelain.rb', line 12153 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12155 12156 12157 |
# File 'lib/models/porcelain.rb', line 12155 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12157 12158 12159 |
# File 'lib/models/porcelain.rb', line 12157 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12159 12160 12161 |
# File 'lib/models/porcelain.rb', line 12159 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12161 12162 12163 |
# File 'lib/models/porcelain.rb', line 12161 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12163 12164 12165 |
# File 'lib/models/porcelain.rb', line 12163 def name @name end |
#password ⇒ Object
The password to authenticate with.
12165 12166 12167 |
# File 'lib/models/porcelain.rb', line 12165 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12167 12168 12169 |
# File 'lib/models/porcelain.rb', line 12167 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
12169 12170 12171 |
# File 'lib/models/porcelain.rb', line 12169 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12171 12172 12173 |
# File 'lib/models/porcelain.rb', line 12171 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to use for IAM (MONGODB-AWS) authentication.
12173 12174 12175 |
# File 'lib/models/porcelain.rb', line 12173 def region @region end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12175 12176 12177 |
# File 'lib/models/porcelain.rb', line 12175 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
12177 12178 12179 |
# File 'lib/models/porcelain.rb', line 12177 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12179 12180 12181 |
# File 'lib/models/porcelain.rb', line 12179 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
12181 12182 12183 |
# File 'lib/models/porcelain.rb', line 12181 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
12183 12184 12185 |
# File 'lib/models/porcelain.rb', line 12183 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12225 12226 12227 12228 12229 12230 12231 |
# File 'lib/models/porcelain.rb', line 12225 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |