Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
11305
11306
11307
11308
11309
11310
11311
11312
11313
11314
11315
# File 'lib/models/porcelain.rb', line 11279

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11245
11246
11247
# File 'lib/models/porcelain.rb', line 11245

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11247
11248
11249
# File 'lib/models/porcelain.rb', line 11247

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



11249
11250
11251
# File 'lib/models/porcelain.rb', line 11249

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11251
11252
11253
# File 'lib/models/porcelain.rb', line 11251

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11253
11254
11255
# File 'lib/models/porcelain.rb', line 11253

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11255
11256
11257
# File 'lib/models/porcelain.rb', line 11255

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11257
11258
11259
# File 'lib/models/porcelain.rb', line 11257

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11259
11260
11261
# File 'lib/models/porcelain.rb', line 11259

def name
  @name
end

#passwordObject

The password to authenticate with.



11261
11262
11263
# File 'lib/models/porcelain.rb', line 11261

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11263
11264
11265
# File 'lib/models/porcelain.rb', line 11263

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11265
11266
11267
# File 'lib/models/porcelain.rb', line 11265

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11267
11268
11269
# File 'lib/models/porcelain.rb', line 11267

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11269
11270
11271
# File 'lib/models/porcelain.rb', line 11269

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11271
11272
11273
# File 'lib/models/porcelain.rb', line 11271

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11273
11274
11275
# File 'lib/models/porcelain.rb', line 11273

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11275
11276
11277
# File 'lib/models/porcelain.rb', line 11275

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11277
11278
11279
# File 'lib/models/porcelain.rb', line 11277

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11317
11318
11319
11320
11321
11322
11323
# File 'lib/models/porcelain.rb', line 11317

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end