Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



11215
11216
11217
11218
11219
11220
11221
11222
11223
11224
11225
11226
11227
11228
11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
11241
11242
11243
11244
11245
11246
11247
11248
11249
11250
11251
# File 'lib/models/porcelain.rb', line 11215

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11181
11182
11183
# File 'lib/models/porcelain.rb', line 11181

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11183
11184
11185
# File 'lib/models/porcelain.rb', line 11183

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



11185
11186
11187
# File 'lib/models/porcelain.rb', line 11185

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11187
11188
11189
# File 'lib/models/porcelain.rb', line 11187

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11189
11190
11191
# File 'lib/models/porcelain.rb', line 11189

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11191
11192
11193
# File 'lib/models/porcelain.rb', line 11191

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11193
11194
11195
# File 'lib/models/porcelain.rb', line 11193

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11195
11196
11197
# File 'lib/models/porcelain.rb', line 11195

def name
  @name
end

#passwordObject

The password to authenticate with.



11197
11198
11199
# File 'lib/models/porcelain.rb', line 11197

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11199
11200
11201
# File 'lib/models/porcelain.rb', line 11199

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11201
11202
11203
# File 'lib/models/porcelain.rb', line 11201

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11203
11204
11205
# File 'lib/models/porcelain.rb', line 11203

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11205
11206
11207
# File 'lib/models/porcelain.rb', line 11205

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11207
11208
11209
# File 'lib/models/porcelain.rb', line 11207

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11209
11210
11211
# File 'lib/models/porcelain.rb', line 11209

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11211
11212
11213
# File 'lib/models/porcelain.rb', line 11211

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11213
11214
11215
# File 'lib/models/porcelain.rb', line 11213

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11253
11254
11255
11256
11257
11258
11259
# File 'lib/models/porcelain.rb', line 11253

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end