Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
10604
10605
10606
10607
10608
10609
10610
10611
10612
10613
10614
10615
10616
10617
10618
10619
10620
10621
10622
10623
10624
10625
10626
10627
# File 'lib/models/porcelain.rb', line 10589

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



10553
10554
10555
# File 'lib/models/porcelain.rb', line 10553

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10555
10556
10557
# File 'lib/models/porcelain.rb', line 10555

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



10557
10558
10559
# File 'lib/models/porcelain.rb', line 10557

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10559
10560
10561
# File 'lib/models/porcelain.rb', line 10559

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10561
10562
10563
# File 'lib/models/porcelain.rb', line 10561

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10563
10564
10565
# File 'lib/models/porcelain.rb', line 10563

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10565
10566
10567
# File 'lib/models/porcelain.rb', line 10565

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10567
10568
10569
# File 'lib/models/porcelain.rb', line 10567

def name
  @name
end

#passwordObject

The password to authenticate with.



10569
10570
10571
# File 'lib/models/porcelain.rb', line 10569

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10571
10572
10573
# File 'lib/models/porcelain.rb', line 10571

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10573
10574
10575
# File 'lib/models/porcelain.rb', line 10573

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10575
10576
10577
# File 'lib/models/porcelain.rb', line 10575

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



10577
10578
10579
# File 'lib/models/porcelain.rb', line 10577

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10579
10580
10581
# File 'lib/models/porcelain.rb', line 10579

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10581
10582
10583
# File 'lib/models/porcelain.rb', line 10581

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10583
10584
10585
# File 'lib/models/porcelain.rb', line 10583

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



10585
10586
10587
# File 'lib/models/porcelain.rb', line 10585

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



10587
10588
10589
# File 'lib/models/porcelain.rb', line 10587

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10629
10630
10631
10632
10633
10634
10635
# File 'lib/models/porcelain.rb', line 10629

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end