Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



9410
9411
9412
9413
9414
9415
9416
9417
9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
# File 'lib/models/porcelain.rb', line 9410

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



9374
9375
9376
# File 'lib/models/porcelain.rb', line 9374

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9376
9377
9378
# File 'lib/models/porcelain.rb', line 9376

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



9378
9379
9380
# File 'lib/models/porcelain.rb', line 9378

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9380
9381
9382
# File 'lib/models/porcelain.rb', line 9380

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9382
9383
9384
# File 'lib/models/porcelain.rb', line 9382

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9384
9385
9386
# File 'lib/models/porcelain.rb', line 9384

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9386
9387
9388
# File 'lib/models/porcelain.rb', line 9386

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9388
9389
9390
# File 'lib/models/porcelain.rb', line 9388

def name
  @name
end

#passwordObject

The password to authenticate with.



9390
9391
9392
# File 'lib/models/porcelain.rb', line 9390

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9392
9393
9394
# File 'lib/models/porcelain.rb', line 9392

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9394
9395
9396
# File 'lib/models/porcelain.rb', line 9394

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9396
9397
9398
# File 'lib/models/porcelain.rb', line 9396

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



9398
9399
9400
# File 'lib/models/porcelain.rb', line 9398

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9400
9401
9402
# File 'lib/models/porcelain.rb', line 9400

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9402
9403
9404
# File 'lib/models/porcelain.rb', line 9402

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9404
9405
9406
# File 'lib/models/porcelain.rb', line 9404

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9406
9407
9408
# File 'lib/models/porcelain.rb', line 9406

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9408
9409
9410
# File 'lib/models/porcelain.rb', line 9408

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9450
9451
9452
9453
9454
9455
9456
# File 'lib/models/porcelain.rb', line 9450

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end