Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
9124
9125
9126
9127
9128
9129
9130
9131
9132
# File 'lib/models/porcelain.rb', line 9094

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



9058
9059
9060
# File 'lib/models/porcelain.rb', line 9058

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9060
9061
9062
# File 'lib/models/porcelain.rb', line 9060

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



9062
9063
9064
# File 'lib/models/porcelain.rb', line 9062

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9064
9065
9066
# File 'lib/models/porcelain.rb', line 9064

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9066
9067
9068
# File 'lib/models/porcelain.rb', line 9066

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9068
9069
9070
# File 'lib/models/porcelain.rb', line 9068

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9070
9071
9072
# File 'lib/models/porcelain.rb', line 9070

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9072
9073
9074
# File 'lib/models/porcelain.rb', line 9072

def name
  @name
end

#passwordObject

The password to authenticate with.



9074
9075
9076
# File 'lib/models/porcelain.rb', line 9074

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9076
9077
9078
# File 'lib/models/porcelain.rb', line 9076

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9078
9079
9080
# File 'lib/models/porcelain.rb', line 9078

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9080
9081
9082
# File 'lib/models/porcelain.rb', line 9080

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



9082
9083
9084
# File 'lib/models/porcelain.rb', line 9082

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9084
9085
9086
# File 'lib/models/porcelain.rb', line 9084

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9086
9087
9088
# File 'lib/models/porcelain.rb', line 9086

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9088
9089
9090
# File 'lib/models/porcelain.rb', line 9088

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9090
9091
9092
# File 'lib/models/porcelain.rb', line 9090

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9092
9093
9094
# File 'lib/models/porcelain.rb', line 9092

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9134
9135
9136
9137
9138
9139
9140
# File 'lib/models/porcelain.rb', line 9134

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end