Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



8243
8244
8245
8246
8247
8248
8249
8250
8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
# File 'lib/models/porcelain.rb', line 8243

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



8207
8208
8209
# File 'lib/models/porcelain.rb', line 8207

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8209
8210
8211
# File 'lib/models/porcelain.rb', line 8209

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



8211
8212
8213
# File 'lib/models/porcelain.rb', line 8211

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8213
8214
8215
# File 'lib/models/porcelain.rb', line 8213

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8215
8216
8217
# File 'lib/models/porcelain.rb', line 8215

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8217
8218
8219
# File 'lib/models/porcelain.rb', line 8217

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8219
8220
8221
# File 'lib/models/porcelain.rb', line 8219

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8221
8222
8223
# File 'lib/models/porcelain.rb', line 8221

def name
  @name
end

#passwordObject

The password to authenticate with.



8223
8224
8225
# File 'lib/models/porcelain.rb', line 8223

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8225
8226
8227
# File 'lib/models/porcelain.rb', line 8225

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8227
8228
8229
# File 'lib/models/porcelain.rb', line 8227

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8229
8230
8231
# File 'lib/models/porcelain.rb', line 8229

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



8231
8232
8233
# File 'lib/models/porcelain.rb', line 8231

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8233
8234
8235
# File 'lib/models/porcelain.rb', line 8233

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8235
8236
8237
# File 'lib/models/porcelain.rb', line 8235

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8237
8238
8239
# File 'lib/models/porcelain.rb', line 8237

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8239
8240
8241
# File 'lib/models/porcelain.rb', line 8239

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8241
8242
8243
# File 'lib/models/porcelain.rb', line 8241

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8283
8284
8285
8286
8287
8288
8289
# File 'lib/models/porcelain.rb', line 8283

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end