Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
8036
8037
8038
8039
8040
8041
8042
8043
8044
8045
8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
# File 'lib/models/porcelain.rb', line 8019

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7983
7984
7985
# File 'lib/models/porcelain.rb', line 7983

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7985
7986
7987
# File 'lib/models/porcelain.rb', line 7985

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



7987
7988
7989
# File 'lib/models/porcelain.rb', line 7987

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7989
7990
7991
# File 'lib/models/porcelain.rb', line 7989

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7991
7992
7993
# File 'lib/models/porcelain.rb', line 7991

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7993
7994
7995
# File 'lib/models/porcelain.rb', line 7993

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7995
7996
7997
# File 'lib/models/porcelain.rb', line 7995

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7997
7998
7999
# File 'lib/models/porcelain.rb', line 7997

def name
  @name
end

#passwordObject

The password to authenticate with.



7999
8000
8001
# File 'lib/models/porcelain.rb', line 7999

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8001
8002
8003
# File 'lib/models/porcelain.rb', line 8001

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8003
8004
8005
# File 'lib/models/porcelain.rb', line 8003

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8005
8006
8007
# File 'lib/models/porcelain.rb', line 8005

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



8007
8008
8009
# File 'lib/models/porcelain.rb', line 8007

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8009
8010
8011
# File 'lib/models/porcelain.rb', line 8009

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8011
8012
8013
# File 'lib/models/porcelain.rb', line 8011

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8013
8014
8015
# File 'lib/models/porcelain.rb', line 8013

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8015
8016
8017
# File 'lib/models/porcelain.rb', line 8015

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8017
8018
8019
# File 'lib/models/porcelain.rb', line 8017

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8059
8060
8061
8062
8063
8064
8065
# File 'lib/models/porcelain.rb', line 8059

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end