Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
7965
7966
7967
7968
7969
7970
7971
7972
7973
7974
7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
# File 'lib/models/porcelain.rb', line 7952

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7916
7917
7918
# File 'lib/models/porcelain.rb', line 7916

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7918
7919
7920
# File 'lib/models/porcelain.rb', line 7918

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



7920
7921
7922
# File 'lib/models/porcelain.rb', line 7920

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7922
7923
7924
# File 'lib/models/porcelain.rb', line 7922

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7924
7925
7926
# File 'lib/models/porcelain.rb', line 7924

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7926
7927
7928
# File 'lib/models/porcelain.rb', line 7926

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7928
7929
7930
# File 'lib/models/porcelain.rb', line 7928

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7930
7931
7932
# File 'lib/models/porcelain.rb', line 7930

def name
  @name
end

#passwordObject

The password to authenticate with.



7932
7933
7934
# File 'lib/models/porcelain.rb', line 7932

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7934
7935
7936
# File 'lib/models/porcelain.rb', line 7934

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7936
7937
7938
# File 'lib/models/porcelain.rb', line 7936

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7938
7939
7940
# File 'lib/models/porcelain.rb', line 7938

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



7940
7941
7942
# File 'lib/models/porcelain.rb', line 7940

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7942
7943
7944
# File 'lib/models/porcelain.rb', line 7942

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7944
7945
7946
# File 'lib/models/porcelain.rb', line 7944

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7946
7947
7948
# File 'lib/models/porcelain.rb', line 7946

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7948
7949
7950
# File 'lib/models/porcelain.rb', line 7948

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7950
7951
7952
# File 'lib/models/porcelain.rb', line 7950

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7992
7993
7994
7995
7996
7997
7998
# File 'lib/models/porcelain.rb', line 7992

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end