Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
# File 'lib/models/porcelain.rb', line 7655

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7619
7620
7621
# File 'lib/models/porcelain.rb', line 7619

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7621
7622
7623
# File 'lib/models/porcelain.rb', line 7621

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



7623
7624
7625
# File 'lib/models/porcelain.rb', line 7623

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7625
7626
7627
# File 'lib/models/porcelain.rb', line 7625

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7627
7628
7629
# File 'lib/models/porcelain.rb', line 7627

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7629
7630
7631
# File 'lib/models/porcelain.rb', line 7629

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7631
7632
7633
# File 'lib/models/porcelain.rb', line 7631

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7633
7634
7635
# File 'lib/models/porcelain.rb', line 7633

def name
  @name
end

#passwordObject

The password to authenticate with.



7635
7636
7637
# File 'lib/models/porcelain.rb', line 7635

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7637
7638
7639
# File 'lib/models/porcelain.rb', line 7637

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7639
7640
7641
# File 'lib/models/porcelain.rb', line 7639

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7641
7642
7643
# File 'lib/models/porcelain.rb', line 7641

def proxy_cluster_id
  @proxy_cluster_id
end

#replica_setObject

The name of the mongo replicaset.



7643
7644
7645
# File 'lib/models/porcelain.rb', line 7643

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7645
7646
7647
# File 'lib/models/porcelain.rb', line 7645

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7647
7648
7649
# File 'lib/models/porcelain.rb', line 7647

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7649
7650
7651
# File 'lib/models/porcelain.rb', line 7649

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7651
7652
7653
# File 'lib/models/porcelain.rb', line 7651

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7653
7654
7655
# File 'lib/models/porcelain.rb', line 7653

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7695
7696
7697
7698
7699
7700
7701
# File 'lib/models/porcelain.rb', line 7695

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end