Class: SDM::MongoReplicaSet
- Inherits:
-
Object
- Object
- SDM::MongoReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#replica_set ⇒ Object
The name of the mongo replicaset.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
constructor
A new instance of MongoReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
Returns a new instance of MongoReplicaSet.
7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 7046 7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 7060 7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 |
# File 'lib/models/porcelain.rb', line 7034 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
7000 7001 7002 |
# File 'lib/models/porcelain.rb', line 7000 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7002 7003 7004 |
# File 'lib/models/porcelain.rb', line 7002 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Set to connect to a replica instead of the primary node.
7004 7005 7006 |
# File 'lib/models/porcelain.rb', line 7004 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7006 7007 7008 |
# File 'lib/models/porcelain.rb', line 7006 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7008 7009 7010 |
# File 'lib/models/porcelain.rb', line 7008 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7010 7011 7012 |
# File 'lib/models/porcelain.rb', line 7010 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7012 7013 7014 |
# File 'lib/models/porcelain.rb', line 7012 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7014 7015 7016 |
# File 'lib/models/porcelain.rb', line 7014 def name @name end |
#password ⇒ Object
The password to authenticate with.
7016 7017 7018 |
# File 'lib/models/porcelain.rb', line 7016 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7018 7019 7020 |
# File 'lib/models/porcelain.rb', line 7018 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7020 7021 7022 |
# File 'lib/models/porcelain.rb', line 7020 def port_override @port_override end |
#replica_set ⇒ Object
The name of the mongo replicaset.
7022 7023 7024 |
# File 'lib/models/porcelain.rb', line 7022 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7024 7025 7026 |
# File 'lib/models/porcelain.rb', line 7024 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7026 7027 7028 |
# File 'lib/models/porcelain.rb', line 7026 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7028 7029 7030 |
# File 'lib/models/porcelain.rb', line 7028 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7030 7031 7032 |
# File 'lib/models/porcelain.rb', line 7030 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7032 7033 7034 |
# File 'lib/models/porcelain.rb', line 7032 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7072 7073 7074 7075 7076 7077 7078 |
# File 'lib/models/porcelain.rb', line 7072 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |