Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoReplicaSet is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
5505
5506
5507
5508
5509
5510
5511
5512
5513
5514
# File 'lib/models/porcelain.rb', line 5478

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5444
5445
5446
# File 'lib/models/porcelain.rb', line 5444

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5446
5447
5448
# File 'lib/models/porcelain.rb', line 5446

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



5448
5449
5450
# File 'lib/models/porcelain.rb', line 5448

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5450
5451
5452
# File 'lib/models/porcelain.rb', line 5450

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5452
5453
5454
# File 'lib/models/porcelain.rb', line 5452

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5454
5455
5456
# File 'lib/models/porcelain.rb', line 5454

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5456
5457
5458
# File 'lib/models/porcelain.rb', line 5456

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5458
5459
5460
# File 'lib/models/porcelain.rb', line 5458

def name
  @name
end

#passwordObject

The password to authenticate with.



5460
5461
5462
# File 'lib/models/porcelain.rb', line 5460

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5462
5463
5464
# File 'lib/models/porcelain.rb', line 5462

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5464
5465
5466
# File 'lib/models/porcelain.rb', line 5464

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



5466
5467
5468
# File 'lib/models/porcelain.rb', line 5466

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5468
5469
5470
# File 'lib/models/porcelain.rb', line 5468

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5470
5471
5472
# File 'lib/models/porcelain.rb', line 5470

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5472
5473
5474
# File 'lib/models/porcelain.rb', line 5472

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5474
5475
5476
# File 'lib/models/porcelain.rb', line 5474

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5476
5477
5478
# File 'lib/models/porcelain.rb', line 5476

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5516
5517
5518
5519
5520
5521
5522
# File 'lib/models/porcelain.rb', line 5516

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end