Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoReplicaSet is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



5306
5307
5308
5309
5310
5311
5312
5313
5314
5315
5316
5317
5318
5319
5320
5321
5322
5323
5324
5325
5326
5327
5328
5329
5330
5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
# File 'lib/models/porcelain.rb', line 5306

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



5272
5273
5274
# File 'lib/models/porcelain.rb', line 5272

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5274
5275
5276
# File 'lib/models/porcelain.rb', line 5274

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Set to connect to a replica instead of the primary node.



5276
5277
5278
# File 'lib/models/porcelain.rb', line 5276

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5278
5279
5280
# File 'lib/models/porcelain.rb', line 5278

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5280
5281
5282
# File 'lib/models/porcelain.rb', line 5280

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5282
5283
5284
# File 'lib/models/porcelain.rb', line 5282

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5284
5285
5286
# File 'lib/models/porcelain.rb', line 5284

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5286
5287
5288
# File 'lib/models/porcelain.rb', line 5286

def name
  @name
end

#passwordObject

The password to authenticate with.



5288
5289
5290
# File 'lib/models/porcelain.rb', line 5288

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5290
5291
5292
# File 'lib/models/porcelain.rb', line 5290

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5292
5293
5294
# File 'lib/models/porcelain.rb', line 5292

def port_override
  @port_override
end

#replica_setObject

The name of the mongo replicaset.



5294
5295
5296
# File 'lib/models/porcelain.rb', line 5294

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5296
5297
5298
# File 'lib/models/porcelain.rb', line 5296

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5298
5299
5300
# File 'lib/models/porcelain.rb', line 5298

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5300
5301
5302
# File 'lib/models/porcelain.rb', line 5300

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



5302
5303
5304
# File 'lib/models/porcelain.rb', line 5302

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



5304
5305
5306
# File 'lib/models/porcelain.rb', line 5304

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5344
5345
5346
5347
5348
5349
5350
# File 'lib/models/porcelain.rb', line 5344

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end