Class: SDM::MongoReplicaSet
- Inherits:
-
Object
- Object
- SDM::MongoReplicaSet
- Defined in:
- lib/models/porcelain.rb
Overview
MongoReplicaSet is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
constructor
A new instance of MongoReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
Returns a new instance of MongoReplicaSet.
5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 5223 |
# File 'lib/models/porcelain.rb', line 5187 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
5153 5154 5155 |
# File 'lib/models/porcelain.rb', line 5153 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
5155 5156 5157 |
# File 'lib/models/porcelain.rb', line 5155 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
5157 5158 5159 |
# File 'lib/models/porcelain.rb', line 5157 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5159 5160 5161 |
# File 'lib/models/porcelain.rb', line 5159 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5161 5162 5163 |
# File 'lib/models/porcelain.rb', line 5161 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5163 5164 5165 |
# File 'lib/models/porcelain.rb', line 5163 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5165 5166 5167 |
# File 'lib/models/porcelain.rb', line 5165 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5167 5168 5169 |
# File 'lib/models/porcelain.rb', line 5167 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5169 5170 5171 |
# File 'lib/models/porcelain.rb', line 5169 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5171 5172 5173 |
# File 'lib/models/porcelain.rb', line 5171 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5173 5174 5175 |
# File 'lib/models/porcelain.rb', line 5173 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
5175 5176 5177 |
# File 'lib/models/porcelain.rb', line 5175 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5177 5178 5179 |
# File 'lib/models/porcelain.rb', line 5177 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5179 5180 5181 |
# File 'lib/models/porcelain.rb', line 5179 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5181 5182 5183 |
# File 'lib/models/porcelain.rb', line 5181 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5183 5184 5185 |
# File 'lib/models/porcelain.rb', line 5183 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5185 5186 5187 |
# File 'lib/models/porcelain.rb', line 5185 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5225 5226 5227 5228 5229 5230 5231 |
# File 'lib/models/porcelain.rb', line 5225 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |