Class: SDM::MongoReplicaSet
- Inherits:
-
Object
- Object
- SDM::MongoReplicaSet
- Defined in:
- lib/models/porcelain.rb
Overview
MongoReplicaSet is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
constructor
A new instance of MongoReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
Returns a new instance of MongoReplicaSet.
4791 4792 4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 4825 |
# File 'lib/models/porcelain.rb', line 4791 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4759 4760 4761 |
# File 'lib/models/porcelain.rb', line 4759 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4761 4762 4763 |
# File 'lib/models/porcelain.rb', line 4761 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
4763 4764 4765 |
# File 'lib/models/porcelain.rb', line 4763 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4765 4766 4767 |
# File 'lib/models/porcelain.rb', line 4765 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4767 4768 4769 |
# File 'lib/models/porcelain.rb', line 4767 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4769 4770 4771 |
# File 'lib/models/porcelain.rb', line 4769 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4771 4772 4773 |
# File 'lib/models/porcelain.rb', line 4771 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4773 4774 4775 |
# File 'lib/models/porcelain.rb', line 4773 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4775 4776 4777 |
# File 'lib/models/porcelain.rb', line 4775 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4777 4778 4779 |
# File 'lib/models/porcelain.rb', line 4777 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4779 4780 4781 |
# File 'lib/models/porcelain.rb', line 4779 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4781 4782 4783 |
# File 'lib/models/porcelain.rb', line 4781 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4783 4784 4785 |
# File 'lib/models/porcelain.rb', line 4783 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4785 4786 4787 |
# File 'lib/models/porcelain.rb', line 4785 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4787 4788 4789 |
# File 'lib/models/porcelain.rb', line 4787 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4789 4790 4791 |
# File 'lib/models/porcelain.rb', line 4789 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4827 4828 4829 4830 4831 4832 4833 |
# File 'lib/models/porcelain.rb', line 4827 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |