Class: SDM::MongoReplicaSet
- Inherits:
-
Object
- Object
- SDM::MongoReplicaSet
- Defined in:
- lib/models/porcelain.rb
Overview
MongoReplicaSet is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
constructor
A new instance of MongoReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
Returns a new instance of MongoReplicaSet.
4454 4455 4456 4457 4458 4459 4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 |
# File 'lib/models/porcelain.rb', line 4454 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4422 4423 4424 |
# File 'lib/models/porcelain.rb', line 4422 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4424 4425 4426 |
# File 'lib/models/porcelain.rb', line 4424 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
4426 4427 4428 |
# File 'lib/models/porcelain.rb', line 4426 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4428 4429 4430 |
# File 'lib/models/porcelain.rb', line 4428 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4430 4431 4432 |
# File 'lib/models/porcelain.rb', line 4430 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4432 4433 4434 |
# File 'lib/models/porcelain.rb', line 4432 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4434 4435 4436 |
# File 'lib/models/porcelain.rb', line 4434 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4436 4437 4438 |
# File 'lib/models/porcelain.rb', line 4436 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4438 4439 4440 |
# File 'lib/models/porcelain.rb', line 4438 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4440 4441 4442 |
# File 'lib/models/porcelain.rb', line 4440 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4442 4443 4444 |
# File 'lib/models/porcelain.rb', line 4442 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4444 4445 4446 |
# File 'lib/models/porcelain.rb', line 4444 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4446 4447 4448 |
# File 'lib/models/porcelain.rb', line 4446 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4448 4449 4450 |
# File 'lib/models/porcelain.rb', line 4448 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4450 4451 4452 |
# File 'lib/models/porcelain.rb', line 4450 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4452 4453 4454 |
# File 'lib/models/porcelain.rb', line 4452 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/models/porcelain.rb', line 4490 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |