Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoReplicaSet is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



4346
4347
4348
4349
4350
4351
4352
4353
4354
4355
4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
# File 'lib/models/porcelain.rb', line 4346

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  replica_set: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @replica_set = replica_set == nil ? "" : replica_set
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4314
4315
4316
# File 'lib/models/porcelain.rb', line 4314

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4316
4317
4318
# File 'lib/models/porcelain.rb', line 4316

def bind_interface
  @bind_interface
end

#connect_to_replicaObject

Returns the value of attribute connect_to_replica.



4318
4319
4320
# File 'lib/models/porcelain.rb', line 4318

def connect_to_replica
  @connect_to_replica
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4320
4321
4322
# File 'lib/models/porcelain.rb', line 4320

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4322
4323
4324
# File 'lib/models/porcelain.rb', line 4322

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4324
4325
4326
# File 'lib/models/porcelain.rb', line 4324

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4326
4327
4328
# File 'lib/models/porcelain.rb', line 4326

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4328
4329
4330
# File 'lib/models/porcelain.rb', line 4328

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4330
4331
4332
# File 'lib/models/porcelain.rb', line 4330

def password
  @password
end

#portObject

Returns the value of attribute port.



4332
4333
4334
# File 'lib/models/porcelain.rb', line 4332

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4334
4335
4336
# File 'lib/models/porcelain.rb', line 4334

def port_override
  @port_override
end

#replica_setObject

Returns the value of attribute replica_set.



4336
4337
4338
# File 'lib/models/porcelain.rb', line 4336

def replica_set
  @replica_set
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4338
4339
4340
# File 'lib/models/porcelain.rb', line 4338

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4340
4341
4342
# File 'lib/models/porcelain.rb', line 4340

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4342
4343
4344
# File 'lib/models/porcelain.rb', line 4342

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4344
4345
4346
# File 'lib/models/porcelain.rb', line 4344

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4382
4383
4384
4385
4386
4387
4388
# File 'lib/models/porcelain.rb', line 4382

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end