Class: SDM::MongoReplicaSet
- Inherits:
-
Object
- Object
- SDM::MongoReplicaSet
- Defined in:
- lib/models/porcelain.rb
Overview
MongoReplicaSet is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
constructor
A new instance of MongoReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
Returns a new instance of MongoReplicaSet.
4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 4361 |
# File 'lib/models/porcelain.rb', line 4327 def initialize( auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4295 4296 4297 |
# File 'lib/models/porcelain.rb', line 4295 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4297 4298 4299 |
# File 'lib/models/porcelain.rb', line 4297 def bind_interface @bind_interface end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
4299 4300 4301 |
# File 'lib/models/porcelain.rb', line 4299 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4301 4302 4303 |
# File 'lib/models/porcelain.rb', line 4301 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4303 4304 4305 |
# File 'lib/models/porcelain.rb', line 4303 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4305 4306 4307 |
# File 'lib/models/porcelain.rb', line 4305 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4307 4308 4309 |
# File 'lib/models/porcelain.rb', line 4307 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4309 4310 4311 |
# File 'lib/models/porcelain.rb', line 4309 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4311 4312 4313 |
# File 'lib/models/porcelain.rb', line 4311 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4313 4314 4315 |
# File 'lib/models/porcelain.rb', line 4313 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4315 4316 4317 |
# File 'lib/models/porcelain.rb', line 4315 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
4317 4318 4319 |
# File 'lib/models/porcelain.rb', line 4317 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4319 4320 4321 |
# File 'lib/models/porcelain.rb', line 4319 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4321 4322 4323 |
# File 'lib/models/porcelain.rb', line 4321 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4323 4324 4325 |
# File 'lib/models/porcelain.rb', line 4323 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4325 4326 4327 |
# File 'lib/models/porcelain.rb', line 4325 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4363 4364 4365 4366 4367 4368 4369 |
# File 'lib/models/porcelain.rb', line 4363 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |