Class: SDM::MongoReplicaSet
- Inherits:
-
Object
- Object
- SDM::MongoReplicaSet
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#replica_set ⇒ Object
Returns the value of attribute replica_set.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
constructor
A new instance of MongoReplicaSet.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet
Returns a new instance of MongoReplicaSet.
3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 |
# File 'lib/models/porcelain.rb', line 3601 def initialize( auth_database: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, replica_set: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @replica_set = replica_set == nil ? "" : replica_set @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
3571 3572 3573 |
# File 'lib/models/porcelain.rb', line 3571 def auth_database @auth_database end |
#connect_to_replica ⇒ Object
Returns the value of attribute connect_to_replica.
3573 3574 3575 |
# File 'lib/models/porcelain.rb', line 3573 def connect_to_replica @connect_to_replica end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
3575 3576 3577 |
# File 'lib/models/porcelain.rb', line 3575 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
3577 3578 3579 |
# File 'lib/models/porcelain.rb', line 3577 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
3579 3580 3581 |
# File 'lib/models/porcelain.rb', line 3579 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
3581 3582 3583 |
# File 'lib/models/porcelain.rb', line 3581 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
3583 3584 3585 |
# File 'lib/models/porcelain.rb', line 3583 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
3585 3586 3587 |
# File 'lib/models/porcelain.rb', line 3585 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
3587 3588 3589 |
# File 'lib/models/porcelain.rb', line 3587 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
3589 3590 3591 |
# File 'lib/models/porcelain.rb', line 3589 def port_override @port_override end |
#replica_set ⇒ Object
Returns the value of attribute replica_set.
3591 3592 3593 |
# File 'lib/models/porcelain.rb', line 3591 def replica_set @replica_set end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
3593 3594 3595 |
# File 'lib/models/porcelain.rb', line 3593 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
3595 3596 3597 |
# File 'lib/models/porcelain.rb', line 3595 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
3597 3598 3599 |
# File 'lib/models/porcelain.rb', line 3597 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
3599 3600 3601 |
# File 'lib/models/porcelain.rb', line 3599 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
3635 3636 3637 3638 3639 3640 3641 |
# File 'lib/models/porcelain.rb', line 3635 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |