Class: SDM::MongoReplicaSet

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, connect_to_replica: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoReplicaSet

Returns a new instance of MongoReplicaSet.



12245
12246
12247
12248
12249
12250
12251
12252
12253
12254
12255
12256
12257
12258
12259
12260
12261
12262
12263
12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
# File 'lib/models/porcelain.rb', line 12245

def initialize(
  auth_database: nil,
  bind_interface: nil,
  connect_to_replica: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @connect_to_replica = connect_to_replica == nil ? false : connect_to_replica
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_database ⇒ Object

The authentication database to use.



12209
12210
12211
# File 'lib/models/porcelain.rb', line 12209

def auth_database
  @auth_database
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12211
12212
12213
# File 'lib/models/porcelain.rb', line 12211

def bind_interface
  @bind_interface
end

#connect_to_replica ⇒ Object

Set to connect to a replica instead of the primary node.



12213
12214
12215
# File 'lib/models/porcelain.rb', line 12213

def connect_to_replica
  @connect_to_replica
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12215
12216
12217
# File 'lib/models/porcelain.rb', line 12215

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12217
12218
12219
# File 'lib/models/porcelain.rb', line 12217

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



12219
12220
12221
# File 'lib/models/porcelain.rb', line 12219

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



12221
12222
12223
# File 'lib/models/porcelain.rb', line 12221

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12223
12224
12225
# File 'lib/models/porcelain.rb', line 12223

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



12225
12226
12227
# File 'lib/models/porcelain.rb', line 12225

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



12227
12228
12229
# File 'lib/models/porcelain.rb', line 12227

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12229
12230
12231
# File 'lib/models/porcelain.rb', line 12229

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12231
12232
12233
# File 'lib/models/porcelain.rb', line 12231

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to use for IAM (MONGODB-AWS) authentication.



12233
12234
12235
# File 'lib/models/porcelain.rb', line 12233

def region
  @region
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12235
12236
12237
# File 'lib/models/porcelain.rb', line 12235

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12237
12238
12239
# File 'lib/models/porcelain.rb', line 12237

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12239
12240
12241
# File 'lib/models/porcelain.rb', line 12239

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



12241
12242
12243
# File 'lib/models/porcelain.rb', line 12241

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



12243
12244
12245
# File 'lib/models/porcelain.rb', line 12243

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12285
12286
12287
12288
12289
12290
12291
# File 'lib/models/porcelain.rb', line 12285

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end