Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to use for IAM (MONGODB-AWS) authentication.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 |
# File 'lib/models/porcelain.rb', line 12268 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
12236 12237 12238 |
# File 'lib/models/porcelain.rb', line 12236 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
12238 12239 12240 |
# File 'lib/models/porcelain.rb', line 12238 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12240 12241 12242 |
# File 'lib/models/porcelain.rb', line 12240 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12242 12243 12244 |
# File 'lib/models/porcelain.rb', line 12242 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12244 12245 12246 |
# File 'lib/models/porcelain.rb', line 12244 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12246 12247 12248 |
# File 'lib/models/porcelain.rb', line 12246 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12248 12249 12250 |
# File 'lib/models/porcelain.rb', line 12248 def name @name end |
#password ⇒ Object
The password to authenticate with.
12250 12251 12252 |
# File 'lib/models/porcelain.rb', line 12250 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
12252 12253 12254 |
# File 'lib/models/porcelain.rb', line 12252 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12254 12255 12256 |
# File 'lib/models/porcelain.rb', line 12254 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to use for IAM (MONGODB-AWS) authentication.
12256 12257 12258 |
# File 'lib/models/porcelain.rb', line 12256 def region @region end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12258 12259 12260 |
# File 'lib/models/porcelain.rb', line 12258 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
12260 12261 12262 |
# File 'lib/models/porcelain.rb', line 12260 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12262 12263 12264 |
# File 'lib/models/porcelain.rb', line 12262 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
12264 12265 12266 |
# File 'lib/models/porcelain.rb', line 12264 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
12266 12267 12268 |
# File 'lib/models/porcelain.rb', line 12266 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12304 12305 12306 12307 12308 12309 12310 |
# File 'lib/models/porcelain.rb', line 12304 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |