Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



12222
12223
12224
12225
12226
12227
12228
12229
12230
12231
12232
12233
12234
12235
12236
12237
12238
12239
12240
12241
12242
12243
12244
12245
12246
12247
12248
12249
12250
12251
12252
12253
12254
# File 'lib/models/porcelain.rb', line 12222

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



12192
12193
12194
# File 'lib/models/porcelain.rb', line 12192

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12194
12195
12196
# File 'lib/models/porcelain.rb', line 12194

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12196
12197
12198
# File 'lib/models/porcelain.rb', line 12196

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12198
12199
12200
# File 'lib/models/porcelain.rb', line 12198

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12200
12201
12202
# File 'lib/models/porcelain.rb', line 12200

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12202
12203
12204
# File 'lib/models/porcelain.rb', line 12202

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12204
12205
12206
# File 'lib/models/porcelain.rb', line 12204

def name
  @name
end

#passwordObject

The password to authenticate with.



12206
12207
12208
# File 'lib/models/porcelain.rb', line 12206

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12208
12209
12210
# File 'lib/models/porcelain.rb', line 12208

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12210
12211
12212
# File 'lib/models/porcelain.rb', line 12210

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12212
12213
12214
# File 'lib/models/porcelain.rb', line 12212

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12214
12215
12216
# File 'lib/models/porcelain.rb', line 12214

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12216
12217
12218
# File 'lib/models/porcelain.rb', line 12216

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



12218
12219
12220
# File 'lib/models/porcelain.rb', line 12218

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



12220
12221
12222
# File 'lib/models/porcelain.rb', line 12220

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12256
12257
12258
12259
12260
12261
12262
# File 'lib/models/porcelain.rb', line 12256

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end