Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



11644
11645
11646
11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
11658
11659
11660
11661
11662
11663
11664
11665
11666
11667
11668
11669
11670
11671
11672
11673
11674
11675
11676
# File 'lib/models/porcelain.rb', line 11644

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11614
11615
11616
# File 'lib/models/porcelain.rb', line 11614

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11616
11617
11618
# File 'lib/models/porcelain.rb', line 11616

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11618
11619
11620
# File 'lib/models/porcelain.rb', line 11618

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11620
11621
11622
# File 'lib/models/porcelain.rb', line 11620

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11622
11623
11624
# File 'lib/models/porcelain.rb', line 11622

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11624
11625
11626
# File 'lib/models/porcelain.rb', line 11624

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11626
11627
11628
# File 'lib/models/porcelain.rb', line 11626

def name
  @name
end

#passwordObject

The password to authenticate with.



11628
11629
11630
# File 'lib/models/porcelain.rb', line 11628

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11630
11631
11632
# File 'lib/models/porcelain.rb', line 11630

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11632
11633
11634
# File 'lib/models/porcelain.rb', line 11632

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11634
11635
11636
# File 'lib/models/porcelain.rb', line 11634

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11636
11637
11638
# File 'lib/models/porcelain.rb', line 11636

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11638
11639
11640
# File 'lib/models/porcelain.rb', line 11638

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11640
11641
11642
# File 'lib/models/porcelain.rb', line 11640

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11642
11643
11644
# File 'lib/models/porcelain.rb', line 11642

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11678
11679
11680
11681
11682
11683
11684
# File 'lib/models/porcelain.rb', line 11678

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end