Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
10693
10694
10695
10696
10697
10698
10699
10700
10701
10702
# File 'lib/models/porcelain.rb', line 10670

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



10640
10641
10642
# File 'lib/models/porcelain.rb', line 10640

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10642
10643
10644
# File 'lib/models/porcelain.rb', line 10642

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10644
10645
10646
# File 'lib/models/porcelain.rb', line 10644

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10646
10647
10648
# File 'lib/models/porcelain.rb', line 10646

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10648
10649
10650
# File 'lib/models/porcelain.rb', line 10648

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10650
10651
10652
# File 'lib/models/porcelain.rb', line 10650

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10652
10653
10654
# File 'lib/models/porcelain.rb', line 10652

def name
  @name
end

#passwordObject

The password to authenticate with.



10654
10655
10656
# File 'lib/models/porcelain.rb', line 10654

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10656
10657
10658
# File 'lib/models/porcelain.rb', line 10656

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10658
10659
10660
# File 'lib/models/porcelain.rb', line 10658

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10660
10661
10662
# File 'lib/models/porcelain.rb', line 10660

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10662
10663
10664
# File 'lib/models/porcelain.rb', line 10662

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10664
10665
10666
# File 'lib/models/porcelain.rb', line 10664

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



10666
10667
10668
# File 'lib/models/porcelain.rb', line 10666

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



10668
10669
10670
# File 'lib/models/porcelain.rb', line 10668

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10704
10705
10706
10707
10708
10709
10710
# File 'lib/models/porcelain.rb', line 10704

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end