Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
9521
9522
9523
9524
9525
9526
# File 'lib/models/porcelain.rb', line 9494

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



9464
9465
9466
# File 'lib/models/porcelain.rb', line 9464

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9466
9467
9468
# File 'lib/models/porcelain.rb', line 9466

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9468
9469
9470
# File 'lib/models/porcelain.rb', line 9468

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9470
9471
9472
# File 'lib/models/porcelain.rb', line 9470

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9472
9473
9474
# File 'lib/models/porcelain.rb', line 9472

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9474
9475
9476
# File 'lib/models/porcelain.rb', line 9474

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9476
9477
9478
# File 'lib/models/porcelain.rb', line 9476

def name
  @name
end

#passwordObject

The password to authenticate with.



9478
9479
9480
# File 'lib/models/porcelain.rb', line 9478

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



9480
9481
9482
# File 'lib/models/porcelain.rb', line 9480

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9482
9483
9484
# File 'lib/models/porcelain.rb', line 9482

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9484
9485
9486
# File 'lib/models/porcelain.rb', line 9484

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9486
9487
9488
# File 'lib/models/porcelain.rb', line 9486

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9488
9489
9490
# File 'lib/models/porcelain.rb', line 9488

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9490
9491
9492
# File 'lib/models/porcelain.rb', line 9490

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9492
9493
9494
# File 'lib/models/porcelain.rb', line 9492

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9528
9529
9530
9531
9532
9533
9534
# File 'lib/models/porcelain.rb', line 9528

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end