Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
9322 9323 9324 9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/models/porcelain.rb', line 9322 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
9292 9293 9294 |
# File 'lib/models/porcelain.rb', line 9292 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9294 9295 9296 |
# File 'lib/models/porcelain.rb', line 9294 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9296 9297 9298 |
# File 'lib/models/porcelain.rb', line 9296 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9298 9299 9300 |
# File 'lib/models/porcelain.rb', line 9298 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9300 9301 9302 |
# File 'lib/models/porcelain.rb', line 9300 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9302 9303 9304 |
# File 'lib/models/porcelain.rb', line 9302 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9304 9305 9306 |
# File 'lib/models/porcelain.rb', line 9304 def name @name end |
#password ⇒ Object
The password to authenticate with.
9306 9307 9308 |
# File 'lib/models/porcelain.rb', line 9306 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9308 9309 9310 |
# File 'lib/models/porcelain.rb', line 9308 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9310 9311 9312 |
# File 'lib/models/porcelain.rb', line 9310 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9312 9313 9314 |
# File 'lib/models/porcelain.rb', line 9312 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9314 9315 9316 |
# File 'lib/models/porcelain.rb', line 9314 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9316 9317 9318 |
# File 'lib/models/porcelain.rb', line 9316 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9318 9319 9320 |
# File 'lib/models/porcelain.rb', line 9318 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9320 9321 9322 |
# File 'lib/models/porcelain.rb', line 9320 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9356 9357 9358 9359 9360 9361 9362 |
# File 'lib/models/porcelain.rb', line 9356 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |