Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
8335
8336
8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/models/porcelain.rb', line 8324

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



8294
8295
8296
# File 'lib/models/porcelain.rb', line 8294

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8296
8297
8298
# File 'lib/models/porcelain.rb', line 8296

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8298
8299
8300
# File 'lib/models/porcelain.rb', line 8298

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8300
8301
8302
# File 'lib/models/porcelain.rb', line 8300

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8302
8303
8304
# File 'lib/models/porcelain.rb', line 8302

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8304
8305
8306
# File 'lib/models/porcelain.rb', line 8304

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8306
8307
8308
# File 'lib/models/porcelain.rb', line 8306

def name
  @name
end

#passwordObject

The password to authenticate with.



8308
8309
8310
# File 'lib/models/porcelain.rb', line 8308

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



8310
8311
8312
# File 'lib/models/porcelain.rb', line 8310

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8312
8313
8314
# File 'lib/models/porcelain.rb', line 8312

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8314
8315
8316
# File 'lib/models/porcelain.rb', line 8314

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8316
8317
8318
# File 'lib/models/porcelain.rb', line 8316

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8318
8319
8320
# File 'lib/models/porcelain.rb', line 8318

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8320
8321
8322
# File 'lib/models/porcelain.rb', line 8320

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8322
8323
8324
# File 'lib/models/porcelain.rb', line 8322

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8358
8359
8360
8361
8362
8363
8364
# File 'lib/models/porcelain.rb', line 8358

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end