Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
8115
8116
8117
8118
8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
# File 'lib/models/porcelain.rb', line 8099

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



8069
8070
8071
# File 'lib/models/porcelain.rb', line 8069

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8071
8072
8073
# File 'lib/models/porcelain.rb', line 8071

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8073
8074
8075
# File 'lib/models/porcelain.rb', line 8073

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8075
8076
8077
# File 'lib/models/porcelain.rb', line 8075

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8077
8078
8079
# File 'lib/models/porcelain.rb', line 8077

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8079
8080
8081
# File 'lib/models/porcelain.rb', line 8079

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8081
8082
8083
# File 'lib/models/porcelain.rb', line 8081

def name
  @name
end

#passwordObject

The password to authenticate with.



8083
8084
8085
# File 'lib/models/porcelain.rb', line 8083

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



8085
8086
8087
# File 'lib/models/porcelain.rb', line 8085

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8087
8088
8089
# File 'lib/models/porcelain.rb', line 8087

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8089
8090
8091
# File 'lib/models/porcelain.rb', line 8089

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8091
8092
8093
# File 'lib/models/porcelain.rb', line 8091

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8093
8094
8095
# File 'lib/models/porcelain.rb', line 8093

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8095
8096
8097
# File 'lib/models/porcelain.rb', line 8095

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8097
8098
8099
# File 'lib/models/porcelain.rb', line 8097

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8133
8134
8135
8136
8137
8138
8139
# File 'lib/models/porcelain.rb', line 8133

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end