Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
# File 'lib/models/porcelain.rb', line 7418

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



7388
7389
7390
# File 'lib/models/porcelain.rb', line 7388

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7390
7391
7392
# File 'lib/models/porcelain.rb', line 7390

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7392
7393
7394
# File 'lib/models/porcelain.rb', line 7392

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7394
7395
7396
# File 'lib/models/porcelain.rb', line 7394

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7396
7397
7398
# File 'lib/models/porcelain.rb', line 7396

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7398
7399
7400
# File 'lib/models/porcelain.rb', line 7398

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7400
7401
7402
# File 'lib/models/porcelain.rb', line 7400

def name
  @name
end

#passwordObject

The password to authenticate with.



7402
7403
7404
# File 'lib/models/porcelain.rb', line 7402

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource.



7404
7405
7406
# File 'lib/models/porcelain.rb', line 7404

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7406
7407
7408
# File 'lib/models/porcelain.rb', line 7406

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7408
7409
7410
# File 'lib/models/porcelain.rb', line 7408

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7410
7411
7412
# File 'lib/models/porcelain.rb', line 7410

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7412
7413
7414
# File 'lib/models/porcelain.rb', line 7412

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7414
7415
7416
# File 'lib/models/porcelain.rb', line 7414

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7416
7417
7418
# File 'lib/models/porcelain.rb', line 7416

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7452
7453
7454
7455
7456
7457
7458
# File 'lib/models/porcelain.rb', line 7452

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end