Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 |
# File 'lib/models/porcelain.rb', line 7111 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
7083 7084 7085 |
# File 'lib/models/porcelain.rb', line 7083 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7085 7086 7087 |
# File 'lib/models/porcelain.rb', line 7085 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7087 7088 7089 |
# File 'lib/models/porcelain.rb', line 7087 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7089 7090 7091 |
# File 'lib/models/porcelain.rb', line 7089 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7091 7092 7093 |
# File 'lib/models/porcelain.rb', line 7091 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7093 7094 7095 |
# File 'lib/models/porcelain.rb', line 7093 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7095 7096 7097 |
# File 'lib/models/porcelain.rb', line 7095 def name @name end |
#password ⇒ Object
The password to authenticate with.
7097 7098 7099 |
# File 'lib/models/porcelain.rb', line 7097 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7099 7100 7101 |
# File 'lib/models/porcelain.rb', line 7099 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7101 7102 7103 |
# File 'lib/models/porcelain.rb', line 7101 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7103 7104 7105 |
# File 'lib/models/porcelain.rb', line 7103 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7105 7106 7107 |
# File 'lib/models/porcelain.rb', line 7105 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7107 7108 7109 |
# File 'lib/models/porcelain.rb', line 7107 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7109 7110 7111 |
# File 'lib/models/porcelain.rb', line 7109 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/models/porcelain.rb', line 7143 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |