Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Overview
MongoShardedCluster is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
5556 5557 5558 5559 5560 5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 |
# File 'lib/models/porcelain.rb', line 5556 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
5528 5529 5530 |
# File 'lib/models/porcelain.rb', line 5528 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5530 5531 5532 |
# File 'lib/models/porcelain.rb', line 5530 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5532 5533 5534 |
# File 'lib/models/porcelain.rb', line 5532 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5534 5535 5536 |
# File 'lib/models/porcelain.rb', line 5534 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5536 5537 5538 |
# File 'lib/models/porcelain.rb', line 5536 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5538 5539 5540 |
# File 'lib/models/porcelain.rb', line 5538 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5540 5541 5542 |
# File 'lib/models/porcelain.rb', line 5540 def name @name end |
#password ⇒ Object
The password to authenticate with.
5542 5543 5544 |
# File 'lib/models/porcelain.rb', line 5542 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5544 5545 5546 |
# File 'lib/models/porcelain.rb', line 5544 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5546 5547 5548 |
# File 'lib/models/porcelain.rb', line 5546 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5548 5549 5550 |
# File 'lib/models/porcelain.rb', line 5548 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5550 5551 5552 |
# File 'lib/models/porcelain.rb', line 5550 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5552 5553 5554 |
# File 'lib/models/porcelain.rb', line 5552 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5554 5555 5556 |
# File 'lib/models/porcelain.rb', line 5554 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5588 5589 5590 5591 5592 5593 5594 |
# File 'lib/models/porcelain.rb', line 5588 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |