Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Overview
MongoShardedCluster is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
The authentication database to use.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
5392 5393 5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 |
# File 'lib/models/porcelain.rb', line 5392 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
The authentication database to use.
5364 5365 5366 |
# File 'lib/models/porcelain.rb', line 5364 def auth_database @auth_database end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5366 5367 5368 |
# File 'lib/models/porcelain.rb', line 5366 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5368 5369 5370 |
# File 'lib/models/porcelain.rb', line 5368 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5370 5371 5372 |
# File 'lib/models/porcelain.rb', line 5370 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5372 5373 5374 |
# File 'lib/models/porcelain.rb', line 5372 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5374 5375 5376 |
# File 'lib/models/porcelain.rb', line 5374 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5376 5377 5378 |
# File 'lib/models/porcelain.rb', line 5376 def name @name end |
#password ⇒ Object
The password to authenticate with.
5378 5379 5380 |
# File 'lib/models/porcelain.rb', line 5378 def password @password end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5380 5381 5382 |
# File 'lib/models/porcelain.rb', line 5380 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5382 5383 5384 |
# File 'lib/models/porcelain.rb', line 5382 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5384 5385 5386 |
# File 'lib/models/porcelain.rb', line 5384 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5386 5387 5388 |
# File 'lib/models/porcelain.rb', line 5386 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5388 5389 5390 |
# File 'lib/models/porcelain.rb', line 5388 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5390 5391 5392 |
# File 'lib/models/porcelain.rb', line 5390 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5424 5425 5426 5427 5428 5429 5430 |
# File 'lib/models/porcelain.rb', line 5424 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |