Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Overview
MongoShardedCluster is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 4892 |
# File 'lib/models/porcelain.rb', line 4864 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4838 4839 4840 |
# File 'lib/models/porcelain.rb', line 4838 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4840 4841 4842 |
# File 'lib/models/porcelain.rb', line 4840 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4842 4843 4844 |
# File 'lib/models/porcelain.rb', line 4842 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4844 4845 4846 |
# File 'lib/models/porcelain.rb', line 4844 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4846 4847 4848 |
# File 'lib/models/porcelain.rb', line 4846 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4848 4849 4850 |
# File 'lib/models/porcelain.rb', line 4848 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4850 4851 4852 |
# File 'lib/models/porcelain.rb', line 4850 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4852 4853 4854 |
# File 'lib/models/porcelain.rb', line 4852 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4854 4855 4856 |
# File 'lib/models/porcelain.rb', line 4854 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4856 4857 4858 |
# File 'lib/models/porcelain.rb', line 4856 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4858 4859 4860 |
# File 'lib/models/porcelain.rb', line 4858 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4860 4861 4862 |
# File 'lib/models/porcelain.rb', line 4860 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4862 4863 4864 |
# File 'lib/models/porcelain.rb', line 4862 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4894 4895 4896 4897 4898 4899 4900 |
# File 'lib/models/porcelain.rb', line 4894 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |