Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoShardedCluster is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
# File 'lib/models/porcelain.rb', line 4527

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4501
4502
4503
# File 'lib/models/porcelain.rb', line 4501

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4503
4504
4505
# File 'lib/models/porcelain.rb', line 4503

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4505
4506
4507
# File 'lib/models/porcelain.rb', line 4505

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4507
4508
4509
# File 'lib/models/porcelain.rb', line 4507

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4509
4510
4511
# File 'lib/models/porcelain.rb', line 4509

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4511
4512
4513
# File 'lib/models/porcelain.rb', line 4511

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4513
4514
4515
# File 'lib/models/porcelain.rb', line 4513

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4515
4516
4517
# File 'lib/models/porcelain.rb', line 4515

def password
  @password
end

#port_overrideObject

Returns the value of attribute port_override.



4517
4518
4519
# File 'lib/models/porcelain.rb', line 4517

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4519
4520
4521
# File 'lib/models/porcelain.rb', line 4519

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4521
4522
4523
# File 'lib/models/porcelain.rb', line 4521

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4523
4524
4525
# File 'lib/models/porcelain.rb', line 4523

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4525
4526
4527
# File 'lib/models/porcelain.rb', line 4525

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4557
4558
4559
4560
4561
4562
4563
# File 'lib/models/porcelain.rb', line 4557

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end