Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

MongoShardedCluster is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
# File 'lib/models/porcelain.rb', line 4419

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

Returns the value of attribute auth_database.



4393
4394
4395
# File 'lib/models/porcelain.rb', line 4393

def auth_database
  @auth_database
end

#bind_interfaceObject

Bind interface



4395
4396
4397
# File 'lib/models/porcelain.rb', line 4395

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4397
4398
4399
# File 'lib/models/porcelain.rb', line 4397

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4399
4400
4401
# File 'lib/models/porcelain.rb', line 4399

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4401
4402
4403
# File 'lib/models/porcelain.rb', line 4401

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4403
4404
4405
# File 'lib/models/porcelain.rb', line 4403

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4405
4406
4407
# File 'lib/models/porcelain.rb', line 4405

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4407
4408
4409
# File 'lib/models/porcelain.rb', line 4407

def password
  @password
end

#port_overrideObject

Returns the value of attribute port_override.



4409
4410
4411
# File 'lib/models/porcelain.rb', line 4409

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4411
4412
4413
# File 'lib/models/porcelain.rb', line 4411

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4413
4414
4415
# File 'lib/models/porcelain.rb', line 4413

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4415
4416
4417
# File 'lib/models/porcelain.rb', line 4415

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4417
4418
4419
# File 'lib/models/porcelain.rb', line 4417

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4449
4450
4451
4452
4453
4454
4455
# File 'lib/models/porcelain.rb', line 4449

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end