Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Overview
MongoShardedCluster is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 4425 4426 4427 4428 4429 4430 4431 4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 |
# File 'lib/models/porcelain.rb', line 4415 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4389 4390 4391 |
# File 'lib/models/porcelain.rb', line 4389 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4391 4392 4393 |
# File 'lib/models/porcelain.rb', line 4391 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4393 4394 4395 |
# File 'lib/models/porcelain.rb', line 4393 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4395 4396 4397 |
# File 'lib/models/porcelain.rb', line 4395 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4397 4398 4399 |
# File 'lib/models/porcelain.rb', line 4397 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4399 4400 4401 |
# File 'lib/models/porcelain.rb', line 4399 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4401 4402 4403 |
# File 'lib/models/porcelain.rb', line 4401 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4403 4404 4405 |
# File 'lib/models/porcelain.rb', line 4403 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4405 4406 4407 |
# File 'lib/models/porcelain.rb', line 4405 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4407 4408 4409 |
# File 'lib/models/porcelain.rb', line 4407 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4409 4410 4411 |
# File 'lib/models/porcelain.rb', line 4409 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4411 4412 4413 |
# File 'lib/models/porcelain.rb', line 4411 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4413 4414 4415 |
# File 'lib/models/porcelain.rb', line 4413 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4445 4446 4447 4448 4449 4450 4451 |
# File 'lib/models/porcelain.rb', line 4445 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |