Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
4057 4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 |
# File 'lib/models/porcelain.rb', line 4057 def initialize( auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @auth_database = auth_database == nil ? "" : auth_database @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4031 4032 4033 |
# File 'lib/models/porcelain.rb', line 4031 def auth_database @auth_database end |
#bind_interface ⇒ Object
Bind interface
4033 4034 4035 |
# File 'lib/models/porcelain.rb', line 4033 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4035 4036 4037 |
# File 'lib/models/porcelain.rb', line 4035 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4037 4038 4039 |
# File 'lib/models/porcelain.rb', line 4037 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4039 4040 4041 |
# File 'lib/models/porcelain.rb', line 4039 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4041 4042 4043 |
# File 'lib/models/porcelain.rb', line 4041 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4043 4044 4045 |
# File 'lib/models/porcelain.rb', line 4043 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4045 4046 4047 |
# File 'lib/models/porcelain.rb', line 4045 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4047 4048 4049 |
# File 'lib/models/porcelain.rb', line 4047 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4049 4050 4051 |
# File 'lib/models/porcelain.rb', line 4049 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4051 4052 4053 |
# File 'lib/models/porcelain.rb', line 4051 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4053 4054 4055 |
# File 'lib/models/porcelain.rb', line 4053 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4055 4056 4057 |
# File 'lib/models/porcelain.rb', line 4055 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4087 4088 4089 4090 4091 4092 4093 |
# File 'lib/models/porcelain.rb', line 4087 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |