Class: SDM::MongoShardedCluster
- Inherits:
-
Object
- Object
- SDM::MongoShardedCluster
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_database ⇒ Object
Returns the value of attribute auth_database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(auth_database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
constructor
A new instance of MongoShardedCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster
Returns a new instance of MongoShardedCluster.
4808 4809 4810 4811 4812 4813 4814 4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 4825 4826 4827 4828 4829 4830 4831 4832 4833 4834 4835 4836 4837 4838 4839 4840 4841 4842 4843 4844 4845 4846 4847 4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 |
# File 'lib/models/porcelain.rb', line 4808 def initialize( auth_database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) if auth_database != nil @auth_database = auth_database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end if username != nil @username = username end end |
Instance Attribute Details
#auth_database ⇒ Object
Returns the value of attribute auth_database.
4784 4785 4786 |
# File 'lib/models/porcelain.rb', line 4784 def auth_database @auth_database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4786 4787 4788 |
# File 'lib/models/porcelain.rb', line 4786 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4788 4789 4790 |
# File 'lib/models/porcelain.rb', line 4788 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4790 4791 4792 |
# File 'lib/models/porcelain.rb', line 4790 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4792 4793 4794 |
# File 'lib/models/porcelain.rb', line 4792 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4794 4795 4796 |
# File 'lib/models/porcelain.rb', line 4794 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4796 4797 4798 |
# File 'lib/models/porcelain.rb', line 4796 def password @password end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4798 4799 4800 |
# File 'lib/models/porcelain.rb', line 4798 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4800 4801 4802 |
# File 'lib/models/porcelain.rb', line 4800 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4802 4803 4804 |
# File 'lib/models/porcelain.rb', line 4802 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4804 4805 4806 |
# File 'lib/models/porcelain.rb', line 4804 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4806 4807 4808 |
# File 'lib/models/porcelain.rb', line 4806 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/models/porcelain.rb', line 4860 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |