Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



11725
11726
11727
11728
11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
11752
11753
11754
11755
11756
11757
# File 'lib/models/porcelain.rb', line 11725

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_databaseObject

The authentication database to use.



11695
11696
11697
# File 'lib/models/porcelain.rb', line 11695

def auth_database
  @auth_database
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11697
11698
11699
# File 'lib/models/porcelain.rb', line 11697

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11699
11700
11701
# File 'lib/models/porcelain.rb', line 11699

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11701
11702
11703
# File 'lib/models/porcelain.rb', line 11701

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11703
11704
11705
# File 'lib/models/porcelain.rb', line 11703

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11705
11706
11707
# File 'lib/models/porcelain.rb', line 11705

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11707
11708
11709
# File 'lib/models/porcelain.rb', line 11707

def name
  @name
end

#passwordObject

The password to authenticate with.



11709
11710
11711
# File 'lib/models/porcelain.rb', line 11709

def password
  @password
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11711
11712
11713
# File 'lib/models/porcelain.rb', line 11711

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11713
11714
11715
# File 'lib/models/porcelain.rb', line 11713

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11715
11716
11717
# File 'lib/models/porcelain.rb', line 11715

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11717
11718
11719
# File 'lib/models/porcelain.rb', line 11717

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11719
11720
11721
# File 'lib/models/porcelain.rb', line 11719

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11721
11722
11723
# File 'lib/models/porcelain.rb', line 11721

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11723
11724
11725
# File 'lib/models/porcelain.rb', line 11723

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11759
11760
11761
11762
11763
11764
11765
# File 'lib/models/porcelain.rb', line 11759

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end