Class: SDM::MongoShardedCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_database: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port_override: nil, proxy_cluster_id: nil, region: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ MongoShardedCluster

Returns a new instance of MongoShardedCluster.



12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
12355
12356
12357
12358
12359
12360
12361
12362
# File 'lib/models/porcelain.rb', line 12328

def initialize(
  auth_database: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @auth_database = auth_database == nil ? "" : auth_database
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#auth_database ⇒ Object

The authentication database to use.



12296
12297
12298
# File 'lib/models/porcelain.rb', line 12296

def auth_database
  @auth_database
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12298
12299
12300
# File 'lib/models/porcelain.rb', line 12298

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12300
12301
12302
# File 'lib/models/porcelain.rb', line 12300

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12302
12303
12304
# File 'lib/models/porcelain.rb', line 12302

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



12304
12305
12306
# File 'lib/models/porcelain.rb', line 12304

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



12306
12307
12308
# File 'lib/models/porcelain.rb', line 12306

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12308
12309
12310
# File 'lib/models/porcelain.rb', line 12308

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



12310
12311
12312
# File 'lib/models/porcelain.rb', line 12310

def password
  @password
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12312
12313
12314
# File 'lib/models/porcelain.rb', line 12312

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12314
12315
12316
# File 'lib/models/porcelain.rb', line 12314

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to use for IAM (MONGODB-AWS) authentication.



12316
12317
12318
# File 'lib/models/porcelain.rb', line 12316

def region
  @region
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12318
12319
12320
# File 'lib/models/porcelain.rb', line 12318

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12320
12321
12322
# File 'lib/models/porcelain.rb', line 12320

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12322
12323
12324
# File 'lib/models/porcelain.rb', line 12322

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



12324
12325
12326
# File 'lib/models/porcelain.rb', line 12324

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



12326
12327
12328
# File 'lib/models/porcelain.rb', line 12326

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12364
12365
12366
12367
12368
12369
12370
# File 'lib/models/porcelain.rb', line 12364

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end