Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



12349
12350
12351
12352
12353
12354
12355
12356
12357
12358
12359
12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
# File 'lib/models/porcelain.rb', line 12349

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12315
12316
12317
# File 'lib/models/porcelain.rb', line 12315

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



12317
12318
12319
# File 'lib/models/porcelain.rb', line 12317

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12319
12320
12321
# File 'lib/models/porcelain.rb', line 12319

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12321
12322
12323
# File 'lib/models/porcelain.rb', line 12321

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12323
12324
12325
# File 'lib/models/porcelain.rb', line 12323

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12325
12326
12327
# File 'lib/models/porcelain.rb', line 12325

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12327
12328
12329
# File 'lib/models/porcelain.rb', line 12327

def name
  @name
end

#passwordObject

The password to authenticate with.



12329
12330
12331
# File 'lib/models/porcelain.rb', line 12329

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12331
12332
12333
# File 'lib/models/porcelain.rb', line 12331

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12333
12334
12335
# File 'lib/models/porcelain.rb', line 12333

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12335
12336
12337
# File 'lib/models/porcelain.rb', line 12335

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



12337
12338
12339
# File 'lib/models/porcelain.rb', line 12337

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12339
12340
12341
# File 'lib/models/porcelain.rb', line 12339

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12341
12342
12343
# File 'lib/models/porcelain.rb', line 12341

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12343
12344
12345
# File 'lib/models/porcelain.rb', line 12343

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



12345
12346
12347
# File 'lib/models/porcelain.rb', line 12345

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



12347
12348
12349
# File 'lib/models/porcelain.rb', line 12347

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12387
12388
12389
12390
12391
12392
12393
# File 'lib/models/porcelain.rb', line 12387

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end