Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



12301
12302
12303
12304
12305
12306
12307
12308
12309
12310
12311
12312
12313
12314
12315
12316
12317
12318
12319
12320
12321
12322
12323
12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
# File 'lib/models/porcelain.rb', line 12301

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12267
12268
12269
# File 'lib/models/porcelain.rb', line 12267

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



12269
12270
12271
# File 'lib/models/porcelain.rb', line 12269

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12271
12272
12273
# File 'lib/models/porcelain.rb', line 12271

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12273
12274
12275
# File 'lib/models/porcelain.rb', line 12273

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12275
12276
12277
# File 'lib/models/porcelain.rb', line 12275

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12277
12278
12279
# File 'lib/models/porcelain.rb', line 12277

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12279
12280
12281
# File 'lib/models/porcelain.rb', line 12279

def name
  @name
end

#passwordObject

The password to authenticate with.



12281
12282
12283
# File 'lib/models/porcelain.rb', line 12281

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12283
12284
12285
# File 'lib/models/porcelain.rb', line 12283

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12285
12286
12287
# File 'lib/models/porcelain.rb', line 12285

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12287
12288
12289
# File 'lib/models/porcelain.rb', line 12287

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



12289
12290
12291
# File 'lib/models/porcelain.rb', line 12289

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12291
12292
12293
# File 'lib/models/porcelain.rb', line 12291

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12293
12294
12295
# File 'lib/models/porcelain.rb', line 12293

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12295
12296
12297
# File 'lib/models/porcelain.rb', line 12295

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



12297
12298
12299
# File 'lib/models/porcelain.rb', line 12297

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



12299
12300
12301
# File 'lib/models/porcelain.rb', line 12299

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12339
12340
12341
12342
12343
12344
12345
# File 'lib/models/porcelain.rb', line 12339

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end