Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



12221
12222
12223
12224
12225
12226
12227
12228
12229
12230
12231
12232
12233
12234
12235
12236
12237
12238
12239
12240
12241
12242
12243
12244
12245
12246
12247
12248
12249
12250
12251
12252
12253
12254
12255
12256
12257
# File 'lib/models/porcelain.rb', line 12221

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12187
12188
12189
# File 'lib/models/porcelain.rb', line 12187

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



12189
12190
12191
# File 'lib/models/porcelain.rb', line 12189

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12191
12192
12193
# File 'lib/models/porcelain.rb', line 12191

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12193
12194
12195
# File 'lib/models/porcelain.rb', line 12193

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12195
12196
12197
# File 'lib/models/porcelain.rb', line 12195

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12197
12198
12199
# File 'lib/models/porcelain.rb', line 12197

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12199
12200
12201
# File 'lib/models/porcelain.rb', line 12199

def name
  @name
end

#passwordObject

The password to authenticate with.



12201
12202
12203
# File 'lib/models/porcelain.rb', line 12201

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12203
12204
12205
# File 'lib/models/porcelain.rb', line 12203

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12205
12206
12207
# File 'lib/models/porcelain.rb', line 12205

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12207
12208
12209
# File 'lib/models/porcelain.rb', line 12207

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



12209
12210
12211
# File 'lib/models/porcelain.rb', line 12209

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12211
12212
12213
# File 'lib/models/porcelain.rb', line 12211

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12213
12214
12215
# File 'lib/models/porcelain.rb', line 12213

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12215
12216
12217
# File 'lib/models/porcelain.rb', line 12215

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



12217
12218
12219
# File 'lib/models/porcelain.rb', line 12217

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



12219
12220
12221
# File 'lib/models/porcelain.rb', line 12219

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12259
12260
12261
12262
12263
12264
12265
# File 'lib/models/porcelain.rb', line 12259

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end