Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



12124
12125
12126
12127
12128
12129
12130
12131
12132
12133
12134
12135
12136
12137
12138
12139
12140
12141
12142
12143
12144
12145
12146
12147
12148
12149
12150
12151
12152
12153
12154
12155
12156
12157
12158
12159
12160
# File 'lib/models/porcelain.rb', line 12124

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12090
12091
12092
# File 'lib/models/porcelain.rb', line 12090

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



12092
12093
12094
# File 'lib/models/porcelain.rb', line 12092

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12094
12095
12096
# File 'lib/models/porcelain.rb', line 12094

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12096
12097
12098
# File 'lib/models/porcelain.rb', line 12096

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12098
12099
12100
# File 'lib/models/porcelain.rb', line 12098

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12100
12101
12102
# File 'lib/models/porcelain.rb', line 12100

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12102
12103
12104
# File 'lib/models/porcelain.rb', line 12102

def name
  @name
end

#passwordObject

The password to authenticate with.



12104
12105
12106
# File 'lib/models/porcelain.rb', line 12104

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12106
12107
12108
# File 'lib/models/porcelain.rb', line 12106

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12108
12109
12110
# File 'lib/models/porcelain.rb', line 12108

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12110
12111
12112
# File 'lib/models/porcelain.rb', line 12110

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



12112
12113
12114
# File 'lib/models/porcelain.rb', line 12112

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12114
12115
12116
# File 'lib/models/porcelain.rb', line 12114

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12116
12117
12118
# File 'lib/models/porcelain.rb', line 12116

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12118
12119
12120
# File 'lib/models/porcelain.rb', line 12118

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



12120
12121
12122
# File 'lib/models/porcelain.rb', line 12120

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



12122
12123
12124
# File 'lib/models/porcelain.rb', line 12122

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12162
12163
12164
12165
12166
12167
12168
# File 'lib/models/porcelain.rb', line 12162

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end