Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



11373
11374
11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
# File 'lib/models/porcelain.rb', line 11373

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11339
11340
11341
# File 'lib/models/porcelain.rb', line 11339

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



11341
11342
11343
# File 'lib/models/porcelain.rb', line 11341

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11343
11344
11345
# File 'lib/models/porcelain.rb', line 11343

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11345
11346
11347
# File 'lib/models/porcelain.rb', line 11345

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11347
11348
11349
# File 'lib/models/porcelain.rb', line 11347

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11349
11350
11351
# File 'lib/models/porcelain.rb', line 11349

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11351
11352
11353
# File 'lib/models/porcelain.rb', line 11351

def name
  @name
end

#passwordObject

The password to authenticate with.



11353
11354
11355
# File 'lib/models/porcelain.rb', line 11353

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11355
11356
11357
# File 'lib/models/porcelain.rb', line 11355

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11357
11358
11359
# File 'lib/models/porcelain.rb', line 11357

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11359
11360
11361
# File 'lib/models/porcelain.rb', line 11359

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



11361
11362
11363
# File 'lib/models/porcelain.rb', line 11361

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11363
11364
11365
# File 'lib/models/porcelain.rb', line 11363

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11365
11366
11367
# File 'lib/models/porcelain.rb', line 11365

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11367
11368
11369
# File 'lib/models/porcelain.rb', line 11367

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



11369
11370
11371
# File 'lib/models/porcelain.rb', line 11369

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



11371
11372
11373
# File 'lib/models/porcelain.rb', line 11371

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11411
11412
11413
11414
11415
11416
11417
# File 'lib/models/porcelain.rb', line 11411

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end