Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
# File 'lib/models/porcelain.rb', line 9558

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9524
9525
9526
# File 'lib/models/porcelain.rb', line 9524

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



9526
9527
9528
# File 'lib/models/porcelain.rb', line 9526

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9528
9529
9530
# File 'lib/models/porcelain.rb', line 9528

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9530
9531
9532
# File 'lib/models/porcelain.rb', line 9530

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9532
9533
9534
# File 'lib/models/porcelain.rb', line 9532

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9534
9535
9536
# File 'lib/models/porcelain.rb', line 9534

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9536
9537
9538
# File 'lib/models/porcelain.rb', line 9536

def name
  @name
end

#passwordObject

The password to authenticate with.



9538
9539
9540
# File 'lib/models/porcelain.rb', line 9538

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9540
9541
9542
# File 'lib/models/porcelain.rb', line 9540

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9542
9543
9544
# File 'lib/models/porcelain.rb', line 9542

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9544
9545
9546
# File 'lib/models/porcelain.rb', line 9544

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



9546
9547
9548
# File 'lib/models/porcelain.rb', line 9546

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9548
9549
9550
# File 'lib/models/porcelain.rb', line 9548

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9550
9551
9552
# File 'lib/models/porcelain.rb', line 9550

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9552
9553
9554
# File 'lib/models/porcelain.rb', line 9552

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



9554
9555
9556
# File 'lib/models/porcelain.rb', line 9554

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



9556
9557
9558
# File 'lib/models/porcelain.rb', line 9556

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9596
9597
9598
9599
9600
9601
9602
# File 'lib/models/porcelain.rb', line 9596

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end