Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
# File 'lib/models/porcelain.rb', line 9401

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9367
9368
9369
# File 'lib/models/porcelain.rb', line 9367

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



9369
9370
9371
# File 'lib/models/porcelain.rb', line 9369

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9371
9372
9373
# File 'lib/models/porcelain.rb', line 9371

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9373
9374
9375
# File 'lib/models/porcelain.rb', line 9373

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9375
9376
9377
# File 'lib/models/porcelain.rb', line 9375

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9377
9378
9379
# File 'lib/models/porcelain.rb', line 9377

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9379
9380
9381
# File 'lib/models/porcelain.rb', line 9379

def name
  @name
end

#passwordObject

The password to authenticate with.



9381
9382
9383
# File 'lib/models/porcelain.rb', line 9381

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9383
9384
9385
# File 'lib/models/porcelain.rb', line 9383

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9385
9386
9387
# File 'lib/models/porcelain.rb', line 9385

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9387
9388
9389
# File 'lib/models/porcelain.rb', line 9387

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



9389
9390
9391
# File 'lib/models/porcelain.rb', line 9389

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9391
9392
9393
# File 'lib/models/porcelain.rb', line 9391

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9393
9394
9395
# File 'lib/models/porcelain.rb', line 9393

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9395
9396
9397
# File 'lib/models/porcelain.rb', line 9395

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



9397
9398
9399
# File 'lib/models/porcelain.rb', line 9397

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



9399
9400
9401
# File 'lib/models/porcelain.rb', line 9399

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9439
9440
9441
9442
9443
9444
9445
# File 'lib/models/porcelain.rb', line 9439

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end