Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
9266
9267
9268
9269
9270
9271
9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
9287
9288
9289
9290
# File 'lib/models/porcelain.rb', line 9254

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9220
9221
9222
# File 'lib/models/porcelain.rb', line 9220

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



9222
9223
9224
# File 'lib/models/porcelain.rb', line 9222

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9224
9225
9226
# File 'lib/models/porcelain.rb', line 9224

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9226
9227
9228
# File 'lib/models/porcelain.rb', line 9226

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9228
9229
9230
# File 'lib/models/porcelain.rb', line 9228

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9230
9231
9232
# File 'lib/models/porcelain.rb', line 9230

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9232
9233
9234
# File 'lib/models/porcelain.rb', line 9232

def name
  @name
end

#passwordObject

The password to authenticate with.



9234
9235
9236
# File 'lib/models/porcelain.rb', line 9234

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9236
9237
9238
# File 'lib/models/porcelain.rb', line 9236

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9238
9239
9240
# File 'lib/models/porcelain.rb', line 9238

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9240
9241
9242
# File 'lib/models/porcelain.rb', line 9240

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



9242
9243
9244
# File 'lib/models/porcelain.rb', line 9242

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9244
9245
9246
# File 'lib/models/porcelain.rb', line 9244

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9246
9247
9248
# File 'lib/models/porcelain.rb', line 9246

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9248
9249
9250
# File 'lib/models/porcelain.rb', line 9248

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



9250
9251
9252
# File 'lib/models/porcelain.rb', line 9250

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



9252
9253
9254
# File 'lib/models/porcelain.rb', line 9252

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9292
9293
9294
9295
9296
9297
9298
# File 'lib/models/porcelain.rb', line 9292

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end