Class: SDM::Mysql
- Inherits:
-
Object
- Object
- SDM::Mysql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility).
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql
constructor
A new instance of Mysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql
Returns a new instance of Mysql.
8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 |
# File 'lib/models/porcelain.rb', line 8328 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @require_native_auth = require_native_auth == nil ? false : require_native_auth @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8294 8295 8296 |
# File 'lib/models/porcelain.rb', line 8294 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks. Does not affect client requests.
8296 8297 8298 |
# File 'lib/models/porcelain.rb', line 8296 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8298 8299 8300 |
# File 'lib/models/porcelain.rb', line 8298 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8300 8301 8302 |
# File 'lib/models/porcelain.rb', line 8300 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8302 8303 8304 |
# File 'lib/models/porcelain.rb', line 8302 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8304 8305 8306 |
# File 'lib/models/porcelain.rb', line 8304 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8306 8307 8308 |
# File 'lib/models/porcelain.rb', line 8306 def name @name end |
#password ⇒ Object
The password to authenticate with.
8308 8309 8310 |
# File 'lib/models/porcelain.rb', line 8308 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8310 8311 8312 |
# File 'lib/models/porcelain.rb', line 8310 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8312 8313 8314 |
# File 'lib/models/porcelain.rb', line 8312 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8314 8315 8316 |
# File 'lib/models/porcelain.rb', line 8314 def proxy_cluster_id @proxy_cluster_id end |
#require_native_auth ⇒ Object
Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)
8316 8317 8318 |
# File 'lib/models/porcelain.rb', line 8316 def require_native_auth @require_native_auth end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8318 8319 8320 |
# File 'lib/models/porcelain.rb', line 8318 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8320 8321 8322 |
# File 'lib/models/porcelain.rb', line 8320 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8322 8323 8324 |
# File 'lib/models/porcelain.rb', line 8322 def @tags end |
#use_azure_single_server_usernames ⇒ Object
If true, appends the hostname to the username when hitting a database.azure.com address
8324 8325 8326 |
# File 'lib/models/porcelain.rb', line 8324 def use_azure_single_server_usernames @use_azure_single_server_usernames end |
#username ⇒ Object
The username to authenticate with.
8326 8327 8328 |
# File 'lib/models/porcelain.rb', line 8326 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8366 8367 8368 8369 8370 8371 8372 |
# File 'lib/models/porcelain.rb', line 8366 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |