Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



8329
8330
8331
8332
8333
8334
8335
8336
8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
# File 'lib/models/porcelain.rb', line 8329

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8295
8296
8297
# File 'lib/models/porcelain.rb', line 8295

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



8297
8298
8299
# File 'lib/models/porcelain.rb', line 8297

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8299
8300
8301
# File 'lib/models/porcelain.rb', line 8299

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8301
8302
8303
# File 'lib/models/porcelain.rb', line 8301

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8303
8304
8305
# File 'lib/models/porcelain.rb', line 8303

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8305
8306
8307
# File 'lib/models/porcelain.rb', line 8305

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8307
8308
8309
# File 'lib/models/porcelain.rb', line 8307

def name
  @name
end

#passwordObject

The password to authenticate with.



8309
8310
8311
# File 'lib/models/porcelain.rb', line 8309

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8311
8312
8313
# File 'lib/models/porcelain.rb', line 8311

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8313
8314
8315
# File 'lib/models/porcelain.rb', line 8313

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8315
8316
8317
# File 'lib/models/porcelain.rb', line 8315

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8317
8318
8319
# File 'lib/models/porcelain.rb', line 8317

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8319
8320
8321
# File 'lib/models/porcelain.rb', line 8319

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8321
8322
8323
# File 'lib/models/porcelain.rb', line 8321

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8323
8324
8325
# File 'lib/models/porcelain.rb', line 8323

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8325
8326
8327
# File 'lib/models/porcelain.rb', line 8325

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8327
8328
8329
# File 'lib/models/porcelain.rb', line 8327

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8367
8368
8369
8370
8371
8372
8373
# File 'lib/models/porcelain.rb', line 8367

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end