Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



8179
8180
8181
8182
8183
8184
8185
8186
8187
8188
8189
8190
8191
8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
8214
8215
# File 'lib/models/porcelain.rb', line 8179

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8145
8146
8147
# File 'lib/models/porcelain.rb', line 8145

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



8147
8148
8149
# File 'lib/models/porcelain.rb', line 8147

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8149
8150
8151
# File 'lib/models/porcelain.rb', line 8149

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8151
8152
8153
# File 'lib/models/porcelain.rb', line 8151

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8153
8154
8155
# File 'lib/models/porcelain.rb', line 8153

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8155
8156
8157
# File 'lib/models/porcelain.rb', line 8155

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8157
8158
8159
# File 'lib/models/porcelain.rb', line 8157

def name
  @name
end

#passwordObject

The password to authenticate with.



8159
8160
8161
# File 'lib/models/porcelain.rb', line 8159

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8161
8162
8163
# File 'lib/models/porcelain.rb', line 8161

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8163
8164
8165
# File 'lib/models/porcelain.rb', line 8163

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8165
8166
8167
# File 'lib/models/porcelain.rb', line 8165

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8167
8168
8169
# File 'lib/models/porcelain.rb', line 8167

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8169
8170
8171
# File 'lib/models/porcelain.rb', line 8169

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8171
8172
8173
# File 'lib/models/porcelain.rb', line 8171

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8173
8174
8175
# File 'lib/models/porcelain.rb', line 8173

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8175
8176
8177
# File 'lib/models/porcelain.rb', line 8175

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8177
8178
8179
# File 'lib/models/porcelain.rb', line 8177

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8217
8218
8219
8220
8221
8222
8223
# File 'lib/models/porcelain.rb', line 8217

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end