Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



8112
8113
8114
8115
8116
8117
8118
8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/models/porcelain.rb', line 8112

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8078
8079
8080
# File 'lib/models/porcelain.rb', line 8078

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



8080
8081
8082
# File 'lib/models/porcelain.rb', line 8080

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8082
8083
8084
# File 'lib/models/porcelain.rb', line 8082

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8084
8085
8086
# File 'lib/models/porcelain.rb', line 8084

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8086
8087
8088
# File 'lib/models/porcelain.rb', line 8086

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8088
8089
8090
# File 'lib/models/porcelain.rb', line 8088

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8090
8091
8092
# File 'lib/models/porcelain.rb', line 8090

def name
  @name
end

#passwordObject

The password to authenticate with.



8092
8093
8094
# File 'lib/models/porcelain.rb', line 8092

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8094
8095
8096
# File 'lib/models/porcelain.rb', line 8094

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8096
8097
8098
# File 'lib/models/porcelain.rb', line 8096

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8098
8099
8100
# File 'lib/models/porcelain.rb', line 8098

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



8100
8101
8102
# File 'lib/models/porcelain.rb', line 8100

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8102
8103
8104
# File 'lib/models/porcelain.rb', line 8102

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8104
8105
8106
# File 'lib/models/porcelain.rb', line 8104

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8106
8107
8108
# File 'lib/models/porcelain.rb', line 8106

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



8108
8109
8110
# File 'lib/models/porcelain.rb', line 8108

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



8110
8111
8112
# File 'lib/models/porcelain.rb', line 8110

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8150
8151
8152
8153
8154
8155
8156
# File 'lib/models/porcelain.rb', line 8150

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end