Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
# File 'lib/models/porcelain.rb', line 7568

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7534
7535
7536
# File 'lib/models/porcelain.rb', line 7534

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks. Does not affect client requests.



7536
7537
7538
# File 'lib/models/porcelain.rb', line 7536

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7538
7539
7540
# File 'lib/models/porcelain.rb', line 7538

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7540
7541
7542
# File 'lib/models/porcelain.rb', line 7540

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7542
7543
7544
# File 'lib/models/porcelain.rb', line 7542

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7544
7545
7546
# File 'lib/models/porcelain.rb', line 7544

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7546
7547
7548
# File 'lib/models/porcelain.rb', line 7546

def name
  @name
end

#passwordObject

The password to authenticate with.



7548
7549
7550
# File 'lib/models/porcelain.rb', line 7548

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7550
7551
7552
# File 'lib/models/porcelain.rb', line 7550

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7552
7553
7554
# File 'lib/models/porcelain.rb', line 7552

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7554
7555
7556
# File 'lib/models/porcelain.rb', line 7554

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



7556
7557
7558
# File 'lib/models/porcelain.rb', line 7556

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7558
7559
7560
# File 'lib/models/porcelain.rb', line 7558

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7560
7561
7562
# File 'lib/models/porcelain.rb', line 7560

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7562
7563
7564
# File 'lib/models/porcelain.rb', line 7562

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



7564
7565
7566
# File 'lib/models/porcelain.rb', line 7564

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



7566
7567
7568
# File 'lib/models/porcelain.rb', line 7566

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7606
7607
7608
7609
7610
7611
7612
# File 'lib/models/porcelain.rb', line 7606

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end