Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



5631
5632
5633
5634
5635
5636
5637
5638
5639
5640
5641
5642
5643
5644
5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/models/porcelain.rb', line 5631

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5599
5600
5601
# File 'lib/models/porcelain.rb', line 5599

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



5601
5602
5603
# File 'lib/models/porcelain.rb', line 5601

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5603
5604
5605
# File 'lib/models/porcelain.rb', line 5603

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5605
5606
5607
# File 'lib/models/porcelain.rb', line 5605

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



5607
5608
5609
# File 'lib/models/porcelain.rb', line 5607

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5609
5610
5611
# File 'lib/models/porcelain.rb', line 5609

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5611
5612
5613
# File 'lib/models/porcelain.rb', line 5611

def name
  @name
end

#passwordObject

The password to authenticate with.



5613
5614
5615
# File 'lib/models/porcelain.rb', line 5613

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5615
5616
5617
# File 'lib/models/porcelain.rb', line 5615

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5617
5618
5619
# File 'lib/models/porcelain.rb', line 5617

def port_override
  @port_override
end

#require_native_authObject

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



5619
5620
5621
# File 'lib/models/porcelain.rb', line 5619

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5621
5622
5623
# File 'lib/models/porcelain.rb', line 5621

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5623
5624
5625
# File 'lib/models/porcelain.rb', line 5623

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5625
5626
5627
# File 'lib/models/porcelain.rb', line 5625

def tags
  @tags
end

#use_azure_single_server_usernamesObject

If true, appends the hostname to the username when hitting a database.azure.com address



5627
5628
5629
# File 'lib/models/porcelain.rb', line 5627

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

The username to authenticate with.



5629
5630
5631
# File 'lib/models/porcelain.rb', line 5629

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5667
5668
5669
5670
5671
5672
5673
# File 'lib/models/porcelain.rb', line 5667

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end