Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
# File 'lib/models/porcelain.rb', line 5339

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5307
5308
5309
# File 'lib/models/porcelain.rb', line 5307

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



5309
5310
5311
# File 'lib/models/porcelain.rb', line 5309

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5311
5312
5313
# File 'lib/models/porcelain.rb', line 5311

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5313
5314
5315
# File 'lib/models/porcelain.rb', line 5313

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5315
5316
5317
# File 'lib/models/porcelain.rb', line 5315

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5317
5318
5319
# File 'lib/models/porcelain.rb', line 5317

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5319
5320
5321
# File 'lib/models/porcelain.rb', line 5319

def name
  @name
end

#passwordObject

Returns the value of attribute password.



5321
5322
5323
# File 'lib/models/porcelain.rb', line 5321

def password
  @password
end

#portObject

Returns the value of attribute port.



5323
5324
5325
# File 'lib/models/porcelain.rb', line 5323

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5325
5326
5327
# File 'lib/models/porcelain.rb', line 5325

def port_override
  @port_override
end

#require_native_authObject

Returns the value of attribute require_native_auth.



5327
5328
5329
# File 'lib/models/porcelain.rb', line 5327

def require_native_auth
  @require_native_auth
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5329
5330
5331
# File 'lib/models/porcelain.rb', line 5329

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5331
5332
5333
# File 'lib/models/porcelain.rb', line 5331

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5333
5334
5335
# File 'lib/models/porcelain.rb', line 5333

def tags
  @tags
end

#use_azure_single_server_usernamesObject

Returns the value of attribute use_azure_single_server_usernames.



5335
5336
5337
# File 'lib/models/porcelain.rb', line 5335

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#usernameObject

Returns the value of attribute username.



5337
5338
5339
# File 'lib/models/porcelain.rb', line 5337

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5375
5376
5377
5378
5379
5380
5381
# File 'lib/models/porcelain.rb', line 5375

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end