Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
4956
4957
4958
4959
# File 'lib/models/porcelain.rb', line 4931

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4905
4906
4907
# File 'lib/models/porcelain.rb', line 4905

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4907
4908
4909
# File 'lib/models/porcelain.rb', line 4907

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4909
4910
4911
# File 'lib/models/porcelain.rb', line 4909

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4911
4912
4913
# File 'lib/models/porcelain.rb', line 4911

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4913
4914
4915
# File 'lib/models/porcelain.rb', line 4913

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4915
4916
4917
# File 'lib/models/porcelain.rb', line 4915

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4917
4918
4919
# File 'lib/models/porcelain.rb', line 4917

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4919
4920
4921
# File 'lib/models/porcelain.rb', line 4919

def password
  @password
end

#portObject

Returns the value of attribute port.



4921
4922
4923
# File 'lib/models/porcelain.rb', line 4921

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4923
4924
4925
# File 'lib/models/porcelain.rb', line 4923

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4925
4926
4927
# File 'lib/models/porcelain.rb', line 4925

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4927
4928
4929
# File 'lib/models/porcelain.rb', line 4927

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4929
4930
4931
# File 'lib/models/porcelain.rb', line 4929

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4961
4962
4963
4964
4965
4966
4967
# File 'lib/models/porcelain.rb', line 4961

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end