Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
4615
4616
4617
4618
4619
4620
4621
# File 'lib/models/porcelain.rb', line 4593

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4567
4568
4569
# File 'lib/models/porcelain.rb', line 4567

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4569
4570
4571
# File 'lib/models/porcelain.rb', line 4569

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4571
4572
4573
# File 'lib/models/porcelain.rb', line 4571

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4573
4574
4575
# File 'lib/models/porcelain.rb', line 4573

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4575
4576
4577
# File 'lib/models/porcelain.rb', line 4575

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4577
4578
4579
# File 'lib/models/porcelain.rb', line 4577

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4579
4580
4581
# File 'lib/models/porcelain.rb', line 4579

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4581
4582
4583
# File 'lib/models/porcelain.rb', line 4581

def password
  @password
end

#portObject

Returns the value of attribute port.



4583
4584
4585
# File 'lib/models/porcelain.rb', line 4583

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4585
4586
4587
# File 'lib/models/porcelain.rb', line 4585

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4587
4588
4589
# File 'lib/models/porcelain.rb', line 4587

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4589
4590
4591
# File 'lib/models/porcelain.rb', line 4589

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4591
4592
4593
# File 'lib/models/porcelain.rb', line 4591

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4623
4624
4625
4626
4627
4628
4629
# File 'lib/models/porcelain.rb', line 4623

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end