Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
# File 'lib/models/porcelain.rb', line 4594

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4568
4569
4570
# File 'lib/models/porcelain.rb', line 4568

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4570
4571
4572
# File 'lib/models/porcelain.rb', line 4570

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4572
4573
4574
# File 'lib/models/porcelain.rb', line 4572

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4574
4575
4576
# File 'lib/models/porcelain.rb', line 4574

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4576
4577
4578
# File 'lib/models/porcelain.rb', line 4576

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4578
4579
4580
# File 'lib/models/porcelain.rb', line 4578

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4580
4581
4582
# File 'lib/models/porcelain.rb', line 4580

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4582
4583
4584
# File 'lib/models/porcelain.rb', line 4582

def password
  @password
end

#portObject

Returns the value of attribute port.



4584
4585
4586
# File 'lib/models/porcelain.rb', line 4584

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4586
4587
4588
# File 'lib/models/porcelain.rb', line 4586

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4588
4589
4590
# File 'lib/models/porcelain.rb', line 4588

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4590
4591
4592
# File 'lib/models/porcelain.rb', line 4590

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4592
4593
4594
# File 'lib/models/porcelain.rb', line 4592

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4624
4625
4626
4627
4628
4629
4630
# File 'lib/models/porcelain.rb', line 4624

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end