Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
4496
4497
4498
4499
4500
4501
4502
4503
4504
4505
4506
4507
4508
4509
4510
4511
4512
4513
4514
# File 'lib/models/porcelain.rb', line 4486

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4460
4461
4462
# File 'lib/models/porcelain.rb', line 4460

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4462
4463
4464
# File 'lib/models/porcelain.rb', line 4462

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4464
4465
4466
# File 'lib/models/porcelain.rb', line 4464

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4466
4467
4468
# File 'lib/models/porcelain.rb', line 4466

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4468
4469
4470
# File 'lib/models/porcelain.rb', line 4468

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4470
4471
4472
# File 'lib/models/porcelain.rb', line 4470

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4472
4473
4474
# File 'lib/models/porcelain.rb', line 4472

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4474
4475
4476
# File 'lib/models/porcelain.rb', line 4474

def password
  @password
end

#portObject

Returns the value of attribute port.



4476
4477
4478
# File 'lib/models/porcelain.rb', line 4476

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4478
4479
4480
# File 'lib/models/porcelain.rb', line 4478

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4480
4481
4482
# File 'lib/models/porcelain.rb', line 4480

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4482
4483
4484
# File 'lib/models/porcelain.rb', line 4482

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4484
4485
4486
# File 'lib/models/porcelain.rb', line 4484

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4516
4517
4518
4519
4520
4521
4522
# File 'lib/models/porcelain.rb', line 4516

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end