Class: SDM::Mysql
- Inherits:
-
Object
- Object
- SDM::Mysql
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Mysql
constructor
A new instance of Mysql.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Mysql
Returns a new instance of Mysql.
4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 4505 4506 4507 4508 4509 4510 |
# File 'lib/models/porcelain.rb', line 4482 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4456 4457 4458 |
# File 'lib/models/porcelain.rb', line 4456 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4458 4459 4460 |
# File 'lib/models/porcelain.rb', line 4458 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4460 4461 4462 |
# File 'lib/models/porcelain.rb', line 4460 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4462 4463 4464 |
# File 'lib/models/porcelain.rb', line 4462 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4464 4465 4466 |
# File 'lib/models/porcelain.rb', line 4464 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4466 4467 4468 |
# File 'lib/models/porcelain.rb', line 4466 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4468 4469 4470 |
# File 'lib/models/porcelain.rb', line 4468 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4470 4471 4472 |
# File 'lib/models/porcelain.rb', line 4470 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4472 4473 4474 |
# File 'lib/models/porcelain.rb', line 4472 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4474 4475 4476 |
# File 'lib/models/porcelain.rb', line 4474 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4476 4477 4478 |
# File 'lib/models/porcelain.rb', line 4476 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4478 4479 4480 |
# File 'lib/models/porcelain.rb', line 4478 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4480 4481 4482 |
# File 'lib/models/porcelain.rb', line 4480 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4512 4513 4514 4515 4516 4517 4518 |
# File 'lib/models/porcelain.rb', line 4512 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |