Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
4135
4136
4137
4138
4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
# File 'lib/models/porcelain.rb', line 4122

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4096
4097
4098
# File 'lib/models/porcelain.rb', line 4096

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4098
4099
4100
# File 'lib/models/porcelain.rb', line 4098

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4100
4101
4102
# File 'lib/models/porcelain.rb', line 4100

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4102
4103
4104
# File 'lib/models/porcelain.rb', line 4102

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4104
4105
4106
# File 'lib/models/porcelain.rb', line 4104

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4106
4107
4108
# File 'lib/models/porcelain.rb', line 4106

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4108
4109
4110
# File 'lib/models/porcelain.rb', line 4108

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4110
4111
4112
# File 'lib/models/porcelain.rb', line 4110

def password
  @password
end

#portObject

Returns the value of attribute port.



4112
4113
4114
# File 'lib/models/porcelain.rb', line 4112

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4114
4115
4116
# File 'lib/models/porcelain.rb', line 4114

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4116
4117
4118
# File 'lib/models/porcelain.rb', line 4116

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4118
4119
4120
# File 'lib/models/porcelain.rb', line 4118

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4120
4121
4122
# File 'lib/models/porcelain.rb', line 4120

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4152
4153
4154
4155
4156
4157
4158
# File 'lib/models/porcelain.rb', line 4152

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end