Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
4907
4908
4909
4910
4911
4912
4913
4914
4915
4916
4917
4918
4919
4920
4921
4922
4923
4924
4925
4926
4927
4928
4929
4930
4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
4944
# File 'lib/models/porcelain.rb', line 4894

def initialize(
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  if database != nil
    @database = database
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if password != nil
    @password = password
  end
  if port != nil
    @port = port
  end
  if port_override != nil
    @port_override = port_override
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
  if username != nil
    @username = username
  end
end

Instance Attribute Details

#databaseObject

Returns the value of attribute database.



4870
4871
4872
# File 'lib/models/porcelain.rb', line 4870

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4872
4873
4874
# File 'lib/models/porcelain.rb', line 4872

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4874
4875
4876
# File 'lib/models/porcelain.rb', line 4874

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4876
4877
4878
# File 'lib/models/porcelain.rb', line 4876

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4878
4879
4880
# File 'lib/models/porcelain.rb', line 4878

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4880
4881
4882
# File 'lib/models/porcelain.rb', line 4880

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4882
4883
4884
# File 'lib/models/porcelain.rb', line 4882

def password
  @password
end

#portObject

Returns the value of attribute port.



4884
4885
4886
# File 'lib/models/porcelain.rb', line 4884

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4886
4887
4888
# File 'lib/models/porcelain.rb', line 4886

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4888
4889
4890
# File 'lib/models/porcelain.rb', line 4888

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4890
4891
4892
# File 'lib/models/porcelain.rb', line 4890

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4892
4893
4894
# File 'lib/models/porcelain.rb', line 4892

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4946
4947
4948
4949
4950
4951
4952
# File 'lib/models/porcelain.rb', line 4946

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end