Class: SDM::Mysql

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, require_native_auth: nil, secret_store_id: nil, subdomain: nil, tags: nil, use_azure_single_server_usernames: nil, username: nil) ⇒ Mysql

Returns a new instance of Mysql.



12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
12440
12441
12442
12443
12444
12445
# File 'lib/models/porcelain.rb', line 12409

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  require_native_auth: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  use_azure_single_server_usernames: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @require_native_auth = require_native_auth == nil ? false : require_native_auth
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @use_azure_single_server_usernames = use_azure_single_server_usernames == nil ? false : use_azure_single_server_usernames
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12375
12376
12377
# File 'lib/models/porcelain.rb', line 12375

def bind_interface
  @bind_interface
end

#database ⇒ Object

The database for healthchecks. Does not affect client requests.



12377
12378
12379
# File 'lib/models/porcelain.rb', line 12377

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12379
12380
12381
# File 'lib/models/porcelain.rb', line 12379

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12381
12382
12383
# File 'lib/models/porcelain.rb', line 12381

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



12383
12384
12385
# File 'lib/models/porcelain.rb', line 12383

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



12385
12386
12387
# File 'lib/models/porcelain.rb', line 12385

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12387
12388
12389
# File 'lib/models/porcelain.rb', line 12387

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



12389
12390
12391
# File 'lib/models/porcelain.rb', line 12389

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



12391
12392
12393
# File 'lib/models/porcelain.rb', line 12391

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12393
12394
12395
# File 'lib/models/porcelain.rb', line 12393

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12395
12396
12397
# File 'lib/models/porcelain.rb', line 12395

def proxy_cluster_id
  @proxy_cluster_id
end

#require_native_auth ⇒ Object

Whether native auth (mysql_native_password) is used for all connections (for backwards compatibility)



12397
12398
12399
# File 'lib/models/porcelain.rb', line 12397

def require_native_auth
  @require_native_auth
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12399
12400
12401
# File 'lib/models/porcelain.rb', line 12399

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12401
12402
12403
# File 'lib/models/porcelain.rb', line 12401

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12403
12404
12405
# File 'lib/models/porcelain.rb', line 12403

def tags
  @tags
end

#use_azure_single_server_usernames ⇒ Object

If true, appends the hostname to the username when hitting a database.azure.com address



12405
12406
12407
# File 'lib/models/porcelain.rb', line 12405

def use_azure_single_server_usernames
  @use_azure_single_server_usernames
end

#username ⇒ Object

The username to authenticate with.



12407
12408
12409
# File 'lib/models/porcelain.rb', line 12407

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12447
12448
12449
12450
12451
12452
12453
# File 'lib/models/porcelain.rb', line 12447

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end