Class: SDM::MysqlEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ MysqlEngine

Returns a new instance of MysqlEngine.



12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
# File 'lib/models/porcelain.rb', line 12386

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  node_selector: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  tls_skip_verify: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @node_selector = node_selector == nil ? "" : node_selector
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttlObject

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



12350
12351
12352
# File 'lib/models/porcelain.rb', line 12350

def after_read_ttl
  @after_read_ttl
end

#databaseObject

Database is the database to verify credential against.



12352
12353
12354
# File 'lib/models/porcelain.rb', line 12352

def database
  @database
end

#hostnameObject

Hostname is the hostname or IP address of the MySQL server.



12354
12355
12356
# File 'lib/models/porcelain.rb', line 12354

def hostname
  @hostname
end

#idObject

Unique identifier of the Secret Engine.



12356
12357
12358
# File 'lib/models/porcelain.rb', line 12356

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



12358
12359
12360
# File 'lib/models/porcelain.rb', line 12358

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



12360
12361
12362
# File 'lib/models/porcelain.rb', line 12360

def name
  @name
end

#node_selectorObject

node selector is used to narrow down the nodes used to communicate with with secret engine



12362
12363
12364
# File 'lib/models/porcelain.rb', line 12362

def node_selector
  @node_selector
end

#passwordObject

Password is the password to connect to the MySQL server.



12364
12365
12366
# File 'lib/models/porcelain.rb', line 12364

def password
  @password
end

#policyObject

Policy for password creation



12366
12367
12368
# File 'lib/models/porcelain.rb', line 12366

def policy
  @policy
end

#portObject

Port is the port number of the MySQL server.



12368
12369
12370
# File 'lib/models/porcelain.rb', line 12368

def port
  @port
end

#public_keyObject

Public key linked with a secret engine



12370
12371
12372
# File 'lib/models/porcelain.rb', line 12370

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



12372
12373
12374
# File 'lib/models/porcelain.rb', line 12372

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



12374
12375
12376
# File 'lib/models/porcelain.rb', line 12374

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



12376
12377
12378
# File 'lib/models/porcelain.rb', line 12376

def tags
  @tags
end

#tlsObject

TLS enables TLS/SSL when connecting to the MySQL server.



12378
12379
12380
# File 'lib/models/porcelain.rb', line 12378

def tls
  @tls
end

#tls_skip_verifyObject

TLS disable certificate verification



12380
12381
12382
# File 'lib/models/porcelain.rb', line 12380

def tls_skip_verify
  @tls_skip_verify
end

#ttlObject

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



12382
12383
12384
# File 'lib/models/porcelain.rb', line 12382

def ttl
  @ttl
end

#usernameObject

Username is the username to connect to the MySQL server.



12384
12385
12386
# File 'lib/models/porcelain.rb', line 12384

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12426
12427
12428
12429
12430
12431
12432
# File 'lib/models/porcelain.rb', line 12426

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end