Class: SDM::MysqlEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ MysqlEngine

Returns a new instance of MysqlEngine.



12210
12211
12212
12213
12214
12215
12216
12217
12218
12219
12220
12221
12222
12223
12224
12225
12226
12227
12228
12229
12230
12231
12232
12233
12234
12235
12236
12237
12238
12239
12240
12241
12242
12243
12244
12245
12246
12247
12248
# File 'lib/models/porcelain.rb', line 12210

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  node_selector: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  tls_skip_verify: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @node_selector = node_selector == nil ? "" : node_selector
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttlObject

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



12174
12175
12176
# File 'lib/models/porcelain.rb', line 12174

def after_read_ttl
  @after_read_ttl
end

#databaseObject

Database is the database to verify credential against.



12176
12177
12178
# File 'lib/models/porcelain.rb', line 12176

def database
  @database
end

#hostnameObject

Hostname is the hostname or IP address of the MySQL server.



12178
12179
12180
# File 'lib/models/porcelain.rb', line 12178

def hostname
  @hostname
end

#idObject

Unique identifier of the Secret Engine.



12180
12181
12182
# File 'lib/models/porcelain.rb', line 12180

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



12182
12183
12184
# File 'lib/models/porcelain.rb', line 12182

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



12184
12185
12186
# File 'lib/models/porcelain.rb', line 12184

def name
  @name
end

#node_selectorObject

node selector is used to narrow down the nodes used to communicate with with secret engine



12186
12187
12188
# File 'lib/models/porcelain.rb', line 12186

def node_selector
  @node_selector
end

#passwordObject

Password is the password to connect to the MySQL server.



12188
12189
12190
# File 'lib/models/porcelain.rb', line 12188

def password
  @password
end

#policyObject

Policy for password creation



12190
12191
12192
# File 'lib/models/porcelain.rb', line 12190

def policy
  @policy
end

#portObject

Port is the port number of the MySQL server.



12192
12193
12194
# File 'lib/models/porcelain.rb', line 12192

def port
  @port
end

#public_keyObject

Public key linked with a secret engine



12194
12195
12196
# File 'lib/models/porcelain.rb', line 12194

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



12196
12197
12198
# File 'lib/models/porcelain.rb', line 12196

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



12198
12199
12200
# File 'lib/models/porcelain.rb', line 12198

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



12200
12201
12202
# File 'lib/models/porcelain.rb', line 12200

def tags
  @tags
end

#tlsObject

TLS enables TLS/SSL when connecting to the MySQL server.



12202
12203
12204
# File 'lib/models/porcelain.rb', line 12202

def tls
  @tls
end

#tls_skip_verifyObject

TLS disable certificate verification



12204
12205
12206
# File 'lib/models/porcelain.rb', line 12204

def tls_skip_verify
  @tls_skip_verify
end

#ttlObject

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



12206
12207
12208
# File 'lib/models/porcelain.rb', line 12206

def ttl
  @ttl
end

#usernameObject

Username is the username to connect to the MySQL server.



12208
12209
12210
# File 'lib/models/porcelain.rb', line 12208

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12250
12251
12252
12253
12254
12255
12256
# File 'lib/models/porcelain.rb', line 12250

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end