Class: SDM::MysqlEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, tls_skip_verify: nil, ttl: nil, username: nil) ⇒ MysqlEngine

Returns a new instance of MysqlEngine.



11520
11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
11539
11540
11541
11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
11552
11553
11554
11555
11556
# File 'lib/models/porcelain.rb', line 11520

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  tls_skip_verify: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @tls_skip_verify = tls_skip_verify == nil ? false : tls_skip_verify
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttlObject

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



11486
11487
11488
# File 'lib/models/porcelain.rb', line 11486

def after_read_ttl
  @after_read_ttl
end

#databaseObject

Database is the database to verify credential against.



11488
11489
11490
# File 'lib/models/porcelain.rb', line 11488

def database
  @database
end

#hostnameObject

Hostname is the hostname or IP address of the MySQL server.



11490
11491
11492
# File 'lib/models/porcelain.rb', line 11490

def hostname
  @hostname
end

#idObject

Unique identifier of the Secret Engine.



11492
11493
11494
# File 'lib/models/porcelain.rb', line 11492

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



11494
11495
11496
# File 'lib/models/porcelain.rb', line 11494

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



11496
11497
11498
# File 'lib/models/porcelain.rb', line 11496

def name
  @name
end

#passwordObject

Password is the password to connect to the MySQL server.



11498
11499
11500
# File 'lib/models/porcelain.rb', line 11498

def password
  @password
end

#policyObject

Policy for password creation



11500
11501
11502
# File 'lib/models/porcelain.rb', line 11500

def policy
  @policy
end

#portObject

Port is the port number of the MySQL server.



11502
11503
11504
# File 'lib/models/porcelain.rb', line 11502

def port
  @port
end

#public_keyObject

Public key linked with a secret engine



11504
11505
11506
# File 'lib/models/porcelain.rb', line 11504

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



11506
11507
11508
# File 'lib/models/porcelain.rb', line 11506

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



11508
11509
11510
# File 'lib/models/porcelain.rb', line 11508

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



11510
11511
11512
# File 'lib/models/porcelain.rb', line 11510

def tags
  @tags
end

#tlsObject

TLS enables TLS/SSL when connecting to the MySQL server.



11512
11513
11514
# File 'lib/models/porcelain.rb', line 11512

def tls
  @tls
end

#tls_skip_verifyObject

TLS disable certificate verification



11514
11515
11516
# File 'lib/models/porcelain.rb', line 11514

def tls_skip_verify
  @tls_skip_verify
end

#ttlObject

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



11516
11517
11518
# File 'lib/models/porcelain.rb', line 11516

def ttl
  @ttl
end

#usernameObject

Username is the username to connect to the MySQL server.



11518
11519
11520
# File 'lib/models/porcelain.rb', line 11518

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11558
11559
11560
11561
11562
11563
11564
# File 'lib/models/porcelain.rb', line 11558

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end