Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



12509
12510
12511
12512
12513
12514
12515
12516
12517
12518
12519
12520
12521
12522
12523
12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/models/porcelain.rb', line 12509

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12485
12486
12487
# File 'lib/models/porcelain.rb', line 12485

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12487
12488
12489
# File 'lib/models/porcelain.rb', line 12487

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12489
12490
12491
# File 'lib/models/porcelain.rb', line 12489

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12491
12492
12493
# File 'lib/models/porcelain.rb', line 12491

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12493
12494
12495
# File 'lib/models/porcelain.rb', line 12493

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12495
12496
12497
# File 'lib/models/porcelain.rb', line 12495

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12497
12498
12499
# File 'lib/models/porcelain.rb', line 12497

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12499
12500
12501
# File 'lib/models/porcelain.rb', line 12499

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12501
12502
12503
# File 'lib/models/porcelain.rb', line 12501

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12503
12504
12505
# File 'lib/models/porcelain.rb', line 12503

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12505
12506
12507
# File 'lib/models/porcelain.rb', line 12505

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12507
12508
12509
# File 'lib/models/porcelain.rb', line 12507

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12537
12538
12539
12540
12541
12542
12543
# File 'lib/models/porcelain.rb', line 12537

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end