Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



12461
12462
12463
12464
12465
12466
12467
12468
12469
12470
12471
12472
12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
# File 'lib/models/porcelain.rb', line 12461

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12437
12438
12439
# File 'lib/models/porcelain.rb', line 12437

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12439
12440
12441
# File 'lib/models/porcelain.rb', line 12439

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12441
12442
12443
# File 'lib/models/porcelain.rb', line 12441

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12443
12444
12445
# File 'lib/models/porcelain.rb', line 12443

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12445
12446
12447
# File 'lib/models/porcelain.rb', line 12445

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12447
12448
12449
# File 'lib/models/porcelain.rb', line 12447

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12449
12450
12451
# File 'lib/models/porcelain.rb', line 12449

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12451
12452
12453
# File 'lib/models/porcelain.rb', line 12451

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12453
12454
12455
# File 'lib/models/porcelain.rb', line 12453

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12455
12456
12457
# File 'lib/models/porcelain.rb', line 12455

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12457
12458
12459
# File 'lib/models/porcelain.rb', line 12457

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12459
12460
12461
# File 'lib/models/porcelain.rb', line 12459

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12489
12490
12491
12492
12493
12494
12495
# File 'lib/models/porcelain.rb', line 12489

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end