Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
# File 'lib/models/porcelain.rb', line 12381

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12357
12358
12359
# File 'lib/models/porcelain.rb', line 12357

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12359
12360
12361
# File 'lib/models/porcelain.rb', line 12359

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12361
12362
12363
# File 'lib/models/porcelain.rb', line 12361

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12363
12364
12365
# File 'lib/models/porcelain.rb', line 12363

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12365
12366
12367
# File 'lib/models/porcelain.rb', line 12365

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12367
12368
12369
# File 'lib/models/porcelain.rb', line 12367

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12369
12370
12371
# File 'lib/models/porcelain.rb', line 12369

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12371
12372
12373
# File 'lib/models/porcelain.rb', line 12371

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12373
12374
12375
# File 'lib/models/porcelain.rb', line 12373

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12375
12376
12377
# File 'lib/models/porcelain.rb', line 12375

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12377
12378
12379
# File 'lib/models/porcelain.rb', line 12377

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12379
12380
12381
# File 'lib/models/porcelain.rb', line 12379

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12409
12410
12411
12412
12413
12414
12415
# File 'lib/models/porcelain.rb', line 12409

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end