Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



12285
12286
12287
12288
12289
12290
12291
12292
12293
12294
12295
12296
12297
12298
12299
12300
12301
12302
12303
12304
12305
12306
12307
12308
12309
12310
12311
# File 'lib/models/porcelain.rb', line 12285

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12261
12262
12263
# File 'lib/models/porcelain.rb', line 12261

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12263
12264
12265
# File 'lib/models/porcelain.rb', line 12263

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12265
12266
12267
# File 'lib/models/porcelain.rb', line 12265

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12267
12268
12269
# File 'lib/models/porcelain.rb', line 12267

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12269
12270
12271
# File 'lib/models/porcelain.rb', line 12269

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12271
12272
12273
# File 'lib/models/porcelain.rb', line 12271

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12273
12274
12275
# File 'lib/models/porcelain.rb', line 12273

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12275
12276
12277
# File 'lib/models/porcelain.rb', line 12275

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12277
12278
12279
# File 'lib/models/porcelain.rb', line 12277

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12279
12280
12281
# File 'lib/models/porcelain.rb', line 12279

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12281
12282
12283
# File 'lib/models/porcelain.rb', line 12281

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12283
12284
12285
# File 'lib/models/porcelain.rb', line 12283

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12313
12314
12315
12316
12317
12318
12319
# File 'lib/models/porcelain.rb', line 12313

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end