Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



11965
11966
11967
11968
11969
11970
11971
11972
11973
11974
11975
11976
11977
11978
11979
11980
11981
11982
11983
11984
11985
11986
11987
11988
11989
11990
11991
# File 'lib/models/porcelain.rb', line 11965

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11941
11942
11943
# File 'lib/models/porcelain.rb', line 11941

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11943
11944
11945
# File 'lib/models/porcelain.rb', line 11943

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



11945
11946
11947
# File 'lib/models/porcelain.rb', line 11945

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11947
11948
11949
# File 'lib/models/porcelain.rb', line 11947

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11949
11950
11951
# File 'lib/models/porcelain.rb', line 11949

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11951
11952
11953
# File 'lib/models/porcelain.rb', line 11951

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11953
11954
11955
# File 'lib/models/porcelain.rb', line 11953

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11955
11956
11957
# File 'lib/models/porcelain.rb', line 11955

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11957
11958
11959
# File 'lib/models/porcelain.rb', line 11957

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11959
11960
11961
# File 'lib/models/porcelain.rb', line 11959

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11961
11962
11963
# File 'lib/models/porcelain.rb', line 11961

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11963
11964
11965
# File 'lib/models/porcelain.rb', line 11963

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11993
11994
11995
11996
11997
11998
11999
# File 'lib/models/porcelain.rb', line 11993

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end