Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



11891
11892
11893
11894
11895
11896
11897
11898
11899
11900
11901
11902
11903
11904
11905
11906
11907
11908
11909
11910
11911
11912
11913
11914
11915
11916
11917
# File 'lib/models/porcelain.rb', line 11891

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11867
11868
11869
# File 'lib/models/porcelain.rb', line 11867

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11869
11870
11871
# File 'lib/models/porcelain.rb', line 11869

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



11871
11872
11873
# File 'lib/models/porcelain.rb', line 11871

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11873
11874
11875
# File 'lib/models/porcelain.rb', line 11873

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11875
11876
11877
# File 'lib/models/porcelain.rb', line 11875

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11877
11878
11879
# File 'lib/models/porcelain.rb', line 11877

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11879
11880
11881
# File 'lib/models/porcelain.rb', line 11879

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11881
11882
11883
# File 'lib/models/porcelain.rb', line 11881

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11883
11884
11885
# File 'lib/models/porcelain.rb', line 11883

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11885
11886
11887
# File 'lib/models/porcelain.rb', line 11885

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11887
11888
11889
# File 'lib/models/porcelain.rb', line 11887

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11889
11890
11891
# File 'lib/models/porcelain.rb', line 11889

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11919
11920
11921
11922
11923
11924
11925
# File 'lib/models/porcelain.rb', line 11919

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end