Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
11607
11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
11618
11619
# File 'lib/models/porcelain.rb', line 11593

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11569
11570
11571
# File 'lib/models/porcelain.rb', line 11569

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11571
11572
11573
# File 'lib/models/porcelain.rb', line 11571

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



11573
11574
11575
# File 'lib/models/porcelain.rb', line 11573

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11575
11576
11577
# File 'lib/models/porcelain.rb', line 11575

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11577
11578
11579
# File 'lib/models/porcelain.rb', line 11577

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11579
11580
11581
# File 'lib/models/porcelain.rb', line 11579

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11581
11582
11583
# File 'lib/models/porcelain.rb', line 11581

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11583
11584
11585
# File 'lib/models/porcelain.rb', line 11583

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11585
11586
11587
# File 'lib/models/porcelain.rb', line 11585

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11587
11588
11589
# File 'lib/models/porcelain.rb', line 11587

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11589
11590
11591
# File 'lib/models/porcelain.rb', line 11589

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11591
11592
11593
# File 'lib/models/porcelain.rb', line 11591

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11621
11622
11623
11624
11625
11626
11627
# File 'lib/models/porcelain.rb', line 11621

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end