Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



10822
10823
10824
10825
10826
10827
10828
10829
10830
10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
# File 'lib/models/porcelain.rb', line 10822

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10798
10799
10800
# File 'lib/models/porcelain.rb', line 10798

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10800
10801
10802
# File 'lib/models/porcelain.rb', line 10800

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



10802
10803
10804
# File 'lib/models/porcelain.rb', line 10802

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10804
10805
10806
# File 'lib/models/porcelain.rb', line 10804

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



10806
10807
10808
# File 'lib/models/porcelain.rb', line 10806

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10808
10809
10810
# File 'lib/models/porcelain.rb', line 10808

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10810
10811
10812
# File 'lib/models/porcelain.rb', line 10810

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10812
10813
10814
# File 'lib/models/porcelain.rb', line 10812

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10814
10815
10816
# File 'lib/models/porcelain.rb', line 10814

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10816
10817
10818
# File 'lib/models/porcelain.rb', line 10816

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10818
10819
10820
# File 'lib/models/porcelain.rb', line 10818

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10820
10821
10822
# File 'lib/models/porcelain.rb', line 10820

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10850
10851
10852
10853
10854
10855
10856
# File 'lib/models/porcelain.rb', line 10850

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end