Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
9905
9906
9907
9908
9909
9910
9911
9912
9913
9914
9915
# File 'lib/models/porcelain.rb', line 9889

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9865
9866
9867
# File 'lib/models/porcelain.rb', line 9865

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9867
9868
9869
# File 'lib/models/porcelain.rb', line 9867

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



9869
9870
9871
# File 'lib/models/porcelain.rb', line 9869

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9871
9872
9873
# File 'lib/models/porcelain.rb', line 9871

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



9873
9874
9875
# File 'lib/models/porcelain.rb', line 9873

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9875
9876
9877
# File 'lib/models/porcelain.rb', line 9875

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9877
9878
9879
# File 'lib/models/porcelain.rb', line 9877

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9879
9880
9881
# File 'lib/models/porcelain.rb', line 9879

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9881
9882
9883
# File 'lib/models/porcelain.rb', line 9881

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9883
9884
9885
# File 'lib/models/porcelain.rb', line 9883

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9885
9886
9887
# File 'lib/models/porcelain.rb', line 9885

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9887
9888
9889
# File 'lib/models/porcelain.rb', line 9887

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9917
9918
9919
9920
9921
9922
9923
# File 'lib/models/porcelain.rb', line 9917

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end