Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



9631
9632
9633
9634
9635
9636
9637
9638
9639
9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
# File 'lib/models/porcelain.rb', line 9631

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9607
9608
9609
# File 'lib/models/porcelain.rb', line 9607

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9609
9610
9611
# File 'lib/models/porcelain.rb', line 9609

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



9611
9612
9613
# File 'lib/models/porcelain.rb', line 9611

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9613
9614
9615
# File 'lib/models/porcelain.rb', line 9613

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



9615
9616
9617
# File 'lib/models/porcelain.rb', line 9615

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9617
9618
9619
# File 'lib/models/porcelain.rb', line 9617

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9619
9620
9621
# File 'lib/models/porcelain.rb', line 9619

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9621
9622
9623
# File 'lib/models/porcelain.rb', line 9621

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9623
9624
9625
# File 'lib/models/porcelain.rb', line 9623

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9625
9626
9627
# File 'lib/models/porcelain.rb', line 9625

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9627
9628
9629
# File 'lib/models/porcelain.rb', line 9627

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9629
9630
9631
# File 'lib/models/porcelain.rb', line 9629

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9659
9660
9661
9662
9663
9664
9665
# File 'lib/models/porcelain.rb', line 9659

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end