Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



9474
9475
9476
9477
9478
9479
9480
9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
# File 'lib/models/porcelain.rb', line 9474

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9450
9451
9452
# File 'lib/models/porcelain.rb', line 9450

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9452
9453
9454
# File 'lib/models/porcelain.rb', line 9452

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



9454
9455
9456
# File 'lib/models/porcelain.rb', line 9454

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9456
9457
9458
# File 'lib/models/porcelain.rb', line 9456

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



9458
9459
9460
# File 'lib/models/porcelain.rb', line 9458

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9460
9461
9462
# File 'lib/models/porcelain.rb', line 9460

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9462
9463
9464
# File 'lib/models/porcelain.rb', line 9462

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9464
9465
9466
# File 'lib/models/porcelain.rb', line 9464

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9466
9467
9468
# File 'lib/models/porcelain.rb', line 9466

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9468
9469
9470
# File 'lib/models/porcelain.rb', line 9468

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9470
9471
9472
# File 'lib/models/porcelain.rb', line 9470

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9472
9473
9474
# File 'lib/models/porcelain.rb', line 9472

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9502
9503
9504
9505
9506
9507
9508
# File 'lib/models/porcelain.rb', line 9502

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end