Class: SDM::Neptune
- Inherits:
-
Object
- Object
- SDM::Neptune
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
constructor
A new instance of Neptune.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
Returns a new instance of Neptune.
9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 |
# File 'lib/models/porcelain.rb', line 9327 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9303 9304 9305 |
# File 'lib/models/porcelain.rb', line 9303 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9305 9306 9307 |
# File 'lib/models/porcelain.rb', line 9305 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com
9307 9308 9309 |
# File 'lib/models/porcelain.rb', line 9307 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9309 9310 9311 |
# File 'lib/models/porcelain.rb', line 9309 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
9311 9312 9313 |
# File 'lib/models/porcelain.rb', line 9311 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9313 9314 9315 |
# File 'lib/models/porcelain.rb', line 9313 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9315 9316 9317 |
# File 'lib/models/porcelain.rb', line 9315 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9317 9318 9319 |
# File 'lib/models/porcelain.rb', line 9317 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9319 9320 9321 |
# File 'lib/models/porcelain.rb', line 9319 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9321 9322 9323 |
# File 'lib/models/porcelain.rb', line 9321 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9323 9324 9325 |
# File 'lib/models/porcelain.rb', line 9323 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9325 9326 9327 |
# File 'lib/models/porcelain.rb', line 9325 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9355 9356 9357 9358 9359 9360 9361 |
# File 'lib/models/porcelain.rb', line 9355 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |