Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



8469
8470
8471
8472
8473
8474
8475
8476
8477
8478
8479
8480
8481
8482
8483
8484
8485
8486
8487
8488
8489
8490
8491
8492
8493
8494
8495
# File 'lib/models/porcelain.rb', line 8469

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8445
8446
8447
# File 'lib/models/porcelain.rb', line 8445

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8447
8448
8449
# File 'lib/models/porcelain.rb', line 8447

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



8449
8450
8451
# File 'lib/models/porcelain.rb', line 8449

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8451
8452
8453
# File 'lib/models/porcelain.rb', line 8451

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8453
8454
8455
# File 'lib/models/porcelain.rb', line 8453

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8455
8456
8457
# File 'lib/models/porcelain.rb', line 8455

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8457
8458
8459
# File 'lib/models/porcelain.rb', line 8457

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8459
8460
8461
# File 'lib/models/porcelain.rb', line 8459

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8461
8462
8463
# File 'lib/models/porcelain.rb', line 8461

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8463
8464
8465
# File 'lib/models/porcelain.rb', line 8463

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8465
8466
8467
# File 'lib/models/porcelain.rb', line 8465

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8467
8468
8469
# File 'lib/models/porcelain.rb', line 8467

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8497
8498
8499
8500
8501
8502
8503
# File 'lib/models/porcelain.rb', line 8497

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end