Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
8413
8414
8415
8416
8417
8418
8419
8420
8421
8422
8423
8424
# File 'lib/models/porcelain.rb', line 8398

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8374
8375
8376
# File 'lib/models/porcelain.rb', line 8374

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8376
8377
8378
# File 'lib/models/porcelain.rb', line 8376

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



8378
8379
8380
# File 'lib/models/porcelain.rb', line 8378

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8380
8381
8382
# File 'lib/models/porcelain.rb', line 8380

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8382
8383
8384
# File 'lib/models/porcelain.rb', line 8382

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8384
8385
8386
# File 'lib/models/porcelain.rb', line 8384

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8386
8387
8388
# File 'lib/models/porcelain.rb', line 8386

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8388
8389
8390
# File 'lib/models/porcelain.rb', line 8388

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8390
8391
8392
# File 'lib/models/porcelain.rb', line 8390

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8392
8393
8394
# File 'lib/models/porcelain.rb', line 8392

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8394
8395
8396
# File 'lib/models/porcelain.rb', line 8394

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8396
8397
8398
# File 'lib/models/porcelain.rb', line 8396

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8426
8427
8428
8429
8430
8431
8432
# File 'lib/models/porcelain.rb', line 8426

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end