Class: SDM::Neptune
- Inherits:
-
Object
- Object
- SDM::Neptune
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
constructor
A new instance of Neptune.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
Returns a new instance of Neptune.
8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 |
# File 'lib/models/porcelain.rb', line 8322 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8298 8299 8300 |
# File 'lib/models/porcelain.rb', line 8298 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8300 8301 8302 |
# File 'lib/models/porcelain.rb', line 8300 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com
8302 8303 8304 |
# File 'lib/models/porcelain.rb', line 8302 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8304 8305 8306 |
# File 'lib/models/porcelain.rb', line 8304 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
8306 8307 8308 |
# File 'lib/models/porcelain.rb', line 8306 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8308 8309 8310 |
# File 'lib/models/porcelain.rb', line 8308 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8310 8311 8312 |
# File 'lib/models/porcelain.rb', line 8310 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8312 8313 8314 |
# File 'lib/models/porcelain.rb', line 8312 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8314 8315 8316 |
# File 'lib/models/porcelain.rb', line 8314 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8316 8317 8318 |
# File 'lib/models/porcelain.rb', line 8316 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8318 8319 8320 |
# File 'lib/models/porcelain.rb', line 8318 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8320 8321 8322 |
# File 'lib/models/porcelain.rb', line 8320 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8350 8351 8352 8353 8354 8355 8356 |
# File 'lib/models/porcelain.rb', line 8350 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |