Class: SDM::Neptune
- Inherits:
-
Object
- Object
- SDM::Neptune
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
constructor
A new instance of Neptune.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
Returns a new instance of Neptune.
8251 8252 8253 8254 8255 8256 8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 8267 8268 8269 8270 8271 8272 8273 8274 8275 8276 8277 |
# File 'lib/models/porcelain.rb', line 8251 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8227 8228 8229 |
# File 'lib/models/porcelain.rb', line 8227 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8229 8230 8231 |
# File 'lib/models/porcelain.rb', line 8229 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com
8231 8232 8233 |
# File 'lib/models/porcelain.rb', line 8231 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8233 8234 8235 |
# File 'lib/models/porcelain.rb', line 8233 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
8235 8236 8237 |
# File 'lib/models/porcelain.rb', line 8235 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8237 8238 8239 |
# File 'lib/models/porcelain.rb', line 8237 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8239 8240 8241 |
# File 'lib/models/porcelain.rb', line 8239 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8241 8242 8243 |
# File 'lib/models/porcelain.rb', line 8241 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8243 8244 8245 |
# File 'lib/models/porcelain.rb', line 8243 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8245 8246 8247 |
# File 'lib/models/porcelain.rb', line 8245 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8247 8248 8249 |
# File 'lib/models/porcelain.rb', line 8247 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8249 8250 8251 |
# File 'lib/models/porcelain.rb', line 8249 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8279 8280 8281 8282 8283 8284 8285 |
# File 'lib/models/porcelain.rb', line 8279 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |