Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



8252
8253
8254
8255
8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
# File 'lib/models/porcelain.rb', line 8252

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8228
8229
8230
# File 'lib/models/porcelain.rb', line 8228

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8230
8231
8232
# File 'lib/models/porcelain.rb', line 8230

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



8232
8233
8234
# File 'lib/models/porcelain.rb', line 8232

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8234
8235
8236
# File 'lib/models/porcelain.rb', line 8234

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8236
8237
8238
# File 'lib/models/porcelain.rb', line 8236

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8238
8239
8240
# File 'lib/models/porcelain.rb', line 8238

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8240
8241
8242
# File 'lib/models/porcelain.rb', line 8240

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8242
8243
8244
# File 'lib/models/porcelain.rb', line 8242

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8244
8245
8246
# File 'lib/models/porcelain.rb', line 8244

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8246
8247
8248
# File 'lib/models/porcelain.rb', line 8246

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8248
8249
8250
# File 'lib/models/porcelain.rb', line 8248

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8250
8251
8252
# File 'lib/models/porcelain.rb', line 8250

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8280
8281
8282
8283
8284
8285
8286
# File 'lib/models/porcelain.rb', line 8280

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end