Class: SDM::Neptune
- Inherits:
-
Object
- Object
- SDM::Neptune
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
constructor
A new instance of Neptune.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
Returns a new instance of Neptune.
8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/models/porcelain.rb', line 8185 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8161 8162 8163 |
# File 'lib/models/porcelain.rb', line 8161 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8163 8164 8165 |
# File 'lib/models/porcelain.rb', line 8163 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com
8165 8166 8167 |
# File 'lib/models/porcelain.rb', line 8165 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8167 8168 8169 |
# File 'lib/models/porcelain.rb', line 8167 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
8169 8170 8171 |
# File 'lib/models/porcelain.rb', line 8169 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8171 8172 8173 |
# File 'lib/models/porcelain.rb', line 8171 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8173 8174 8175 |
# File 'lib/models/porcelain.rb', line 8173 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8175 8176 8177 |
# File 'lib/models/porcelain.rb', line 8175 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8177 8178 8179 |
# File 'lib/models/porcelain.rb', line 8177 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8179 8180 8181 |
# File 'lib/models/porcelain.rb', line 8179 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8181 8182 8183 |
# File 'lib/models/porcelain.rb', line 8181 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8183 8184 8185 |
# File 'lib/models/porcelain.rb', line 8183 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8213 8214 8215 8216 8217 8218 8219 |
# File 'lib/models/porcelain.rb', line 8213 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |