Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
7581
7582
7583
7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
7596
# File 'lib/models/porcelain.rb', line 7570

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7546
7547
7548
# File 'lib/models/porcelain.rb', line 7546

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7548
7549
7550
# File 'lib/models/porcelain.rb', line 7548

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



7550
7551
7552
# File 'lib/models/porcelain.rb', line 7550

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7552
7553
7554
# File 'lib/models/porcelain.rb', line 7552

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7554
7555
7556
# File 'lib/models/porcelain.rb', line 7554

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7556
7557
7558
# File 'lib/models/porcelain.rb', line 7556

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7558
7559
7560
# File 'lib/models/porcelain.rb', line 7558

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7560
7561
7562
# File 'lib/models/porcelain.rb', line 7560

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7562
7563
7564
# File 'lib/models/porcelain.rb', line 7562

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7564
7565
7566
# File 'lib/models/porcelain.rb', line 7564

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7566
7567
7568
# File 'lib/models/porcelain.rb', line 7566

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7568
7569
7570
# File 'lib/models/porcelain.rb', line 7568

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7598
7599
7600
7601
7602
7603
7604
# File 'lib/models/porcelain.rb', line 7598

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end