Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



5851
5852
5853
5854
5855
5856
5857
5858
5859
5860
5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
# File 'lib/models/porcelain.rb', line 5851

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5829
5830
5831
# File 'lib/models/porcelain.rb', line 5829

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5831
5832
5833
# File 'lib/models/porcelain.rb', line 5831

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



5833
5834
5835
# File 'lib/models/porcelain.rb', line 5833

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5835
5836
5837
# File 'lib/models/porcelain.rb', line 5835

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5837
5838
5839
# File 'lib/models/porcelain.rb', line 5837

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5839
5840
5841
# File 'lib/models/porcelain.rb', line 5839

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5841
5842
5843
# File 'lib/models/porcelain.rb', line 5841

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5843
5844
5845
# File 'lib/models/porcelain.rb', line 5843

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5845
5846
5847
# File 'lib/models/porcelain.rb', line 5845

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5847
5848
5849
# File 'lib/models/porcelain.rb', line 5847

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5849
5850
5851
# File 'lib/models/porcelain.rb', line 5849

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5877
5878
5879
5880
5881
5882
5883
# File 'lib/models/porcelain.rb', line 5877

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end