Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



5700
5701
5702
5703
5704
5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
5719
5720
5721
5722
5723
5724
# File 'lib/models/porcelain.rb', line 5700

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5678
5679
5680
# File 'lib/models/porcelain.rb', line 5678

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5680
5681
5682
# File 'lib/models/porcelain.rb', line 5680

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



5682
5683
5684
# File 'lib/models/porcelain.rb', line 5682

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5684
5685
5686
# File 'lib/models/porcelain.rb', line 5684

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5686
5687
5688
# File 'lib/models/porcelain.rb', line 5686

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5688
5689
5690
# File 'lib/models/porcelain.rb', line 5688

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5690
5691
5692
# File 'lib/models/porcelain.rb', line 5690

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5692
5693
5694
# File 'lib/models/porcelain.rb', line 5692

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5694
5695
5696
# File 'lib/models/porcelain.rb', line 5694

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5696
5697
5698
# File 'lib/models/porcelain.rb', line 5696

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5698
5699
5700
# File 'lib/models/porcelain.rb', line 5698

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5726
5727
5728
5729
5730
5731
5732
# File 'lib/models/porcelain.rb', line 5726

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end