Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



5533
5534
5535
5536
5537
5538
5539
5540
5541
5542
5543
5544
5545
5546
5547
5548
5549
5550
5551
5552
5553
5554
5555
5556
5557
# File 'lib/models/porcelain.rb', line 5533

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5511
5512
5513
# File 'lib/models/porcelain.rb', line 5511

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5513
5514
5515
# File 'lib/models/porcelain.rb', line 5513

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



5515
5516
5517
# File 'lib/models/porcelain.rb', line 5515

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5517
5518
5519
# File 'lib/models/porcelain.rb', line 5517

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5519
5520
5521
# File 'lib/models/porcelain.rb', line 5519

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5521
5522
5523
# File 'lib/models/porcelain.rb', line 5521

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5523
5524
5525
# File 'lib/models/porcelain.rb', line 5523

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5525
5526
5527
# File 'lib/models/porcelain.rb', line 5525

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5527
5528
5529
# File 'lib/models/porcelain.rb', line 5527

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5529
5530
5531
# File 'lib/models/porcelain.rb', line 5529

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5531
5532
5533
# File 'lib/models/porcelain.rb', line 5531

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5559
5560
5561
5562
5563
5564
5565
# File 'lib/models/porcelain.rb', line 5559

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end