Class: SDM::Neptune
- Inherits:
-
Object
- Object
- SDM::Neptune
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
constructor
A new instance of Neptune.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune
Returns a new instance of Neptune.
5408 5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 |
# File 'lib/models/porcelain.rb', line 5408 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5386 5387 5388 |
# File 'lib/models/porcelain.rb', line 5386 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5388 5389 5390 |
# File 'lib/models/porcelain.rb', line 5388 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
5390 5391 5392 |
# File 'lib/models/porcelain.rb', line 5390 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5392 5393 5394 |
# File 'lib/models/porcelain.rb', line 5392 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5394 5395 5396 |
# File 'lib/models/porcelain.rb', line 5394 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5396 5397 5398 |
# File 'lib/models/porcelain.rb', line 5396 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5398 5399 5400 |
# File 'lib/models/porcelain.rb', line 5398 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5400 5401 5402 |
# File 'lib/models/porcelain.rb', line 5400 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5402 5403 5404 |
# File 'lib/models/porcelain.rb', line 5402 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5404 5405 5406 |
# File 'lib/models/porcelain.rb', line 5404 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5406 5407 5408 |
# File 'lib/models/porcelain.rb', line 5406 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/models/porcelain.rb', line 5434 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |