Class: SDM::Neptune
- Inherits:
-
Object
- Object
- SDM::Neptune
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Neptune
constructor
A new instance of Neptune.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Neptune
Returns a new instance of Neptune.
4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 |
# File 'lib/models/porcelain.rb', line 4992 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4972 4973 4974 |
# File 'lib/models/porcelain.rb', line 4972 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4974 4975 4976 |
# File 'lib/models/porcelain.rb', line 4974 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
4976 4977 4978 |
# File 'lib/models/porcelain.rb', line 4976 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4978 4979 4980 |
# File 'lib/models/porcelain.rb', line 4978 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4980 4981 4982 |
# File 'lib/models/porcelain.rb', line 4980 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4982 4983 4984 |
# File 'lib/models/porcelain.rb', line 4982 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4984 4985 4986 |
# File 'lib/models/porcelain.rb', line 4984 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4986 4987 4988 |
# File 'lib/models/porcelain.rb', line 4986 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4988 4989 4990 |
# File 'lib/models/porcelain.rb', line 4988 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4990 4991 4992 |
# File 'lib/models/porcelain.rb', line 4990 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5016 5017 5018 5019 5020 5021 5022 |
# File 'lib/models/porcelain.rb', line 5016 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |