Class: SDM::Neptune
- Inherits:
-
Object
- Object
- SDM::Neptune
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Neptune
constructor
A new instance of Neptune.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Neptune
Returns a new instance of Neptune.
4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/models/porcelain.rb', line 4654 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4634 4635 4636 |
# File 'lib/models/porcelain.rb', line 4634 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4636 4637 4638 |
# File 'lib/models/porcelain.rb', line 4636 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
4638 4639 4640 |
# File 'lib/models/porcelain.rb', line 4638 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4640 4641 4642 |
# File 'lib/models/porcelain.rb', line 4640 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4642 4643 4644 |
# File 'lib/models/porcelain.rb', line 4642 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4644 4645 4646 |
# File 'lib/models/porcelain.rb', line 4644 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4646 4647 4648 |
# File 'lib/models/porcelain.rb', line 4646 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4648 4649 4650 |
# File 'lib/models/porcelain.rb', line 4648 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4650 4651 4652 |
# File 'lib/models/porcelain.rb', line 4650 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4652 4653 4654 |
# File 'lib/models/porcelain.rb', line 4652 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4678 4679 4680 4681 4682 4683 4684 |
# File 'lib/models/porcelain.rb', line 4678 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |