Class: SDM::Neptune
- Inherits:
-
Object
- Object
- SDM::Neptune
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Neptune
constructor
A new instance of Neptune.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Neptune
Returns a new instance of Neptune.
4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 |
# File 'lib/models/porcelain.rb', line 4543 def initialize( bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4523 4524 4525 |
# File 'lib/models/porcelain.rb', line 4523 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4525 4526 4527 |
# File 'lib/models/porcelain.rb', line 4525 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
4527 4528 4529 |
# File 'lib/models/porcelain.rb', line 4527 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4529 4530 4531 |
# File 'lib/models/porcelain.rb', line 4529 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4531 4532 4533 |
# File 'lib/models/porcelain.rb', line 4531 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4533 4534 4535 |
# File 'lib/models/porcelain.rb', line 4533 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4535 4536 4537 |
# File 'lib/models/porcelain.rb', line 4535 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4537 4538 4539 |
# File 'lib/models/porcelain.rb', line 4537 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4539 4540 4541 |
# File 'lib/models/porcelain.rb', line 4539 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4541 4542 4543 |
# File 'lib/models/porcelain.rb', line 4541 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4567 4568 4569 4570 4571 4572 4573 |
# File 'lib/models/porcelain.rb', line 4567 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |