Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



4975
4976
4977
4978
4979
4980
4981
4982
4983
4984
4985
4986
4987
4988
4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
5013
# File 'lib/models/porcelain.rb', line 4975

def initialize(
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil
)
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if endpoint != nil
    @endpoint = endpoint
  end
  if healthy != nil
    @healthy = healthy
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if port != nil
    @port = port
  end
  if port_override != nil
    @port_override = port_override
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
end

Instance Attribute Details

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4957
4958
4959
# File 'lib/models/porcelain.rb', line 4957

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



4959
4960
4961
# File 'lib/models/porcelain.rb', line 4959

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4961
4962
4963
# File 'lib/models/porcelain.rb', line 4961

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4963
4964
4965
# File 'lib/models/porcelain.rb', line 4963

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4965
4966
4967
# File 'lib/models/porcelain.rb', line 4965

def name
  @name
end

#portObject

Returns the value of attribute port.



4967
4968
4969
# File 'lib/models/porcelain.rb', line 4967

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4969
4970
4971
# File 'lib/models/porcelain.rb', line 4969

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4971
4972
4973
# File 'lib/models/porcelain.rb', line 4971

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4973
4974
4975
# File 'lib/models/porcelain.rb', line 4973

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5015
5016
5017
5018
5019
5020
5021
# File 'lib/models/porcelain.rb', line 5015

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end