Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



12248
12249
12250
12251
12252
12253
12254
12255
12256
12257
12258
12259
12260
12261
12262
12263
12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
# File 'lib/models/porcelain.rb', line 12248

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12224
12225
12226
# File 'lib/models/porcelain.rb', line 12224

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12226
12227
12228
# File 'lib/models/porcelain.rb', line 12226

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12228
12229
12230
# File 'lib/models/porcelain.rb', line 12228

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12230
12231
12232
# File 'lib/models/porcelain.rb', line 12230

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12232
12233
12234
# File 'lib/models/porcelain.rb', line 12232

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12234
12235
12236
# File 'lib/models/porcelain.rb', line 12234

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12236
12237
12238
# File 'lib/models/porcelain.rb', line 12236

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12238
12239
12240
# File 'lib/models/porcelain.rb', line 12238

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12240
12241
12242
# File 'lib/models/porcelain.rb', line 12240

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12242
12243
12244
# File 'lib/models/porcelain.rb', line 12242

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12244
12245
12246
# File 'lib/models/porcelain.rb', line 12244

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12246
12247
12248
# File 'lib/models/porcelain.rb', line 12246

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12276
12277
12278
12279
12280
12281
12282
# File 'lib/models/porcelain.rb', line 12276

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end