Class: SDM::Neptune

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ Neptune

Returns a new instance of Neptune.



12569
12570
12571
12572
12573
12574
12575
12576
12577
12578
12579
12580
12581
12582
12583
12584
12585
12586
12587
12588
12589
12590
12591
12592
12593
12594
12595
# File 'lib/models/porcelain.rb', line 12569

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12545
12546
12547
# File 'lib/models/porcelain.rb', line 12545

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12547
12548
12549
# File 'lib/models/porcelain.rb', line 12547

def egress_filter
  @egress_filter
end

#endpoint ⇒ Object

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12549
12550
12551
# File 'lib/models/porcelain.rb', line 12549

def endpoint
  @endpoint
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12551
12552
12553
# File 'lib/models/porcelain.rb', line 12551

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



12553
12554
12555
# File 'lib/models/porcelain.rb', line 12553

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12555
12556
12557
# File 'lib/models/porcelain.rb', line 12555

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



12557
12558
12559
# File 'lib/models/porcelain.rb', line 12557

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12559
12560
12561
# File 'lib/models/porcelain.rb', line 12559

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12561
12562
12563
# File 'lib/models/porcelain.rb', line 12561

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12563
12564
12565
# File 'lib/models/porcelain.rb', line 12563

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12565
12566
12567
# File 'lib/models/porcelain.rb', line 12565

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12567
12568
12569
# File 'lib/models/porcelain.rb', line 12567

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12597
12598
12599
12600
12601
12602
12603
# File 'lib/models/porcelain.rb', line 12597

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end