Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



12582
12583
12584
12585
12586
12587
12588
12589
12590
12591
12592
12593
12594
12595
12596
12597
12598
12599
12600
12601
12602
12603
12604
12605
12606
12607
12608
12609
12610
12611
12612
12613
12614
12615
12616
12617
12618
# File 'lib/models/porcelain.rb', line 12582

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



12548
12549
12550
# File 'lib/models/porcelain.rb', line 12548

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12550
12551
12552
# File 'lib/models/porcelain.rb', line 12550

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12552
12553
12554
# File 'lib/models/porcelain.rb', line 12552

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12554
12555
12556
# File 'lib/models/porcelain.rb', line 12554

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12556
12557
12558
# File 'lib/models/porcelain.rb', line 12556

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12558
12559
12560
# File 'lib/models/porcelain.rb', line 12558

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12560
12561
12562
# File 'lib/models/porcelain.rb', line 12560

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12562
12563
12564
# File 'lib/models/porcelain.rb', line 12562

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12564
12565
12566
# File 'lib/models/porcelain.rb', line 12564

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12566
12567
12568
# File 'lib/models/porcelain.rb', line 12566

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



12568
12569
12570
# File 'lib/models/porcelain.rb', line 12568

def region
  @region
end

#role_arnObject

The role to assume after logging in.



12570
12571
12572
# File 'lib/models/porcelain.rb', line 12570

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



12572
12573
12574
# File 'lib/models/porcelain.rb', line 12572

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



12574
12575
12576
# File 'lib/models/porcelain.rb', line 12574

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12576
12577
12578
# File 'lib/models/porcelain.rb', line 12576

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12578
12579
12580
# File 'lib/models/porcelain.rb', line 12578

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12580
12581
12582
# File 'lib/models/porcelain.rb', line 12580

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12620
12621
12622
12623
12624
12625
12626
# File 'lib/models/porcelain.rb', line 12620

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end