Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



12454
12455
12456
12457
12458
12459
12460
12461
12462
12463
12464
12465
12466
12467
12468
12469
12470
12471
12472
12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
# File 'lib/models/porcelain.rb', line 12454

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



12420
12421
12422
# File 'lib/models/porcelain.rb', line 12420

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12422
12423
12424
# File 'lib/models/porcelain.rb', line 12422

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12424
12425
12426
# File 'lib/models/porcelain.rb', line 12424

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12426
12427
12428
# File 'lib/models/porcelain.rb', line 12426

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12428
12429
12430
# File 'lib/models/porcelain.rb', line 12428

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12430
12431
12432
# File 'lib/models/porcelain.rb', line 12430

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12432
12433
12434
# File 'lib/models/porcelain.rb', line 12432

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12434
12435
12436
# File 'lib/models/porcelain.rb', line 12434

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12436
12437
12438
# File 'lib/models/porcelain.rb', line 12436

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12438
12439
12440
# File 'lib/models/porcelain.rb', line 12438

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



12440
12441
12442
# File 'lib/models/porcelain.rb', line 12440

def region
  @region
end

#role_arnObject

The role to assume after logging in.



12442
12443
12444
# File 'lib/models/porcelain.rb', line 12442

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



12444
12445
12446
# File 'lib/models/porcelain.rb', line 12444

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



12446
12447
12448
# File 'lib/models/porcelain.rb', line 12446

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12448
12449
12450
# File 'lib/models/porcelain.rb', line 12448

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12450
12451
12452
# File 'lib/models/porcelain.rb', line 12450

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12452
12453
12454
# File 'lib/models/porcelain.rb', line 12452

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12492
12493
12494
12495
12496
12497
12498
# File 'lib/models/porcelain.rb', line 12492

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end