Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



12358
12359
12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
# File 'lib/models/porcelain.rb', line 12358

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



12324
12325
12326
# File 'lib/models/porcelain.rb', line 12324

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12326
12327
12328
# File 'lib/models/porcelain.rb', line 12326

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12328
12329
12330
# File 'lib/models/porcelain.rb', line 12328

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12330
12331
12332
# File 'lib/models/porcelain.rb', line 12330

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12332
12333
12334
# File 'lib/models/porcelain.rb', line 12332

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12334
12335
12336
# File 'lib/models/porcelain.rb', line 12334

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12336
12337
12338
# File 'lib/models/porcelain.rb', line 12336

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12338
12339
12340
# File 'lib/models/porcelain.rb', line 12338

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12340
12341
12342
# File 'lib/models/porcelain.rb', line 12340

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12342
12343
12344
# File 'lib/models/porcelain.rb', line 12342

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



12344
12345
12346
# File 'lib/models/porcelain.rb', line 12344

def region
  @region
end

#role_arnObject

The role to assume after logging in.



12346
12347
12348
# File 'lib/models/porcelain.rb', line 12346

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



12348
12349
12350
# File 'lib/models/porcelain.rb', line 12348

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



12350
12351
12352
# File 'lib/models/porcelain.rb', line 12350

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12352
12353
12354
# File 'lib/models/porcelain.rb', line 12352

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12354
12355
12356
# File 'lib/models/porcelain.rb', line 12354

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12356
12357
12358
# File 'lib/models/porcelain.rb', line 12356

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12396
12397
12398
12399
12400
12401
12402
# File 'lib/models/porcelain.rb', line 12396

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end