Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



11952
11953
11954
11955
11956
11957
11958
11959
11960
11961
11962
11963
11964
11965
11966
11967
11968
11969
11970
11971
11972
11973
11974
11975
11976
11977
11978
11979
11980
11981
11982
11983
11984
11985
11986
11987
11988
# File 'lib/models/porcelain.rb', line 11952

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



11918
11919
11920
# File 'lib/models/porcelain.rb', line 11918

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11920
11921
11922
# File 'lib/models/porcelain.rb', line 11920

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11922
11923
11924
# File 'lib/models/porcelain.rb', line 11922

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



11924
11925
11926
# File 'lib/models/porcelain.rb', line 11924

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11926
11927
11928
# File 'lib/models/porcelain.rb', line 11926

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11928
11929
11930
# File 'lib/models/porcelain.rb', line 11928

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11930
11931
11932
# File 'lib/models/porcelain.rb', line 11930

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11932
11933
11934
# File 'lib/models/porcelain.rb', line 11932

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11934
11935
11936
# File 'lib/models/porcelain.rb', line 11934

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11936
11937
11938
# File 'lib/models/porcelain.rb', line 11936

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



11938
11939
11940
# File 'lib/models/porcelain.rb', line 11938

def region
  @region
end

#role_arnObject

The role to assume after logging in.



11940
11941
11942
# File 'lib/models/porcelain.rb', line 11940

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



11942
11943
11944
# File 'lib/models/porcelain.rb', line 11942

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



11944
11945
11946
# File 'lib/models/porcelain.rb', line 11944

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11946
11947
11948
# File 'lib/models/porcelain.rb', line 11946

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11948
11949
11950
# File 'lib/models/porcelain.rb', line 11948

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11950
11951
11952
# File 'lib/models/porcelain.rb', line 11950

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11990
11991
11992
11993
11994
11995
11996
# File 'lib/models/porcelain.rb', line 11990

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end