Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



11666
11667
11668
11669
11670
11671
11672
11673
11674
11675
11676
11677
11678
11679
11680
11681
11682
11683
11684
11685
11686
11687
11688
11689
11690
11691
11692
11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
# File 'lib/models/porcelain.rb', line 11666

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



11632
11633
11634
# File 'lib/models/porcelain.rb', line 11632

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11634
11635
11636
# File 'lib/models/porcelain.rb', line 11634

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11636
11637
11638
# File 'lib/models/porcelain.rb', line 11636

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



11638
11639
11640
# File 'lib/models/porcelain.rb', line 11638

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11640
11641
11642
# File 'lib/models/porcelain.rb', line 11640

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11642
11643
11644
# File 'lib/models/porcelain.rb', line 11642

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11644
11645
11646
# File 'lib/models/porcelain.rb', line 11644

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11646
11647
11648
# File 'lib/models/porcelain.rb', line 11646

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



11648
11649
11650
# File 'lib/models/porcelain.rb', line 11648

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11650
11651
11652
# File 'lib/models/porcelain.rb', line 11650

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



11652
11653
11654
# File 'lib/models/porcelain.rb', line 11652

def region
  @region
end

#role_arnObject

The role to assume after logging in.



11654
11655
11656
# File 'lib/models/porcelain.rb', line 11654

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



11656
11657
11658
# File 'lib/models/porcelain.rb', line 11656

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



11658
11659
11660
# File 'lib/models/porcelain.rb', line 11658

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11660
11661
11662
# File 'lib/models/porcelain.rb', line 11660

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11662
11663
11664
# File 'lib/models/porcelain.rb', line 11662

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11664
11665
11666
# File 'lib/models/porcelain.rb', line 11664

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11704
11705
11706
11707
11708
11709
11710
# File 'lib/models/porcelain.rb', line 11704

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end