Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



10895
10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
10920
10921
10922
10923
10924
10925
10926
10927
10928
10929
10930
10931
# File 'lib/models/porcelain.rb', line 10895

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



10861
10862
10863
# File 'lib/models/porcelain.rb', line 10861

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



10863
10864
10865
# File 'lib/models/porcelain.rb', line 10863

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10865
10866
10867
# File 'lib/models/porcelain.rb', line 10865

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



10867
10868
10869
# File 'lib/models/porcelain.rb', line 10867

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10869
10870
10871
# File 'lib/models/porcelain.rb', line 10869

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



10871
10872
10873
# File 'lib/models/porcelain.rb', line 10871

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10873
10874
10875
# File 'lib/models/porcelain.rb', line 10873

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10875
10876
10877
# File 'lib/models/porcelain.rb', line 10875

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



10877
10878
10879
# File 'lib/models/porcelain.rb', line 10877

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10879
10880
10881
# File 'lib/models/porcelain.rb', line 10879

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10881
10882
10883
# File 'lib/models/porcelain.rb', line 10881

def region
  @region
end

#role_arnObject

The role to assume after logging in.



10883
10884
10885
# File 'lib/models/porcelain.rb', line 10883

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



10885
10886
10887
# File 'lib/models/porcelain.rb', line 10885

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



10887
10888
10889
# File 'lib/models/porcelain.rb', line 10887

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10889
10890
10891
# File 'lib/models/porcelain.rb', line 10889

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



10891
10892
10893
# File 'lib/models/porcelain.rb', line 10891

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10893
10894
10895
# File 'lib/models/porcelain.rb', line 10893

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10933
10934
10935
10936
10937
10938
10939
# File 'lib/models/porcelain.rb', line 10933

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end