Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
9815
9816
9817
9818
9819
9820
9821
# File 'lib/models/porcelain.rb', line 9785

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



9751
9752
9753
# File 'lib/models/porcelain.rb', line 9751

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9753
9754
9755
# File 'lib/models/porcelain.rb', line 9753

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9755
9756
9757
# File 'lib/models/porcelain.rb', line 9755

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



9757
9758
9759
# File 'lib/models/porcelain.rb', line 9757

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9759
9760
9761
# File 'lib/models/porcelain.rb', line 9759

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



9761
9762
9763
# File 'lib/models/porcelain.rb', line 9761

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9763
9764
9765
# File 'lib/models/porcelain.rb', line 9763

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9765
9766
9767
# File 'lib/models/porcelain.rb', line 9765

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9767
9768
9769
# File 'lib/models/porcelain.rb', line 9767

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9769
9770
9771
# File 'lib/models/porcelain.rb', line 9769

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



9771
9772
9773
# File 'lib/models/porcelain.rb', line 9771

def region
  @region
end

#role_arnObject

The role to assume after logging in.



9773
9774
9775
# File 'lib/models/porcelain.rb', line 9773

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



9775
9776
9777
# File 'lib/models/porcelain.rb', line 9775

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



9777
9778
9779
# File 'lib/models/porcelain.rb', line 9777

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9779
9780
9781
# File 'lib/models/porcelain.rb', line 9779

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9781
9782
9783
# File 'lib/models/porcelain.rb', line 9781

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9783
9784
9785
# File 'lib/models/porcelain.rb', line 9783

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9823
9824
9825
9826
9827
9828
9829
# File 'lib/models/porcelain.rb', line 9823

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end