Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



9547
9548
9549
9550
9551
9552
9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
9567
9568
9569
9570
9571
9572
9573
9574
9575
9576
9577
9578
9579
9580
9581
9582
9583
# File 'lib/models/porcelain.rb', line 9547

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



9513
9514
9515
# File 'lib/models/porcelain.rb', line 9513

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9515
9516
9517
# File 'lib/models/porcelain.rb', line 9515

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9517
9518
9519
# File 'lib/models/porcelain.rb', line 9517

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



9519
9520
9521
# File 'lib/models/porcelain.rb', line 9519

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9521
9522
9523
# File 'lib/models/porcelain.rb', line 9521

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



9523
9524
9525
# File 'lib/models/porcelain.rb', line 9523

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9525
9526
9527
# File 'lib/models/porcelain.rb', line 9525

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9527
9528
9529
# File 'lib/models/porcelain.rb', line 9527

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9529
9530
9531
# File 'lib/models/porcelain.rb', line 9529

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9531
9532
9533
# File 'lib/models/porcelain.rb', line 9531

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



9533
9534
9535
# File 'lib/models/porcelain.rb', line 9533

def region
  @region
end

#role_arnObject

The role to assume after logging in.



9535
9536
9537
# File 'lib/models/porcelain.rb', line 9535

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



9537
9538
9539
# File 'lib/models/porcelain.rb', line 9537

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



9539
9540
9541
# File 'lib/models/porcelain.rb', line 9539

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9541
9542
9543
# File 'lib/models/porcelain.rb', line 9541

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9543
9544
9545
# File 'lib/models/porcelain.rb', line 9543

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9545
9546
9547
# File 'lib/models/porcelain.rb', line 9545

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9585
9586
9587
9588
9589
9590
9591
# File 'lib/models/porcelain.rb', line 9585

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end