Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



9468
9469
9470
9471
9472
9473
9474
9475
9476
9477
9478
9479
9480
9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
# File 'lib/models/porcelain.rb', line 9468

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



9434
9435
9436
# File 'lib/models/porcelain.rb', line 9434

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9436
9437
9438
# File 'lib/models/porcelain.rb', line 9436

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9438
9439
9440
# File 'lib/models/porcelain.rb', line 9438

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



9440
9441
9442
# File 'lib/models/porcelain.rb', line 9440

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9442
9443
9444
# File 'lib/models/porcelain.rb', line 9442

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



9444
9445
9446
# File 'lib/models/porcelain.rb', line 9444

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9446
9447
9448
# File 'lib/models/porcelain.rb', line 9446

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9448
9449
9450
# File 'lib/models/porcelain.rb', line 9448

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9450
9451
9452
# File 'lib/models/porcelain.rb', line 9450

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9452
9453
9454
# File 'lib/models/porcelain.rb', line 9452

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



9454
9455
9456
# File 'lib/models/porcelain.rb', line 9454

def region
  @region
end

#role_arnObject

The role to assume after logging in.



9456
9457
9458
# File 'lib/models/porcelain.rb', line 9456

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



9458
9459
9460
# File 'lib/models/porcelain.rb', line 9458

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



9460
9461
9462
# File 'lib/models/porcelain.rb', line 9460

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9462
9463
9464
# File 'lib/models/porcelain.rb', line 9462

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9464
9465
9466
# File 'lib/models/porcelain.rb', line 9464

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9466
9467
9468
# File 'lib/models/porcelain.rb', line 9466

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9506
9507
9508
9509
9510
9511
9512
# File 'lib/models/porcelain.rb', line 9506

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end