Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



8550
8551
8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
# File 'lib/models/porcelain.rb', line 8550

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



8516
8517
8518
# File 'lib/models/porcelain.rb', line 8516

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8518
8519
8520
# File 'lib/models/porcelain.rb', line 8518

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8520
8521
8522
# File 'lib/models/porcelain.rb', line 8520

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



8522
8523
8524
# File 'lib/models/porcelain.rb', line 8522

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8524
8525
8526
# File 'lib/models/porcelain.rb', line 8524

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8526
8527
8528
# File 'lib/models/porcelain.rb', line 8526

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8528
8529
8530
# File 'lib/models/porcelain.rb', line 8528

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8530
8531
8532
# File 'lib/models/porcelain.rb', line 8530

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8532
8533
8534
# File 'lib/models/porcelain.rb', line 8532

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8534
8535
8536
# File 'lib/models/porcelain.rb', line 8534

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



8536
8537
8538
# File 'lib/models/porcelain.rb', line 8536

def region
  @region
end

#role_arnObject

The role to assume after logging in.



8538
8539
8540
# File 'lib/models/porcelain.rb', line 8538

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



8540
8541
8542
# File 'lib/models/porcelain.rb', line 8540

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



8542
8543
8544
# File 'lib/models/porcelain.rb', line 8542

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8544
8545
8546
# File 'lib/models/porcelain.rb', line 8544

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8546
8547
8548
# File 'lib/models/porcelain.rb', line 8546

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8548
8549
8550
# File 'lib/models/porcelain.rb', line 8548

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8588
8589
8590
8591
8592
8593
8594
# File 'lib/models/porcelain.rb', line 8588

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end