Class: SDM::NeptuneIAM
- Inherits:
-
Object
- Object
- SDM::NeptuneIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
The Access Key ID to use to authenticate.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_arn ⇒ Object
The role to assume after logging in.
-
#role_external_id ⇒ Object
The external ID to associate with assume role requests.
-
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM
constructor
A new instance of NeptuneIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM
Returns a new instance of NeptuneIAM.
8395 8396 8397 8398 8399 8400 8401 8402 8403 8404 8405 8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 8418 8419 8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 |
# File 'lib/models/porcelain.rb', line 8395 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
The Access Key ID to use to authenticate.
8361 8362 8363 |
# File 'lib/models/porcelain.rb', line 8361 def access_key @access_key end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8363 8364 8365 |
# File 'lib/models/porcelain.rb', line 8363 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8365 8366 8367 |
# File 'lib/models/porcelain.rb', line 8365 def egress_filter @egress_filter end |
#endpoint ⇒ Object
The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com
8367 8368 8369 |
# File 'lib/models/porcelain.rb', line 8367 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8369 8370 8371 |
# File 'lib/models/porcelain.rb', line 8369 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
8371 8372 8373 |
# File 'lib/models/porcelain.rb', line 8371 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8373 8374 8375 |
# File 'lib/models/porcelain.rb', line 8373 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8375 8376 8377 |
# File 'lib/models/porcelain.rb', line 8375 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8377 8378 8379 |
# File 'lib/models/porcelain.rb', line 8377 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8379 8380 8381 |
# File 'lib/models/porcelain.rb', line 8379 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
8381 8382 8383 |
# File 'lib/models/porcelain.rb', line 8381 def region @region end |
#role_arn ⇒ Object
The role to assume after logging in.
8383 8384 8385 |
# File 'lib/models/porcelain.rb', line 8383 def role_arn @role_arn end |
#role_external_id ⇒ Object
The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.
8385 8386 8387 |
# File 'lib/models/porcelain.rb', line 8385 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
The Secret Access Key to use to authenticate.
8387 8388 8389 |
# File 'lib/models/porcelain.rb', line 8387 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8389 8390 8391 |
# File 'lib/models/porcelain.rb', line 8389 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8391 8392 8393 |
# File 'lib/models/porcelain.rb', line 8391 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8393 8394 8395 |
# File 'lib/models/porcelain.rb', line 8393 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8433 8434 8435 8436 8437 8438 8439 |
# File 'lib/models/porcelain.rb', line 8433 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |