Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
8335
8336
8337
8338
8339
8340
8341
8342
8343
8344
8345
8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
8357
8358
8359
8360
8361
# File 'lib/models/porcelain.rb', line 8325

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



8291
8292
8293
# File 'lib/models/porcelain.rb', line 8291

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8293
8294
8295
# File 'lib/models/porcelain.rb', line 8293

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8295
8296
8297
# File 'lib/models/porcelain.rb', line 8295

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



8297
8298
8299
# File 'lib/models/porcelain.rb', line 8297

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8299
8300
8301
# File 'lib/models/porcelain.rb', line 8299

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



8301
8302
8303
# File 'lib/models/porcelain.rb', line 8301

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8303
8304
8305
# File 'lib/models/porcelain.rb', line 8303

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8305
8306
8307
# File 'lib/models/porcelain.rb', line 8305

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8307
8308
8309
# File 'lib/models/porcelain.rb', line 8307

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8309
8310
8311
# File 'lib/models/porcelain.rb', line 8309

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



8311
8312
8313
# File 'lib/models/porcelain.rb', line 8311

def region
  @region
end

#role_arnObject

The role to assume after logging in.



8313
8314
8315
# File 'lib/models/porcelain.rb', line 8313

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



8315
8316
8317
# File 'lib/models/porcelain.rb', line 8315

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



8317
8318
8319
# File 'lib/models/porcelain.rb', line 8317

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8319
8320
8321
# File 'lib/models/porcelain.rb', line 8319

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8321
8322
8323
# File 'lib/models/porcelain.rb', line 8321

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8323
8324
8325
# File 'lib/models/porcelain.rb', line 8323

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8363
8364
8365
8366
8367
8368
8369
# File 'lib/models/porcelain.rb', line 8363

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end