Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



7963
7964
7965
7966
7967
7968
7969
7970
7971
7972
7973
7974
7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
7994
7995
7996
7997
7998
7999
# File 'lib/models/porcelain.rb', line 7963

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



7929
7930
7931
# File 'lib/models/porcelain.rb', line 7929

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7931
7932
7933
# File 'lib/models/porcelain.rb', line 7931

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7933
7934
7935
# File 'lib/models/porcelain.rb', line 7933

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



7935
7936
7937
# File 'lib/models/porcelain.rb', line 7935

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7937
7938
7939
# File 'lib/models/porcelain.rb', line 7937

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7939
7940
7941
# File 'lib/models/porcelain.rb', line 7939

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7941
7942
7943
# File 'lib/models/porcelain.rb', line 7941

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7943
7944
7945
# File 'lib/models/porcelain.rb', line 7943

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7945
7946
7947
# File 'lib/models/porcelain.rb', line 7945

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7947
7948
7949
# File 'lib/models/porcelain.rb', line 7947

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



7949
7950
7951
# File 'lib/models/porcelain.rb', line 7949

def region
  @region
end

#role_arnObject

The role to assume after logging in.



7951
7952
7953
# File 'lib/models/porcelain.rb', line 7951

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



7953
7954
7955
# File 'lib/models/porcelain.rb', line 7953

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



7955
7956
7957
# File 'lib/models/porcelain.rb', line 7955

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7957
7958
7959
# File 'lib/models/porcelain.rb', line 7957

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7959
7960
7961
# File 'lib/models/porcelain.rb', line 7959

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7961
7962
7963
# File 'lib/models/porcelain.rb', line 7961

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8001
8002
8003
8004
8005
8006
8007
# File 'lib/models/porcelain.rb', line 8001

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end