Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



7714
7715
7716
7717
7718
7719
7720
7721
7722
7723
7724
7725
7726
7727
7728
7729
7730
7731
7732
7733
7734
7735
7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
# File 'lib/models/porcelain.rb', line 7714

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



7680
7681
7682
# File 'lib/models/porcelain.rb', line 7680

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7682
7683
7684
# File 'lib/models/porcelain.rb', line 7682

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7684
7685
7686
# File 'lib/models/porcelain.rb', line 7684

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



7686
7687
7688
# File 'lib/models/porcelain.rb', line 7686

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7688
7689
7690
# File 'lib/models/porcelain.rb', line 7688

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7690
7691
7692
# File 'lib/models/porcelain.rb', line 7690

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7692
7693
7694
# File 'lib/models/porcelain.rb', line 7692

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7694
7695
7696
# File 'lib/models/porcelain.rb', line 7694

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7696
7697
7698
# File 'lib/models/porcelain.rb', line 7696

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7698
7699
7700
# File 'lib/models/porcelain.rb', line 7698

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



7700
7701
7702
# File 'lib/models/porcelain.rb', line 7700

def region
  @region
end

#role_arnObject

The role to assume after logging in.



7702
7703
7704
# File 'lib/models/porcelain.rb', line 7702

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



7704
7705
7706
# File 'lib/models/porcelain.rb', line 7704

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



7706
7707
7708
# File 'lib/models/porcelain.rb', line 7706

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7708
7709
7710
# File 'lib/models/porcelain.rb', line 7708

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7710
7711
7712
# File 'lib/models/porcelain.rb', line 7710

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7712
7713
7714
# File 'lib/models/porcelain.rb', line 7712

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7752
7753
7754
7755
7756
7757
7758
# File 'lib/models/porcelain.rb', line 7752

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end