Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



7643
7644
7645
7646
7647
7648
7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/models/porcelain.rb', line 7643

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



7609
7610
7611
# File 'lib/models/porcelain.rb', line 7609

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7611
7612
7613
# File 'lib/models/porcelain.rb', line 7611

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7613
7614
7615
# File 'lib/models/porcelain.rb', line 7613

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



7615
7616
7617
# File 'lib/models/porcelain.rb', line 7615

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7617
7618
7619
# File 'lib/models/porcelain.rb', line 7617

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



7619
7620
7621
# File 'lib/models/porcelain.rb', line 7619

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7621
7622
7623
# File 'lib/models/porcelain.rb', line 7621

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7623
7624
7625
# File 'lib/models/porcelain.rb', line 7623

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7625
7626
7627
# File 'lib/models/porcelain.rb', line 7625

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



7627
7628
7629
# File 'lib/models/porcelain.rb', line 7627

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



7629
7630
7631
# File 'lib/models/porcelain.rb', line 7629

def region
  @region
end

#role_arnObject

The role to assume after logging in.



7631
7632
7633
# File 'lib/models/porcelain.rb', line 7631

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



7633
7634
7635
# File 'lib/models/porcelain.rb', line 7633

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



7635
7636
7637
# File 'lib/models/porcelain.rb', line 7635

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7637
7638
7639
# File 'lib/models/porcelain.rb', line 7637

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7639
7640
7641
# File 'lib/models/porcelain.rb', line 7639

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7641
7642
7643
# File 'lib/models/porcelain.rb', line 7641

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7681
7682
7683
7684
7685
7686
7687
# File 'lib/models/porcelain.rb', line 7681

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end