Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
5819
5820
5821
5822
5823
5824
5825
5826
5827
5828
5829
5830
5831
5832
5833
5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/models/porcelain.rb', line 5808

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



5776
5777
5778
# File 'lib/models/porcelain.rb', line 5776

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5778
5779
5780
# File 'lib/models/porcelain.rb', line 5778

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5780
5781
5782
# File 'lib/models/porcelain.rb', line 5780

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



5782
5783
5784
# File 'lib/models/porcelain.rb', line 5782

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5784
5785
5786
# File 'lib/models/porcelain.rb', line 5784

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5786
5787
5788
# File 'lib/models/porcelain.rb', line 5786

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5788
5789
5790
# File 'lib/models/porcelain.rb', line 5788

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5790
5791
5792
# File 'lib/models/porcelain.rb', line 5790

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5792
5793
5794
# File 'lib/models/porcelain.rb', line 5792

def port_override
  @port_override
end

#regionObject

The AWS region to connect to.



5794
5795
5796
# File 'lib/models/porcelain.rb', line 5794

def region
  @region
end

#role_arnObject

The role to assume after logging in.



5796
5797
5798
# File 'lib/models/porcelain.rb', line 5796

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



5798
5799
5800
# File 'lib/models/porcelain.rb', line 5798

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



5800
5801
5802
# File 'lib/models/porcelain.rb', line 5800

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5802
5803
5804
# File 'lib/models/porcelain.rb', line 5802

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5804
5805
5806
# File 'lib/models/porcelain.rb', line 5804

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5806
5807
5808
# File 'lib/models/porcelain.rb', line 5806

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5844
5845
5846
5847
5848
5849
5850
# File 'lib/models/porcelain.rb', line 5844

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end