Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
5636
# File 'lib/models/porcelain.rb', line 5602

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

The Access Key ID to use to authenticate.



5570
5571
5572
# File 'lib/models/porcelain.rb', line 5570

def access_key
  @access_key
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



5572
5573
5574
# File 'lib/models/porcelain.rb', line 5572

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5574
5575
5576
# File 'lib/models/porcelain.rb', line 5574

def egress_filter
  @egress_filter
end

#endpointObject

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



5576
5577
5578
# File 'lib/models/porcelain.rb', line 5576

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5578
5579
5580
# File 'lib/models/porcelain.rb', line 5578

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5580
5581
5582
# File 'lib/models/porcelain.rb', line 5580

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5582
5583
5584
# File 'lib/models/porcelain.rb', line 5582

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



5584
5585
5586
# File 'lib/models/porcelain.rb', line 5584

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



5586
5587
5588
# File 'lib/models/porcelain.rb', line 5586

def port_override
  @port_override
end

#regionObject

The AWS region to connect to.



5588
5589
5590
# File 'lib/models/porcelain.rb', line 5588

def region
  @region
end

#role_arnObject

The role to assume after logging in.



5590
5591
5592
# File 'lib/models/porcelain.rb', line 5590

def role_arn
  @role_arn
end

#role_external_idObject

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



5592
5593
5594
# File 'lib/models/porcelain.rb', line 5592

def role_external_id
  @role_external_id
end

#secret_access_keyObject

The Secret Access Key to use to authenticate.



5594
5595
5596
# File 'lib/models/porcelain.rb', line 5594

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5596
5597
5598
# File 'lib/models/porcelain.rb', line 5596

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5598
5599
5600
# File 'lib/models/porcelain.rb', line 5598

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5600
5601
5602
# File 'lib/models/porcelain.rb', line 5600

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5638
5639
5640
5641
5642
5643
5644
# File 'lib/models/porcelain.rb', line 5638

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end