Class: SDM::NeptuneIAM
- Inherits:
-
Object
- Object
- SDM::NeptuneIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM
constructor
A new instance of NeptuneIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM
Returns a new instance of NeptuneIAM.
5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 |
# File 'lib/models/porcelain.rb', line 5476 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
5444 5445 5446 |
# File 'lib/models/porcelain.rb', line 5444 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
5446 5447 5448 |
# File 'lib/models/porcelain.rb', line 5446 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5448 5449 5450 |
# File 'lib/models/porcelain.rb', line 5448 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
5450 5451 5452 |
# File 'lib/models/porcelain.rb', line 5450 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5452 5453 5454 |
# File 'lib/models/porcelain.rb', line 5452 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5454 5455 5456 |
# File 'lib/models/porcelain.rb', line 5454 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5456 5457 5458 |
# File 'lib/models/porcelain.rb', line 5456 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5458 5459 5460 |
# File 'lib/models/porcelain.rb', line 5458 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5460 5461 5462 |
# File 'lib/models/porcelain.rb', line 5460 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
5462 5463 5464 |
# File 'lib/models/porcelain.rb', line 5462 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
5464 5465 5466 |
# File 'lib/models/porcelain.rb', line 5464 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
5466 5467 5468 |
# File 'lib/models/porcelain.rb', line 5466 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
5468 5469 5470 |
# File 'lib/models/porcelain.rb', line 5468 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5470 5471 5472 |
# File 'lib/models/porcelain.rb', line 5470 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5472 5473 5474 |
# File 'lib/models/porcelain.rb', line 5472 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5474 5475 5476 |
# File 'lib/models/porcelain.rb', line 5474 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5512 5513 5514 5515 5516 5517 5518 |
# File 'lib/models/porcelain.rb', line 5512 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |