Class: SDM::NeptuneIAM
- Inherits:
-
Object
- Object
- SDM::NeptuneIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM
constructor
A new instance of NeptuneIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM
Returns a new instance of NeptuneIAM.
5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 |
# File 'lib/models/porcelain.rb', line 5404 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
5372 5373 5374 |
# File 'lib/models/porcelain.rb', line 5372 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
5374 5375 5376 |
# File 'lib/models/porcelain.rb', line 5374 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5376 5377 5378 |
# File 'lib/models/porcelain.rb', line 5376 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
5378 5379 5380 |
# File 'lib/models/porcelain.rb', line 5378 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5380 5381 5382 |
# File 'lib/models/porcelain.rb', line 5380 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5382 5383 5384 |
# File 'lib/models/porcelain.rb', line 5382 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5384 5385 5386 |
# File 'lib/models/porcelain.rb', line 5384 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5386 5387 5388 |
# File 'lib/models/porcelain.rb', line 5386 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5388 5389 5390 |
# File 'lib/models/porcelain.rb', line 5388 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
5390 5391 5392 |
# File 'lib/models/porcelain.rb', line 5390 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
5392 5393 5394 |
# File 'lib/models/porcelain.rb', line 5392 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
5394 5395 5396 |
# File 'lib/models/porcelain.rb', line 5394 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
5396 5397 5398 |
# File 'lib/models/porcelain.rb', line 5396 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5398 5399 5400 |
# File 'lib/models/porcelain.rb', line 5398 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5400 5401 5402 |
# File 'lib/models/porcelain.rb', line 5400 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5402 5403 5404 |
# File 'lib/models/porcelain.rb', line 5402 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5440 5441 5442 5443 5444 5445 5446 |
# File 'lib/models/porcelain.rb', line 5440 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |