Class: SDM::NeptuneIAM
- Inherits:
-
Object
- Object
- SDM::NeptuneIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM
constructor
A new instance of NeptuneIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM
Returns a new instance of NeptuneIAM.
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 5266 5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 |
# File 'lib/models/porcelain.rb', line 5250 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
5218 5219 5220 |
# File 'lib/models/porcelain.rb', line 5218 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
5220 5221 5222 |
# File 'lib/models/porcelain.rb', line 5220 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5222 5223 5224 |
# File 'lib/models/porcelain.rb', line 5222 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
5224 5225 5226 |
# File 'lib/models/porcelain.rb', line 5224 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5226 5227 5228 |
# File 'lib/models/porcelain.rb', line 5226 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5228 5229 5230 |
# File 'lib/models/porcelain.rb', line 5228 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5230 5231 5232 |
# File 'lib/models/porcelain.rb', line 5230 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5232 5233 5234 |
# File 'lib/models/porcelain.rb', line 5232 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5234 5235 5236 |
# File 'lib/models/porcelain.rb', line 5234 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
5236 5237 5238 |
# File 'lib/models/porcelain.rb', line 5236 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
5238 5239 5240 |
# File 'lib/models/porcelain.rb', line 5238 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
5240 5241 5242 |
# File 'lib/models/porcelain.rb', line 5240 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
5242 5243 5244 |
# File 'lib/models/porcelain.rb', line 5242 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5244 5245 5246 |
# File 'lib/models/porcelain.rb', line 5244 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5246 5247 5248 |
# File 'lib/models/porcelain.rb', line 5246 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5248 5249 5250 |
# File 'lib/models/porcelain.rb', line 5248 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5286 5287 5288 5289 5290 5291 5292 |
# File 'lib/models/porcelain.rb', line 5286 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |