Class: SDM::NeptuneIAM
- Inherits:
-
Object
- Object
- SDM::NeptuneIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM
constructor
A new instance of NeptuneIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM
Returns a new instance of NeptuneIAM.
5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 |
# File 'lib/models/porcelain.rb', line 5056 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
5026 5027 5028 |
# File 'lib/models/porcelain.rb', line 5026 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
5028 5029 5030 |
# File 'lib/models/porcelain.rb', line 5028 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5030 5031 5032 |
# File 'lib/models/porcelain.rb', line 5030 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
5032 5033 5034 |
# File 'lib/models/porcelain.rb', line 5032 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5034 5035 5036 |
# File 'lib/models/porcelain.rb', line 5034 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
5036 5037 5038 |
# File 'lib/models/porcelain.rb', line 5036 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5038 5039 5040 |
# File 'lib/models/porcelain.rb', line 5038 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5040 5041 5042 |
# File 'lib/models/porcelain.rb', line 5040 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5042 5043 5044 |
# File 'lib/models/porcelain.rb', line 5042 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
5044 5045 5046 |
# File 'lib/models/porcelain.rb', line 5044 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
5046 5047 5048 |
# File 'lib/models/porcelain.rb', line 5046 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
5048 5049 5050 |
# File 'lib/models/porcelain.rb', line 5048 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
5050 5051 5052 |
# File 'lib/models/porcelain.rb', line 5050 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5052 5053 5054 |
# File 'lib/models/porcelain.rb', line 5052 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5054 5055 5056 |
# File 'lib/models/porcelain.rb', line 5054 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5090 5091 5092 5093 5094 5095 5096 |
# File 'lib/models/porcelain.rb', line 5090 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |