Class: SDM::NeptuneIAM
- Inherits:
-
Object
- Object
- SDM::NeptuneIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM
constructor
A new instance of NeptuneIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM
Returns a new instance of NeptuneIAM.
4718 4719 4720 4721 4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 |
# File 'lib/models/porcelain.rb', line 4718 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
4688 4689 4690 |
# File 'lib/models/porcelain.rb', line 4688 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
4690 4691 4692 |
# File 'lib/models/porcelain.rb', line 4690 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4692 4693 4694 |
# File 'lib/models/porcelain.rb', line 4692 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
4694 4695 4696 |
# File 'lib/models/porcelain.rb', line 4694 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4696 4697 4698 |
# File 'lib/models/porcelain.rb', line 4696 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4698 4699 4700 |
# File 'lib/models/porcelain.rb', line 4698 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4700 4701 4702 |
# File 'lib/models/porcelain.rb', line 4700 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4702 4703 4704 |
# File 'lib/models/porcelain.rb', line 4702 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4704 4705 4706 |
# File 'lib/models/porcelain.rb', line 4704 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
4706 4707 4708 |
# File 'lib/models/porcelain.rb', line 4706 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
4708 4709 4710 |
# File 'lib/models/porcelain.rb', line 4708 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
4710 4711 4712 |
# File 'lib/models/porcelain.rb', line 4710 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
4712 4713 4714 |
# File 'lib/models/porcelain.rb', line 4712 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4714 4715 4716 |
# File 'lib/models/porcelain.rb', line 4714 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4716 4717 4718 |
# File 'lib/models/porcelain.rb', line 4716 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4752 4753 4754 4755 4756 4757 4758 |
# File 'lib/models/porcelain.rb', line 4752 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |