Class: SDM::NeptuneIAM
- Inherits:
-
Object
- Object
- SDM::NeptuneIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#access_key ⇒ Object
Returns the value of attribute access_key.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#region ⇒ Object
Returns the value of attribute region.
-
#role_arn ⇒ Object
Returns the value of attribute role_arn.
-
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM
constructor
A new instance of NeptuneIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM
Returns a new instance of NeptuneIAM.
4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 |
# File 'lib/models/porcelain.rb', line 4607 def initialize( access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil ) @access_key = access_key == nil ? "" : access_key @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @endpoint = endpoint == nil ? "" : endpoint @healthy = healthy == nil ? false : healthy @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @region = region == nil ? "" : region @role_arn = role_arn == nil ? "" : role_arn @role_external_id = role_external_id == nil ? "" : role_external_id @secret_access_key = secret_access_key == nil ? "" : secret_access_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_key ⇒ Object
Returns the value of attribute access_key.
4577 4578 4579 |
# File 'lib/models/porcelain.rb', line 4577 def access_key @access_key end |
#bind_interface ⇒ Object
Bind interface
4579 4580 4581 |
# File 'lib/models/porcelain.rb', line 4579 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4581 4582 4583 |
# File 'lib/models/porcelain.rb', line 4581 def egress_filter @egress_filter end |
#endpoint ⇒ Object
Returns the value of attribute endpoint.
4583 4584 4585 |
# File 'lib/models/porcelain.rb', line 4583 def endpoint @endpoint end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4585 4586 4587 |
# File 'lib/models/porcelain.rb', line 4585 def healthy @healthy end |
#id ⇒ Object
Unique identifier of the Resource.
4587 4588 4589 |
# File 'lib/models/porcelain.rb', line 4587 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4589 4590 4591 |
# File 'lib/models/porcelain.rb', line 4589 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
4591 4592 4593 |
# File 'lib/models/porcelain.rb', line 4591 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4593 4594 4595 |
# File 'lib/models/porcelain.rb', line 4593 def port_override @port_override end |
#region ⇒ Object
Returns the value of attribute region.
4595 4596 4597 |
# File 'lib/models/porcelain.rb', line 4595 def region @region end |
#role_arn ⇒ Object
Returns the value of attribute role_arn.
4597 4598 4599 |
# File 'lib/models/porcelain.rb', line 4597 def role_arn @role_arn end |
#role_external_id ⇒ Object
Returns the value of attribute role_external_id.
4599 4600 4601 |
# File 'lib/models/porcelain.rb', line 4599 def role_external_id @role_external_id end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
4601 4602 4603 |
# File 'lib/models/porcelain.rb', line 4601 def secret_access_key @secret_access_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4603 4604 4605 |
# File 'lib/models/porcelain.rb', line 4603 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4605 4606 4607 |
# File 'lib/models/porcelain.rb', line 4605 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4641 4642 4643 4644 4645 4646 4647 |
# File 'lib/models/porcelain.rb', line 4641 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |