Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
4623
4624
# File 'lib/models/porcelain.rb', line 4592

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



4562
4563
4564
# File 'lib/models/porcelain.rb', line 4562

def access_key
  @access_key
end

#bind_interfaceObject

Bind interface



4564
4565
4566
# File 'lib/models/porcelain.rb', line 4564

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4566
4567
4568
# File 'lib/models/porcelain.rb', line 4566

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



4568
4569
4570
# File 'lib/models/porcelain.rb', line 4568

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4570
4571
4572
# File 'lib/models/porcelain.rb', line 4570

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4572
4573
4574
# File 'lib/models/porcelain.rb', line 4572

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4574
4575
4576
# File 'lib/models/porcelain.rb', line 4574

def name
  @name
end

#portObject

Returns the value of attribute port.



4576
4577
4578
# File 'lib/models/porcelain.rb', line 4576

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4578
4579
4580
# File 'lib/models/porcelain.rb', line 4578

def port_override
  @port_override
end

#regionObject

Returns the value of attribute region.



4580
4581
4582
# File 'lib/models/porcelain.rb', line 4580

def region
  @region
end

#role_arnObject

Returns the value of attribute role_arn.



4582
4583
4584
# File 'lib/models/porcelain.rb', line 4582

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



4584
4585
4586
# File 'lib/models/porcelain.rb', line 4584

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



4586
4587
4588
# File 'lib/models/porcelain.rb', line 4586

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4588
4589
4590
# File 'lib/models/porcelain.rb', line 4588

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4590
4591
4592
# File 'lib/models/porcelain.rb', line 4590

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4626
4627
4628
4629
4630
4631
4632
# File 'lib/models/porcelain.rb', line 4626

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end