Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



4512
4513
4514
4515
4516
4517
4518
4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
# File 'lib/models/porcelain.rb', line 4512

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



4482
4483
4484
# File 'lib/models/porcelain.rb', line 4482

def access_key
  @access_key
end

#bind_interfaceObject

Bind interface



4484
4485
4486
# File 'lib/models/porcelain.rb', line 4484

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4486
4487
4488
# File 'lib/models/porcelain.rb', line 4486

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



4488
4489
4490
# File 'lib/models/porcelain.rb', line 4488

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4490
4491
4492
# File 'lib/models/porcelain.rb', line 4490

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



4492
4493
4494
# File 'lib/models/porcelain.rb', line 4492

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4494
4495
4496
# File 'lib/models/porcelain.rb', line 4494

def name
  @name
end

#portObject

Returns the value of attribute port.



4496
4497
4498
# File 'lib/models/porcelain.rb', line 4496

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4498
4499
4500
# File 'lib/models/porcelain.rb', line 4498

def port_override
  @port_override
end

#regionObject

Returns the value of attribute region.



4500
4501
4502
# File 'lib/models/porcelain.rb', line 4500

def region
  @region
end

#role_arnObject

Returns the value of attribute role_arn.



4502
4503
4504
# File 'lib/models/porcelain.rb', line 4502

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



4504
4505
4506
# File 'lib/models/porcelain.rb', line 4504

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



4506
4507
4508
# File 'lib/models/porcelain.rb', line 4506

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4508
4509
4510
# File 'lib/models/porcelain.rb', line 4508

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4510
4511
4512
# File 'lib/models/porcelain.rb', line 4510

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4546
4547
4548
4549
4550
4551
4552
# File 'lib/models/porcelain.rb', line 4546

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end