Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
# File 'lib/models/porcelain.rb', line 5053

def initialize(
  access_key: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  tags: nil
)
  if access_key != nil
    @access_key = access_key
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if endpoint != nil
    @endpoint = endpoint
  end
  if healthy != nil
    @healthy = healthy
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if port != nil
    @port = port
  end
  if port_override != nil
    @port_override = port_override
  end
  if region != nil
    @region = region
  end
  if role_arn != nil
    @role_arn = role_arn
  end
  if role_external_id != nil
    @role_external_id = role_external_id
  end
  if secret_access_key != nil
    @secret_access_key = secret_access_key
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
end

Instance Attribute Details

#access_keyObject

Returns the value of attribute access_key.



5025
5026
5027
# File 'lib/models/porcelain.rb', line 5025

def access_key
  @access_key
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5027
5028
5029
# File 'lib/models/porcelain.rb', line 5027

def egress_filter
  @egress_filter
end

#endpointObject

Returns the value of attribute endpoint.



5029
5030
5031
# File 'lib/models/porcelain.rb', line 5029

def endpoint
  @endpoint
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5031
5032
5033
# File 'lib/models/porcelain.rb', line 5031

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



5033
5034
5035
# File 'lib/models/porcelain.rb', line 5033

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5035
5036
5037
# File 'lib/models/porcelain.rb', line 5035

def name
  @name
end

#portObject

Returns the value of attribute port.



5037
5038
5039
# File 'lib/models/porcelain.rb', line 5037

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5039
5040
5041
# File 'lib/models/porcelain.rb', line 5039

def port_override
  @port_override
end

#regionObject

Returns the value of attribute region.



5041
5042
5043
# File 'lib/models/porcelain.rb', line 5041

def region
  @region
end

#role_arnObject

Returns the value of attribute role_arn.



5043
5044
5045
# File 'lib/models/porcelain.rb', line 5043

def role_arn
  @role_arn
end

#role_external_idObject

Returns the value of attribute role_external_id.



5045
5046
5047
# File 'lib/models/porcelain.rb', line 5045

def role_external_id
  @role_external_id
end

#secret_access_keyObject

Returns the value of attribute secret_access_key.



5047
5048
5049
# File 'lib/models/porcelain.rb', line 5047

def secret_access_key
  @secret_access_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5049
5050
5051
# File 'lib/models/porcelain.rb', line 5049

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5051
5052
5053
# File 'lib/models/porcelain.rb', line 5051

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5113
5114
5115
5116
5117
5118
5119
# File 'lib/models/porcelain.rb', line 5113

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end