Class: SDM::NeptuneIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_key: nil, bind_interface: nil, egress_filter: nil, endpoint: nil, healthy: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_arn: nil, role_external_id: nil, secret_access_key: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ NeptuneIAM

Returns a new instance of NeptuneIAM.



12642
12643
12644
12645
12646
12647
12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
12659
12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
12677
12678
# File 'lib/models/porcelain.rb', line 12642

def initialize(
  access_key: nil,
  bind_interface: nil,
  egress_filter: nil,
  endpoint: nil,
  healthy: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_arn: nil,
  role_external_id: nil,
  secret_access_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @access_key = access_key == nil ? "" : access_key
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @endpoint = endpoint == nil ? "" : endpoint
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_arn = role_arn == nil ? "" : role_arn
  @role_external_id = role_external_id == nil ? "" : role_external_id
  @secret_access_key = secret_access_key == nil ? "" : secret_access_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_key ⇒ Object

The Access Key ID to use to authenticate.



12608
12609
12610
# File 'lib/models/porcelain.rb', line 12608

def access_key
  @access_key
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12610
12611
12612
# File 'lib/models/porcelain.rb', line 12610

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12612
12613
12614
# File 'lib/models/porcelain.rb', line 12612

def egress_filter
  @egress_filter
end

#endpoint ⇒ Object

The neptune endpoint to connect to as in endpoint.region.neptune.amazonaws.com



12614
12615
12616
# File 'lib/models/porcelain.rb', line 12614

def endpoint
  @endpoint
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12616
12617
12618
# File 'lib/models/porcelain.rb', line 12616

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



12618
12619
12620
# File 'lib/models/porcelain.rb', line 12618

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12620
12621
12622
# File 'lib/models/porcelain.rb', line 12620

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



12622
12623
12624
# File 'lib/models/porcelain.rb', line 12622

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12624
12625
12626
# File 'lib/models/porcelain.rb', line 12624

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12626
12627
12628
# File 'lib/models/porcelain.rb', line 12626

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to connect to.



12628
12629
12630
# File 'lib/models/porcelain.rb', line 12628

def region
  @region
end

#role_arn ⇒ Object

The role to assume after logging in.



12630
12631
12632
# File 'lib/models/porcelain.rb', line 12630

def role_arn
  @role_arn
end

#role_external_id ⇒ Object

The external ID to associate with assume role requests. Does nothing if a role ARN is not provided.



12632
12633
12634
# File 'lib/models/porcelain.rb', line 12632

def role_external_id
  @role_external_id
end

#secret_access_key ⇒ Object

The Secret Access Key to use to authenticate.



12634
12635
12636
# File 'lib/models/porcelain.rb', line 12634

def secret_access_key
  @secret_access_key
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12636
12637
12638
# File 'lib/models/porcelain.rb', line 12636

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12638
12639
12640
# File 'lib/models/porcelain.rb', line 12638

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12640
12641
12642
# File 'lib/models/porcelain.rb', line 12640

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12680
12681
12682
12683
12684
12685
12686
# File 'lib/models/porcelain.rb', line 12680

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end