Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



12641
12642
12643
12644
12645
12646
12647
12648
12649
12650
12651
# File 'lib/models/porcelain.rb', line 12641

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



12632
12633
12634
# File 'lib/models/porcelain.rb', line 12632

def meta
  @meta
end

#nodeObject

The created Node.



12634
12635
12636
# File 'lib/models/porcelain.rb', line 12634

def node
  @node
end

#rate_limitObject

Rate limit information.



12636
12637
12638
# File 'lib/models/porcelain.rb', line 12636

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



12639
12640
12641
# File 'lib/models/porcelain.rb', line 12639

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12653
12654
12655
12656
12657
12658
12659
# File 'lib/models/porcelain.rb', line 12653

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end