Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
12417 12418 12419 12420 12421 12422 12423 12424 12425 12426 12427 |
# File 'lib/models/porcelain.rb', line 12417 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
12408 12409 12410 |
# File 'lib/models/porcelain.rb', line 12408 def @meta end |
#node ⇒ Object
The created Node.
12410 12411 12412 |
# File 'lib/models/porcelain.rb', line 12410 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
12412 12413 12414 |
# File 'lib/models/porcelain.rb', line 12412 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
12415 12416 12417 |
# File 'lib/models/porcelain.rb', line 12415 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12429 12430 12431 12432 12433 12434 12435 |
# File 'lib/models/porcelain.rb', line 12429 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |