Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
12397 12398 12399 12400 12401 12402 12403 12404 12405 12406 12407 |
# File 'lib/models/porcelain.rb', line 12397 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
12388 12389 12390 |
# File 'lib/models/porcelain.rb', line 12388 def @meta end |
#node ⇒ Object
The created Node.
12390 12391 12392 |
# File 'lib/models/porcelain.rb', line 12390 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
12392 12393 12394 |
# File 'lib/models/porcelain.rb', line 12392 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
12395 12396 12397 |
# File 'lib/models/porcelain.rb', line 12395 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12409 12410 12411 12412 12413 12414 12415 |
# File 'lib/models/porcelain.rb', line 12409 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |