Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 |
# File 'lib/models/porcelain.rb', line 12023 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
12014 12015 12016 |
# File 'lib/models/porcelain.rb', line 12014 def @meta end |
#node ⇒ Object
The created Node.
12016 12017 12018 |
# File 'lib/models/porcelain.rb', line 12016 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
12018 12019 12020 |
# File 'lib/models/porcelain.rb', line 12018 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
12021 12022 12023 |
# File 'lib/models/porcelain.rb', line 12021 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12035 12036 12037 12038 12039 12040 12041 |
# File 'lib/models/porcelain.rb', line 12035 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |