Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
11725 11726 11727 11728 11729 11730 11731 11732 11733 11734 11735 |
# File 'lib/models/porcelain.rb', line 11725 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
11716 11717 11718 |
# File 'lib/models/porcelain.rb', line 11716 def @meta end |
#node ⇒ Object
The created Node.
11718 11719 11720 |
# File 'lib/models/porcelain.rb', line 11718 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
11720 11721 11722 |
# File 'lib/models/porcelain.rb', line 11720 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
11723 11724 11725 |
# File 'lib/models/porcelain.rb', line 11723 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11737 11738 11739 11740 11741 11742 11743 |
# File 'lib/models/porcelain.rb', line 11737 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |