Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



11661
11662
11663
11664
11665
11666
11667
11668
11669
11670
11671
# File 'lib/models/porcelain.rb', line 11661

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



11652
11653
11654
# File 'lib/models/porcelain.rb', line 11652

def meta
  @meta
end

#nodeObject

The created Node.



11654
11655
11656
# File 'lib/models/porcelain.rb', line 11654

def node
  @node
end

#rate_limitObject

Rate limit information.



11656
11657
11658
# File 'lib/models/porcelain.rb', line 11656

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



11659
11660
11661
# File 'lib/models/porcelain.rb', line 11659

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11673
11674
11675
11676
11677
11678
11679
# File 'lib/models/porcelain.rb', line 11673

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end