Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 |
# File 'lib/models/porcelain.rb', line 10954 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
10945 10946 10947 |
# File 'lib/models/porcelain.rb', line 10945 def @meta end |
#node ⇒ Object
The created Node.
10947 10948 10949 |
# File 'lib/models/porcelain.rb', line 10947 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
10949 10950 10951 |
# File 'lib/models/porcelain.rb', line 10949 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
10952 10953 10954 |
# File 'lib/models/porcelain.rb', line 10952 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10966 10967 10968 10969 10970 10971 10972 |
# File 'lib/models/porcelain.rb', line 10966 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |