Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
9778 9779 9780 9781 9782 9783 9784 9785 9786 9787 9788 |
# File 'lib/models/porcelain.rb', line 9778 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
9769 9770 9771 |
# File 'lib/models/porcelain.rb', line 9769 def @meta end |
#node ⇒ Object
The created Node.
9771 9772 9773 |
# File 'lib/models/porcelain.rb', line 9771 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
9773 9774 9775 |
# File 'lib/models/porcelain.rb', line 9773 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
9776 9777 9778 |
# File 'lib/models/porcelain.rb', line 9776 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9790 9791 9792 9793 9794 9795 9796 |
# File 'lib/models/porcelain.rb', line 9790 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |