Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
9606 9607 9608 9609 9610 9611 9612 9613 9614 9615 9616 |
# File 'lib/models/porcelain.rb', line 9606 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
9597 9598 9599 |
# File 'lib/models/porcelain.rb', line 9597 def @meta end |
#node ⇒ Object
The created Node.
9599 9600 9601 |
# File 'lib/models/porcelain.rb', line 9599 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
9601 9602 9603 |
# File 'lib/models/porcelain.rb', line 9601 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
9604 9605 9606 |
# File 'lib/models/porcelain.rb', line 9604 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9618 9619 9620 9621 9622 9623 9624 |
# File 'lib/models/porcelain.rb', line 9618 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |