Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 |
# File 'lib/models/porcelain.rb', line 9459 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
9450 9451 9452 |
# File 'lib/models/porcelain.rb', line 9450 def @meta end |
#node ⇒ Object
The created Node.
9452 9453 9454 |
# File 'lib/models/porcelain.rb', line 9452 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
9454 9455 9456 |
# File 'lib/models/porcelain.rb', line 9454 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
9457 9458 9459 |
# File 'lib/models/porcelain.rb', line 9457 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/models/porcelain.rb', line 9471 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |