Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
# File 'lib/models/porcelain.rb', line 8608

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



8599
8600
8601
# File 'lib/models/porcelain.rb', line 8599

def meta
  @meta
end

#nodeObject

The created Node.



8601
8602
8603
# File 'lib/models/porcelain.rb', line 8601

def node
  @node
end

#rate_limitObject

Rate limit information.



8603
8604
8605
# File 'lib/models/porcelain.rb', line 8603

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



8606
8607
8608
# File 'lib/models/porcelain.rb', line 8606

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8620
8621
8622
8623
8624
8625
8626
# File 'lib/models/porcelain.rb', line 8620

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end