Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
# File 'lib/models/porcelain.rb', line 8533

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



8524
8525
8526
# File 'lib/models/porcelain.rb', line 8524

def meta
  @meta
end

#nodeObject

The created Node.



8526
8527
8528
# File 'lib/models/porcelain.rb', line 8526

def node
  @node
end

#rate_limitObject

Rate limit information.



8528
8529
8530
# File 'lib/models/porcelain.rb', line 8528

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



8531
8532
8533
# File 'lib/models/porcelain.rb', line 8531

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8545
8546
8547
8548
8549
8550
8551
# File 'lib/models/porcelain.rb', line 8545

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end