Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
# File 'lib/models/porcelain.rb', line 8454

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



8445
8446
8447
# File 'lib/models/porcelain.rb', line 8445

def meta
  @meta
end

#nodeObject

The created Node.



8447
8448
8449
# File 'lib/models/porcelain.rb', line 8447

def node
  @node
end

#rate_limitObject

Rate limit information.



8449
8450
8451
# File 'lib/models/porcelain.rb', line 8449

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



8452
8453
8454
# File 'lib/models/porcelain.rb', line 8452

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8466
8467
8468
8469
8470
8471
8472
# File 'lib/models/porcelain.rb', line 8466

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end