Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
8383 8384 8385 8386 8387 8388 8389 8390 8391 8392 8393 |
# File 'lib/models/porcelain.rb', line 8383 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
8374 8375 8376 |
# File 'lib/models/porcelain.rb', line 8374 def @meta end |
#node ⇒ Object
The created Node.
8376 8377 8378 |
# File 'lib/models/porcelain.rb', line 8376 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
8378 8379 8380 |
# File 'lib/models/porcelain.rb', line 8378 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
8381 8382 8383 |
# File 'lib/models/porcelain.rb', line 8381 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8395 8396 8397 8398 8399 8400 8401 |
# File 'lib/models/porcelain.rb', line 8395 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |