Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
8394
# File 'lib/models/porcelain.rb', line 8384

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



8375
8376
8377
# File 'lib/models/porcelain.rb', line 8375

def meta
  @meta
end

#nodeObject

The created Node.



8377
8378
8379
# File 'lib/models/porcelain.rb', line 8377

def node
  @node
end

#rate_limitObject

Rate limit information.



8379
8380
8381
# File 'lib/models/porcelain.rb', line 8379

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



8382
8383
8384
# File 'lib/models/porcelain.rb', line 8382

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8396
8397
8398
8399
8400
8401
8402
# File 'lib/models/porcelain.rb', line 8396

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end