Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
# File 'lib/models/porcelain.rb', line 8022

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



8013
8014
8015
# File 'lib/models/porcelain.rb', line 8013

def meta
  @meta
end

#nodeObject

The created Node.



8015
8016
8017
# File 'lib/models/porcelain.rb', line 8015

def node
  @node
end

#rate_limitObject

Rate limit information.



8017
8018
8019
# File 'lib/models/porcelain.rb', line 8017

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



8020
8021
8022
# File 'lib/models/porcelain.rb', line 8020

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8034
8035
8036
8037
8038
8039
8040
# File 'lib/models/porcelain.rb', line 8034

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end