Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



7773
7774
7775
7776
7777
7778
7779
7780
7781
7782
7783
# File 'lib/models/porcelain.rb', line 7773

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



7764
7765
7766
# File 'lib/models/porcelain.rb', line 7764

def meta
  @meta
end

#nodeObject

The created Node.



7766
7767
7768
# File 'lib/models/porcelain.rb', line 7766

def node
  @node
end

#rate_limitObject

Rate limit information.



7768
7769
7770
# File 'lib/models/porcelain.rb', line 7768

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



7771
7772
7773
# File 'lib/models/porcelain.rb', line 7771

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7785
7786
7787
7788
7789
7790
7791
# File 'lib/models/porcelain.rb', line 7785

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end