Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 |
# File 'lib/models/porcelain.rb', line 7381 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
7372 7373 7374 |
# File 'lib/models/porcelain.rb', line 7372 def @meta end |
#node ⇒ Object
The created Node.
7374 7375 7376 |
# File 'lib/models/porcelain.rb', line 7374 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
7376 7377 7378 |
# File 'lib/models/porcelain.rb', line 7376 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
7379 7380 7381 |
# File 'lib/models/porcelain.rb', line 7379 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7393 7394 7395 7396 7397 7398 7399 |
# File 'lib/models/porcelain.rb', line 7393 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |