Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
# File 'lib/models/porcelain.rb', line 7381

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



7372
7373
7374
# File 'lib/models/porcelain.rb', line 7372

def meta
  @meta
end

#nodeObject

The created Node.



7374
7375
7376
# File 'lib/models/porcelain.rb', line 7374

def node
  @node
end

#rate_limitObject

Rate limit information.



7376
7377
7378
# File 'lib/models/porcelain.rb', line 7376

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



7379
7380
7381
# File 'lib/models/porcelain.rb', line 7379

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7393
7394
7395
7396
7397
7398
7399
# File 'lib/models/porcelain.rb', line 7393

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end