Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 |
# File 'lib/models/porcelain.rb', line 5659 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
5650 5651 5652 |
# File 'lib/models/porcelain.rb', line 5650 def @meta end |
#node ⇒ Object
The created Node.
5652 5653 5654 |
# File 'lib/models/porcelain.rb', line 5652 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
5654 5655 5656 |
# File 'lib/models/porcelain.rb', line 5654 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
5657 5658 5659 |
# File 'lib/models/porcelain.rb', line 5657 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5671 5672 5673 5674 5675 5676 5677 |
# File 'lib/models/porcelain.rb', line 5671 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |