Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 |
# File 'lib/models/porcelain.rb', line 5111 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
5102 5103 5104 |
# File 'lib/models/porcelain.rb', line 5102 def @meta end |
#node ⇒ Object
The created Node.
5104 5105 5106 |
# File 'lib/models/porcelain.rb', line 5104 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
5106 5107 5108 |
# File 'lib/models/porcelain.rb', line 5106 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
5109 5110 5111 |
# File 'lib/models/porcelain.rb', line 5109 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5123 5124 5125 5126 5127 5128 5129 |
# File 'lib/models/porcelain.rb', line 5123 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |