Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
4676
# File 'lib/models/porcelain.rb', line 4666

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



4657
4658
4659
# File 'lib/models/porcelain.rb', line 4657

def meta
  @meta
end

#nodeObject

The created Node.



4659
4660
4661
# File 'lib/models/porcelain.rb', line 4659

def node
  @node
end

#rate_limitObject

Rate limit information.



4661
4662
4663
# File 'lib/models/porcelain.rb', line 4661

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



4664
4665
4666
# File 'lib/models/porcelain.rb', line 4664

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4678
4679
4680
4681
4682
4683
4684
# File 'lib/models/porcelain.rb', line 4678

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end