Class: SDM::NodeCreateResponse
- Inherits:
-
Object
- Object
- SDM::NodeCreateResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeCreateResponse reports how the Nodes were created in the system.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Reserved for future use.
-
#node ⇒ Object
The created Node.
-
#rate_limit ⇒ Object
Rate limit information.
-
#token ⇒ Object
The auth token generated for the Node.
Instance Method Summary collapse
-
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
constructor
A new instance of NodeCreateResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse
Returns a new instance of NodeCreateResponse.
4662 4663 4664 4665 4666 4667 4668 4669 4670 4671 4672 |
# File 'lib/models/porcelain.rb', line 4662 def initialize( meta: nil, node: nil, rate_limit: nil, token: nil ) @meta = == nil ? nil : @node = node == nil ? nil : node @rate_limit = rate_limit == nil ? nil : rate_limit @token = token == nil ? "" : token end |
Instance Attribute Details
#meta ⇒ Object
Reserved for future use.
4653 4654 4655 |
# File 'lib/models/porcelain.rb', line 4653 def @meta end |
#node ⇒ Object
The created Node.
4655 4656 4657 |
# File 'lib/models/porcelain.rb', line 4655 def node @node end |
#rate_limit ⇒ Object
Rate limit information.
4657 4658 4659 |
# File 'lib/models/porcelain.rb', line 4657 def rate_limit @rate_limit end |
#token ⇒ Object
The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.
4660 4661 4662 |
# File 'lib/models/porcelain.rb', line 4660 def token @token end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4674 4675 4676 4677 4678 4679 4680 |
# File 'lib/models/porcelain.rb', line 4674 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |