Class: SDM::NodeCreateResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeCreateResponse reports how the Nodes were created in the system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(meta: nil, node: nil, rate_limit: nil, token: nil) ⇒ NodeCreateResponse

Returns a new instance of NodeCreateResponse.



9595
9596
9597
9598
9599
9600
9601
9602
9603
9604
9605
# File 'lib/models/porcelain.rb', line 9595

def initialize(
  meta: nil,
  node: nil,
  rate_limit: nil,
  token: nil
)
  @meta = meta == nil ? nil : meta
  @node = node == nil ? nil : node
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @token = token == nil ? "" : token
end

Instance Attribute Details

#metaObject

Reserved for future use.



9586
9587
9588
# File 'lib/models/porcelain.rb', line 9586

def meta
  @meta
end

#nodeObject

The created Node.



9588
9589
9590
# File 'lib/models/porcelain.rb', line 9588

def node
  @node
end

#rate_limitObject

Rate limit information.



9590
9591
9592
# File 'lib/models/porcelain.rb', line 9590

def rate_limit
  @rate_limit
end

#tokenObject

The auth token generated for the Node. The Node will use this token to authenticate with the strongDM API.



9593
9594
9595
# File 'lib/models/porcelain.rb', line 9593

def token
  @token
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9607
9608
9609
9610
9611
9612
9613
# File 'lib/models/porcelain.rb', line 9607

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end