Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



12504
12505
12506
12507
12508
12509
12510
12511
12512
12513
12514
# File 'lib/models/porcelain.rb', line 12504

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



12496
12497
12498
# File 'lib/models/porcelain.rb', line 12496

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



12498
12499
12500
# File 'lib/models/porcelain.rb', line 12498

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



12500
12501
12502
# File 'lib/models/porcelain.rb', line 12500

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



12502
12503
12504
# File 'lib/models/porcelain.rb', line 12502

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12516
12517
12518
12519
12520
12521
12522
# File 'lib/models/porcelain.rb', line 12516

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end