Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



12184
12185
12186
12187
12188
12189
12190
12191
12192
12193
12194
# File 'lib/models/porcelain.rb', line 12184

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



12176
12177
12178
# File 'lib/models/porcelain.rb', line 12176

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



12178
12179
12180
# File 'lib/models/porcelain.rb', line 12178

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



12180
12181
12182
# File 'lib/models/porcelain.rb', line 12180

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



12182
12183
12184
# File 'lib/models/porcelain.rb', line 12182

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12196
12197
12198
12199
12200
12201
12202
# File 'lib/models/porcelain.rb', line 12196

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end