Class: SDM::NodeHistory
- Inherits:
-
Object
- Object
- SDM::NodeHistory
- Defined in:
- lib/models/porcelain.rb
Overview
NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node.
-
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
-
#node ⇒ Object
The complete Node state at this time.
-
#timestamp ⇒ Object
The time at which the Node state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
constructor
A new instance of NodeHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
Returns a new instance of NodeHistory.
9850 9851 9852 9853 9854 9855 9856 9857 9858 9859 9860 |
# File 'lib/models/porcelain.rb', line 9850 def initialize( activity_id: nil, deleted_at: nil, node: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @node = node == nil ? nil : node @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.
9842 9843 9844 |
# File 'lib/models/porcelain.rb', line 9842 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
9844 9845 9846 |
# File 'lib/models/porcelain.rb', line 9844 def deleted_at @deleted_at end |
#node ⇒ Object
The complete Node state at this time.
9846 9847 9848 |
# File 'lib/models/porcelain.rb', line 9846 def node @node end |
#timestamp ⇒ Object
The time at which the Node state was recorded.
9848 9849 9850 |
# File 'lib/models/porcelain.rb', line 9848 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9862 9863 9864 9865 9866 9867 9868 |
# File 'lib/models/porcelain.rb', line 9862 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |