Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



9682
9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
# File 'lib/models/porcelain.rb', line 9682

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



9674
9675
9676
# File 'lib/models/porcelain.rb', line 9674

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



9676
9677
9678
# File 'lib/models/porcelain.rb', line 9676

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



9678
9679
9680
# File 'lib/models/porcelain.rb', line 9678

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



9680
9681
9682
# File 'lib/models/porcelain.rb', line 9680

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9694
9695
9696
9697
9698
9699
9700
# File 'lib/models/porcelain.rb', line 9694

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end