Class: SDM::NodeHistory
- Inherits:
-
Object
- Object
- SDM::NodeHistory
- Defined in:
- lib/models/porcelain.rb
Overview
NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node.
-
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
-
#node ⇒ Object
The complete Node state at this time.
-
#timestamp ⇒ Object
The time at which the Node state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
constructor
A new instance of NodeHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
Returns a new instance of NodeHistory.
9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 |
# File 'lib/models/porcelain.rb', line 9682 def initialize( activity_id: nil, deleted_at: nil, node: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @node = node == nil ? nil : node @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.
9674 9675 9676 |
# File 'lib/models/porcelain.rb', line 9674 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
9676 9677 9678 |
# File 'lib/models/porcelain.rb', line 9676 def deleted_at @deleted_at end |
#node ⇒ Object
The complete Node state at this time.
9678 9679 9680 |
# File 'lib/models/porcelain.rb', line 9678 def node @node end |
#timestamp ⇒ Object
The time at which the Node state was recorded.
9680 9681 9682 |
# File 'lib/models/porcelain.rb', line 9680 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9694 9695 9696 9697 9698 9699 9700 |
# File 'lib/models/porcelain.rb', line 9694 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |