Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



8620
8621
8622
8623
8624
8625
8626
8627
8628
8629
8630
# File 'lib/models/porcelain.rb', line 8620

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



8612
8613
8614
# File 'lib/models/porcelain.rb', line 8612

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



8614
8615
8616
# File 'lib/models/porcelain.rb', line 8614

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



8616
8617
8618
# File 'lib/models/porcelain.rb', line 8616

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



8618
8619
8620
# File 'lib/models/porcelain.rb', line 8618

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8632
8633
8634
8635
8636
8637
8638
# File 'lib/models/porcelain.rb', line 8632

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end