Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
# File 'lib/models/porcelain.rb', line 8541

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



8533
8534
8535
# File 'lib/models/porcelain.rb', line 8533

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



8535
8536
8537
# File 'lib/models/porcelain.rb', line 8535

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



8537
8538
8539
# File 'lib/models/porcelain.rb', line 8537

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



8539
8540
8541
# File 'lib/models/porcelain.rb', line 8539

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8553
8554
8555
8556
8557
8558
8559
# File 'lib/models/porcelain.rb', line 8553

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end