Class: SDM::NodeHistory
- Inherits:
-
Object
- Object
- SDM::NodeHistory
- Defined in:
- lib/models/porcelain.rb
Overview
NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node.
-
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
-
#node ⇒ Object
The complete Node state at this time.
-
#timestamp ⇒ Object
The time at which the Node state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
constructor
A new instance of NodeHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
Returns a new instance of NodeHistory.
8541 8542 8543 8544 8545 8546 8547 8548 8549 8550 8551 |
# File 'lib/models/porcelain.rb', line 8541 def initialize( activity_id: nil, deleted_at: nil, node: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @node = node == nil ? nil : node @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.
8533 8534 8535 |
# File 'lib/models/porcelain.rb', line 8533 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
8535 8536 8537 |
# File 'lib/models/porcelain.rb', line 8535 def deleted_at @deleted_at end |
#node ⇒ Object
The complete Node state at this time.
8537 8538 8539 |
# File 'lib/models/porcelain.rb', line 8537 def node @node end |
#timestamp ⇒ Object
The time at which the Node state was recorded.
8539 8540 8541 |
# File 'lib/models/porcelain.rb', line 8539 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8553 8554 8555 8556 8557 8558 8559 |
# File 'lib/models/porcelain.rb', line 8553 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |