Class: SDM::NodeHistory
- Inherits:
-
Object
- Object
- SDM::NodeHistory
- Defined in:
- lib/models/porcelain.rb
Overview
NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node.
-
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
-
#node ⇒ Object
The complete Node state at this time.
-
#timestamp ⇒ Object
The time at which the Node state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
constructor
A new instance of NodeHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
Returns a new instance of NodeHistory.
8470 8471 8472 8473 8474 8475 8476 8477 8478 8479 8480 |
# File 'lib/models/porcelain.rb', line 8470 def initialize( activity_id: nil, deleted_at: nil, node: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @node = node == nil ? nil : node @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.
8462 8463 8464 |
# File 'lib/models/porcelain.rb', line 8462 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
8464 8465 8466 |
# File 'lib/models/porcelain.rb', line 8464 def deleted_at @deleted_at end |
#node ⇒ Object
The complete Node state at this time.
8466 8467 8468 |
# File 'lib/models/porcelain.rb', line 8466 def node @node end |
#timestamp ⇒ Object
The time at which the Node state was recorded.
8468 8469 8470 |
# File 'lib/models/porcelain.rb', line 8468 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8482 8483 8484 8485 8486 8487 8488 |
# File 'lib/models/porcelain.rb', line 8482 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |