Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



8107
8108
8109
8110
8111
8112
8113
8114
8115
8116
8117
# File 'lib/models/porcelain.rb', line 8107

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



8099
8100
8101
# File 'lib/models/porcelain.rb', line 8099

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



8101
8102
8103
# File 'lib/models/porcelain.rb', line 8101

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



8103
8104
8105
# File 'lib/models/porcelain.rb', line 8103

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



8105
8106
8107
# File 'lib/models/porcelain.rb', line 8105

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8119
8120
8121
8122
8123
8124
8125
# File 'lib/models/porcelain.rb', line 8119

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end