Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
# File 'lib/models/porcelain.rb', line 7860

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



7852
7853
7854
# File 'lib/models/porcelain.rb', line 7852

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



7854
7855
7856
# File 'lib/models/porcelain.rb', line 7854

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



7856
7857
7858
# File 'lib/models/porcelain.rb', line 7856

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



7858
7859
7860
# File 'lib/models/porcelain.rb', line 7858

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7872
7873
7874
7875
7876
7877
7878
# File 'lib/models/porcelain.rb', line 7872

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end