Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
# File 'lib/models/porcelain.rb', line 7789

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



7781
7782
7783
# File 'lib/models/porcelain.rb', line 7781

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



7783
7784
7785
# File 'lib/models/porcelain.rb', line 7783

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



7785
7786
7787
# File 'lib/models/porcelain.rb', line 7785

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



7787
7788
7789
# File 'lib/models/porcelain.rb', line 7787

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7801
7802
7803
7804
7805
7806
7807
# File 'lib/models/porcelain.rb', line 7801

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end