Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



7468
7469
7470
7471
7472
7473
7474
7475
7476
7477
7478
# File 'lib/models/porcelain.rb', line 7468

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



7460
7461
7462
# File 'lib/models/porcelain.rb', line 7460

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



7462
7463
7464
# File 'lib/models/porcelain.rb', line 7462

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



7464
7465
7466
# File 'lib/models/porcelain.rb', line 7464

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



7466
7467
7468
# File 'lib/models/porcelain.rb', line 7466

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7480
7481
7482
7483
7484
7485
7486
# File 'lib/models/porcelain.rb', line 7480

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end