Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
# File 'lib/models/porcelain.rb', line 5913

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



5905
5906
5907
# File 'lib/models/porcelain.rb', line 5905

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



5907
5908
5909
# File 'lib/models/porcelain.rb', line 5907

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



5909
5910
5911
# File 'lib/models/porcelain.rb', line 5909

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



5911
5912
5913
# File 'lib/models/porcelain.rb', line 5911

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5925
5926
5927
5928
5929
5930
5931
# File 'lib/models/porcelain.rb', line 5925

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end