Class: SDM::NodeHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory

Returns a new instance of NodeHistory.



5746
5747
5748
5749
5750
5751
5752
5753
5754
5755
5756
# File 'lib/models/porcelain.rb', line 5746

def initialize(
  activity_id: nil,
  deleted_at: nil,
  node: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @node = node == nil ? nil : node
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.



5738
5739
5740
# File 'lib/models/porcelain.rb', line 5738

def activity_id
  @activity_id
end

#deleted_atObject

If this Node was deleted, the time it was deleted.



5740
5741
5742
# File 'lib/models/porcelain.rb', line 5740

def deleted_at
  @deleted_at
end

#nodeObject

The complete Node state at this time.



5742
5743
5744
# File 'lib/models/porcelain.rb', line 5742

def node
  @node
end

#timestampObject

The time at which the Node state was recorded.



5744
5745
5746
# File 'lib/models/porcelain.rb', line 5744

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5758
5759
5760
5761
5762
5763
5764
# File 'lib/models/porcelain.rb', line 5758

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end