Class: SDM::NodeHistory
- Inherits:
-
Object
- Object
- SDM::NodeHistory
- Defined in:
- lib/models/porcelain.rb
Overview
NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node.
-
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
-
#node ⇒ Object
The complete Node state at this time.
-
#timestamp ⇒ Object
The time at which the Node state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
constructor
A new instance of NodeHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
Returns a new instance of NodeHistory.
5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 |
# File 'lib/models/porcelain.rb', line 5564 def initialize( activity_id: nil, deleted_at: nil, node: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @node = node == nil ? nil : node @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.
5556 5557 5558 |
# File 'lib/models/porcelain.rb', line 5556 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
5558 5559 5560 |
# File 'lib/models/porcelain.rb', line 5558 def deleted_at @deleted_at end |
#node ⇒ Object
The complete Node state at this time.
5560 5561 5562 |
# File 'lib/models/porcelain.rb', line 5560 def node @node end |
#timestamp ⇒ Object
The time at which the Node state was recorded.
5562 5563 5564 |
# File 'lib/models/porcelain.rb', line 5562 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5576 5577 5578 5579 5580 5581 5582 |
# File 'lib/models/porcelain.rb', line 5576 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |