Class: SDM::NodeHistory
- Inherits:
-
Object
- Object
- SDM::NodeHistory
- Defined in:
- lib/models/porcelain.rb
Overview
NodeHistory records the state of a Node at a given point in time, where every change (create, update and delete) to a Node produces an NodeHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node.
-
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
-
#node ⇒ Object
The complete Node state at this time.
-
#timestamp ⇒ Object
The time at which the Node state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
constructor
A new instance of NodeHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, node: nil, timestamp: nil) ⇒ NodeHistory
Returns a new instance of NodeHistory.
12467 12468 12469 12470 12471 12472 12473 12474 12475 12476 12477 |
# File 'lib/models/porcelain.rb', line 12467 def initialize( activity_id: nil, deleted_at: nil, node: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @node = node == nil ? nil : node = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Node. May be empty for some system-initiated updates.
12459 12460 12461 |
# File 'lib/models/porcelain.rb', line 12459 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Node was deleted, the time it was deleted.
12461 12462 12463 |
# File 'lib/models/porcelain.rb', line 12461 def deleted_at @deleted_at end |
#node ⇒ Object
The complete Node state at this time.
12463 12464 12465 |
# File 'lib/models/porcelain.rb', line 12463 def node @node end |
#timestamp ⇒ Object
The time at which the Node state was recorded.
12465 12466 12467 |
# File 'lib/models/porcelain.rb', line 12465 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12479 12480 12481 12482 12483 12484 12485 |
# File 'lib/models/porcelain.rb', line 12479 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |