Class: SDM::NodeMaintenanceWindow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(cron_schedule: nil, require_idleness: nil) ⇒ NodeMaintenanceWindow

Returns a new instance of NodeMaintenanceWindow.



12539
12540
12541
12542
12543
12544
12545
# File 'lib/models/porcelain.rb', line 12539

def initialize(
  cron_schedule: nil,
  require_idleness: nil
)
  @cron_schedule = cron_schedule == nil ? "" : cron_schedule
  @require_idleness = require_idleness == nil ? false : require_idleness
end

Instance Attribute Details

#cron_scheduleObject

Cron job syntax for when this maintenance window is active. On this schedule, associated nodes will restart if requested, provided other checks allow the restart to proceed. Times are represented in UTC. e.g. * 7 * * 0,6 to check for a restart at every minute from 7:00 to 8:00 UTC on Sunday and Saturday. Not all possible inputs are supported: the month and day of month selections must be '*'.



12531
12532
12533
# File 'lib/models/porcelain.rb', line 12531

def cron_schedule
  @cron_schedule
end

#require_idlenessObject

Require Idleness defines whether this window can sever live connections. If true, this window will not allow a node to be restarted unless it is serving no connections. If false, given a restart of the node has been requested (for an update, usually), the node will restart as soon as it enters an allowed day / hour combination. At least one maintenance window, out of all configured windows for a node, must have this as false.



12537
12538
12539
# File 'lib/models/porcelain.rb', line 12537

def require_idleness
  @require_idleness
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12547
12548
12549
12550
12551
12552
12553
# File 'lib/models/porcelain.rb', line 12547

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end