Class: SDM::NodeMaintenanceWindow

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(cron_schedule: nil, require_idleness: nil) ⇒ NodeMaintenanceWindow

Returns a new instance of NodeMaintenanceWindow.



8577
8578
8579
8580
8581
8582
8583
# File 'lib/models/porcelain.rb', line 8577

def initialize(
  cron_schedule: nil,
  require_idleness: nil
)
  @cron_schedule = cron_schedule == nil ? "" : cron_schedule
  @require_idleness = require_idleness == nil ? false : require_idleness
end

Instance Attribute Details

#cron_scheduleObject

Cron job syntax for when this maintenance window is active. On this schedule, associated nodes will restart if requested, provided other checks allow the restart to proceed. Times are represented in UTC. e.g. * 7 * * 0,6 to check for a restart at every minute from 7:00 to 8:00 UTC on Sunday and Saturday. Not all possible inputs are supported: the month and day of month selections must be '*'.



8569
8570
8571
# File 'lib/models/porcelain.rb', line 8569

def cron_schedule
  @cron_schedule
end

#require_idlenessObject

Require Idleness defines whether this window can sever live connections. If true, this window will not allow a node to be restarted unless it is serving no connections. If false, given a restart of the node has been requested (for an update, usually), the node will restart as soon as it enters an allowed day / hour combination. At least one maintenance window, out of all configured windows for a node, must have this as false.



8575
8576
8577
# File 'lib/models/porcelain.rb', line 8575

def require_idleness
  @require_idleness
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8585
8586
8587
8588
8589
8590
8591
# File 'lib/models/porcelain.rb', line 8585

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end