Class: SDM::NodeTCPProbeResponse
- Inherits:
-
Object
- Object
- SDM::NodeTCPProbeResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeTCPProbeResponse reports the result of a TCP probe.
Instance Attribute Summary collapse
-
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
-
#meta ⇒ Object
Reserved for future use.
-
#rate_limit ⇒ Object
Rate limit information.
-
#succeeded ⇒ Object
True if the node was able to connect to the target address.
Instance Method Summary collapse
-
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
constructor
A new instance of NodeTCPProbeResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
Returns a new instance of NodeTCPProbeResponse.
12792 12793 12794 12795 12796 12797 12798 12799 12800 12801 12802 |
# File 'lib/models/porcelain.rb', line 12792 def initialize( error: nil, meta: nil, rate_limit: nil, succeeded: nil ) @error = error == nil ? "" : error @meta = == nil ? nil : @rate_limit = rate_limit == nil ? nil : rate_limit @succeeded = succeeded == nil ? false : succeeded end |
Instance Attribute Details
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
12784 12785 12786 |
# File 'lib/models/porcelain.rb', line 12784 def error @error end |
#meta ⇒ Object
Reserved for future use.
12786 12787 12788 |
# File 'lib/models/porcelain.rb', line 12786 def @meta end |
#rate_limit ⇒ Object
Rate limit information.
12788 12789 12790 |
# File 'lib/models/porcelain.rb', line 12788 def rate_limit @rate_limit end |
#succeeded ⇒ Object
True if the node was able to connect to the target address.
12790 12791 12792 |
# File 'lib/models/porcelain.rb', line 12790 def succeeded @succeeded end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12804 12805 12806 12807 12808 12809 12810 |
# File 'lib/models/porcelain.rb', line 12804 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |