Class: SDM::NodeTCPProbeResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeTCPProbeResponse reports the result of a TCP probe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse

Returns a new instance of NodeTCPProbeResponse.



12744
12745
12746
12747
12748
12749
12750
12751
12752
12753
12754
# File 'lib/models/porcelain.rb', line 12744

def initialize(
  error: nil,
  meta: nil,
  rate_limit: nil,
  succeeded: nil
)
  @error = error == nil ? "" : error
  @meta = meta == nil ? nil : meta
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @succeeded = succeeded == nil ? false : succeeded
end

Instance Attribute Details

#errorObject

The connection error reported by the node, or the empty string if the probe succeeded.



12736
12737
12738
# File 'lib/models/porcelain.rb', line 12736

def error
  @error
end

#metaObject

Reserved for future use.



12738
12739
12740
# File 'lib/models/porcelain.rb', line 12738

def meta
  @meta
end

#rate_limitObject

Rate limit information.



12740
12741
12742
# File 'lib/models/porcelain.rb', line 12740

def rate_limit
  @rate_limit
end

#succeededObject

True if the node was able to connect to the target address.



12742
12743
12744
# File 'lib/models/porcelain.rb', line 12742

def succeeded
  @succeeded
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12756
12757
12758
12759
12760
12761
12762
# File 'lib/models/porcelain.rb', line 12756

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end