Class: SDM::NodeTCPProbeResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeTCPProbeResponse reports the result of a TCP probe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse

Returns a new instance of NodeTCPProbeResponse.



12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
# File 'lib/models/porcelain.rb', line 12664

def initialize(
  error: nil,
  meta: nil,
  rate_limit: nil,
  succeeded: nil
)
  @error = error == nil ? "" : error
  @meta = meta == nil ? nil : meta
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @succeeded = succeeded == nil ? false : succeeded
end

Instance Attribute Details

#errorObject

The connection error reported by the node, or the empty string if the probe succeeded.



12656
12657
12658
# File 'lib/models/porcelain.rb', line 12656

def error
  @error
end

#metaObject

Reserved for future use.



12658
12659
12660
# File 'lib/models/porcelain.rb', line 12658

def meta
  @meta
end

#rate_limitObject

Rate limit information.



12660
12661
12662
# File 'lib/models/porcelain.rb', line 12660

def rate_limit
  @rate_limit
end

#succeededObject

True if the node was able to connect to the target address.



12662
12663
12664
# File 'lib/models/porcelain.rb', line 12662

def succeeded
  @succeeded
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12676
12677
12678
12679
12680
12681
12682
# File 'lib/models/porcelain.rb', line 12676

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end