Class: SDM::NodeTCPProbeResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeTCPProbeResponse reports the result of a TCP probe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse

Returns a new instance of NodeTCPProbeResponse.



12567
12568
12569
12570
12571
12572
12573
12574
12575
12576
12577
# File 'lib/models/porcelain.rb', line 12567

def initialize(
  error: nil,
  meta: nil,
  rate_limit: nil,
  succeeded: nil
)
  @error = error == nil ? "" : error
  @meta = meta == nil ? nil : meta
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @succeeded = succeeded == nil ? false : succeeded
end

Instance Attribute Details

#errorObject

The connection error reported by the node, or the empty string if the probe succeeded.



12559
12560
12561
# File 'lib/models/porcelain.rb', line 12559

def error
  @error
end

#metaObject

Reserved for future use.



12561
12562
12563
# File 'lib/models/porcelain.rb', line 12561

def meta
  @meta
end

#rate_limitObject

Rate limit information.



12563
12564
12565
# File 'lib/models/porcelain.rb', line 12563

def rate_limit
  @rate_limit
end

#succeededObject

True if the node was able to connect to the target address.



12565
12566
12567
# File 'lib/models/porcelain.rb', line 12565

def succeeded
  @succeeded
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12579
12580
12581
12582
12583
12584
12585
# File 'lib/models/porcelain.rb', line 12579

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end