Class: SDM::NodeTCPProbeResponse
- Inherits:
-
Object
- Object
- SDM::NodeTCPProbeResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeTCPProbeResponse reports the result of a TCP probe.
Instance Attribute Summary collapse
-
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
-
#meta ⇒ Object
Reserved for future use.
-
#rate_limit ⇒ Object
Rate limit information.
-
#succeeded ⇒ Object
True if the node was able to connect to the target address.
Instance Method Summary collapse
-
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
constructor
A new instance of NodeTCPProbeResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
Returns a new instance of NodeTCPProbeResponse.
12568 12569 12570 12571 12572 12573 12574 12575 12576 12577 12578 |
# File 'lib/models/porcelain.rb', line 12568 def initialize( error: nil, meta: nil, rate_limit: nil, succeeded: nil ) @error = error == nil ? "" : error @meta = == nil ? nil : @rate_limit = rate_limit == nil ? nil : rate_limit @succeeded = succeeded == nil ? false : succeeded end |
Instance Attribute Details
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
12560 12561 12562 |
# File 'lib/models/porcelain.rb', line 12560 def error @error end |
#meta ⇒ Object
Reserved for future use.
12562 12563 12564 |
# File 'lib/models/porcelain.rb', line 12562 def @meta end |
#rate_limit ⇒ Object
Rate limit information.
12564 12565 12566 |
# File 'lib/models/porcelain.rb', line 12564 def rate_limit @rate_limit end |
#succeeded ⇒ Object
True if the node was able to connect to the target address.
12566 12567 12568 |
# File 'lib/models/porcelain.rb', line 12566 def succeeded @succeeded end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12580 12581 12582 12583 12584 12585 12586 |
# File 'lib/models/porcelain.rb', line 12580 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |