Class: SDM::NodeTCPProbeResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeTCPProbeResponse reports the result of a TCP probe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse

Returns a new instance of NodeTCPProbeResponse.



12174
12175
12176
12177
12178
12179
12180
12181
12182
12183
12184
# File 'lib/models/porcelain.rb', line 12174

def initialize(
  error: nil,
  meta: nil,
  rate_limit: nil,
  succeeded: nil
)
  @error = error == nil ? "" : error
  @meta = meta == nil ? nil : meta
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @succeeded = succeeded == nil ? false : succeeded
end

Instance Attribute Details

#errorObject

The connection error reported by the node, or the empty string if the probe succeeded.



12166
12167
12168
# File 'lib/models/porcelain.rb', line 12166

def error
  @error
end

#metaObject

Reserved for future use.



12168
12169
12170
# File 'lib/models/porcelain.rb', line 12168

def meta
  @meta
end

#rate_limitObject

Rate limit information.



12170
12171
12172
# File 'lib/models/porcelain.rb', line 12170

def rate_limit
  @rate_limit
end

#succeededObject

True if the node was able to connect to the target address.



12172
12173
12174
# File 'lib/models/porcelain.rb', line 12172

def succeeded
  @succeeded
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12186
12187
12188
12189
12190
12191
12192
# File 'lib/models/porcelain.rb', line 12186

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end