Class: SDM::NodeTCPProbeResponse
- Inherits:
-
Object
- Object
- SDM::NodeTCPProbeResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeTCPProbeResponse reports the result of a TCP probe.
Instance Attribute Summary collapse
-
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
-
#meta ⇒ Object
Reserved for future use.
-
#rate_limit ⇒ Object
Rate limit information.
-
#succeeded ⇒ Object
True if the node was able to connect to the target address.
Instance Method Summary collapse
-
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
constructor
A new instance of NodeTCPProbeResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
Returns a new instance of NodeTCPProbeResponse.
12162 12163 12164 12165 12166 12167 12168 12169 12170 12171 12172 |
# File 'lib/models/porcelain.rb', line 12162 def initialize( error: nil, meta: nil, rate_limit: nil, succeeded: nil ) @error = error == nil ? "" : error @meta = == nil ? nil : @rate_limit = rate_limit == nil ? nil : rate_limit @succeeded = succeeded == nil ? false : succeeded end |
Instance Attribute Details
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
12154 12155 12156 |
# File 'lib/models/porcelain.rb', line 12154 def error @error end |
#meta ⇒ Object
Reserved for future use.
12156 12157 12158 |
# File 'lib/models/porcelain.rb', line 12156 def @meta end |
#rate_limit ⇒ Object
Rate limit information.
12158 12159 12160 |
# File 'lib/models/porcelain.rb', line 12158 def rate_limit @rate_limit end |
#succeeded ⇒ Object
True if the node was able to connect to the target address.
12160 12161 12162 |
# File 'lib/models/porcelain.rb', line 12160 def succeeded @succeeded end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12174 12175 12176 12177 12178 12179 12180 |
# File 'lib/models/porcelain.rb', line 12174 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |