Class: SDM::NodeTCPProbeResponse
- Inherits:
-
Object
- Object
- SDM::NodeTCPProbeResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeTCPProbeResponse reports the result of a TCP probe.
Instance Attribute Summary collapse
-
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
-
#meta ⇒ Object
Reserved for future use.
-
#rate_limit ⇒ Object
Rate limit information.
-
#succeeded ⇒ Object
True if the node was able to connect to the target address.
Instance Method Summary collapse
-
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
constructor
A new instance of NodeTCPProbeResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
Returns a new instance of NodeTCPProbeResponse.
11876 11877 11878 11879 11880 11881 11882 11883 11884 11885 11886 |
# File 'lib/models/porcelain.rb', line 11876 def initialize( error: nil, meta: nil, rate_limit: nil, succeeded: nil ) @error = error == nil ? "" : error @meta = == nil ? nil : @rate_limit = rate_limit == nil ? nil : rate_limit @succeeded = succeeded == nil ? false : succeeded end |
Instance Attribute Details
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
11868 11869 11870 |
# File 'lib/models/porcelain.rb', line 11868 def error @error end |
#meta ⇒ Object
Reserved for future use.
11870 11871 11872 |
# File 'lib/models/porcelain.rb', line 11870 def @meta end |
#rate_limit ⇒ Object
Rate limit information.
11872 11873 11874 |
# File 'lib/models/porcelain.rb', line 11872 def rate_limit @rate_limit end |
#succeeded ⇒ Object
True if the node was able to connect to the target address.
11874 11875 11876 |
# File 'lib/models/porcelain.rb', line 11874 def succeeded @succeeded end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11888 11889 11890 11891 11892 11893 11894 |
# File 'lib/models/porcelain.rb', line 11888 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |