Class: SDM::NodeTCPProbeResponse
- Inherits:
-
Object
- Object
- SDM::NodeTCPProbeResponse
- Defined in:
- lib/models/porcelain.rb
Overview
NodeTCPProbeResponse reports the result of a TCP probe.
Instance Attribute Summary collapse
-
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
-
#meta ⇒ Object
Reserved for future use.
-
#rate_limit ⇒ Object
Rate limit information.
-
#succeeded ⇒ Object
True if the node was able to connect to the target address.
Instance Method Summary collapse
-
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
constructor
A new instance of NodeTCPProbeResponse.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse
Returns a new instance of NodeTCPProbeResponse.
12247 12248 12249 12250 12251 12252 12253 12254 12255 12256 12257 |
# File 'lib/models/porcelain.rb', line 12247 def initialize( error: nil, meta: nil, rate_limit: nil, succeeded: nil ) @error = error == nil ? "" : error @meta = == nil ? nil : @rate_limit = rate_limit == nil ? nil : rate_limit @succeeded = succeeded == nil ? false : succeeded end |
Instance Attribute Details
#error ⇒ Object
The connection error reported by the node, or the empty string if the probe succeeded.
12239 12240 12241 |
# File 'lib/models/porcelain.rb', line 12239 def error @error end |
#meta ⇒ Object
Reserved for future use.
12241 12242 12243 |
# File 'lib/models/porcelain.rb', line 12241 def @meta end |
#rate_limit ⇒ Object
Rate limit information.
12243 12244 12245 |
# File 'lib/models/porcelain.rb', line 12243 def rate_limit @rate_limit end |
#succeeded ⇒ Object
True if the node was able to connect to the target address.
12245 12246 12247 |
# File 'lib/models/porcelain.rb', line 12245 def succeeded @succeeded end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12259 12260 12261 12262 12263 12264 12265 |
# File 'lib/models/porcelain.rb', line 12259 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |