Class: SDM::NodeTCPProbeResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

NodeTCPProbeResponse reports the result of a TCP probe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(error: nil, meta: nil, rate_limit: nil, succeeded: nil) ⇒ NodeTCPProbeResponse

Returns a new instance of NodeTCPProbeResponse.



12852
12853
12854
12855
12856
12857
12858
12859
12860
12861
12862
# File 'lib/models/porcelain.rb', line 12852

def initialize(
  error: nil,
  meta: nil,
  rate_limit: nil,
  succeeded: nil
)
  @error = error == nil ? "" : error
  @meta = meta == nil ? nil : meta
  @rate_limit = rate_limit == nil ? nil : rate_limit
  @succeeded = succeeded == nil ? false : succeeded
end

Instance Attribute Details

#error ⇒ Object

The connection error reported by the node, or the empty string if the probe succeeded.



12844
12845
12846
# File 'lib/models/porcelain.rb', line 12844

def error
  @error
end

#meta ⇒ Object

Reserved for future use.



12846
12847
12848
# File 'lib/models/porcelain.rb', line 12846

def meta
  @meta
end

#rate_limit ⇒ Object

Rate limit information.



12848
12849
12850
# File 'lib/models/porcelain.rb', line 12848

def rate_limit
  @rate_limit
end

#succeeded ⇒ Object

True if the node was able to connect to the target address.



12850
12851
12852
# File 'lib/models/porcelain.rb', line 12850

def succeeded
  @succeeded
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12864
12865
12866
12867
12868
12869
12870
# File 'lib/models/porcelain.rb', line 12864

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end