Class: SDM::Nodes
Overview
Nodes make up the StrongDM network, and allow your users to connect securely to your resources. There are three types of nodes:
- Relay: creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
- Gateway: a relay that also listens for connections from StrongDM clients
- Proxy Cluster: a cluster of workers that together mediate access from clients to resources
See: Gateway ProxyCluster Relay
Instance Method Summary collapse
-
#create(node, deadline: nil) ⇒ Object
Create registers a new Node.
-
#delete(id, deadline: nil) ⇒ Object
Delete removes a Node by ID.
-
#get(id, deadline: nil) ⇒ Object
Get reads one Node by ID.
-
#initialize(channel, parent) ⇒ Nodes
constructor
A new instance of Nodes.
-
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of Nodes matching a given set of criteria.
-
#tcp_probe(node_id, host, port, deadline: nil) ⇒ Object
TCPProbe instructs a Node to connect to an address via TCP and report the result.
-
#update(node, deadline: nil) ⇒ Object
Update replaces all the fields of a Node by ID.
Constructor Details
#initialize(channel, parent) ⇒ Nodes
Returns a new instance of Nodes.
4870 4871 4872 4873 4874 4875 4876 4877 |
# File 'lib/svc.rb', line 4870 def initialize(channel, parent) begin @stub = V1::Nodes::Stub.new(nil, nil, channel_override: channel) rescue => exception raise Plumbing::convert_error_to_porcelain(exception) end @parent = parent end |
Instance Method Details
#create(node, deadline: nil) ⇒ Object
Create registers a new Node.
4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 4912 4913 |
# File 'lib/svc.rb', line 4880 def create( node, deadline: nil ) req = V1::NodeCreateRequest.new() req.node = Plumbing::convert_node_to_plumbing(node) # Execute before interceptor hooks req = @parent.interceptor.execute_before("Nodes.Create", self, req) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.create(req, metadata: @parent.("Nodes.Create", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end # Execute after interceptor hooks plumbing_response = @parent.interceptor.execute_after("Nodes.Create", self, req, plumbing_response) resp = NodeCreateResponse.new() resp. = Plumbing::(plumbing_response.) resp.node = Plumbing::convert_node_to_porcelain(plumbing_response.node) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp.token = (plumbing_response.token) resp end |
#delete(id, deadline: nil) ⇒ Object
Delete removes a Node by ID.
4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 |
# File 'lib/svc.rb', line 4990 def delete( id, deadline: nil ) req = V1::NodeDeleteRequest.new() req.id = (id) # Execute before interceptor hooks req = @parent.interceptor.execute_before("Nodes.Delete", self, req) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.delete(req, metadata: @parent.("Nodes.Delete", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end # Execute after interceptor hooks plumbing_response = @parent.interceptor.execute_after("Nodes.Delete", self, req, plumbing_response) resp = NodeDeleteResponse.new() resp. = Plumbing::(plumbing_response.) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp end |
#get(id, deadline: nil) ⇒ Object
Get reads one Node by ID.
4916 4917 4918 4919 4920 4921 4922 4923 4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 4936 4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/svc.rb', line 4916 def get( id, deadline: nil ) req = V1::NodeGetRequest.new() if not @parent.snapshot_time.nil? req. = V1::GetRequestMetadata.new() req..snapshot_at = @parent.snapshot_time end req.id = (id) # Execute before interceptor hooks req = @parent.interceptor.execute_before("Nodes.Get", self, req) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.get(req, metadata: @parent.("Nodes.Get", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end # Execute after interceptor hooks plumbing_response = @parent.interceptor.execute_after("Nodes.Get", self, req, plumbing_response) resp = NodeGetResponse.new() resp. = Plumbing::(plumbing_response.) resp.node = Plumbing::convert_node_to_porcelain(plumbing_response.node) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp end |
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of Nodes matching a given set of criteria.
5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 5060 |
# File 'lib/svc.rb', line 5024 def list( filter, *args, deadline: nil ) req = V1::NodeListRequest.new() req. = V1::ListRequestMetadata.new() if not @parent.page_limit.nil? req..limit = @parent.page_limit end if not @parent.snapshot_time.nil? req..snapshot_at = @parent.snapshot_time end req.filter = Plumbing::quote_filter_args(filter, *args) resp = Enumerator::Generator.new { |g| tries = 0 loop do begin plumbing_response = @stub.list(req, metadata: @parent.("Nodes.List", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end tries = 0 plumbing_response.nodes.each do |plumbing_item| g.yield Plumbing::convert_node_to_porcelain(plumbing_item) end break if plumbing_response..next_cursor == "" req..cursor = plumbing_response..next_cursor end } resp end |
#tcp_probe(node_id, host, port, deadline: nil) ⇒ Object
TCPProbe instructs a Node to connect to an address via TCP and report the result.
5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 5101 |
# File 'lib/svc.rb', line 5064 def tcp_probe( node_id, host, port, deadline: nil ) req = V1::NodeTCPProbeRequest.new() req.node_id = (node_id) req.host = (host) req.port = (port) # Execute before interceptor hooks req = @parent.interceptor.execute_before("Nodes.TCPProbe", self, req) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.tcp_probe(req, metadata: @parent.("Nodes.TCPProbe", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end # Execute after interceptor hooks plumbing_response = @parent.interceptor.execute_after("Nodes.TCPProbe", self, req, plumbing_response) resp = NodeTCPProbeResponse.new() resp.error = (plumbing_response.error) resp. = Plumbing::(plumbing_response.) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp.succeeded = (plumbing_response.succeeded) resp end |
#update(node, deadline: nil) ⇒ Object
Update replaces all the fields of a Node by ID.
4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 |
# File 'lib/svc.rb', line 4955 def update( node, deadline: nil ) req = V1::NodeUpdateRequest.new() req.node = Plumbing::convert_node_to_plumbing(node) # Execute before interceptor hooks req = @parent.interceptor.execute_before("Nodes.Update", self, req) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.update(req, metadata: @parent.("Nodes.Update", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end # Execute after interceptor hooks plumbing_response = @parent.interceptor.execute_after("Nodes.Update", self, req, plumbing_response) resp = NodeUpdateResponse.new() resp. = Plumbing::(plumbing_response.) resp.node = Plumbing::convert_node_to_porcelain(plumbing_response.node) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp end |