Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
12886
12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
12897
12898
12899
12900
12901
12902
# File 'lib/models/porcelain.rb', line 12872

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12844
12845
12846
# File 'lib/models/porcelain.rb', line 12844

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



12846
12847
12848
# File 'lib/models/porcelain.rb', line 12846

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



12848
12849
12850
# File 'lib/models/porcelain.rb', line 12848

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12850
12851
12852
# File 'lib/models/porcelain.rb', line 12850

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



12852
12853
12854
# File 'lib/models/porcelain.rb', line 12852

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12854
12855
12856
# File 'lib/models/porcelain.rb', line 12854

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12856
12857
12858
# File 'lib/models/porcelain.rb', line 12856

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12858
12859
12860
# File 'lib/models/porcelain.rb', line 12858

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



12860
12861
12862
# File 'lib/models/porcelain.rb', line 12860

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



12862
12863
12864
# File 'lib/models/porcelain.rb', line 12862

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12864
12865
12866
# File 'lib/models/porcelain.rb', line 12864

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12866
12867
12868
# File 'lib/models/porcelain.rb', line 12866

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12868
12869
12870
# File 'lib/models/porcelain.rb', line 12868

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12870
12871
12872
# File 'lib/models/porcelain.rb', line 12870

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12904
12905
12906
12907
12908
12909
12910
# File 'lib/models/porcelain.rb', line 12904

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end