Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12824
12825
12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
12854
# File 'lib/models/porcelain.rb', line 12824

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12796
12797
12798
# File 'lib/models/porcelain.rb', line 12796

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



12798
12799
12800
# File 'lib/models/porcelain.rb', line 12798

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



12800
12801
12802
# File 'lib/models/porcelain.rb', line 12800

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12802
12803
12804
# File 'lib/models/porcelain.rb', line 12802

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



12804
12805
12806
# File 'lib/models/porcelain.rb', line 12804

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12806
12807
12808
# File 'lib/models/porcelain.rb', line 12806

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12808
12809
12810
# File 'lib/models/porcelain.rb', line 12808

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12810
12811
12812
# File 'lib/models/porcelain.rb', line 12810

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



12812
12813
12814
# File 'lib/models/porcelain.rb', line 12812

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



12814
12815
12816
# File 'lib/models/porcelain.rb', line 12814

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12816
12817
12818
# File 'lib/models/porcelain.rb', line 12816

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12818
12819
12820
# File 'lib/models/porcelain.rb', line 12818

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12820
12821
12822
# File 'lib/models/porcelain.rb', line 12820

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12822
12823
12824
# File 'lib/models/porcelain.rb', line 12822

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12856
12857
12858
12859
12860
12861
12862
# File 'lib/models/porcelain.rb', line 12856

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end