Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12744
12745
12746
12747
12748
12749
12750
12751
12752
12753
12754
12755
12756
12757
12758
12759
12760
12761
12762
12763
12764
12765
12766
12767
12768
12769
12770
12771
12772
12773
12774
# File 'lib/models/porcelain.rb', line 12744

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12716
12717
12718
# File 'lib/models/porcelain.rb', line 12716

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



12718
12719
12720
# File 'lib/models/porcelain.rb', line 12718

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



12720
12721
12722
# File 'lib/models/porcelain.rb', line 12720

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12722
12723
12724
# File 'lib/models/porcelain.rb', line 12722

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



12724
12725
12726
# File 'lib/models/porcelain.rb', line 12724

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12726
12727
12728
# File 'lib/models/porcelain.rb', line 12726

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12728
12729
12730
# File 'lib/models/porcelain.rb', line 12728

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12730
12731
12732
# File 'lib/models/porcelain.rb', line 12730

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



12732
12733
12734
# File 'lib/models/porcelain.rb', line 12732

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



12734
12735
12736
# File 'lib/models/porcelain.rb', line 12734

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12736
12737
12738
# File 'lib/models/porcelain.rb', line 12736

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12738
12739
12740
# File 'lib/models/porcelain.rb', line 12738

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12740
12741
12742
# File 'lib/models/porcelain.rb', line 12740

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12742
12743
12744
# File 'lib/models/porcelain.rb', line 12742

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12776
12777
12778
12779
12780
12781
12782
# File 'lib/models/porcelain.rb', line 12776

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end