Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12648
12649
12650
12651
12652
12653
12654
12655
12656
12657
12658
12659
12660
12661
12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
12677
12678
# File 'lib/models/porcelain.rb', line 12648

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12620
12621
12622
# File 'lib/models/porcelain.rb', line 12620

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



12622
12623
12624
# File 'lib/models/porcelain.rb', line 12622

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



12624
12625
12626
# File 'lib/models/porcelain.rb', line 12624

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12626
12627
12628
# File 'lib/models/porcelain.rb', line 12626

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



12628
12629
12630
# File 'lib/models/porcelain.rb', line 12628

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12630
12631
12632
# File 'lib/models/porcelain.rb', line 12630

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12632
12633
12634
# File 'lib/models/porcelain.rb', line 12632

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12634
12635
12636
# File 'lib/models/porcelain.rb', line 12634

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



12636
12637
12638
# File 'lib/models/porcelain.rb', line 12636

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



12638
12639
12640
# File 'lib/models/porcelain.rb', line 12638

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12640
12641
12642
# File 'lib/models/porcelain.rb', line 12640

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12642
12643
12644
# File 'lib/models/porcelain.rb', line 12642

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12644
12645
12646
# File 'lib/models/porcelain.rb', line 12644

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12646
12647
12648
# File 'lib/models/porcelain.rb', line 12646

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12680
12681
12682
12683
12684
12685
12686
# File 'lib/models/porcelain.rb', line 12680

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end