Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OktaGroups is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
12355
12356
12357
12358
# File 'lib/models/porcelain.rb', line 12328

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12300
12301
12302
# File 'lib/models/porcelain.rb', line 12300

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



12302
12303
12304
# File 'lib/models/porcelain.rb', line 12302

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



12304
12305
12306
# File 'lib/models/porcelain.rb', line 12304

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12306
12307
12308
# File 'lib/models/porcelain.rb', line 12306

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



12308
12309
12310
# File 'lib/models/porcelain.rb', line 12308

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12310
12311
12312
# File 'lib/models/porcelain.rb', line 12310

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12312
12313
12314
# File 'lib/models/porcelain.rb', line 12312

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12314
12315
12316
# File 'lib/models/porcelain.rb', line 12314

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



12316
12317
12318
# File 'lib/models/porcelain.rb', line 12316

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



12318
12319
12320
# File 'lib/models/porcelain.rb', line 12318

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12320
12321
12322
# File 'lib/models/porcelain.rb', line 12320

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12322
12323
12324
# File 'lib/models/porcelain.rb', line 12322

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12324
12325
12326
# File 'lib/models/porcelain.rb', line 12324

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12326
12327
12328
# File 'lib/models/porcelain.rb', line 12326

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12360
12361
12362
12363
12364
12365
12366
# File 'lib/models/porcelain.rb', line 12360

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end