Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OktaGroups is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
12345
12346
12347
12348
12349
12350
12351
12352
12353
12354
12355
12356
12357
12358
12359
# File 'lib/models/porcelain.rb', line 12329

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12301
12302
12303
# File 'lib/models/porcelain.rb', line 12301

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



12303
12304
12305
# File 'lib/models/porcelain.rb', line 12303

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



12305
12306
12307
# File 'lib/models/porcelain.rb', line 12305

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12307
12308
12309
# File 'lib/models/porcelain.rb', line 12307

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



12309
12310
12311
# File 'lib/models/porcelain.rb', line 12309

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12311
12312
12313
# File 'lib/models/porcelain.rb', line 12311

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12313
12314
12315
# File 'lib/models/porcelain.rb', line 12313

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12315
12316
12317
# File 'lib/models/porcelain.rb', line 12315

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



12317
12318
12319
# File 'lib/models/porcelain.rb', line 12317

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



12319
12320
12321
# File 'lib/models/porcelain.rb', line 12319

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12321
12322
12323
# File 'lib/models/porcelain.rb', line 12321

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12323
12324
12325
# File 'lib/models/porcelain.rb', line 12323

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12325
12326
12327
# File 'lib/models/porcelain.rb', line 12325

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12327
12328
12329
# File 'lib/models/porcelain.rb', line 12327

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12361
12362
12363
12364
12365
12366
12367
# File 'lib/models/porcelain.rb', line 12361

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end