Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OktaGroups is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12243
12244
12245
12246
12247
12248
12249
12250
12251
12252
12253
12254
12255
12256
12257
12258
12259
12260
12261
12262
12263
12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
# File 'lib/models/porcelain.rb', line 12243

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12215
12216
12217
# File 'lib/models/porcelain.rb', line 12215

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



12217
12218
12219
# File 'lib/models/porcelain.rb', line 12217

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



12219
12220
12221
# File 'lib/models/porcelain.rb', line 12219

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12221
12222
12223
# File 'lib/models/porcelain.rb', line 12221

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



12223
12224
12225
# File 'lib/models/porcelain.rb', line 12223

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12225
12226
12227
# File 'lib/models/porcelain.rb', line 12225

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



12227
12228
12229
# File 'lib/models/porcelain.rb', line 12227

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12229
12230
12231
# File 'lib/models/porcelain.rb', line 12229

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



12231
12232
12233
# File 'lib/models/porcelain.rb', line 12231

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



12233
12234
12235
# File 'lib/models/porcelain.rb', line 12233

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12235
12236
12237
# File 'lib/models/porcelain.rb', line 12235

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12237
12238
12239
# File 'lib/models/porcelain.rb', line 12237

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12239
12240
12241
# File 'lib/models/porcelain.rb', line 12239

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12241
12242
12243
# File 'lib/models/porcelain.rb', line 12241

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12275
12276
12277
12278
12279
12280
12281
# File 'lib/models/porcelain.rb', line 12275

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end