Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OktaGroups is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



11957
11958
11959
11960
11961
11962
11963
11964
11965
11966
11967
11968
11969
11970
11971
11972
11973
11974
11975
11976
11977
11978
11979
11980
11981
11982
11983
11984
11985
11986
11987
# File 'lib/models/porcelain.rb', line 11957

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



11929
11930
11931
# File 'lib/models/porcelain.rb', line 11929

def bind_interface
  @bind_interface
end

#discovery_enabledObject

If true, configures discovery of the Okta org to be run from a node.



11931
11932
11933
# File 'lib/models/porcelain.rb', line 11931

def discovery_enabled
  @discovery_enabled
end

#domainObject

Represents the Okta Org Client URL



11933
11934
11935
# File 'lib/models/porcelain.rb', line 11933

def domain
  @domain
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11935
11936
11937
# File 'lib/models/porcelain.rb', line 11935

def egress_filter
  @egress_filter
end

#group_namesObject

comma separated list of group names to filter by. Supports wildcards (*)



11937
11938
11939
# File 'lib/models/porcelain.rb', line 11937

def group_names
  @group_names
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11939
11940
11941
# File 'lib/models/porcelain.rb', line 11939

def healthy
  @healthy
end

#idObject

Unique identifier of the Resource.



11941
11942
11943
# File 'lib/models/porcelain.rb', line 11941

def id
  @id
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



11943
11944
11945
# File 'lib/models/porcelain.rb', line 11943

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



11945
11946
11947
# File 'lib/models/porcelain.rb', line 11945

def name
  @name
end

#privilege_levelsObject

The privilege levels specify which Groups are managed externally



11947
11948
11949
# File 'lib/models/porcelain.rb', line 11947

def privilege_levels
  @privilege_levels
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11949
11950
11951
# File 'lib/models/porcelain.rb', line 11949

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11951
11952
11953
# File 'lib/models/porcelain.rb', line 11951

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



11953
11954
11955
# File 'lib/models/porcelain.rb', line 11953

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11955
11956
11957
# File 'lib/models/porcelain.rb', line 11955

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11989
11990
11991
11992
11993
11994
11995
# File 'lib/models/porcelain.rb', line 11989

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end