Class: SDM::OktaGroups

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, discovery_enabled: nil, domain: nil, egress_filter: nil, group_names: nil, healthy: nil, id: nil, identity_set_id: nil, name: nil, privilege_levels: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ OktaGroups

Returns a new instance of OktaGroups.



12932
12933
12934
12935
12936
12937
12938
12939
12940
12941
12942
12943
12944
12945
12946
12947
12948
12949
12950
12951
12952
12953
12954
12955
12956
12957
12958
12959
12960
12961
12962
# File 'lib/models/porcelain.rb', line 12932

def initialize(
  bind_interface: nil,
  discovery_enabled: nil,
  domain: nil,
  egress_filter: nil,
  group_names: nil,
  healthy: nil,
  id: nil,
  identity_set_id: nil,
  name: nil,
  privilege_levels: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @discovery_enabled = discovery_enabled == nil ? false : discovery_enabled
  @domain = domain == nil ? "" : domain
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @group_names = group_names == nil ? "" : group_names
  @healthy = healthy == nil ? false : healthy
  @id = id == nil ? "" : id
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @privilege_levels = privilege_levels == nil ? "" : privilege_levels
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12904
12905
12906
# File 'lib/models/porcelain.rb', line 12904

def bind_interface
  @bind_interface
end

#discovery_enabled ⇒ Object

If true, configures discovery of the Okta org to be run from a node.



12906
12907
12908
# File 'lib/models/porcelain.rb', line 12906

def discovery_enabled
  @discovery_enabled
end

#domain ⇒ Object

Represents the Okta Org Client URL



12908
12909
12910
# File 'lib/models/porcelain.rb', line 12908

def domain
  @domain
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



12910
12911
12912
# File 'lib/models/porcelain.rb', line 12910

def egress_filter
  @egress_filter
end

#group_names ⇒ Object

comma separated list of group names to filter by. Supports wildcards (*)



12912
12913
12914
# File 'lib/models/porcelain.rb', line 12912

def group_names
  @group_names
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



12914
12915
12916
# File 'lib/models/porcelain.rb', line 12914

def healthy
  @healthy
end

#id ⇒ Object

Unique identifier of the Resource.



12916
12917
12918
# File 'lib/models/porcelain.rb', line 12916

def id
  @id
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



12918
12919
12920
# File 'lib/models/porcelain.rb', line 12918

def identity_set_id
  @identity_set_id
end

#name ⇒ Object

Unique human-readable name of the Resource.



12920
12921
12922
# File 'lib/models/porcelain.rb', line 12920

def name
  @name
end

#privilege_levels ⇒ Object

The privilege levels specify which Groups are managed externally



12922
12923
12924
# File 'lib/models/porcelain.rb', line 12922

def privilege_levels
  @privilege_levels
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



12924
12925
12926
# File 'lib/models/porcelain.rb', line 12924

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



12926
12927
12928
# File 'lib/models/porcelain.rb', line 12926

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12928
12929
12930
# File 'lib/models/porcelain.rb', line 12928

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



12930
12931
12932
# File 'lib/models/porcelain.rb', line 12930

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12964
12965
12966
12967
12968
12969
12970
# File 'lib/models/porcelain.rb', line 12964

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end