Class: SDM::OktaMFAConfig
- Inherits:
-
Object
- Object
- SDM::OktaMFAConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#api_token ⇒ Object
The API token to authenticate with when auth_mode is api_token.
-
#api_token_set ⇒ Object
Indicates if an API token is already stored.
-
#auth_mode ⇒ Object
The Okta auth mode, one of the OktaAuthMode constants.
-
#client_id ⇒ Object
The Okta client ID to authenticate with when auth_mode is client_credentials.
-
#multidevice_push_enabled ⇒ Object
Indicates if multidevice push is enabled.
-
#organization_url ⇒ Object
The Okta organization URL.
-
#private_key_id ⇒ Object
The key ID (kid) assigned by Okta to the registered public key.
-
#private_key_id_set ⇒ Object
Indicates if a key ID is already stored or explicitly supplied.
-
#private_key_pem ⇒ Object
The PEM encoded private key to authenticate with when auth_mode is client_credentials.
-
#private_key_pem_set ⇒ Object
Indicates if a PEM encoded private key is already stored.
-
#user_lookup ⇒ Object
The Okta user lookup strategy, one of the OktaUserLookup constants.
Instance Method Summary collapse
-
#initialize(api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil) ⇒ OktaMFAConfig
constructor
A new instance of OktaMFAConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil) ⇒ OktaMFAConfig
Returns a new instance of OktaMFAConfig.
12939 12940 12941 12942 12943 12944 12945 12946 12947 12948 12949 12950 12951 12952 12953 12954 12955 12956 12957 12958 12959 12960 12961 12962 12963 |
# File 'lib/models/porcelain.rb', line 12939 def initialize( api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil ) @api_token = api_token == nil ? "" : api_token @api_token_set = api_token_set == nil ? false : api_token_set @auth_mode = auth_mode == nil ? "" : auth_mode @client_id = client_id == nil ? "" : client_id @multidevice_push_enabled = multidevice_push_enabled == nil ? false : multidevice_push_enabled @organization_url = organization_url == nil ? "" : organization_url @private_key_id = private_key_id == nil ? "" : private_key_id @private_key_id_set = private_key_id_set == nil ? false : private_key_id_set @private_key_pem = private_key_pem == nil ? "" : private_key_pem @private_key_pem_set = private_key_pem_set == nil ? false : private_key_pem_set @user_lookup = user_lookup == nil ? "" : user_lookup end |
Instance Attribute Details
#api_token ⇒ Object
The API token to authenticate with when auth_mode is api_token.
12915 12916 12917 |
# File 'lib/models/porcelain.rb', line 12915 def api_token @api_token end |
#api_token_set ⇒ Object
Indicates if an API token is already stored.
12917 12918 12919 |
# File 'lib/models/porcelain.rb', line 12917 def api_token_set @api_token_set end |
#auth_mode ⇒ Object
The Okta auth mode, one of the OktaAuthMode constants.
12919 12920 12921 |
# File 'lib/models/porcelain.rb', line 12919 def auth_mode @auth_mode end |
#client_id ⇒ Object
The Okta client ID to authenticate with when auth_mode is client_credentials.
12921 12922 12923 |
# File 'lib/models/porcelain.rb', line 12921 def client_id @client_id end |
#multidevice_push_enabled ⇒ Object
Indicates if multidevice push is enabled.
12923 12924 12925 |
# File 'lib/models/porcelain.rb', line 12923 def multidevice_push_enabled @multidevice_push_enabled end |
#organization_url ⇒ Object
The Okta organization URL.
12925 12926 12927 |
# File 'lib/models/porcelain.rb', line 12925 def organization_url @organization_url end |
#private_key_id ⇒ Object
The key ID (kid) assigned by Okta to the registered public key.
12927 12928 12929 |
# File 'lib/models/porcelain.rb', line 12927 def private_key_id @private_key_id end |
#private_key_id_set ⇒ Object
Indicates if a key ID is already stored or explicitly supplied. This allows callers to preserve the existing value when omitted or clear it by sending an empty string with private_key_id_set=true.
12931 12932 12933 |
# File 'lib/models/porcelain.rb', line 12931 def private_key_id_set @private_key_id_set end |
#private_key_pem ⇒ Object
The PEM encoded private key to authenticate with when auth_mode is client_credentials.
12933 12934 12935 |
# File 'lib/models/porcelain.rb', line 12933 def private_key_pem @private_key_pem end |
#private_key_pem_set ⇒ Object
Indicates if a PEM encoded private key is already stored.
12935 12936 12937 |
# File 'lib/models/porcelain.rb', line 12935 def private_key_pem_set @private_key_pem_set end |
#user_lookup ⇒ Object
The Okta user lookup strategy, one of the OktaUserLookup constants.
12937 12938 12939 |
# File 'lib/models/porcelain.rb', line 12937 def user_lookup @user_lookup end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12965 12966 12967 12968 12969 12970 12971 |
# File 'lib/models/porcelain.rb', line 12965 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |