Class: SDM::OktaMFAConfig
- Inherits:
-
Object
- Object
- SDM::OktaMFAConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#api_token ⇒ Object
The API token to authenticate with when auth_mode is api_token.
-
#api_token_set ⇒ Object
Indicates if an API token is already stored.
-
#auth_mode ⇒ Object
The Okta auth mode, one of the OktaAuthMode constants.
-
#client_id ⇒ Object
The Okta client ID to authenticate with when auth_mode is client_credentials.
-
#multidevice_push_enabled ⇒ Object
Indicates if multidevice push is enabled.
-
#organization_url ⇒ Object
The Okta organization URL.
-
#private_key_id ⇒ Object
The key ID (kid) assigned by Okta to the registered public key.
-
#private_key_id_set ⇒ Object
Indicates if a key ID is already stored or explicitly supplied.
-
#private_key_pem ⇒ Object
The PEM encoded private key to authenticate with when auth_mode is client_credentials.
-
#private_key_pem_set ⇒ Object
Indicates if a PEM encoded private key is already stored.
-
#user_lookup ⇒ Object
The Okta user lookup strategy, one of the OktaUserLookup constants.
Instance Method Summary collapse
-
#initialize(api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil) ⇒ OktaMFAConfig
constructor
A new instance of OktaMFAConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil) ⇒ OktaMFAConfig
Returns a new instance of OktaMFAConfig.
12891 12892 12893 12894 12895 12896 12897 12898 12899 12900 12901 12902 12903 12904 12905 12906 12907 12908 12909 12910 12911 12912 12913 12914 12915 |
# File 'lib/models/porcelain.rb', line 12891 def initialize( api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil ) @api_token = api_token == nil ? "" : api_token @api_token_set = api_token_set == nil ? false : api_token_set @auth_mode = auth_mode == nil ? "" : auth_mode @client_id = client_id == nil ? "" : client_id @multidevice_push_enabled = multidevice_push_enabled == nil ? false : multidevice_push_enabled @organization_url = organization_url == nil ? "" : organization_url @private_key_id = private_key_id == nil ? "" : private_key_id @private_key_id_set = private_key_id_set == nil ? false : private_key_id_set @private_key_pem = private_key_pem == nil ? "" : private_key_pem @private_key_pem_set = private_key_pem_set == nil ? false : private_key_pem_set @user_lookup = user_lookup == nil ? "" : user_lookup end |
Instance Attribute Details
#api_token ⇒ Object
The API token to authenticate with when auth_mode is api_token.
12867 12868 12869 |
# File 'lib/models/porcelain.rb', line 12867 def api_token @api_token end |
#api_token_set ⇒ Object
Indicates if an API token is already stored.
12869 12870 12871 |
# File 'lib/models/porcelain.rb', line 12869 def api_token_set @api_token_set end |
#auth_mode ⇒ Object
The Okta auth mode, one of the OktaAuthMode constants.
12871 12872 12873 |
# File 'lib/models/porcelain.rb', line 12871 def auth_mode @auth_mode end |
#client_id ⇒ Object
The Okta client ID to authenticate with when auth_mode is client_credentials.
12873 12874 12875 |
# File 'lib/models/porcelain.rb', line 12873 def client_id @client_id end |
#multidevice_push_enabled ⇒ Object
Indicates if multidevice push is enabled.
12875 12876 12877 |
# File 'lib/models/porcelain.rb', line 12875 def multidevice_push_enabled @multidevice_push_enabled end |
#organization_url ⇒ Object
The Okta organization URL.
12877 12878 12879 |
# File 'lib/models/porcelain.rb', line 12877 def organization_url @organization_url end |
#private_key_id ⇒ Object
The key ID (kid) assigned by Okta to the registered public key.
12879 12880 12881 |
# File 'lib/models/porcelain.rb', line 12879 def private_key_id @private_key_id end |
#private_key_id_set ⇒ Object
Indicates if a key ID is already stored or explicitly supplied. This allows callers to preserve the existing value when omitted or clear it by sending an empty string with private_key_id_set=true.
12883 12884 12885 |
# File 'lib/models/porcelain.rb', line 12883 def private_key_id_set @private_key_id_set end |
#private_key_pem ⇒ Object
The PEM encoded private key to authenticate with when auth_mode is client_credentials.
12885 12886 12887 |
# File 'lib/models/porcelain.rb', line 12885 def private_key_pem @private_key_pem end |
#private_key_pem_set ⇒ Object
Indicates if a PEM encoded private key is already stored.
12887 12888 12889 |
# File 'lib/models/porcelain.rb', line 12887 def private_key_pem_set @private_key_pem_set end |
#user_lookup ⇒ Object
The Okta user lookup strategy, one of the OktaUserLookup constants.
12889 12890 12891 |
# File 'lib/models/porcelain.rb', line 12889 def user_lookup @user_lookup end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12917 12918 12919 12920 12921 12922 12923 |
# File 'lib/models/porcelain.rb', line 12917 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |