Class: SDM::OktaMFAConfig
- Inherits:
-
Object
- Object
- SDM::OktaMFAConfig
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#api_token ⇒ Object
The API token to authenticate with when auth_mode is api_token.
-
#api_token_set ⇒ Object
Indicates if an API token is already stored.
-
#auth_mode ⇒ Object
The Okta auth mode, one of the OktaAuthMode constants.
-
#client_id ⇒ Object
The Okta client ID to authenticate with when auth_mode is client_credentials.
-
#multidevice_push_enabled ⇒ Object
Indicates if multidevice push is enabled.
-
#organization_url ⇒ Object
The Okta organization URL.
-
#private_key_id ⇒ Object
The key ID (kid) assigned by Okta to the registered public key.
-
#private_key_id_set ⇒ Object
Indicates if a key ID is already stored or explicitly supplied.
-
#private_key_pem ⇒ Object
The PEM encoded private key to authenticate with when auth_mode is client_credentials.
-
#private_key_pem_set ⇒ Object
Indicates if a PEM encoded private key is already stored.
-
#user_lookup ⇒ Object
The Okta user lookup strategy, one of the OktaUserLookup constants.
Instance Method Summary collapse
-
#initialize(api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil) ⇒ OktaMFAConfig
constructor
A new instance of OktaMFAConfig.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil) ⇒ OktaMFAConfig
Returns a new instance of OktaMFAConfig.
12999 13000 13001 13002 13003 13004 13005 13006 13007 13008 13009 13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 13021 13022 13023 |
# File 'lib/models/porcelain.rb', line 12999 def initialize( api_token: nil, api_token_set: nil, auth_mode: nil, client_id: nil, multidevice_push_enabled: nil, organization_url: nil, private_key_id: nil, private_key_id_set: nil, private_key_pem: nil, private_key_pem_set: nil, user_lookup: nil ) @api_token = api_token == nil ? "" : api_token @api_token_set = api_token_set == nil ? false : api_token_set @auth_mode = auth_mode == nil ? "" : auth_mode @client_id = client_id == nil ? "" : client_id @multidevice_push_enabled = multidevice_push_enabled == nil ? false : multidevice_push_enabled @organization_url = organization_url == nil ? "" : organization_url @private_key_id = private_key_id == nil ? "" : private_key_id @private_key_id_set = private_key_id_set == nil ? false : private_key_id_set @private_key_pem = private_key_pem == nil ? "" : private_key_pem @private_key_pem_set = private_key_pem_set == nil ? false : private_key_pem_set @user_lookup = user_lookup == nil ? "" : user_lookup end |
Instance Attribute Details
#api_token ⇒ Object
The API token to authenticate with when auth_mode is api_token.
12975 12976 12977 |
# File 'lib/models/porcelain.rb', line 12975 def api_token @api_token end |
#api_token_set ⇒ Object
Indicates if an API token is already stored.
12977 12978 12979 |
# File 'lib/models/porcelain.rb', line 12977 def api_token_set @api_token_set end |
#auth_mode ⇒ Object
The Okta auth mode, one of the OktaAuthMode constants.
12979 12980 12981 |
# File 'lib/models/porcelain.rb', line 12979 def auth_mode @auth_mode end |
#client_id ⇒ Object
The Okta client ID to authenticate with when auth_mode is client_credentials.
12981 12982 12983 |
# File 'lib/models/porcelain.rb', line 12981 def client_id @client_id end |
#multidevice_push_enabled ⇒ Object
Indicates if multidevice push is enabled.
12983 12984 12985 |
# File 'lib/models/porcelain.rb', line 12983 def multidevice_push_enabled @multidevice_push_enabled end |
#organization_url ⇒ Object
The Okta organization URL.
12985 12986 12987 |
# File 'lib/models/porcelain.rb', line 12985 def organization_url @organization_url end |
#private_key_id ⇒ Object
The key ID (kid) assigned by Okta to the registered public key.
12987 12988 12989 |
# File 'lib/models/porcelain.rb', line 12987 def private_key_id @private_key_id end |
#private_key_id_set ⇒ Object
Indicates if a key ID is already stored or explicitly supplied. This allows callers to preserve the existing value when omitted or clear it by sending an empty string with private_key_id_set=true.
12991 12992 12993 |
# File 'lib/models/porcelain.rb', line 12991 def private_key_id_set @private_key_id_set end |
#private_key_pem ⇒ Object
The PEM encoded private key to authenticate with when auth_mode is client_credentials.
12993 12994 12995 |
# File 'lib/models/porcelain.rb', line 12993 def private_key_pem @private_key_pem end |
#private_key_pem_set ⇒ Object
Indicates if a PEM encoded private key is already stored.
12995 12996 12997 |
# File 'lib/models/porcelain.rb', line 12995 def private_key_pem_set @private_key_pem_set end |
#user_lookup ⇒ Object
The Okta user lookup strategy, one of the OktaUserLookup constants.
12997 12998 12999 |
# File 'lib/models/porcelain.rb', line 12997 def user_lookup @user_lookup end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13025 13026 13027 13028 13029 13030 13031 |
# File 'lib/models/porcelain.rb', line 13025 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |