Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



13008
13009
13010
13011
13012
13013
13014
13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
13028
13029
13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
# File 'lib/models/porcelain.rb', line 13008

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12976
12977
12978
# File 'lib/models/porcelain.rb', line 12976

def bind_interface
  @bind_interface
end

#databaseObject

Oracle service name to connect to



12978
12979
12980
# File 'lib/models/porcelain.rb', line 12978

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12980
12981
12982
# File 'lib/models/porcelain.rb', line 12980

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12982
12983
12984
# File 'lib/models/porcelain.rb', line 12982

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12984
12985
12986
# File 'lib/models/porcelain.rb', line 12984

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12986
12987
12988
# File 'lib/models/porcelain.rb', line 12986

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12988
12989
12990
# File 'lib/models/porcelain.rb', line 12988

def name
  @name
end

#passwordObject

The password to authenticate with.



12990
12991
12992
# File 'lib/models/porcelain.rb', line 12990

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12992
12993
12994
# File 'lib/models/porcelain.rb', line 12992

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12994
12995
12996
# File 'lib/models/porcelain.rb', line 12994

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12996
12997
12998
# File 'lib/models/porcelain.rb', line 12996

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12998
12999
13000
# File 'lib/models/porcelain.rb', line 12998

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13000
13001
13002
# File 'lib/models/porcelain.rb', line 13000

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13002
13003
13004
# File 'lib/models/porcelain.rb', line 13002

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



13004
13005
13006
# File 'lib/models/porcelain.rb', line 13004

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



13006
13007
13008
# File 'lib/models/porcelain.rb', line 13006

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13044
13045
13046
13047
13048
13049
13050
# File 'lib/models/porcelain.rb', line 13044

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end