Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
# File 'lib/models/porcelain.rb', line 12404

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12372
12373
12374
# File 'lib/models/porcelain.rb', line 12372

def bind_interface
  @bind_interface
end

#databaseObject

Oracle service name to connect to



12374
12375
12376
# File 'lib/models/porcelain.rb', line 12374

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12376
12377
12378
# File 'lib/models/porcelain.rb', line 12376

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12378
12379
12380
# File 'lib/models/porcelain.rb', line 12378

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12380
12381
12382
# File 'lib/models/porcelain.rb', line 12380

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12382
12383
12384
# File 'lib/models/porcelain.rb', line 12382

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12384
12385
12386
# File 'lib/models/porcelain.rb', line 12384

def name
  @name
end

#passwordObject

The password to authenticate with.



12386
12387
12388
# File 'lib/models/porcelain.rb', line 12386

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12388
12389
12390
# File 'lib/models/porcelain.rb', line 12388

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12390
12391
12392
# File 'lib/models/porcelain.rb', line 12390

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12392
12393
12394
# File 'lib/models/porcelain.rb', line 12392

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12394
12395
12396
# File 'lib/models/porcelain.rb', line 12394

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12396
12397
12398
# File 'lib/models/porcelain.rb', line 12396

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12398
12399
12400
# File 'lib/models/porcelain.rb', line 12398

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



12400
12401
12402
# File 'lib/models/porcelain.rb', line 12400

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



12402
12403
12404
# File 'lib/models/porcelain.rb', line 12402

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12440
12441
12442
12443
12444
12445
12446
# File 'lib/models/porcelain.rb', line 12440

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end