Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
9981 9982 9983 9984 9985 9986 9987 9988 9989 9990 9991 9992 9993 9994 9995 9996 9997 9998 9999 10000 10001 10002 10003 10004 10005 10006 10007 10008 10009 10010 10011 10012 10013 10014 10015 |
# File 'lib/models/porcelain.rb', line 9981 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9949 9950 9951 |
# File 'lib/models/porcelain.rb', line 9949 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9951 9952 9953 |
# File 'lib/models/porcelain.rb', line 9951 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9953 9954 9955 |
# File 'lib/models/porcelain.rb', line 9953 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9955 9956 9957 |
# File 'lib/models/porcelain.rb', line 9955 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9957 9958 9959 |
# File 'lib/models/porcelain.rb', line 9957 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9959 9960 9961 |
# File 'lib/models/porcelain.rb', line 9959 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9961 9962 9963 |
# File 'lib/models/porcelain.rb', line 9961 def name @name end |
#password ⇒ Object
The password to authenticate with.
9963 9964 9965 |
# File 'lib/models/porcelain.rb', line 9963 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9965 9966 9967 |
# File 'lib/models/porcelain.rb', line 9965 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9967 9968 9969 |
# File 'lib/models/porcelain.rb', line 9967 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9969 9970 9971 |
# File 'lib/models/porcelain.rb', line 9969 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9971 9972 9973 |
# File 'lib/models/porcelain.rb', line 9971 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9973 9974 9975 |
# File 'lib/models/porcelain.rb', line 9973 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9975 9976 9977 |
# File 'lib/models/porcelain.rb', line 9975 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9977 9978 9979 |
# File 'lib/models/porcelain.rb', line 9977 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9979 9980 9981 |
# File 'lib/models/porcelain.rb', line 9979 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10017 10018 10019 10020 10021 10022 10023 |
# File 'lib/models/porcelain.rb', line 10017 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |