Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 9826 9827 9828 9829 9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 9842 9843 |
# File 'lib/models/porcelain.rb', line 9809 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9777 9778 9779 |
# File 'lib/models/porcelain.rb', line 9777 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9779 9780 9781 |
# File 'lib/models/porcelain.rb', line 9779 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9781 9782 9783 |
# File 'lib/models/porcelain.rb', line 9781 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9783 9784 9785 |
# File 'lib/models/porcelain.rb', line 9783 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9785 9786 9787 |
# File 'lib/models/porcelain.rb', line 9785 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9787 9788 9789 |
# File 'lib/models/porcelain.rb', line 9787 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9789 9790 9791 |
# File 'lib/models/porcelain.rb', line 9789 def name @name end |
#password ⇒ Object
The password to authenticate with.
9791 9792 9793 |
# File 'lib/models/porcelain.rb', line 9791 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9793 9794 9795 |
# File 'lib/models/porcelain.rb', line 9793 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9795 9796 9797 |
# File 'lib/models/porcelain.rb', line 9795 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9797 9798 9799 |
# File 'lib/models/porcelain.rb', line 9797 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9799 9800 9801 |
# File 'lib/models/porcelain.rb', line 9799 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9801 9802 9803 |
# File 'lib/models/porcelain.rb', line 9801 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9803 9804 9805 |
# File 'lib/models/porcelain.rb', line 9803 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9805 9806 9807 |
# File 'lib/models/porcelain.rb', line 9805 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9807 9808 9809 |
# File 'lib/models/porcelain.rb', line 9807 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9845 9846 9847 9848 9849 9850 9851 |
# File 'lib/models/porcelain.rb', line 9845 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |