Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
# File 'lib/models/porcelain.rb', line 8812

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8780
8781
8782
# File 'lib/models/porcelain.rb', line 8780

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8782
8783
8784
# File 'lib/models/porcelain.rb', line 8782

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8784
8785
8786
# File 'lib/models/porcelain.rb', line 8784

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8786
8787
8788
# File 'lib/models/porcelain.rb', line 8786

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8788
8789
8790
# File 'lib/models/porcelain.rb', line 8788

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8790
8791
8792
# File 'lib/models/porcelain.rb', line 8790

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8792
8793
8794
# File 'lib/models/porcelain.rb', line 8792

def name
  @name
end

#passwordObject

The password to authenticate with.



8794
8795
8796
# File 'lib/models/porcelain.rb', line 8794

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8796
8797
8798
# File 'lib/models/porcelain.rb', line 8796

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8798
8799
8800
# File 'lib/models/porcelain.rb', line 8798

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8800
8801
8802
# File 'lib/models/porcelain.rb', line 8800

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8802
8803
8804
# File 'lib/models/porcelain.rb', line 8802

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8804
8805
8806
# File 'lib/models/porcelain.rb', line 8804

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8806
8807
8808
# File 'lib/models/porcelain.rb', line 8806

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8808
8809
8810
# File 'lib/models/porcelain.rb', line 8808

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8810
8811
8812
# File 'lib/models/porcelain.rb', line 8810

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8848
8849
8850
8851
8852
8853
8854
# File 'lib/models/porcelain.rb', line 8848

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end