Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



8737
8738
8739
8740
8741
8742
8743
8744
8745
8746
8747
8748
8749
8750
8751
8752
8753
8754
8755
8756
8757
8758
8759
8760
8761
8762
8763
8764
8765
8766
8767
8768
8769
8770
8771
# File 'lib/models/porcelain.rb', line 8737

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8705
8706
8707
# File 'lib/models/porcelain.rb', line 8705

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8707
8708
8709
# File 'lib/models/porcelain.rb', line 8707

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8709
8710
8711
# File 'lib/models/porcelain.rb', line 8709

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8711
8712
8713
# File 'lib/models/porcelain.rb', line 8711

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8713
8714
8715
# File 'lib/models/porcelain.rb', line 8713

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8715
8716
8717
# File 'lib/models/porcelain.rb', line 8715

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8717
8718
8719
# File 'lib/models/porcelain.rb', line 8717

def name
  @name
end

#passwordObject

The password to authenticate with.



8719
8720
8721
# File 'lib/models/porcelain.rb', line 8719

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8721
8722
8723
# File 'lib/models/porcelain.rb', line 8721

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8723
8724
8725
# File 'lib/models/porcelain.rb', line 8723

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8725
8726
8727
# File 'lib/models/porcelain.rb', line 8725

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8727
8728
8729
# File 'lib/models/porcelain.rb', line 8727

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8729
8730
8731
# File 'lib/models/porcelain.rb', line 8729

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8731
8732
8733
# File 'lib/models/porcelain.rb', line 8731

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8733
8734
8735
# File 'lib/models/porcelain.rb', line 8733

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8735
8736
8737
# File 'lib/models/porcelain.rb', line 8735

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8773
8774
8775
8776
8777
8778
8779
# File 'lib/models/porcelain.rb', line 8773

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end