Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 |
# File 'lib/models/porcelain.rb', line 8733 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8701 8702 8703 |
# File 'lib/models/porcelain.rb', line 8701 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8703 8704 8705 |
# File 'lib/models/porcelain.rb', line 8703 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8705 8706 8707 |
# File 'lib/models/porcelain.rb', line 8705 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8707 8708 8709 |
# File 'lib/models/porcelain.rb', line 8707 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8709 8710 8711 |
# File 'lib/models/porcelain.rb', line 8709 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8711 8712 8713 |
# File 'lib/models/porcelain.rb', line 8711 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8713 8714 8715 |
# File 'lib/models/porcelain.rb', line 8713 def name @name end |
#password ⇒ Object
The password to authenticate with.
8715 8716 8717 |
# File 'lib/models/porcelain.rb', line 8715 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8717 8718 8719 |
# File 'lib/models/porcelain.rb', line 8717 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8719 8720 8721 |
# File 'lib/models/porcelain.rb', line 8719 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8721 8722 8723 |
# File 'lib/models/porcelain.rb', line 8721 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8723 8724 8725 |
# File 'lib/models/porcelain.rb', line 8723 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8725 8726 8727 |
# File 'lib/models/porcelain.rb', line 8725 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8727 8728 8729 |
# File 'lib/models/porcelain.rb', line 8727 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8729 8730 8731 |
# File 'lib/models/porcelain.rb', line 8729 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8731 8732 8733 |
# File 'lib/models/porcelain.rb', line 8731 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8769 8770 8771 8772 8773 8774 8775 |
# File 'lib/models/porcelain.rb', line 8769 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |