Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
# File 'lib/models/porcelain.rb', line 8657

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8625
8626
8627
# File 'lib/models/porcelain.rb', line 8625

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8627
8628
8629
# File 'lib/models/porcelain.rb', line 8627

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8629
8630
8631
# File 'lib/models/porcelain.rb', line 8629

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8631
8632
8633
# File 'lib/models/porcelain.rb', line 8631

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8633
8634
8635
# File 'lib/models/porcelain.rb', line 8633

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8635
8636
8637
# File 'lib/models/porcelain.rb', line 8635

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8637
8638
8639
# File 'lib/models/porcelain.rb', line 8637

def name
  @name
end

#passwordObject

The password to authenticate with.



8639
8640
8641
# File 'lib/models/porcelain.rb', line 8639

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8641
8642
8643
# File 'lib/models/porcelain.rb', line 8641

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8643
8644
8645
# File 'lib/models/porcelain.rb', line 8643

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



8645
8646
8647
# File 'lib/models/porcelain.rb', line 8645

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8647
8648
8649
# File 'lib/models/porcelain.rb', line 8647

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8649
8650
8651
# File 'lib/models/porcelain.rb', line 8649

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8651
8652
8653
# File 'lib/models/porcelain.rb', line 8651

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



8653
8654
8655
# File 'lib/models/porcelain.rb', line 8653

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



8655
8656
8657
# File 'lib/models/porcelain.rb', line 8655

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8693
8694
8695
8696
8697
8698
8699
# File 'lib/models/porcelain.rb', line 8693

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end