Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 8604 8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 |
# File 'lib/models/porcelain.rb', line 8587 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8555 8556 8557 |
# File 'lib/models/porcelain.rb', line 8555 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8557 8558 8559 |
# File 'lib/models/porcelain.rb', line 8557 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8559 8560 8561 |
# File 'lib/models/porcelain.rb', line 8559 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8561 8562 8563 |
# File 'lib/models/porcelain.rb', line 8561 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8563 8564 8565 |
# File 'lib/models/porcelain.rb', line 8563 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8565 8566 8567 |
# File 'lib/models/porcelain.rb', line 8565 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8567 8568 8569 |
# File 'lib/models/porcelain.rb', line 8567 def name @name end |
#password ⇒ Object
The password to authenticate with.
8569 8570 8571 |
# File 'lib/models/porcelain.rb', line 8569 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8571 8572 8573 |
# File 'lib/models/porcelain.rb', line 8571 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8573 8574 8575 |
# File 'lib/models/porcelain.rb', line 8573 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8575 8576 8577 |
# File 'lib/models/porcelain.rb', line 8575 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8577 8578 8579 |
# File 'lib/models/porcelain.rb', line 8577 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8579 8580 8581 |
# File 'lib/models/porcelain.rb', line 8579 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8581 8582 8583 |
# File 'lib/models/porcelain.rb', line 8581 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8583 8584 8585 |
# File 'lib/models/porcelain.rb', line 8583 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8585 8586 8587 |
# File 'lib/models/porcelain.rb', line 8585 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8623 8624 8625 8626 8627 8628 8629 |
# File 'lib/models/porcelain.rb', line 8623 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |