Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 |
# File 'lib/models/porcelain.rb', line 7905 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7873 7874 7875 |
# File 'lib/models/porcelain.rb', line 7873 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7875 7876 7877 |
# File 'lib/models/porcelain.rb', line 7875 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7877 7878 7879 |
# File 'lib/models/porcelain.rb', line 7877 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7879 7880 7881 |
# File 'lib/models/porcelain.rb', line 7879 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7881 7882 7883 |
# File 'lib/models/porcelain.rb', line 7881 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7883 7884 7885 |
# File 'lib/models/porcelain.rb', line 7883 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7885 7886 7887 |
# File 'lib/models/porcelain.rb', line 7885 def name @name end |
#password ⇒ Object
The password to authenticate with.
7887 7888 7889 |
# File 'lib/models/porcelain.rb', line 7887 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7889 7890 7891 |
# File 'lib/models/porcelain.rb', line 7889 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7891 7892 7893 |
# File 'lib/models/porcelain.rb', line 7891 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
7893 7894 7895 |
# File 'lib/models/porcelain.rb', line 7893 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7895 7896 7897 |
# File 'lib/models/porcelain.rb', line 7895 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7897 7898 7899 |
# File 'lib/models/porcelain.rb', line 7897 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7899 7900 7901 |
# File 'lib/models/porcelain.rb', line 7899 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7901 7902 7903 |
# File 'lib/models/porcelain.rb', line 7901 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7903 7904 7905 |
# File 'lib/models/porcelain.rb', line 7903 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7941 7942 7943 7944 7945 7946 7947 |
# File 'lib/models/porcelain.rb', line 7941 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |