Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 |
# File 'lib/models/porcelain.rb', line 7582 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7552 7553 7554 |
# File 'lib/models/porcelain.rb', line 7552 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7554 7555 7556 |
# File 'lib/models/porcelain.rb', line 7554 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7556 7557 7558 |
# File 'lib/models/porcelain.rb', line 7556 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7558 7559 7560 |
# File 'lib/models/porcelain.rb', line 7558 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7560 7561 7562 |
# File 'lib/models/porcelain.rb', line 7560 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7562 7563 7564 |
# File 'lib/models/porcelain.rb', line 7562 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7564 7565 7566 |
# File 'lib/models/porcelain.rb', line 7564 def name @name end |
#password ⇒ Object
The password to authenticate with.
7566 7567 7568 |
# File 'lib/models/porcelain.rb', line 7566 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7568 7569 7570 |
# File 'lib/models/porcelain.rb', line 7568 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7570 7571 7572 |
# File 'lib/models/porcelain.rb', line 7570 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7572 7573 7574 |
# File 'lib/models/porcelain.rb', line 7572 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7574 7575 7576 |
# File 'lib/models/porcelain.rb', line 7574 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7576 7577 7578 |
# File 'lib/models/porcelain.rb', line 7576 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7578 7579 7580 |
# File 'lib/models/porcelain.rb', line 7578 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7580 7581 7582 |
# File 'lib/models/porcelain.rb', line 7580 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7616 7617 7618 7619 7620 7621 7622 |
# File 'lib/models/porcelain.rb', line 7616 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |