Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
6027 6028 6029 6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 6059 |
# File 'lib/models/porcelain.rb', line 6027 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5997 5998 5999 |
# File 'lib/models/porcelain.rb', line 5997 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
5999 6000 6001 |
# File 'lib/models/porcelain.rb', line 5999 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6001 6002 6003 |
# File 'lib/models/porcelain.rb', line 6001 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6003 6004 6005 |
# File 'lib/models/porcelain.rb', line 6003 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6005 6006 6007 |
# File 'lib/models/porcelain.rb', line 6005 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6007 6008 6009 |
# File 'lib/models/porcelain.rb', line 6007 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6009 6010 6011 |
# File 'lib/models/porcelain.rb', line 6009 def name @name end |
#password ⇒ Object
The password to authenticate with.
6011 6012 6013 |
# File 'lib/models/porcelain.rb', line 6011 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6013 6014 6015 |
# File 'lib/models/porcelain.rb', line 6013 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6015 6016 6017 |
# File 'lib/models/porcelain.rb', line 6015 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6017 6018 6019 |
# File 'lib/models/porcelain.rb', line 6017 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6019 6020 6021 |
# File 'lib/models/porcelain.rb', line 6019 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6021 6022 6023 |
# File 'lib/models/porcelain.rb', line 6021 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
6023 6024 6025 |
# File 'lib/models/porcelain.rb', line 6023 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
6025 6026 6027 |
# File 'lib/models/porcelain.rb', line 6025 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6061 6062 6063 6064 6065 6066 6067 |
# File 'lib/models/porcelain.rb', line 6061 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |