Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 5885 5886 5887 |
# File 'lib/models/porcelain.rb', line 5855 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
5825 5826 5827 |
# File 'lib/models/porcelain.rb', line 5825 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
5827 5828 5829 |
# File 'lib/models/porcelain.rb', line 5827 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5829 5830 5831 |
# File 'lib/models/porcelain.rb', line 5829 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5831 5832 5833 |
# File 'lib/models/porcelain.rb', line 5831 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
5833 5834 5835 |
# File 'lib/models/porcelain.rb', line 5833 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5835 5836 5837 |
# File 'lib/models/porcelain.rb', line 5835 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5837 5838 5839 |
# File 'lib/models/porcelain.rb', line 5837 def name @name end |
#password ⇒ Object
The password to authenticate with.
5839 5840 5841 |
# File 'lib/models/porcelain.rb', line 5839 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
5841 5842 5843 |
# File 'lib/models/porcelain.rb', line 5841 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
5843 5844 5845 |
# File 'lib/models/porcelain.rb', line 5843 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5845 5846 5847 |
# File 'lib/models/porcelain.rb', line 5845 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5847 5848 5849 |
# File 'lib/models/porcelain.rb', line 5847 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5849 5850 5851 |
# File 'lib/models/porcelain.rb', line 5849 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
5851 5852 5853 |
# File 'lib/models/porcelain.rb', line 5851 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
5853 5854 5855 |
# File 'lib/models/porcelain.rb', line 5853 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5889 5890 5891 5892 5893 5894 5895 |
# File 'lib/models/porcelain.rb', line 5889 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |