Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 5714 5715 5716 5717 5718 5719 5720 5721 5722 5723 5724 5725 5726 5727 5728 5729 5730 5731 5732 5733 5734 |
# File 'lib/models/porcelain.rb', line 5702 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5672 5673 5674 |
# File 'lib/models/porcelain.rb', line 5672 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5674 5675 5676 |
# File 'lib/models/porcelain.rb', line 5674 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5676 5677 5678 |
# File 'lib/models/porcelain.rb', line 5676 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5678 5679 5680 |
# File 'lib/models/porcelain.rb', line 5678 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5680 5681 5682 |
# File 'lib/models/porcelain.rb', line 5680 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5682 5683 5684 |
# File 'lib/models/porcelain.rb', line 5682 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5684 5685 5686 |
# File 'lib/models/porcelain.rb', line 5684 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5686 5687 5688 |
# File 'lib/models/porcelain.rb', line 5686 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5688 5689 5690 |
# File 'lib/models/porcelain.rb', line 5688 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5690 5691 5692 |
# File 'lib/models/porcelain.rb', line 5690 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5692 5693 5694 |
# File 'lib/models/porcelain.rb', line 5692 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5694 5695 5696 |
# File 'lib/models/porcelain.rb', line 5694 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5696 5697 5698 |
# File 'lib/models/porcelain.rb', line 5696 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5698 5699 5700 |
# File 'lib/models/porcelain.rb', line 5698 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5700 5701 5702 |
# File 'lib/models/porcelain.rb', line 5700 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/models/porcelain.rb', line 5736 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |