Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
# File 'lib/models/porcelain.rb', line 5646

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5616
5617
5618
# File 'lib/models/porcelain.rb', line 5616

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



5618
5619
5620
# File 'lib/models/porcelain.rb', line 5618

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5620
5621
5622
# File 'lib/models/porcelain.rb', line 5620

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5622
5623
5624
# File 'lib/models/porcelain.rb', line 5622

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5624
5625
5626
# File 'lib/models/porcelain.rb', line 5624

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5626
5627
5628
# File 'lib/models/porcelain.rb', line 5626

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5628
5629
5630
# File 'lib/models/porcelain.rb', line 5628

def name
  @name
end

#passwordObject

Returns the value of attribute password.



5630
5631
5632
# File 'lib/models/porcelain.rb', line 5630

def password
  @password
end

#portObject

Returns the value of attribute port.



5632
5633
5634
# File 'lib/models/porcelain.rb', line 5632

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5634
5635
5636
# File 'lib/models/porcelain.rb', line 5634

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5636
5637
5638
# File 'lib/models/porcelain.rb', line 5636

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5638
5639
5640
# File 'lib/models/porcelain.rb', line 5638

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5640
5641
5642
# File 'lib/models/porcelain.rb', line 5640

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



5642
5643
5644
# File 'lib/models/porcelain.rb', line 5642

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



5644
5645
5646
# File 'lib/models/porcelain.rb', line 5644

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5680
5681
5682
5683
5684
5685
5686
# File 'lib/models/porcelain.rb', line 5680

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end