Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
5306
5307
5308
# File 'lib/models/porcelain.rb', line 5278

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5250
5251
5252
# File 'lib/models/porcelain.rb', line 5250

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



5252
5253
5254
# File 'lib/models/porcelain.rb', line 5252

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5254
5255
5256
# File 'lib/models/porcelain.rb', line 5254

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5256
5257
5258
# File 'lib/models/porcelain.rb', line 5256

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5258
5259
5260
# File 'lib/models/porcelain.rb', line 5258

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5260
5261
5262
# File 'lib/models/porcelain.rb', line 5260

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5262
5263
5264
# File 'lib/models/porcelain.rb', line 5262

def name
  @name
end

#passwordObject

Returns the value of attribute password.



5264
5265
5266
# File 'lib/models/porcelain.rb', line 5264

def password
  @password
end

#portObject

Returns the value of attribute port.



5266
5267
5268
# File 'lib/models/porcelain.rb', line 5266

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5268
5269
5270
# File 'lib/models/porcelain.rb', line 5268

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5270
5271
5272
# File 'lib/models/porcelain.rb', line 5270

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5272
5273
5274
# File 'lib/models/porcelain.rb', line 5272

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



5274
5275
5276
# File 'lib/models/porcelain.rb', line 5274

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



5276
5277
5278
# File 'lib/models/porcelain.rb', line 5276

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5310
5311
5312
5313
5314
5315
5316
# File 'lib/models/porcelain.rb', line 5310

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end