Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
4905 4906 4907 4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 4919 4920 4921 4922 4923 4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/models/porcelain.rb', line 4905 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4877 4878 4879 |
# File 'lib/models/porcelain.rb', line 4877 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4879 4880 4881 |
# File 'lib/models/porcelain.rb', line 4879 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4881 4882 4883 |
# File 'lib/models/porcelain.rb', line 4881 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4883 4884 4885 |
# File 'lib/models/porcelain.rb', line 4883 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4885 4886 4887 |
# File 'lib/models/porcelain.rb', line 4885 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4887 4888 4889 |
# File 'lib/models/porcelain.rb', line 4887 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4889 4890 4891 |
# File 'lib/models/porcelain.rb', line 4889 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4891 4892 4893 |
# File 'lib/models/porcelain.rb', line 4891 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4893 4894 4895 |
# File 'lib/models/porcelain.rb', line 4893 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4895 4896 4897 |
# File 'lib/models/porcelain.rb', line 4895 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4897 4898 4899 |
# File 'lib/models/porcelain.rb', line 4897 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4899 4900 4901 |
# File 'lib/models/porcelain.rb', line 4899 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4901 4902 4903 |
# File 'lib/models/porcelain.rb', line 4901 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4903 4904 4905 |
# File 'lib/models/porcelain.rb', line 4903 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4937 4938 4939 4940 4941 4942 4943 |
# File 'lib/models/porcelain.rb', line 4937 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |