Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
4828
# File 'lib/models/porcelain.rb', line 4798

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4770
4771
4772
# File 'lib/models/porcelain.rb', line 4770

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4772
4773
4774
# File 'lib/models/porcelain.rb', line 4772

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4774
4775
4776
# File 'lib/models/porcelain.rb', line 4774

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4776
4777
4778
# File 'lib/models/porcelain.rb', line 4776

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4778
4779
4780
# File 'lib/models/porcelain.rb', line 4778

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4780
4781
4782
# File 'lib/models/porcelain.rb', line 4780

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4782
4783
4784
# File 'lib/models/porcelain.rb', line 4782

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4784
4785
4786
# File 'lib/models/porcelain.rb', line 4784

def password
  @password
end

#portObject

Returns the value of attribute port.



4786
4787
4788
# File 'lib/models/porcelain.rb', line 4786

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4788
4789
4790
# File 'lib/models/porcelain.rb', line 4788

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4790
4791
4792
# File 'lib/models/porcelain.rb', line 4790

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4792
4793
4794
# File 'lib/models/porcelain.rb', line 4792

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4794
4795
4796
# File 'lib/models/porcelain.rb', line 4794

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4796
4797
4798
# File 'lib/models/porcelain.rb', line 4796

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4830
4831
4832
4833
4834
4835
4836
# File 'lib/models/porcelain.rb', line 4830

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end