Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 4792 4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 |
# File 'lib/models/porcelain.rb', line 4779 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4751 4752 4753 |
# File 'lib/models/porcelain.rb', line 4751 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4753 4754 4755 |
# File 'lib/models/porcelain.rb', line 4753 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4755 4756 4757 |
# File 'lib/models/porcelain.rb', line 4755 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4757 4758 4759 |
# File 'lib/models/porcelain.rb', line 4757 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4759 4760 4761 |
# File 'lib/models/porcelain.rb', line 4759 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4761 4762 4763 |
# File 'lib/models/porcelain.rb', line 4761 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4763 4764 4765 |
# File 'lib/models/porcelain.rb', line 4763 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4765 4766 4767 |
# File 'lib/models/porcelain.rb', line 4765 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4767 4768 4769 |
# File 'lib/models/porcelain.rb', line 4767 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4769 4770 4771 |
# File 'lib/models/porcelain.rb', line 4769 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4771 4772 4773 |
# File 'lib/models/porcelain.rb', line 4771 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4773 4774 4775 |
# File 'lib/models/porcelain.rb', line 4773 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4775 4776 4777 |
# File 'lib/models/porcelain.rb', line 4775 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4777 4778 4779 |
# File 'lib/models/porcelain.rb', line 4777 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4811 4812 4813 4814 4815 4816 4817 |
# File 'lib/models/porcelain.rb', line 4811 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |