Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
4466
# File 'lib/models/porcelain.rb', line 4436

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4408
4409
4410
# File 'lib/models/porcelain.rb', line 4408

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4410
4411
4412
# File 'lib/models/porcelain.rb', line 4410

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4412
4413
4414
# File 'lib/models/porcelain.rb', line 4412

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4414
4415
4416
# File 'lib/models/porcelain.rb', line 4414

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4416
4417
4418
# File 'lib/models/porcelain.rb', line 4416

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4418
4419
4420
# File 'lib/models/porcelain.rb', line 4418

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4420
4421
4422
# File 'lib/models/porcelain.rb', line 4420

def name
  @name
end

#passwordObject

Returns the value of attribute password.



4422
4423
4424
# File 'lib/models/porcelain.rb', line 4422

def password
  @password
end

#portObject

Returns the value of attribute port.



4424
4425
4426
# File 'lib/models/porcelain.rb', line 4424

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4426
4427
4428
# File 'lib/models/porcelain.rb', line 4426

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4428
4429
4430
# File 'lib/models/porcelain.rb', line 4428

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4430
4431
4432
# File 'lib/models/porcelain.rb', line 4430

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



4432
4433
4434
# File 'lib/models/porcelain.rb', line 4432

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



4434
4435
4436
# File 'lib/models/porcelain.rb', line 4434

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4468
4469
4470
4471
4472
4473
4474
# File 'lib/models/porcelain.rb', line 4468

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end