Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 5319 5320 5321 5322 5323 5324 5325 5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 |
# File 'lib/models/porcelain.rb', line 5287 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
5261 5262 5263 |
# File 'lib/models/porcelain.rb', line 5261 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5263 5264 5265 |
# File 'lib/models/porcelain.rb', line 5263 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5265 5266 5267 |
# File 'lib/models/porcelain.rb', line 5265 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5267 5268 5269 |
# File 'lib/models/porcelain.rb', line 5267 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5269 5270 5271 |
# File 'lib/models/porcelain.rb', line 5269 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5271 5272 5273 |
# File 'lib/models/porcelain.rb', line 5271 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5273 5274 5275 |
# File 'lib/models/porcelain.rb', line 5273 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5275 5276 5277 |
# File 'lib/models/porcelain.rb', line 5275 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5277 5278 5279 |
# File 'lib/models/porcelain.rb', line 5277 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5279 5280 5281 |
# File 'lib/models/porcelain.rb', line 5279 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5281 5282 5283 |
# File 'lib/models/porcelain.rb', line 5281 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5283 5284 5285 |
# File 'lib/models/porcelain.rb', line 5283 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5285 5286 5287 |
# File 'lib/models/porcelain.rb', line 5285 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5343 5344 5345 5346 5347 5348 5349 |
# File 'lib/models/porcelain.rb', line 5343 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |