Class: SDM::Oracle
- Inherits:
-
Object
- Object
- SDM::Oracle
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
Oracle service name to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
constructor
A new instance of Oracle.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle
Returns a new instance of Oracle.
12703 12704 12705 12706 12707 12708 12709 12710 12711 12712 12713 12714 12715 12716 12717 12718 12719 12720 12721 12722 12723 12724 12725 12726 12727 12728 12729 12730 12731 12732 12733 12734 12735 12736 12737 |
# File 'lib/models/porcelain.rb', line 12703 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
12671 12672 12673 |
# File 'lib/models/porcelain.rb', line 12671 def bind_interface @bind_interface end |
#database ⇒ Object
Oracle service name to connect to
12673 12674 12675 |
# File 'lib/models/porcelain.rb', line 12673 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12675 12676 12677 |
# File 'lib/models/porcelain.rb', line 12675 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12677 12678 12679 |
# File 'lib/models/porcelain.rb', line 12677 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12679 12680 12681 |
# File 'lib/models/porcelain.rb', line 12679 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12681 12682 12683 |
# File 'lib/models/porcelain.rb', line 12681 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12683 12684 12685 |
# File 'lib/models/porcelain.rb', line 12683 def name @name end |
#password ⇒ Object
The password to authenticate with.
12685 12686 12687 |
# File 'lib/models/porcelain.rb', line 12685 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12687 12688 12689 |
# File 'lib/models/porcelain.rb', line 12687 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
12689 12690 12691 |
# File 'lib/models/porcelain.rb', line 12689 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12691 12692 12693 |
# File 'lib/models/porcelain.rb', line 12691 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12693 12694 12695 |
# File 'lib/models/porcelain.rb', line 12693 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
12695 12696 12697 |
# File 'lib/models/porcelain.rb', line 12695 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12697 12698 12699 |
# File 'lib/models/porcelain.rb', line 12697 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
12699 12700 12701 |
# File 'lib/models/porcelain.rb', line 12699 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
12701 12702 12703 |
# File 'lib/models/porcelain.rb', line 12701 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12739 12740 12741 12742 12743 12744 12745 |
# File 'lib/models/porcelain.rb', line 12739 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |