Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



12555
12556
12557
12558
12559
12560
12561
12562
12563
12564
12565
12566
12567
12568
12569
12570
12571
12572
12573
12574
12575
12576
12577
12578
12579
12580
12581
12582
12583
12584
12585
12586
12587
12588
12589
# File 'lib/models/porcelain.rb', line 12555

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12523
12524
12525
# File 'lib/models/porcelain.rb', line 12523

def bind_interface
  @bind_interface
end

#databaseObject

Oracle service name to connect to



12525
12526
12527
# File 'lib/models/porcelain.rb', line 12525

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12527
12528
12529
# File 'lib/models/porcelain.rb', line 12527

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12529
12530
12531
# File 'lib/models/porcelain.rb', line 12529

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12531
12532
12533
# File 'lib/models/porcelain.rb', line 12531

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12533
12534
12535
# File 'lib/models/porcelain.rb', line 12533

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12535
12536
12537
# File 'lib/models/porcelain.rb', line 12535

def name
  @name
end

#passwordObject

The password to authenticate with.



12537
12538
12539
# File 'lib/models/porcelain.rb', line 12537

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12539
12540
12541
# File 'lib/models/porcelain.rb', line 12539

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12541
12542
12543
# File 'lib/models/porcelain.rb', line 12541

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12543
12544
12545
# File 'lib/models/porcelain.rb', line 12543

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12545
12546
12547
# File 'lib/models/porcelain.rb', line 12545

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12547
12548
12549
# File 'lib/models/porcelain.rb', line 12547

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12549
12550
12551
# File 'lib/models/porcelain.rb', line 12549

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



12551
12552
12553
# File 'lib/models/porcelain.rb', line 12551

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



12553
12554
12555
# File 'lib/models/porcelain.rb', line 12553

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12591
12592
12593
12594
12595
12596
12597
# File 'lib/models/porcelain.rb', line 12591

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end