Class: SDM::Oracle

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Oracle

Returns a new instance of Oracle.



13068
13069
13070
13071
13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
13082
13083
13084
13085
13086
13087
13088
13089
13090
13091
13092
13093
13094
13095
13096
13097
13098
13099
13100
13101
13102
# File 'lib/models/porcelain.rb', line 13068

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13036
13037
13038
# File 'lib/models/porcelain.rb', line 13036

def bind_interface
  @bind_interface
end

#database ⇒ Object

Oracle service name to connect to



13038
13039
13040
# File 'lib/models/porcelain.rb', line 13038

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



13040
13041
13042
# File 'lib/models/porcelain.rb', line 13040

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



13042
13043
13044
# File 'lib/models/porcelain.rb', line 13042

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



13044
13045
13046
# File 'lib/models/porcelain.rb', line 13044

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



13046
13047
13048
# File 'lib/models/porcelain.rb', line 13046

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



13048
13049
13050
# File 'lib/models/porcelain.rb', line 13048

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



13050
13051
13052
# File 'lib/models/porcelain.rb', line 13050

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



13052
13053
13054
# File 'lib/models/porcelain.rb', line 13052

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13054
13055
13056
# File 'lib/models/porcelain.rb', line 13054

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



13056
13057
13058
# File 'lib/models/porcelain.rb', line 13056

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



13058
13059
13060
# File 'lib/models/porcelain.rb', line 13058

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13060
13061
13062
# File 'lib/models/porcelain.rb', line 13060

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



13062
13063
13064
# File 'lib/models/porcelain.rb', line 13062

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



13064
13065
13066
# File 'lib/models/porcelain.rb', line 13064

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



13066
13067
13068
# File 'lib/models/porcelain.rb', line 13066

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13104
13105
13106
13107
13108
13109
13110
# File 'lib/models/porcelain.rb', line 13104

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end