Class: SDM::OracleNNE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE

Returns a new instance of OracleNNE.



13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
13054
13055
13056
13057
13058
13059
13060
13061
13062
13063
13064
13065
13066
13067
13068
13069
13070
13071
13072
13073
# File 'lib/models/porcelain.rb', line 13039

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13007
13008
13009
# File 'lib/models/porcelain.rb', line 13007

def bind_interface
  @bind_interface
end

#databaseObject

Oracle service name to connect to



13009
13010
13011
# File 'lib/models/porcelain.rb', line 13009

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13011
13012
13013
# File 'lib/models/porcelain.rb', line 13011

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13013
13014
13015
# File 'lib/models/porcelain.rb', line 13013

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13015
13016
13017
# File 'lib/models/porcelain.rb', line 13015

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13017
13018
13019
# File 'lib/models/porcelain.rb', line 13017

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13019
13020
13021
# File 'lib/models/porcelain.rb', line 13019

def name
  @name
end

#passwordObject

The password to authenticate with.



13021
13022
13023
# File 'lib/models/porcelain.rb', line 13021

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13023
13024
13025
# File 'lib/models/porcelain.rb', line 13023

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13025
13026
13027
# File 'lib/models/porcelain.rb', line 13025

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13027
13028
13029
# File 'lib/models/porcelain.rb', line 13027

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13029
13030
13031
# File 'lib/models/porcelain.rb', line 13029

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13031
13032
13033
# File 'lib/models/porcelain.rb', line 13031

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13033
13034
13035
# File 'lib/models/porcelain.rb', line 13033

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



13035
13036
13037
# File 'lib/models/porcelain.rb', line 13035

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



13037
13038
13039
# File 'lib/models/porcelain.rb', line 13037

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13075
13076
13077
13078
13079
13080
13081
# File 'lib/models/porcelain.rb', line 13075

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end