Class: SDM::OracleNNE
- Inherits:
-
Object
- Object
- SDM::OracleNNE
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
Oracle service name to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE
constructor
A new instance of OracleNNE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE
Returns a new instance of OracleNNE.
12959 12960 12961 12962 12963 12964 12965 12966 12967 12968 12969 12970 12971 12972 12973 12974 12975 12976 12977 12978 12979 12980 12981 12982 12983 12984 12985 12986 12987 12988 12989 12990 12991 12992 12993 |
# File 'lib/models/porcelain.rb', line 12959 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
12927 12928 12929 |
# File 'lib/models/porcelain.rb', line 12927 def bind_interface @bind_interface end |
#database ⇒ Object
Oracle service name to connect to
12929 12930 12931 |
# File 'lib/models/porcelain.rb', line 12929 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12931 12932 12933 |
# File 'lib/models/porcelain.rb', line 12931 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12933 12934 12935 |
# File 'lib/models/porcelain.rb', line 12933 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12935 12936 12937 |
# File 'lib/models/porcelain.rb', line 12935 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12937 12938 12939 |
# File 'lib/models/porcelain.rb', line 12937 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12939 12940 12941 |
# File 'lib/models/porcelain.rb', line 12939 def name @name end |
#password ⇒ Object
The password to authenticate with.
12941 12942 12943 |
# File 'lib/models/porcelain.rb', line 12941 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12943 12944 12945 |
# File 'lib/models/porcelain.rb', line 12943 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
12945 12946 12947 |
# File 'lib/models/porcelain.rb', line 12945 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12947 12948 12949 |
# File 'lib/models/porcelain.rb', line 12947 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12949 12950 12951 |
# File 'lib/models/porcelain.rb', line 12949 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
12951 12952 12953 |
# File 'lib/models/porcelain.rb', line 12951 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12953 12954 12955 |
# File 'lib/models/porcelain.rb', line 12953 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
12955 12956 12957 |
# File 'lib/models/porcelain.rb', line 12955 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
12957 12958 12959 |
# File 'lib/models/porcelain.rb', line 12957 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12995 12996 12997 12998 12999 13000 13001 |
# File 'lib/models/porcelain.rb', line 12995 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |