Class: SDM::OracleNNE
- Inherits:
-
Object
- Object
- SDM::OracleNNE
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
Oracle service name to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE
constructor
A new instance of OracleNNE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE
Returns a new instance of OracleNNE.
12801 12802 12803 12804 12805 12806 12807 12808 12809 12810 12811 12812 12813 12814 12815 12816 12817 12818 12819 12820 12821 12822 12823 12824 12825 12826 12827 12828 12829 12830 12831 12832 12833 12834 12835 |
# File 'lib/models/porcelain.rb', line 12801 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
12769 12770 12771 |
# File 'lib/models/porcelain.rb', line 12769 def bind_interface @bind_interface end |
#database ⇒ Object
Oracle service name to connect to
12771 12772 12773 |
# File 'lib/models/porcelain.rb', line 12771 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12773 12774 12775 |
# File 'lib/models/porcelain.rb', line 12773 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12775 12776 12777 |
# File 'lib/models/porcelain.rb', line 12775 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12777 12778 12779 |
# File 'lib/models/porcelain.rb', line 12777 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12779 12780 12781 |
# File 'lib/models/porcelain.rb', line 12779 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12781 12782 12783 |
# File 'lib/models/porcelain.rb', line 12781 def name @name end |
#password ⇒ Object
The password to authenticate with.
12783 12784 12785 |
# File 'lib/models/porcelain.rb', line 12783 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12785 12786 12787 |
# File 'lib/models/porcelain.rb', line 12785 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
12787 12788 12789 |
# File 'lib/models/porcelain.rb', line 12787 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12789 12790 12791 |
# File 'lib/models/porcelain.rb', line 12789 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12791 12792 12793 |
# File 'lib/models/porcelain.rb', line 12791 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
12793 12794 12795 |
# File 'lib/models/porcelain.rb', line 12793 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12795 12796 12797 |
# File 'lib/models/porcelain.rb', line 12795 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
12797 12798 12799 |
# File 'lib/models/porcelain.rb', line 12797 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
12799 12800 12801 |
# File 'lib/models/porcelain.rb', line 12799 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12837 12838 12839 12840 12841 12842 12843 |
# File 'lib/models/porcelain.rb', line 12837 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |