Class: SDM::OracleNNE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE

Returns a new instance of OracleNNE.



12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
12817
12818
12819
12820
12821
12822
12823
12824
12825
12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
# File 'lib/models/porcelain.rb', line 12802

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12770
12771
12772
# File 'lib/models/porcelain.rb', line 12770

def bind_interface
  @bind_interface
end

#databaseObject

Oracle service name to connect to



12772
12773
12774
# File 'lib/models/porcelain.rb', line 12772

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12774
12775
12776
# File 'lib/models/porcelain.rb', line 12774

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12776
12777
12778
# File 'lib/models/porcelain.rb', line 12776

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12778
12779
12780
# File 'lib/models/porcelain.rb', line 12778

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12780
12781
12782
# File 'lib/models/porcelain.rb', line 12780

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12782
12783
12784
# File 'lib/models/porcelain.rb', line 12782

def name
  @name
end

#passwordObject

The password to authenticate with.



12784
12785
12786
# File 'lib/models/porcelain.rb', line 12784

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12786
12787
12788
# File 'lib/models/porcelain.rb', line 12786

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12788
12789
12790
# File 'lib/models/porcelain.rb', line 12788

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12790
12791
12792
# File 'lib/models/porcelain.rb', line 12790

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12792
12793
12794
# File 'lib/models/porcelain.rb', line 12792

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12794
12795
12796
# File 'lib/models/porcelain.rb', line 12794

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12796
12797
12798
# File 'lib/models/porcelain.rb', line 12796

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



12798
12799
12800
# File 'lib/models/porcelain.rb', line 12798

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



12800
12801
12802
# File 'lib/models/porcelain.rb', line 12800

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12838
12839
12840
12841
12842
12843
12844
# File 'lib/models/porcelain.rb', line 12838

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end