Class: SDM::OracleNNE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE

Returns a new instance of OracleNNE.



12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
12500
12501
12502
12503
12504
12505
12506
12507
12508
12509
12510
12511
12512
12513
12514
12515
12516
12517
# File 'lib/models/porcelain.rb', line 12483

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12451
12452
12453
# File 'lib/models/porcelain.rb', line 12451

def bind_interface
  @bind_interface
end

#databaseObject

Oracle service name to connect to



12453
12454
12455
# File 'lib/models/porcelain.rb', line 12453

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12455
12456
12457
# File 'lib/models/porcelain.rb', line 12455

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12457
12458
12459
# File 'lib/models/porcelain.rb', line 12457

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12459
12460
12461
# File 'lib/models/porcelain.rb', line 12459

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12461
12462
12463
# File 'lib/models/porcelain.rb', line 12461

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12463
12464
12465
# File 'lib/models/porcelain.rb', line 12463

def name
  @name
end

#passwordObject

The password to authenticate with.



12465
12466
12467
# File 'lib/models/porcelain.rb', line 12465

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12467
12468
12469
# File 'lib/models/porcelain.rb', line 12467

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12469
12470
12471
# File 'lib/models/porcelain.rb', line 12469

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12471
12472
12473
# File 'lib/models/porcelain.rb', line 12471

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12473
12474
12475
# File 'lib/models/porcelain.rb', line 12473

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12475
12476
12477
# File 'lib/models/porcelain.rb', line 12475

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12477
12478
12479
# File 'lib/models/porcelain.rb', line 12477

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



12479
12480
12481
# File 'lib/models/porcelain.rb', line 12479

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



12481
12482
12483
# File 'lib/models/porcelain.rb', line 12481

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12519
12520
12521
12522
12523
12524
12525
# File 'lib/models/porcelain.rb', line 12519

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end