Class: SDM::OracleNNE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE

Returns a new instance of OracleNNE.



12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
12432
12433
12434
12435
12436
12437
12438
12439
12440
12441
12442
12443
# File 'lib/models/porcelain.rb', line 12409

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12377
12378
12379
# File 'lib/models/porcelain.rb', line 12377

def bind_interface
  @bind_interface
end

#databaseObject

Oracle service name to connect to



12379
12380
12381
# File 'lib/models/porcelain.rb', line 12379

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12381
12382
12383
# File 'lib/models/porcelain.rb', line 12381

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12383
12384
12385
# File 'lib/models/porcelain.rb', line 12383

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12385
12386
12387
# File 'lib/models/porcelain.rb', line 12385

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12387
12388
12389
# File 'lib/models/porcelain.rb', line 12387

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12389
12390
12391
# File 'lib/models/porcelain.rb', line 12389

def name
  @name
end

#passwordObject

The password to authenticate with.



12391
12392
12393
# File 'lib/models/porcelain.rb', line 12391

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12393
12394
12395
# File 'lib/models/porcelain.rb', line 12393

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12395
12396
12397
# File 'lib/models/porcelain.rb', line 12395

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12397
12398
12399
# File 'lib/models/porcelain.rb', line 12397

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12399
12400
12401
# File 'lib/models/porcelain.rb', line 12399

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12401
12402
12403
# File 'lib/models/porcelain.rb', line 12401

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12403
12404
12405
# File 'lib/models/porcelain.rb', line 12403

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



12405
12406
12407
# File 'lib/models/porcelain.rb', line 12405

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



12407
12408
12409
# File 'lib/models/porcelain.rb', line 12407

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12445
12446
12447
12448
12449
12450
12451
# File 'lib/models/porcelain.rb', line 12445

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end