Class: SDM::OracleNNE
- Inherits:
-
Object
- Object
- SDM::OracleNNE
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ OracleNNE
constructor
A new instance of OracleNNE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ OracleNNE
Returns a new instance of OracleNNE.
10043 10044 10045 10046 10047 10048 10049 10050 10051 10052 10053 10054 10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 |
# File 'lib/models/porcelain.rb', line 10043 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10013 10014 10015 |
# File 'lib/models/porcelain.rb', line 10013 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
10015 10016 10017 |
# File 'lib/models/porcelain.rb', line 10015 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10017 10018 10019 |
# File 'lib/models/porcelain.rb', line 10017 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10019 10020 10021 |
# File 'lib/models/porcelain.rb', line 10019 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10021 10022 10023 |
# File 'lib/models/porcelain.rb', line 10021 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10023 10024 10025 |
# File 'lib/models/porcelain.rb', line 10023 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10025 10026 10027 |
# File 'lib/models/porcelain.rb', line 10025 def name @name end |
#password ⇒ Object
The password to authenticate with.
10027 10028 10029 |
# File 'lib/models/porcelain.rb', line 10027 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10029 10030 10031 |
# File 'lib/models/porcelain.rb', line 10029 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10031 10032 10033 |
# File 'lib/models/porcelain.rb', line 10031 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10033 10034 10035 |
# File 'lib/models/porcelain.rb', line 10033 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10035 10036 10037 |
# File 'lib/models/porcelain.rb', line 10035 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10037 10038 10039 |
# File 'lib/models/porcelain.rb', line 10037 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10039 10040 10041 |
# File 'lib/models/porcelain.rb', line 10039 def @tags end |
#username ⇒ Object
The username to authenticate with.
10041 10042 10043 |
# File 'lib/models/porcelain.rb', line 10041 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10077 10078 10079 10080 10081 10082 10083 |
# File 'lib/models/porcelain.rb', line 10077 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |