Class: SDM::OracleNNE

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OracleNNE is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ OracleNNE

Returns a new instance of OracleNNE.



9808
9809
9810
9811
9812
9813
9814
9815
9816
9817
9818
9819
9820
9821
9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
9840
# File 'lib/models/porcelain.rb', line 9808

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9778
9779
9780
# File 'lib/models/porcelain.rb', line 9778

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9780
9781
9782
# File 'lib/models/porcelain.rb', line 9780

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9782
9783
9784
# File 'lib/models/porcelain.rb', line 9782

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9784
9785
9786
# File 'lib/models/porcelain.rb', line 9784

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9786
9787
9788
# File 'lib/models/porcelain.rb', line 9786

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9788
9789
9790
# File 'lib/models/porcelain.rb', line 9788

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9790
9791
9792
# File 'lib/models/porcelain.rb', line 9790

def name
  @name
end

#passwordObject

The password to authenticate with.



9792
9793
9794
# File 'lib/models/porcelain.rb', line 9792

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9794
9795
9796
# File 'lib/models/porcelain.rb', line 9794

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9796
9797
9798
# File 'lib/models/porcelain.rb', line 9796

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9798
9799
9800
# File 'lib/models/porcelain.rb', line 9798

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9800
9801
9802
# File 'lib/models/porcelain.rb', line 9800

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9802
9803
9804
# File 'lib/models/porcelain.rb', line 9802

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9804
9805
9806
# File 'lib/models/porcelain.rb', line 9804

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9806
9807
9808
# File 'lib/models/porcelain.rb', line 9806

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9842
9843
9844
9845
9846
9847
9848
# File 'lib/models/porcelain.rb', line 9842

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end