Class: SDM::OracleNNE
- Inherits:
-
Object
- Object
- SDM::OracleNNE
- Defined in:
- lib/models/porcelain.rb
Overview
OracleNNE is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ OracleNNE
constructor
A new instance of OracleNNE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ OracleNNE
Returns a new instance of OracleNNE.
9808 9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 9826 9827 9828 9829 9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 |
# File 'lib/models/porcelain.rb', line 9808 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9778 9779 9780 |
# File 'lib/models/porcelain.rb', line 9778 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9780 9781 9782 |
# File 'lib/models/porcelain.rb', line 9780 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9782 9783 9784 |
# File 'lib/models/porcelain.rb', line 9782 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9784 9785 9786 |
# File 'lib/models/porcelain.rb', line 9784 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9786 9787 9788 |
# File 'lib/models/porcelain.rb', line 9786 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9788 9789 9790 |
# File 'lib/models/porcelain.rb', line 9788 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9790 9791 9792 |
# File 'lib/models/porcelain.rb', line 9790 def name @name end |
#password ⇒ Object
The password to authenticate with.
9792 9793 9794 |
# File 'lib/models/porcelain.rb', line 9792 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9794 9795 9796 |
# File 'lib/models/porcelain.rb', line 9794 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9796 9797 9798 |
# File 'lib/models/porcelain.rb', line 9796 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9798 9799 9800 |
# File 'lib/models/porcelain.rb', line 9798 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9800 9801 9802 |
# File 'lib/models/porcelain.rb', line 9800 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9802 9803 9804 |
# File 'lib/models/porcelain.rb', line 9802 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9804 9805 9806 |
# File 'lib/models/porcelain.rb', line 9804 def @tags end |
#username ⇒ Object
The username to authenticate with.
9806 9807 9808 |
# File 'lib/models/porcelain.rb', line 9806 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/models/porcelain.rb', line 9842 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |