Class: SDM::OracleNNE
- Inherits:
-
Object
- Object
- SDM::OracleNNE
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
Oracle service name to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE
constructor
A new instance of OracleNNE.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ OracleNNE
Returns a new instance of OracleNNE.
12482 12483 12484 12485 12486 12487 12488 12489 12490 12491 12492 12493 12494 12495 12496 12497 12498 12499 12500 12501 12502 12503 12504 12505 12506 12507 12508 12509 12510 12511 12512 12513 12514 12515 12516 |
# File 'lib/models/porcelain.rb', line 12482 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
12450 12451 12452 |
# File 'lib/models/porcelain.rb', line 12450 def bind_interface @bind_interface end |
#database ⇒ Object
Oracle service name to connect to
12452 12453 12454 |
# File 'lib/models/porcelain.rb', line 12452 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12454 12455 12456 |
# File 'lib/models/porcelain.rb', line 12454 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12456 12457 12458 |
# File 'lib/models/porcelain.rb', line 12456 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12458 12459 12460 |
# File 'lib/models/porcelain.rb', line 12458 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12460 12461 12462 |
# File 'lib/models/porcelain.rb', line 12460 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
12462 12463 12464 |
# File 'lib/models/porcelain.rb', line 12462 def name @name end |
#password ⇒ Object
The password to authenticate with.
12464 12465 12466 |
# File 'lib/models/porcelain.rb', line 12464 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12466 12467 12468 |
# File 'lib/models/porcelain.rb', line 12466 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
12468 12469 12470 |
# File 'lib/models/porcelain.rb', line 12468 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12470 12471 12472 |
# File 'lib/models/porcelain.rb', line 12470 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12472 12473 12474 |
# File 'lib/models/porcelain.rb', line 12472 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
12474 12475 12476 |
# File 'lib/models/porcelain.rb', line 12474 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12476 12477 12478 |
# File 'lib/models/porcelain.rb', line 12476 def end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
12478 12479 12480 |
# File 'lib/models/porcelain.rb', line 12478 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
12480 12481 12482 |
# File 'lib/models/porcelain.rb', line 12480 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12518 12519 12520 12521 12522 12523 12524 |
# File 'lib/models/porcelain.rb', line 12518 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |