Class: SDM::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, discard_replays: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_config: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, public_key_pem: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization

Returns a new instance of Organization.



13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
13167
13168
13169
13170
13171
13172
13173
13174
13175
13176
13177
13178
13179
13180
13181
13182
13183
13184
13185
13186
13187
13188
13189
13190
13191
13192
13193
13194
13195
13196
13197
13198
13199
13200
13201
13202
13203
13204
13205
13206
13207
13208
13209
13210
13211
13212
13213
13214
13215
13216
13217
13218
13219
13220
# File 'lib/models/porcelain.rb', line 13156

def initialize(
  auth_provider: nil,
  created_at: nil,
  device_trust_enabled: nil,
  device_trust_provider: nil,
  discard_replays: nil,
  enforce_single_session: nil,
  idle_timeout: nil,
  idle_timeout_enabled: nil,
  kind: nil,
  log_config: nil,
  log_local_encoder: nil,
  log_local_format: nil,
  log_local_storage: nil,
  log_remote_encoder: nil,
  log_socket_path: nil,
  log_tcp_address: nil,
  loopback_range: nil,
  mfa_enabled: nil,
  mfa_provider: nil,
  name: nil,
  public_key_pem: nil,
  require_secret_store: nil,
  saml_metadata_url: nil,
  scim_provider: nil,
  sensitive_label: nil,
  session_timeout: nil,
  session_timeout_enabled: nil,
  ssh_certificate_authority_public_key: nil,
  ssh_certificate_authority_updated_at: nil,
  updated_at: nil,
  websites_subdomain: nil
)
  @auth_provider = auth_provider == nil ? "" : auth_provider
  @created_at = created_at == nil ? nil : created_at
  @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled
  @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider
  @discard_replays = discard_replays == nil ? false : discard_replays
  @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session
  @idle_timeout = idle_timeout == nil ? nil : idle_timeout
  @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled
  @kind = kind == nil ? "" : kind
  @log_config = log_config == nil ? nil : log_config
  @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder
  @log_local_format = log_local_format == nil ? "" : log_local_format
  @log_local_storage = log_local_storage == nil ? "" : log_local_storage
  @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder
  @log_socket_path = log_socket_path == nil ? "" : log_socket_path
  @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address
  @loopback_range = loopback_range == nil ? "" : loopback_range
  @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled
  @mfa_provider = mfa_provider == nil ? "" : mfa_provider
  @name = name == nil ? "" : name
  @public_key_pem = public_key_pem == nil ? "" : public_key_pem
  @require_secret_store = require_secret_store == nil ? false : require_secret_store
  @saml_metadata_url =  == nil ? "" : 
  @scim_provider = scim_provider == nil ? "" : scim_provider
  @sensitive_label = sensitive_label == nil ? "" : sensitive_label
  @session_timeout = session_timeout == nil ? nil : session_timeout
  @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled
  @ssh_certificate_authority_public_key = ssh_certificate_authority_public_key == nil ? "" : ssh_certificate_authority_public_key
  @ssh_certificate_authority_updated_at = ssh_certificate_authority_updated_at == nil ? nil : ssh_certificate_authority_updated_at
  @updated_at = updated_at == nil ? nil : updated_at
  @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain
end

Instance Attribute Details

#auth_providerObject

The Organization's authentication provider, one of the AuthProvider constants.



13086
13087
13088
# File 'lib/models/porcelain.rb', line 13086

def auth_provider
  @auth_provider
end

#created_atObject

The time at which the Organization was created.



13088
13089
13090
# File 'lib/models/porcelain.rb', line 13088

def created_at
  @created_at
end

#device_trust_enabledObject

Indicates if the Organization has device trust enabled.



13090
13091
13092
# File 'lib/models/porcelain.rb', line 13090

def device_trust_enabled
  @device_trust_enabled
end

#device_trust_providerObject

The Organization's device trust provider, one of the DeviceTrustProvider constants.



13092
13093
13094
# File 'lib/models/porcelain.rb', line 13092

def device_trust_provider
  @device_trust_provider
end

#discard_replaysObject

Indicates if the Organization should drop replay data for SSH, RDP, and K8s logs. Deprecated: use categories specific log_config.categories.remote_discard_replays instead



13095
13096
13097
# File 'lib/models/porcelain.rb', line 13095

def discard_replays
  @discard_replays
end

#enforce_single_sessionObject

Indicates if the Organization enforces a single session per user for the CLI and AdminUI.



13097
13098
13099
# File 'lib/models/porcelain.rb', line 13097

def enforce_single_session
  @enforce_single_session
end

#idle_timeoutObject

The Organization's idle timeout, if enabled.



13099
13100
13101
# File 'lib/models/porcelain.rb', line 13099

def idle_timeout
  @idle_timeout
end

#idle_timeout_enabledObject

Indicates if the Organization has idle timeouts enabled.



13101
13102
13103
# File 'lib/models/porcelain.rb', line 13101

def idle_timeout_enabled
  @idle_timeout_enabled
end

#kindObject

The Organization's type, one of the OrgKind constants.



13103
13104
13105
# File 'lib/models/porcelain.rb', line 13103

def kind
  @kind
end

#log_configObject

The Organization's logging settings



13105
13106
13107
# File 'lib/models/porcelain.rb', line 13105

def log_config
  @log_config
end

#log_local_encoderObject

The Organization's local log encryption encoder, one of the LogLocalEncoder constants. Deprecated: use log_config.local_encoder instead



13108
13109
13110
# File 'lib/models/porcelain.rb', line 13108

def log_local_encoder
  @log_local_encoder
end

#log_local_formatObject

The Organization's local log format, one of the LogLocalFormat constants. Deprecated: use log_config.local_format instead



13111
13112
13113
# File 'lib/models/porcelain.rb', line 13111

def log_local_format
  @log_local_format
end

#log_local_storageObject

The Organization's local log storage, one of the LogLocalStorage constants. Deprecated: use log_config.local_storage instead



13114
13115
13116
# File 'lib/models/porcelain.rb', line 13114

def log_local_storage
  @log_local_storage
end

#log_remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants. Deprecated: use categories specific log_config.categories.remote_encoder instead



13117
13118
13119
# File 'lib/models/porcelain.rb', line 13117

def log_remote_encoder
  @log_remote_encoder
end

#log_socket_pathObject

The Organization's socket path for Socket local log storage. Deprecated: use log_config.local_socket_path instead



13120
13121
13122
# File 'lib/models/porcelain.rb', line 13120

def log_socket_path
  @log_socket_path
end

#log_tcp_addressObject

The Organization's TCP address for TCP or Syslog local log storage. Deprecated: use log_config.local_tcp_address instead



13123
13124
13125
# File 'lib/models/porcelain.rb', line 13123

def log_tcp_address
  @log_tcp_address
end

#loopback_rangeObject

The Organization's loopback range.



13125
13126
13127
# File 'lib/models/porcelain.rb', line 13125

def loopback_range
  @loopback_range
end

#mfa_enabledObject

Indicates if the Organization has multi-factor authentication enabled.



13127
13128
13129
# File 'lib/models/porcelain.rb', line 13127

def mfa_enabled
  @mfa_enabled
end

#mfa_providerObject

The Organization's multi-factor authentication provider, one of the MFAProvider constants.



13129
13130
13131
# File 'lib/models/porcelain.rb', line 13129

def mfa_provider
  @mfa_provider
end

#nameObject

The Organization's name.



13131
13132
13133
# File 'lib/models/porcelain.rb', line 13131

def name
  @name
end

#public_key_pemObject

The Organization's public key PEM for encrypting remote logs. Deprecated: use log_config.public_key instead



13134
13135
13136
# File 'lib/models/porcelain.rb', line 13134

def public_key_pem
  @public_key_pem
end

#require_secret_storeObject

Indicates if the Organization requires secret stores.



13136
13137
13138
# File 'lib/models/porcelain.rb', line 13136

def require_secret_store
  @require_secret_store
end

#saml_metadata_urlObject

The Organization's URL for SAML metadata.



13138
13139
13140
# File 'lib/models/porcelain.rb', line 13138

def 
  @saml_metadata_url
end

#scim_providerObject

The Organization's SCIM provider, one of the SCIMProvider constants.



13140
13141
13142
# File 'lib/models/porcelain.rb', line 13140

def scim_provider
  @scim_provider
end

#sensitive_labelObject

The Organization's label for sensitive resources.



13142
13143
13144
# File 'lib/models/porcelain.rb', line 13142

def sensitive_label
  @sensitive_label
end

#session_timeoutObject

The Organization's session timeout, if enabled.



13144
13145
13146
# File 'lib/models/porcelain.rb', line 13144

def session_timeout
  @session_timeout
end

#session_timeout_enabledObject

Indicates if the Organization has session timeouts enabled.



13146
13147
13148
# File 'lib/models/porcelain.rb', line 13146

def session_timeout_enabled
  @session_timeout_enabled
end

#ssh_certificate_authority_public_keyObject

The Organization's SSH certificate authority public key.



13148
13149
13150
# File 'lib/models/porcelain.rb', line 13148

def ssh_certificate_authority_public_key
  @ssh_certificate_authority_public_key
end

#ssh_certificate_authority_updated_atObject

The time at which the Organization's SSH certificate authority was last updated.



13150
13151
13152
# File 'lib/models/porcelain.rb', line 13150

def ssh_certificate_authority_updated_at
  @ssh_certificate_authority_updated_at
end

#updated_atObject

The time at which the Organization was last updated.



13152
13153
13154
# File 'lib/models/porcelain.rb', line 13152

def updated_at
  @updated_at
end

#websites_subdomainObject

The Organization's web site domain.



13154
13155
13156
# File 'lib/models/porcelain.rb', line 13154

def websites_subdomain
  @websites_subdomain
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13222
13223
13224
13225
13226
13227
13228
# File 'lib/models/porcelain.rb', line 13222

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end