Class: SDM::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, discard_replays: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_config: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, public_key_pem: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization

Returns a new instance of Organization.



12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
12931
12932
12933
12934
12935
12936
12937
12938
12939
12940
12941
12942
12943
12944
12945
12946
12947
12948
12949
12950
12951
12952
12953
12954
12955
12956
12957
12958
12959
12960
12961
12962
12963
12964
12965
12966
12967
12968
12969
12970
12971
12972
12973
12974
12975
12976
12977
12978
12979
12980
12981
12982
12983
# File 'lib/models/porcelain.rb', line 12919

def initialize(
  auth_provider: nil,
  created_at: nil,
  device_trust_enabled: nil,
  device_trust_provider: nil,
  discard_replays: nil,
  enforce_single_session: nil,
  idle_timeout: nil,
  idle_timeout_enabled: nil,
  kind: nil,
  log_config: nil,
  log_local_encoder: nil,
  log_local_format: nil,
  log_local_storage: nil,
  log_remote_encoder: nil,
  log_socket_path: nil,
  log_tcp_address: nil,
  loopback_range: nil,
  mfa_enabled: nil,
  mfa_provider: nil,
  name: nil,
  public_key_pem: nil,
  require_secret_store: nil,
  saml_metadata_url: nil,
  scim_provider: nil,
  sensitive_label: nil,
  session_timeout: nil,
  session_timeout_enabled: nil,
  ssh_certificate_authority_public_key: nil,
  ssh_certificate_authority_updated_at: nil,
  updated_at: nil,
  websites_subdomain: nil
)
  @auth_provider = auth_provider == nil ? "" : auth_provider
  @created_at = created_at == nil ? nil : created_at
  @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled
  @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider
  @discard_replays = discard_replays == nil ? false : discard_replays
  @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session
  @idle_timeout = idle_timeout == nil ? nil : idle_timeout
  @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled
  @kind = kind == nil ? "" : kind
  @log_config = log_config == nil ? nil : log_config
  @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder
  @log_local_format = log_local_format == nil ? "" : log_local_format
  @log_local_storage = log_local_storage == nil ? "" : log_local_storage
  @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder
  @log_socket_path = log_socket_path == nil ? "" : log_socket_path
  @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address
  @loopback_range = loopback_range == nil ? "" : loopback_range
  @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled
  @mfa_provider = mfa_provider == nil ? "" : mfa_provider
  @name = name == nil ? "" : name
  @public_key_pem = public_key_pem == nil ? "" : public_key_pem
  @require_secret_store = require_secret_store == nil ? false : require_secret_store
  @saml_metadata_url =  == nil ? "" : 
  @scim_provider = scim_provider == nil ? "" : scim_provider
  @sensitive_label = sensitive_label == nil ? "" : sensitive_label
  @session_timeout = session_timeout == nil ? nil : session_timeout
  @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled
  @ssh_certificate_authority_public_key = ssh_certificate_authority_public_key == nil ? "" : ssh_certificate_authority_public_key
  @ssh_certificate_authority_updated_at = ssh_certificate_authority_updated_at == nil ? nil : ssh_certificate_authority_updated_at
  @updated_at = updated_at == nil ? nil : updated_at
  @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain
end

Instance Attribute Details

#auth_providerObject

The Organization's authentication provider, one of the AuthProvider constants.



12849
12850
12851
# File 'lib/models/porcelain.rb', line 12849

def auth_provider
  @auth_provider
end

#created_atObject

The time at which the Organization was created.



12851
12852
12853
# File 'lib/models/porcelain.rb', line 12851

def created_at
  @created_at
end

#device_trust_enabledObject

Indicates if the Organization has device trust enabled.



12853
12854
12855
# File 'lib/models/porcelain.rb', line 12853

def device_trust_enabled
  @device_trust_enabled
end

#device_trust_providerObject

The Organization's device trust provider, one of the DeviceTrustProvider constants.



12855
12856
12857
# File 'lib/models/porcelain.rb', line 12855

def device_trust_provider
  @device_trust_provider
end

#discard_replaysObject

Indicates if the Organization should drop replay data for SSH, RDP, and K8s logs. Deprecated: use categories specific log_config.categories[].remote_discard_replays instead



12858
12859
12860
# File 'lib/models/porcelain.rb', line 12858

def discard_replays
  @discard_replays
end

#enforce_single_sessionObject

Indicates if the Organization enforces a single session per user for the CLI and AdminUI.



12860
12861
12862
# File 'lib/models/porcelain.rb', line 12860

def enforce_single_session
  @enforce_single_session
end

#idle_timeoutObject

The Organization's idle timeout, if enabled.



12862
12863
12864
# File 'lib/models/porcelain.rb', line 12862

def idle_timeout
  @idle_timeout
end

#idle_timeout_enabledObject

Indicates if the Organization has idle timeouts enabled.



12864
12865
12866
# File 'lib/models/porcelain.rb', line 12864

def idle_timeout_enabled
  @idle_timeout_enabled
end

#kindObject

The Organization's type, one of the OrgKind constants.



12866
12867
12868
# File 'lib/models/porcelain.rb', line 12866

def kind
  @kind
end

#log_configObject

The Organization's logging settings



12868
12869
12870
# File 'lib/models/porcelain.rb', line 12868

def log_config
  @log_config
end

#log_local_encoderObject

The Organization's local log encryption encoder, one of the LogLocalEncoder constants. Deprecated: use log_config.local_encoder instead



12871
12872
12873
# File 'lib/models/porcelain.rb', line 12871

def log_local_encoder
  @log_local_encoder
end

#log_local_formatObject

The Organization's local log format, one of the LogLocalFormat constants. Deprecated: use log_config.local_format instead



12874
12875
12876
# File 'lib/models/porcelain.rb', line 12874

def log_local_format
  @log_local_format
end

#log_local_storageObject

The Organization's local log storage, one of the LogLocalStorage constants. Deprecated: use log_config.local_storage instead



12877
12878
12879
# File 'lib/models/porcelain.rb', line 12877

def log_local_storage
  @log_local_storage
end

#log_remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants. Deprecated: use categories specific log_config.categories[].remote_encoder instead



12880
12881
12882
# File 'lib/models/porcelain.rb', line 12880

def log_remote_encoder
  @log_remote_encoder
end

#log_socket_pathObject

The Organization's socket path for Socket local log storage. Deprecated: use log_config.local_socket_path instead



12883
12884
12885
# File 'lib/models/porcelain.rb', line 12883

def log_socket_path
  @log_socket_path
end

#log_tcp_addressObject

The Organization's TCP address for TCP or Syslog local log storage. Deprecated: use log_config.local_tcp_address instead



12886
12887
12888
# File 'lib/models/porcelain.rb', line 12886

def log_tcp_address
  @log_tcp_address
end

#loopback_rangeObject

The Organization's loopback range.



12888
12889
12890
# File 'lib/models/porcelain.rb', line 12888

def loopback_range
  @loopback_range
end

#mfa_enabledObject

Indicates if the Organization has multi-factor authentication enabled.



12890
12891
12892
# File 'lib/models/porcelain.rb', line 12890

def mfa_enabled
  @mfa_enabled
end

#mfa_providerObject

The Organization's multi-factor authentication provider, one of the MFAProvider constants.



12892
12893
12894
# File 'lib/models/porcelain.rb', line 12892

def mfa_provider
  @mfa_provider
end

#nameObject

The Organization's name.



12894
12895
12896
# File 'lib/models/porcelain.rb', line 12894

def name
  @name
end

#public_key_pemObject

The Organization's public key PEM for encrypting remote logs. Deprecated: use log_config.public_key instead



12897
12898
12899
# File 'lib/models/porcelain.rb', line 12897

def public_key_pem
  @public_key_pem
end

#require_secret_storeObject

Indicates if the Organization requires secret stores.



12899
12900
12901
# File 'lib/models/porcelain.rb', line 12899

def require_secret_store
  @require_secret_store
end

#saml_metadata_urlObject

The Organization's URL for SAML metadata.



12901
12902
12903
# File 'lib/models/porcelain.rb', line 12901

def 
  @saml_metadata_url
end

#scim_providerObject

The Organization's SCIM provider, one of the SCIMProvider constants.



12903
12904
12905
# File 'lib/models/porcelain.rb', line 12903

def scim_provider
  @scim_provider
end

#sensitive_labelObject

The Organization's label for sensitive resources.



12905
12906
12907
# File 'lib/models/porcelain.rb', line 12905

def sensitive_label
  @sensitive_label
end

#session_timeoutObject

The Organization's session timeout, if enabled.



12907
12908
12909
# File 'lib/models/porcelain.rb', line 12907

def session_timeout
  @session_timeout
end

#session_timeout_enabledObject

Indicates if the Organization has session timeouts enabled.



12909
12910
12911
# File 'lib/models/porcelain.rb', line 12909

def session_timeout_enabled
  @session_timeout_enabled
end

#ssh_certificate_authority_public_keyObject

The Organization's SSH certificate authority public key.



12911
12912
12913
# File 'lib/models/porcelain.rb', line 12911

def ssh_certificate_authority_public_key
  @ssh_certificate_authority_public_key
end

#ssh_certificate_authority_updated_atObject

The time at which the Organization's SSH certificate authority was last updated.



12913
12914
12915
# File 'lib/models/porcelain.rb', line 12913

def ssh_certificate_authority_updated_at
  @ssh_certificate_authority_updated_at
end

#updated_atObject

The time at which the Organization was last updated.



12915
12916
12917
# File 'lib/models/porcelain.rb', line 12915

def updated_at
  @updated_at
end

#websites_subdomainObject

The Organization's web site domain.



12917
12918
12919
# File 'lib/models/porcelain.rb', line 12917

def websites_subdomain
  @websites_subdomain
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12985
12986
12987
12988
12989
12990
12991
# File 'lib/models/porcelain.rb', line 12985

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end