Class: SDM::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, discard_replays: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_config: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, public_key_pem: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization

Returns a new instance of Organization.



12228
12229
12230
12231
12232
12233
12234
12235
12236
12237
12238
12239
12240
12241
12242
12243
12244
12245
12246
12247
12248
12249
12250
12251
12252
12253
12254
12255
12256
12257
12258
12259
12260
12261
12262
12263
12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
12290
12291
12292
# File 'lib/models/porcelain.rb', line 12228

def initialize(
  auth_provider: nil,
  created_at: nil,
  device_trust_enabled: nil,
  device_trust_provider: nil,
  discard_replays: nil,
  enforce_single_session: nil,
  idle_timeout: nil,
  idle_timeout_enabled: nil,
  kind: nil,
  log_config: nil,
  log_local_encoder: nil,
  log_local_format: nil,
  log_local_storage: nil,
  log_remote_encoder: nil,
  log_socket_path: nil,
  log_tcp_address: nil,
  loopback_range: nil,
  mfa_enabled: nil,
  mfa_provider: nil,
  name: nil,
  public_key_pem: nil,
  require_secret_store: nil,
  saml_metadata_url: nil,
  scim_provider: nil,
  sensitive_label: nil,
  session_timeout: nil,
  session_timeout_enabled: nil,
  ssh_certificate_authority_public_key: nil,
  ssh_certificate_authority_updated_at: nil,
  updated_at: nil,
  websites_subdomain: nil
)
  @auth_provider = auth_provider == nil ? "" : auth_provider
  @created_at = created_at == nil ? nil : created_at
  @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled
  @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider
  @discard_replays = discard_replays == nil ? false : discard_replays
  @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session
  @idle_timeout = idle_timeout == nil ? nil : idle_timeout
  @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled
  @kind = kind == nil ? "" : kind
  @log_config = log_config == nil ? nil : log_config
  @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder
  @log_local_format = log_local_format == nil ? "" : log_local_format
  @log_local_storage = log_local_storage == nil ? "" : log_local_storage
  @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder
  @log_socket_path = log_socket_path == nil ? "" : log_socket_path
  @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address
  @loopback_range = loopback_range == nil ? "" : loopback_range
  @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled
  @mfa_provider = mfa_provider == nil ? "" : mfa_provider
  @name = name == nil ? "" : name
  @public_key_pem = public_key_pem == nil ? "" : public_key_pem
  @require_secret_store = require_secret_store == nil ? false : require_secret_store
  @saml_metadata_url =  == nil ? "" : 
  @scim_provider = scim_provider == nil ? "" : scim_provider
  @sensitive_label = sensitive_label == nil ? "" : sensitive_label
  @session_timeout = session_timeout == nil ? nil : session_timeout
  @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled
  @ssh_certificate_authority_public_key = ssh_certificate_authority_public_key == nil ? "" : ssh_certificate_authority_public_key
  @ssh_certificate_authority_updated_at = ssh_certificate_authority_updated_at == nil ? nil : ssh_certificate_authority_updated_at
  @updated_at = updated_at == nil ? nil : updated_at
  @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain
end

Instance Attribute Details

#auth_providerObject

The Organization's authentication provider, one of the AuthProvider constants.



12158
12159
12160
# File 'lib/models/porcelain.rb', line 12158

def auth_provider
  @auth_provider
end

#created_atObject

The time at which the Organization was created.



12160
12161
12162
# File 'lib/models/porcelain.rb', line 12160

def created_at
  @created_at
end

#device_trust_enabledObject

Indicates if the Organization has device trust enabled.



12162
12163
12164
# File 'lib/models/porcelain.rb', line 12162

def device_trust_enabled
  @device_trust_enabled
end

#device_trust_providerObject

The Organization's device trust provider, one of the DeviceTrustProvider constants.



12164
12165
12166
# File 'lib/models/porcelain.rb', line 12164

def device_trust_provider
  @device_trust_provider
end

#discard_replaysObject

Indicates if the Organization should drop replay data for SSH, RDP, and K8s logs. Deprecated: use categories specific log_config.categories[].remote_discard_replays instead



12167
12168
12169
# File 'lib/models/porcelain.rb', line 12167

def discard_replays
  @discard_replays
end

#enforce_single_sessionObject

Indicates if the Organization enforces a single session per user for the CLI and AdminUI.



12169
12170
12171
# File 'lib/models/porcelain.rb', line 12169

def enforce_single_session
  @enforce_single_session
end

#idle_timeoutObject

The Organization's idle timeout, if enabled.



12171
12172
12173
# File 'lib/models/porcelain.rb', line 12171

def idle_timeout
  @idle_timeout
end

#idle_timeout_enabledObject

Indicates if the Organization has idle timeouts enabled.



12173
12174
12175
# File 'lib/models/porcelain.rb', line 12173

def idle_timeout_enabled
  @idle_timeout_enabled
end

#kindObject

The Organization's type, one of the OrgKind constants.



12175
12176
12177
# File 'lib/models/porcelain.rb', line 12175

def kind
  @kind
end

#log_configObject

The Organization's logging settings



12177
12178
12179
# File 'lib/models/porcelain.rb', line 12177

def log_config
  @log_config
end

#log_local_encoderObject

The Organization's local log encryption encoder, one of the LogLocalEncoder constants. Deprecated: use log_config.local_encoder instead



12180
12181
12182
# File 'lib/models/porcelain.rb', line 12180

def log_local_encoder
  @log_local_encoder
end

#log_local_formatObject

The Organization's local log format, one of the LogLocalFormat constants. Deprecated: use log_config.local_format instead



12183
12184
12185
# File 'lib/models/porcelain.rb', line 12183

def log_local_format
  @log_local_format
end

#log_local_storageObject

The Organization's local log storage, one of the LogLocalStorage constants. Deprecated: use log_config.local_storage instead



12186
12187
12188
# File 'lib/models/porcelain.rb', line 12186

def log_local_storage
  @log_local_storage
end

#log_remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants. Deprecated: use categories specific log_config.categories[].remote_encoder instead



12189
12190
12191
# File 'lib/models/porcelain.rb', line 12189

def log_remote_encoder
  @log_remote_encoder
end

#log_socket_pathObject

The Organization's socket path for Socket local log storage. Deprecated: use log_config.local_socket_path instead



12192
12193
12194
# File 'lib/models/porcelain.rb', line 12192

def log_socket_path
  @log_socket_path
end

#log_tcp_addressObject

The Organization's TCP address for TCP or Syslog local log storage. Deprecated: use log_config.local_tcp_address instead



12195
12196
12197
# File 'lib/models/porcelain.rb', line 12195

def log_tcp_address
  @log_tcp_address
end

#loopback_rangeObject

The Organization's loopback range.



12197
12198
12199
# File 'lib/models/porcelain.rb', line 12197

def loopback_range
  @loopback_range
end

#mfa_enabledObject

Indicates if the Organization has multi-factor authentication enabled.



12199
12200
12201
# File 'lib/models/porcelain.rb', line 12199

def mfa_enabled
  @mfa_enabled
end

#mfa_providerObject

The Organization's multi-factor authentication provider, one of the MFAProvider constants.



12201
12202
12203
# File 'lib/models/porcelain.rb', line 12201

def mfa_provider
  @mfa_provider
end

#nameObject

The Organization's name.



12203
12204
12205
# File 'lib/models/porcelain.rb', line 12203

def name
  @name
end

#public_key_pemObject

The Organization's public key PEM for encrypting remote logs. Deprecated: use log_config.public_key instead



12206
12207
12208
# File 'lib/models/porcelain.rb', line 12206

def public_key_pem
  @public_key_pem
end

#require_secret_storeObject

Indicates if the Organization requires secret stores.



12208
12209
12210
# File 'lib/models/porcelain.rb', line 12208

def require_secret_store
  @require_secret_store
end

#saml_metadata_urlObject

The Organization's URL for SAML metadata.



12210
12211
12212
# File 'lib/models/porcelain.rb', line 12210

def 
  @saml_metadata_url
end

#scim_providerObject

The Organization's SCIM provider, one of the SCIMProvider constants.



12212
12213
12214
# File 'lib/models/porcelain.rb', line 12212

def scim_provider
  @scim_provider
end

#sensitive_labelObject

The Organization's label for sensitive resources.



12214
12215
12216
# File 'lib/models/porcelain.rb', line 12214

def sensitive_label
  @sensitive_label
end

#session_timeoutObject

The Organization's session timeout, if enabled.



12216
12217
12218
# File 'lib/models/porcelain.rb', line 12216

def session_timeout
  @session_timeout
end

#session_timeout_enabledObject

Indicates if the Organization has session timeouts enabled.



12218
12219
12220
# File 'lib/models/porcelain.rb', line 12218

def session_timeout_enabled
  @session_timeout_enabled
end

#ssh_certificate_authority_public_keyObject

The Organization's SSH certificate authority public key.



12220
12221
12222
# File 'lib/models/porcelain.rb', line 12220

def ssh_certificate_authority_public_key
  @ssh_certificate_authority_public_key
end

#ssh_certificate_authority_updated_atObject

The time at which the Organization's SSH certificate authority was last updated.



12222
12223
12224
# File 'lib/models/porcelain.rb', line 12222

def ssh_certificate_authority_updated_at
  @ssh_certificate_authority_updated_at
end

#updated_atObject

The time at which the Organization was last updated.



12224
12225
12226
# File 'lib/models/porcelain.rb', line 12224

def updated_at
  @updated_at
end

#websites_subdomainObject

The Organization's web site domain.



12226
12227
12228
# File 'lib/models/porcelain.rb', line 12226

def websites_subdomain
  @websites_subdomain
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12294
12295
12296
12297
12298
12299
12300
# File 'lib/models/porcelain.rb', line 12294

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end