Class: SDM::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, discard_replays: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_config: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, public_key_pem: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization

Returns a new instance of Organization.



11353
11354
11355
11356
11357
11358
11359
11360
11361
11362
11363
11364
11365
11366
11367
11368
11369
11370
11371
11372
11373
11374
11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
# File 'lib/models/porcelain.rb', line 11353

def initialize(
  auth_provider: nil,
  created_at: nil,
  device_trust_enabled: nil,
  device_trust_provider: nil,
  discard_replays: nil,
  enforce_single_session: nil,
  idle_timeout: nil,
  idle_timeout_enabled: nil,
  kind: nil,
  log_config: nil,
  log_local_encoder: nil,
  log_local_format: nil,
  log_local_storage: nil,
  log_remote_encoder: nil,
  log_socket_path: nil,
  log_tcp_address: nil,
  loopback_range: nil,
  mfa_enabled: nil,
  mfa_provider: nil,
  name: nil,
  public_key_pem: nil,
  require_secret_store: nil,
  saml_metadata_url: nil,
  scim_provider: nil,
  sensitive_label: nil,
  session_timeout: nil,
  session_timeout_enabled: nil,
  ssh_certificate_authority_public_key: nil,
  ssh_certificate_authority_updated_at: nil,
  updated_at: nil,
  websites_subdomain: nil
)
  @auth_provider = auth_provider == nil ? "" : auth_provider
  @created_at = created_at == nil ? nil : created_at
  @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled
  @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider
  @discard_replays = discard_replays == nil ? false : discard_replays
  @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session
  @idle_timeout = idle_timeout == nil ? nil : idle_timeout
  @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled
  @kind = kind == nil ? "" : kind
  @log_config = log_config == nil ? nil : log_config
  @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder
  @log_local_format = log_local_format == nil ? "" : log_local_format
  @log_local_storage = log_local_storage == nil ? "" : log_local_storage
  @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder
  @log_socket_path = log_socket_path == nil ? "" : log_socket_path
  @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address
  @loopback_range = loopback_range == nil ? "" : loopback_range
  @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled
  @mfa_provider = mfa_provider == nil ? "" : mfa_provider
  @name = name == nil ? "" : name
  @public_key_pem = public_key_pem == nil ? "" : public_key_pem
  @require_secret_store = require_secret_store == nil ? false : require_secret_store
  @saml_metadata_url =  == nil ? "" : 
  @scim_provider = scim_provider == nil ? "" : scim_provider
  @sensitive_label = sensitive_label == nil ? "" : sensitive_label
  @session_timeout = session_timeout == nil ? nil : session_timeout
  @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled
  @ssh_certificate_authority_public_key = ssh_certificate_authority_public_key == nil ? "" : ssh_certificate_authority_public_key
  @ssh_certificate_authority_updated_at = ssh_certificate_authority_updated_at == nil ? nil : ssh_certificate_authority_updated_at
  @updated_at = updated_at == nil ? nil : updated_at
  @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain
end

Instance Attribute Details

#auth_providerObject

The Organization's authentication provider, one of the AuthProvider constants.



11283
11284
11285
# File 'lib/models/porcelain.rb', line 11283

def auth_provider
  @auth_provider
end

#created_atObject

The time at which the Organization was created.



11285
11286
11287
# File 'lib/models/porcelain.rb', line 11285

def created_at
  @created_at
end

#device_trust_enabledObject

Indicates if the Organization has device trust enabled.



11287
11288
11289
# File 'lib/models/porcelain.rb', line 11287

def device_trust_enabled
  @device_trust_enabled
end

#device_trust_providerObject

The Organization's device trust provider, one of the DeviceTrustProvider constants.



11289
11290
11291
# File 'lib/models/porcelain.rb', line 11289

def device_trust_provider
  @device_trust_provider
end

#discard_replaysObject

Indicates if the Organization should drop replay data for SSH, RDP, and K8s logs. Deprecated: use categories specific log_config.categories[].remote_discard_replays instead



11292
11293
11294
# File 'lib/models/porcelain.rb', line 11292

def discard_replays
  @discard_replays
end

#enforce_single_sessionObject

Indicates if the Organization enforces a single session per user for the CLI and AdminUI.



11294
11295
11296
# File 'lib/models/porcelain.rb', line 11294

def enforce_single_session
  @enforce_single_session
end

#idle_timeoutObject

The Organization's idle timeout, if enabled.



11296
11297
11298
# File 'lib/models/porcelain.rb', line 11296

def idle_timeout
  @idle_timeout
end

#idle_timeout_enabledObject

Indicates if the Organization has idle timeouts enabled.



11298
11299
11300
# File 'lib/models/porcelain.rb', line 11298

def idle_timeout_enabled
  @idle_timeout_enabled
end

#kindObject

The Organization's type, one of the OrgKind constants.



11300
11301
11302
# File 'lib/models/porcelain.rb', line 11300

def kind
  @kind
end

#log_configObject

The Organization's logging settings



11302
11303
11304
# File 'lib/models/porcelain.rb', line 11302

def log_config
  @log_config
end

#log_local_encoderObject

The Organization's local log encryption encoder, one of the LogLocalEncoder constants. Deprecated: use log_config.local_encoder instead



11305
11306
11307
# File 'lib/models/porcelain.rb', line 11305

def log_local_encoder
  @log_local_encoder
end

#log_local_formatObject

The Organization's local log format, one of the LogLocalFormat constants. Deprecated: use log_config.local_format instead



11308
11309
11310
# File 'lib/models/porcelain.rb', line 11308

def log_local_format
  @log_local_format
end

#log_local_storageObject

The Organization's local log storage, one of the LogLocalStorage constants. Deprecated: use log_config.local_storage instead



11311
11312
11313
# File 'lib/models/porcelain.rb', line 11311

def log_local_storage
  @log_local_storage
end

#log_remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants. Deprecated: use categories specific log_config.categories[].remote_encoder instead



11314
11315
11316
# File 'lib/models/porcelain.rb', line 11314

def log_remote_encoder
  @log_remote_encoder
end

#log_socket_pathObject

The Organization's socket path for Socket local log storage. Deprecated: use log_config.local_socket_path instead



11317
11318
11319
# File 'lib/models/porcelain.rb', line 11317

def log_socket_path
  @log_socket_path
end

#log_tcp_addressObject

The Organization's TCP address for TCP or Syslog local log storage. Deprecated: use log_config.local_tcp_address instead



11320
11321
11322
# File 'lib/models/porcelain.rb', line 11320

def log_tcp_address
  @log_tcp_address
end

#loopback_rangeObject

The Organization's loopback range.



11322
11323
11324
# File 'lib/models/porcelain.rb', line 11322

def loopback_range
  @loopback_range
end

#mfa_enabledObject

Indicates if the Organization has multi-factor authentication enabled.



11324
11325
11326
# File 'lib/models/porcelain.rb', line 11324

def mfa_enabled
  @mfa_enabled
end

#mfa_providerObject

The Organization's multi-factor authentication provider, one of the MFAProvider constants.



11326
11327
11328
# File 'lib/models/porcelain.rb', line 11326

def mfa_provider
  @mfa_provider
end

#nameObject

The Organization's name.



11328
11329
11330
# File 'lib/models/porcelain.rb', line 11328

def name
  @name
end

#public_key_pemObject

The Organization's public key PEM for encrypting remote logs. Deprecated: use log_config.public_key instead



11331
11332
11333
# File 'lib/models/porcelain.rb', line 11331

def public_key_pem
  @public_key_pem
end

#require_secret_storeObject

Indicates if the Organization requires secret stores.



11333
11334
11335
# File 'lib/models/porcelain.rb', line 11333

def require_secret_store
  @require_secret_store
end

#saml_metadata_urlObject

The Organization's URL for SAML metadata.



11335
11336
11337
# File 'lib/models/porcelain.rb', line 11335

def 
  @saml_metadata_url
end

#scim_providerObject

The Organization's SCIM provider, one of the SCIMProvider constants.



11337
11338
11339
# File 'lib/models/porcelain.rb', line 11337

def scim_provider
  @scim_provider
end

#sensitive_labelObject

The Organization's label for sensitive resources.



11339
11340
11341
# File 'lib/models/porcelain.rb', line 11339

def sensitive_label
  @sensitive_label
end

#session_timeoutObject

The Organization's session timeout, if enabled.



11341
11342
11343
# File 'lib/models/porcelain.rb', line 11341

def session_timeout
  @session_timeout
end

#session_timeout_enabledObject

Indicates if the Organization has session timeouts enabled.



11343
11344
11345
# File 'lib/models/porcelain.rb', line 11343

def session_timeout_enabled
  @session_timeout_enabled
end

#ssh_certificate_authority_public_keyObject

The Organization's SSH certificate authority public key.



11345
11346
11347
# File 'lib/models/porcelain.rb', line 11345

def ssh_certificate_authority_public_key
  @ssh_certificate_authority_public_key
end

#ssh_certificate_authority_updated_atObject

The time at which the Organization's SSH certificate authority was last updated.



11347
11348
11349
# File 'lib/models/porcelain.rb', line 11347

def ssh_certificate_authority_updated_at
  @ssh_certificate_authority_updated_at
end

#updated_atObject

The time at which the Organization was last updated.



11349
11350
11351
# File 'lib/models/porcelain.rb', line 11349

def updated_at
  @updated_at
end

#websites_subdomainObject

The Organization's web site domain.



11351
11352
11353
# File 'lib/models/porcelain.rb', line 11351

def websites_subdomain
  @websites_subdomain
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11419
11420
11421
11422
11423
11424
11425
# File 'lib/models/porcelain.rb', line 11419

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end