Class: SDM::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, discard_replays: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, public_key_pem: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization

Returns a new instance of Organization.



10148
10149
10150
10151
10152
10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
10174
10175
10176
10177
10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
10191
10192
10193
10194
10195
10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
# File 'lib/models/porcelain.rb', line 10148

def initialize(
  auth_provider: nil,
  created_at: nil,
  device_trust_enabled: nil,
  device_trust_provider: nil,
  discard_replays: nil,
  enforce_single_session: nil,
  idle_timeout: nil,
  idle_timeout_enabled: nil,
  kind: nil,
  log_local_encoder: nil,
  log_local_format: nil,
  log_local_storage: nil,
  log_remote_encoder: nil,
  log_socket_path: nil,
  log_tcp_address: nil,
  loopback_range: nil,
  mfa_enabled: nil,
  mfa_provider: nil,
  name: nil,
  public_key_pem: nil,
  require_secret_store: nil,
  saml_metadata_url: nil,
  scim_provider: nil,
  sensitive_label: nil,
  session_timeout: nil,
  session_timeout_enabled: nil,
  ssh_certificate_authority_public_key: nil,
  ssh_certificate_authority_updated_at: nil,
  updated_at: nil,
  websites_subdomain: nil
)
  @auth_provider = auth_provider == nil ? "" : auth_provider
  @created_at = created_at == nil ? nil : created_at
  @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled
  @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider
  @discard_replays = discard_replays == nil ? false : discard_replays
  @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session
  @idle_timeout = idle_timeout == nil ? nil : idle_timeout
  @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled
  @kind = kind == nil ? "" : kind
  @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder
  @log_local_format = log_local_format == nil ? "" : log_local_format
  @log_local_storage = log_local_storage == nil ? "" : log_local_storage
  @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder
  @log_socket_path = log_socket_path == nil ? "" : log_socket_path
  @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address
  @loopback_range = loopback_range == nil ? "" : loopback_range
  @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled
  @mfa_provider = mfa_provider == nil ? "" : mfa_provider
  @name = name == nil ? "" : name
  @public_key_pem = public_key_pem == nil ? "" : public_key_pem
  @require_secret_store = require_secret_store == nil ? false : require_secret_store
  @saml_metadata_url =  == nil ? "" : 
  @scim_provider = scim_provider == nil ? "" : scim_provider
  @sensitive_label = sensitive_label == nil ? "" : sensitive_label
  @session_timeout = session_timeout == nil ? nil : session_timeout
  @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled
  @ssh_certificate_authority_public_key = ssh_certificate_authority_public_key == nil ? "" : ssh_certificate_authority_public_key
  @ssh_certificate_authority_updated_at = ssh_certificate_authority_updated_at == nil ? nil : ssh_certificate_authority_updated_at
  @updated_at = updated_at == nil ? nil : updated_at
  @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain
end

Instance Attribute Details

#auth_providerObject

The Organization's authentication provider, one of the AuthProvider constants.



10088
10089
10090
# File 'lib/models/porcelain.rb', line 10088

def auth_provider
  @auth_provider
end

#created_atObject

The time at which the Organization was created.



10090
10091
10092
# File 'lib/models/porcelain.rb', line 10090

def created_at
  @created_at
end

#device_trust_enabledObject

Indicates if the Organization has device trust enabled.



10092
10093
10094
# File 'lib/models/porcelain.rb', line 10092

def device_trust_enabled
  @device_trust_enabled
end

#device_trust_providerObject

The Organization's device trust provider, one of the DeviceTrustProvider constants.



10094
10095
10096
# File 'lib/models/porcelain.rb', line 10094

def device_trust_provider
  @device_trust_provider
end

#discard_replaysObject

Indicates if the Organization should drop replay data for SSH, RDP, and K8s logs.



10096
10097
10098
# File 'lib/models/porcelain.rb', line 10096

def discard_replays
  @discard_replays
end

#enforce_single_sessionObject

Indicates if the Organization enforces a single session per user for the CLI and AdminUI.



10098
10099
10100
# File 'lib/models/porcelain.rb', line 10098

def enforce_single_session
  @enforce_single_session
end

#idle_timeoutObject

The Organization's idle timeout, if enabled.



10100
10101
10102
# File 'lib/models/porcelain.rb', line 10100

def idle_timeout
  @idle_timeout
end

#idle_timeout_enabledObject

Indicates if the Organization has idle timeouts enabled.



10102
10103
10104
# File 'lib/models/porcelain.rb', line 10102

def idle_timeout_enabled
  @idle_timeout_enabled
end

#kindObject

The Organization's type, one of the OrgKind constants.



10104
10105
10106
# File 'lib/models/porcelain.rb', line 10104

def kind
  @kind
end

#log_local_encoderObject

The Organization's local log encryption encoder, one of the LogLocalEncoder constants.



10106
10107
10108
# File 'lib/models/porcelain.rb', line 10106

def log_local_encoder
  @log_local_encoder
end

#log_local_formatObject

The Organization's local log format, one of the LogLocalFormat constants.



10108
10109
10110
# File 'lib/models/porcelain.rb', line 10108

def log_local_format
  @log_local_format
end

#log_local_storageObject

The Organization's local log storage, one of the LogLocalStorage constants.



10110
10111
10112
# File 'lib/models/porcelain.rb', line 10110

def log_local_storage
  @log_local_storage
end

#log_remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.



10112
10113
10114
# File 'lib/models/porcelain.rb', line 10112

def log_remote_encoder
  @log_remote_encoder
end

#log_socket_pathObject

The Organization's socket path for Socket local log storage.



10114
10115
10116
# File 'lib/models/porcelain.rb', line 10114

def log_socket_path
  @log_socket_path
end

#log_tcp_addressObject

The Organization's TCP address for TCP or Syslog local log storage.



10116
10117
10118
# File 'lib/models/porcelain.rb', line 10116

def log_tcp_address
  @log_tcp_address
end

#loopback_rangeObject

The Organization's loopback range.



10118
10119
10120
# File 'lib/models/porcelain.rb', line 10118

def loopback_range
  @loopback_range
end

#mfa_enabledObject

Indicates if the Organization has multi-factor authentication enabled.



10120
10121
10122
# File 'lib/models/porcelain.rb', line 10120

def mfa_enabled
  @mfa_enabled
end

#mfa_providerObject

The Organization's multi-factor authentication provider, one of the MFAProvider constants.



10122
10123
10124
# File 'lib/models/porcelain.rb', line 10122

def mfa_provider
  @mfa_provider
end

#nameObject

The Organization's name.



10124
10125
10126
# File 'lib/models/porcelain.rb', line 10124

def name
  @name
end

#public_key_pemObject

The Organization's public key PEM for encrypting remote logs.



10126
10127
10128
# File 'lib/models/porcelain.rb', line 10126

def public_key_pem
  @public_key_pem
end

#require_secret_storeObject

Indicates if the Organization requires secret stores.



10128
10129
10130
# File 'lib/models/porcelain.rb', line 10128

def require_secret_store
  @require_secret_store
end

#saml_metadata_urlObject

The Organization's URL for SAML metadata.



10130
10131
10132
# File 'lib/models/porcelain.rb', line 10130

def 
  @saml_metadata_url
end

#scim_providerObject

The Organization's SCIM provider, one of the SCIMProvider constants.



10132
10133
10134
# File 'lib/models/porcelain.rb', line 10132

def scim_provider
  @scim_provider
end

#sensitive_labelObject

The Organization's label for sensitive resources.



10134
10135
10136
# File 'lib/models/porcelain.rb', line 10134

def sensitive_label
  @sensitive_label
end

#session_timeoutObject

The Organization's session timeout, if enabled.



10136
10137
10138
# File 'lib/models/porcelain.rb', line 10136

def session_timeout
  @session_timeout
end

#session_timeout_enabledObject

Indicates if the Organization has session timeouts enabled.



10138
10139
10140
# File 'lib/models/porcelain.rb', line 10138

def session_timeout_enabled
  @session_timeout_enabled
end

#ssh_certificate_authority_public_keyObject

The Organization's SSH certificate authority public key.



10140
10141
10142
# File 'lib/models/porcelain.rb', line 10140

def ssh_certificate_authority_public_key
  @ssh_certificate_authority_public_key
end

#ssh_certificate_authority_updated_atObject

The time at which the Organization's SSH certificate authority was last updated.



10142
10143
10144
# File 'lib/models/porcelain.rb', line 10142

def ssh_certificate_authority_updated_at
  @ssh_certificate_authority_updated_at
end

#updated_atObject

The time at which the Organization was last updated.



10144
10145
10146
# File 'lib/models/porcelain.rb', line 10144

def updated_at
  @updated_at
end

#websites_subdomainObject

The Organization's web site domain.



10146
10147
10148
# File 'lib/models/porcelain.rb', line 10146

def websites_subdomain
  @websites_subdomain
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10212
10213
10214
10215
10216
10217
10218
# File 'lib/models/porcelain.rb', line 10212

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end