Class: SDM::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization

Returns a new instance of Organization.



9977
9978
9979
9980
9981
9982
9983
9984
9985
9986
9987
9988
9989
9990
9991
9992
9993
9994
9995
9996
9997
9998
9999
10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
10027
10028
10029
10030
10031
10032
10033
10034
10035
# File 'lib/models/porcelain.rb', line 9977

def initialize(
  auth_provider: nil,
  created_at: nil,
  device_trust_enabled: nil,
  device_trust_provider: nil,
  enforce_single_session: nil,
  idle_timeout: nil,
  idle_timeout_enabled: nil,
  kind: nil,
  log_local_encoder: nil,
  log_local_format: nil,
  log_local_storage: nil,
  log_remote_encoder: nil,
  log_socket_path: nil,
  log_tcp_address: nil,
  loopback_range: nil,
  mfa_enabled: nil,
  mfa_provider: nil,
  name: nil,
  require_secret_store: nil,
  saml_metadata_url: nil,
  scim_provider: nil,
  sensitive_label: nil,
  session_timeout: nil,
  session_timeout_enabled: nil,
  ssh_certificate_authority_public_key: nil,
  ssh_certificate_authority_updated_at: nil,
  updated_at: nil,
  websites_subdomain: nil
)
  @auth_provider = auth_provider == nil ? "" : auth_provider
  @created_at = created_at == nil ? nil : created_at
  @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled
  @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider
  @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session
  @idle_timeout = idle_timeout == nil ? nil : idle_timeout
  @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled
  @kind = kind == nil ? "" : kind
  @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder
  @log_local_format = log_local_format == nil ? "" : log_local_format
  @log_local_storage = log_local_storage == nil ? "" : log_local_storage
  @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder
  @log_socket_path = log_socket_path == nil ? "" : log_socket_path
  @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address
  @loopback_range = loopback_range == nil ? "" : loopback_range
  @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled
  @mfa_provider = mfa_provider == nil ? "" : mfa_provider
  @name = name == nil ? "" : name
  @require_secret_store = require_secret_store == nil ? false : require_secret_store
  @saml_metadata_url =  == nil ? "" : 
  @scim_provider = scim_provider == nil ? "" : scim_provider
  @sensitive_label = sensitive_label == nil ? "" : sensitive_label
  @session_timeout = session_timeout == nil ? nil : session_timeout
  @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled
  @ssh_certificate_authority_public_key = ssh_certificate_authority_public_key == nil ? "" : ssh_certificate_authority_public_key
  @ssh_certificate_authority_updated_at = ssh_certificate_authority_updated_at == nil ? nil : ssh_certificate_authority_updated_at
  @updated_at = updated_at == nil ? nil : updated_at
  @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain
end

Instance Attribute Details

#auth_providerObject

The Organization's authentication provider, one of the AuthProvider constants.



9921
9922
9923
# File 'lib/models/porcelain.rb', line 9921

def auth_provider
  @auth_provider
end

#created_atObject

The time at which the Organization was created.



9923
9924
9925
# File 'lib/models/porcelain.rb', line 9923

def created_at
  @created_at
end

#device_trust_enabledObject

Indicates if the Organization has device trust enabled.



9925
9926
9927
# File 'lib/models/porcelain.rb', line 9925

def device_trust_enabled
  @device_trust_enabled
end

#device_trust_providerObject

The Organization's device trust provider, one of the DeviceTrustProvider constants.



9927
9928
9929
# File 'lib/models/porcelain.rb', line 9927

def device_trust_provider
  @device_trust_provider
end

#enforce_single_sessionObject

Indicates if the Organization enforces a single session per user for the CLI and AdminUI.



9929
9930
9931
# File 'lib/models/porcelain.rb', line 9929

def enforce_single_session
  @enforce_single_session
end

#idle_timeoutObject

The Organization's idle timeout, if enabled.



9931
9932
9933
# File 'lib/models/porcelain.rb', line 9931

def idle_timeout
  @idle_timeout
end

#idle_timeout_enabledObject

Indicates if the Organization has idle timeouts enabled.



9933
9934
9935
# File 'lib/models/porcelain.rb', line 9933

def idle_timeout_enabled
  @idle_timeout_enabled
end

#kindObject

The Organization's type, one of the OrgKind constants.



9935
9936
9937
# File 'lib/models/porcelain.rb', line 9935

def kind
  @kind
end

#log_local_encoderObject

The Organization's local log encryption encoder, one of the LogLocalEncoder constants.



9937
9938
9939
# File 'lib/models/porcelain.rb', line 9937

def log_local_encoder
  @log_local_encoder
end

#log_local_formatObject

The Organization's local log format, one of the LogLocalFormat constants.



9939
9940
9941
# File 'lib/models/porcelain.rb', line 9939

def log_local_format
  @log_local_format
end

#log_local_storageObject

The Organization's local log storage, one of the LogLocalStorage constants.



9941
9942
9943
# File 'lib/models/porcelain.rb', line 9941

def log_local_storage
  @log_local_storage
end

#log_remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.



9943
9944
9945
# File 'lib/models/porcelain.rb', line 9943

def log_remote_encoder
  @log_remote_encoder
end

#log_socket_pathObject

The Organization's socket path for Socket local log storage.



9945
9946
9947
# File 'lib/models/porcelain.rb', line 9945

def log_socket_path
  @log_socket_path
end

#log_tcp_addressObject

The Organization's TCP address for TCP or Syslog local log storage.



9947
9948
9949
# File 'lib/models/porcelain.rb', line 9947

def log_tcp_address
  @log_tcp_address
end

#loopback_rangeObject

The Organization's loopback range.



9949
9950
9951
# File 'lib/models/porcelain.rb', line 9949

def loopback_range
  @loopback_range
end

#mfa_enabledObject

Indicates if the Organization has multi-factor authentication enabled.



9951
9952
9953
# File 'lib/models/porcelain.rb', line 9951

def mfa_enabled
  @mfa_enabled
end

#mfa_providerObject

The Organization's multi-factor authentication provider, one of the MFAProvider constants.



9953
9954
9955
# File 'lib/models/porcelain.rb', line 9953

def mfa_provider
  @mfa_provider
end

#nameObject

The Organization's name.



9955
9956
9957
# File 'lib/models/porcelain.rb', line 9955

def name
  @name
end

#require_secret_storeObject

Indicates if the Organization requires secret stores.



9957
9958
9959
# File 'lib/models/porcelain.rb', line 9957

def require_secret_store
  @require_secret_store
end

#saml_metadata_urlObject

The Organization's URL for SAML metadata.



9959
9960
9961
# File 'lib/models/porcelain.rb', line 9959

def 
  @saml_metadata_url
end

#scim_providerObject

The Organization's SCIM provider, one of the SCIMProvider constants.



9961
9962
9963
# File 'lib/models/porcelain.rb', line 9961

def scim_provider
  @scim_provider
end

#sensitive_labelObject

The Organization's label for sensitive resources.



9963
9964
9965
# File 'lib/models/porcelain.rb', line 9963

def sensitive_label
  @sensitive_label
end

#session_timeoutObject

The Organization's session timeout, if enabled.



9965
9966
9967
# File 'lib/models/porcelain.rb', line 9965

def session_timeout
  @session_timeout
end

#session_timeout_enabledObject

Indicates if the Organization has session timeouts enabled.



9967
9968
9969
# File 'lib/models/porcelain.rb', line 9967

def session_timeout_enabled
  @session_timeout_enabled
end

#ssh_certificate_authority_public_keyObject

The Organization's SSH certificate authority public key.



9969
9970
9971
# File 'lib/models/porcelain.rb', line 9969

def ssh_certificate_authority_public_key
  @ssh_certificate_authority_public_key
end

#ssh_certificate_authority_updated_atObject

The time at which the Organization's SSH certificate authority was last updated.



9971
9972
9973
# File 'lib/models/porcelain.rb', line 9971

def ssh_certificate_authority_updated_at
  @ssh_certificate_authority_updated_at
end

#updated_atObject

The time at which the Organization was last updated.



9973
9974
9975
# File 'lib/models/porcelain.rb', line 9973

def updated_at
  @updated_at
end

#websites_subdomainObject

The Organization's web site domain.



9975
9976
9977
# File 'lib/models/porcelain.rb', line 9975

def websites_subdomain
  @websites_subdomain
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10037
10038
10039
10040
10041
10042
10043
# File 'lib/models/porcelain.rb', line 10037

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end