Class: SDM::Organization
- Inherits:
-
Object
- Object
- SDM::Organization
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_provider ⇒ Object
The Organization's authentication provider, one of the AuthProvider constants.
-
#created_at ⇒ Object
The time at which the Organization was created.
-
#device_trust_enabled ⇒ Object
Indicates if the Organization has device trust enabled.
-
#device_trust_provider ⇒ Object
The Organization's device trust provider, one of the DeviceTrustProvider constants.
-
#enforce_single_session ⇒ Object
Indicates if the Organization enforces a single session per user for the CLI and AdminUI.
-
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
-
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
-
#kind ⇒ Object
The Organization's type, one of the OrgKind constants.
-
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
-
#log_local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
-
#log_local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
-
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.
-
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
-
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
-
#loopback_range ⇒ Object
The Organization's loopback range.
-
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
-
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, one of the MFAProvider constants.
-
#name ⇒ Object
The Organization's name.
-
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
-
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
-
#scim_provider ⇒ Object
The Organization's SCIM provider, one of the SCIMProvider constants.
-
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
-
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
-
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
-
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
-
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
-
#updated_at ⇒ Object
The time at which the Organization was last updated.
-
#websites_subdomain ⇒ Object
The Organization's web site domain.
Instance Method Summary collapse
-
#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
constructor
A new instance of Organization.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
Returns a new instance of Organization.
8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 8941 8942 8943 8944 8945 8946 8947 8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 8964 8965 8966 8967 8968 8969 8970 8971 8972 |
# File 'lib/models/porcelain.rb', line 8914 def initialize( auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil ) @auth_provider = auth_provider == nil ? "" : auth_provider @created_at = created_at == nil ? nil : created_at @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session @idle_timeout = idle_timeout == nil ? nil : idle_timeout @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled @kind = kind == nil ? "" : kind @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder @log_local_format = log_local_format == nil ? "" : log_local_format @log_local_storage = log_local_storage == nil ? "" : log_local_storage @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder @log_socket_path = log_socket_path == nil ? "" : log_socket_path @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address @loopback_range = loopback_range == nil ? "" : loopback_range @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled @mfa_provider = mfa_provider == nil ? "" : mfa_provider @name = name == nil ? "" : name @require_secret_store = require_secret_store == nil ? false : require_secret_store @saml_metadata_url = == nil ? "" : @scim_provider = scim_provider == nil ? "" : scim_provider @sensitive_label = sensitive_label == nil ? "" : sensitive_label @session_timeout = session_timeout == nil ? nil : session_timeout @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled @ssh_certificate_authority_public_key = == nil ? "" : @ssh_certificate_authority_updated_at = == nil ? nil : @updated_at = updated_at == nil ? nil : updated_at @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain end |
Instance Attribute Details
#auth_provider ⇒ Object
The Organization's authentication provider, one of the AuthProvider constants.
8858 8859 8860 |
# File 'lib/models/porcelain.rb', line 8858 def auth_provider @auth_provider end |
#created_at ⇒ Object
The time at which the Organization was created.
8860 8861 8862 |
# File 'lib/models/porcelain.rb', line 8860 def created_at @created_at end |
#device_trust_enabled ⇒ Object
Indicates if the Organization has device trust enabled.
8862 8863 8864 |
# File 'lib/models/porcelain.rb', line 8862 def device_trust_enabled @device_trust_enabled end |
#device_trust_provider ⇒ Object
The Organization's device trust provider, one of the DeviceTrustProvider constants.
8864 8865 8866 |
# File 'lib/models/porcelain.rb', line 8864 def device_trust_provider @device_trust_provider end |
#enforce_single_session ⇒ Object
Indicates if the Organization enforces a single session per user for the CLI and AdminUI.
8866 8867 8868 |
# File 'lib/models/porcelain.rb', line 8866 def enforce_single_session @enforce_single_session end |
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
8868 8869 8870 |
# File 'lib/models/porcelain.rb', line 8868 def idle_timeout @idle_timeout end |
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
8870 8871 8872 |
# File 'lib/models/porcelain.rb', line 8870 def idle_timeout_enabled @idle_timeout_enabled end |
#kind ⇒ Object
The Organization's type, one of the OrgKind constants.
8872 8873 8874 |
# File 'lib/models/porcelain.rb', line 8872 def kind @kind end |
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
8874 8875 8876 |
# File 'lib/models/porcelain.rb', line 8874 def log_local_encoder @log_local_encoder end |
#log_local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
8876 8877 8878 |
# File 'lib/models/porcelain.rb', line 8876 def log_local_format @log_local_format end |
#log_local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
8878 8879 8880 |
# File 'lib/models/porcelain.rb', line 8878 def log_local_storage @log_local_storage end |
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.
8880 8881 8882 |
# File 'lib/models/porcelain.rb', line 8880 def log_remote_encoder @log_remote_encoder end |
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
8882 8883 8884 |
# File 'lib/models/porcelain.rb', line 8882 def log_socket_path @log_socket_path end |
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
8884 8885 8886 |
# File 'lib/models/porcelain.rb', line 8884 def log_tcp_address @log_tcp_address end |
#loopback_range ⇒ Object
The Organization's loopback range.
8886 8887 8888 |
# File 'lib/models/porcelain.rb', line 8886 def loopback_range @loopback_range end |
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
8888 8889 8890 |
# File 'lib/models/porcelain.rb', line 8888 def mfa_enabled @mfa_enabled end |
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, one of the MFAProvider constants.
8890 8891 8892 |
# File 'lib/models/porcelain.rb', line 8890 def mfa_provider @mfa_provider end |
#name ⇒ Object
The Organization's name.
8892 8893 8894 |
# File 'lib/models/porcelain.rb', line 8892 def name @name end |
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
8894 8895 8896 |
# File 'lib/models/porcelain.rb', line 8894 def require_secret_store @require_secret_store end |
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
8896 8897 8898 |
# File 'lib/models/porcelain.rb', line 8896 def @saml_metadata_url end |
#scim_provider ⇒ Object
The Organization's SCIM provider, one of the SCIMProvider constants.
8898 8899 8900 |
# File 'lib/models/porcelain.rb', line 8898 def scim_provider @scim_provider end |
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
8900 8901 8902 |
# File 'lib/models/porcelain.rb', line 8900 def sensitive_label @sensitive_label end |
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
8902 8903 8904 |
# File 'lib/models/porcelain.rb', line 8902 def session_timeout @session_timeout end |
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
8904 8905 8906 |
# File 'lib/models/porcelain.rb', line 8904 def session_timeout_enabled @session_timeout_enabled end |
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
8906 8907 8908 |
# File 'lib/models/porcelain.rb', line 8906 def @ssh_certificate_authority_public_key end |
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
8908 8909 8910 |
# File 'lib/models/porcelain.rb', line 8908 def @ssh_certificate_authority_updated_at end |
#updated_at ⇒ Object
The time at which the Organization was last updated.
8910 8911 8912 |
# File 'lib/models/porcelain.rb', line 8910 def updated_at @updated_at end |
#websites_subdomain ⇒ Object
The Organization's web site domain.
8912 8913 8914 |
# File 'lib/models/porcelain.rb', line 8912 def websites_subdomain @websites_subdomain end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8974 8975 8976 8977 8978 8979 8980 |
# File 'lib/models/porcelain.rb', line 8974 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |