Class: SDM::Organization

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization

Returns a new instance of Organization.



8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
8859
8860
8861
8862
8863
8864
8865
8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
8890
8891
8892
8893
8894
8895
8896
8897
# File 'lib/models/porcelain.rb', line 8839

def initialize(
  auth_provider: nil,
  created_at: nil,
  device_trust_enabled: nil,
  device_trust_provider: nil,
  enforce_single_session: nil,
  idle_timeout: nil,
  idle_timeout_enabled: nil,
  kind: nil,
  log_local_encoder: nil,
  log_local_format: nil,
  log_local_storage: nil,
  log_remote_encoder: nil,
  log_socket_path: nil,
  log_tcp_address: nil,
  loopback_range: nil,
  mfa_enabled: nil,
  mfa_provider: nil,
  name: nil,
  require_secret_store: nil,
  saml_metadata_url: nil,
  scim_provider: nil,
  sensitive_label: nil,
  session_timeout: nil,
  session_timeout_enabled: nil,
  ssh_certificate_authority_public_key: nil,
  ssh_certificate_authority_updated_at: nil,
  updated_at: nil,
  websites_subdomain: nil
)
  @auth_provider = auth_provider == nil ? "" : auth_provider
  @created_at = created_at == nil ? nil : created_at
  @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled
  @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider
  @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session
  @idle_timeout = idle_timeout == nil ? nil : idle_timeout
  @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled
  @kind = kind == nil ? "" : kind
  @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder
  @log_local_format = log_local_format == nil ? "" : log_local_format
  @log_local_storage = log_local_storage == nil ? "" : log_local_storage
  @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder
  @log_socket_path = log_socket_path == nil ? "" : log_socket_path
  @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address
  @loopback_range = loopback_range == nil ? "" : loopback_range
  @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled
  @mfa_provider = mfa_provider == nil ? "" : mfa_provider
  @name = name == nil ? "" : name
  @require_secret_store = require_secret_store == nil ? false : require_secret_store
  @saml_metadata_url =  == nil ? "" : 
  @scim_provider = scim_provider == nil ? "" : scim_provider
  @sensitive_label = sensitive_label == nil ? "" : sensitive_label
  @session_timeout = session_timeout == nil ? nil : session_timeout
  @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled
  @ssh_certificate_authority_public_key = ssh_certificate_authority_public_key == nil ? "" : ssh_certificate_authority_public_key
  @ssh_certificate_authority_updated_at = ssh_certificate_authority_updated_at == nil ? nil : ssh_certificate_authority_updated_at
  @updated_at = updated_at == nil ? nil : updated_at
  @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain
end

Instance Attribute Details

#auth_providerObject

The Organization's authentication provider, one of the AuthProvider constants.



8783
8784
8785
# File 'lib/models/porcelain.rb', line 8783

def auth_provider
  @auth_provider
end

#created_atObject

The time at which the Organization was created.



8785
8786
8787
# File 'lib/models/porcelain.rb', line 8785

def created_at
  @created_at
end

#device_trust_enabledObject

Indicates if the Organization has device trust enabled.



8787
8788
8789
# File 'lib/models/porcelain.rb', line 8787

def device_trust_enabled
  @device_trust_enabled
end

#device_trust_providerObject

The Organization's device trust provider, one of the DeviceTrustProvider constants.



8789
8790
8791
# File 'lib/models/porcelain.rb', line 8789

def device_trust_provider
  @device_trust_provider
end

#enforce_single_sessionObject

Indicates if the Organization enforces a single session per user for the CLI and AdminUI.



8791
8792
8793
# File 'lib/models/porcelain.rb', line 8791

def enforce_single_session
  @enforce_single_session
end

#idle_timeoutObject

The Organization's idle timeout, if enabled.



8793
8794
8795
# File 'lib/models/porcelain.rb', line 8793

def idle_timeout
  @idle_timeout
end

#idle_timeout_enabledObject

Indicates if the Organization has idle timeouts enabled.



8795
8796
8797
# File 'lib/models/porcelain.rb', line 8795

def idle_timeout_enabled
  @idle_timeout_enabled
end

#kindObject

The Organization's type, one of the OrgKind constants.



8797
8798
8799
# File 'lib/models/porcelain.rb', line 8797

def kind
  @kind
end

#log_local_encoderObject

The Organization's local log encryption encoder, one of the LogLocalEncoder constants.



8799
8800
8801
# File 'lib/models/porcelain.rb', line 8799

def log_local_encoder
  @log_local_encoder
end

#log_local_formatObject

The Organization's local log format, one of the LogLocalFormat constants.



8801
8802
8803
# File 'lib/models/porcelain.rb', line 8801

def log_local_format
  @log_local_format
end

#log_local_storageObject

The Organization's local log storage, one of the LogLocalStorage constants.



8803
8804
8805
# File 'lib/models/porcelain.rb', line 8803

def log_local_storage
  @log_local_storage
end

#log_remote_encoderObject

The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.



8805
8806
8807
# File 'lib/models/porcelain.rb', line 8805

def log_remote_encoder
  @log_remote_encoder
end

#log_socket_pathObject

The Organization's socket path for Socket local log storage.



8807
8808
8809
# File 'lib/models/porcelain.rb', line 8807

def log_socket_path
  @log_socket_path
end

#log_tcp_addressObject

The Organization's TCP address for TCP or Syslog local log storage.



8809
8810
8811
# File 'lib/models/porcelain.rb', line 8809

def log_tcp_address
  @log_tcp_address
end

#loopback_rangeObject

The Organization's loopback range.



8811
8812
8813
# File 'lib/models/porcelain.rb', line 8811

def loopback_range
  @loopback_range
end

#mfa_enabledObject

Indicates if the Organization has multi-factor authentication enabled.



8813
8814
8815
# File 'lib/models/porcelain.rb', line 8813

def mfa_enabled
  @mfa_enabled
end

#mfa_providerObject

The Organization's multi-factor authentication provider, one of the MFAProvider constants.



8815
8816
8817
# File 'lib/models/porcelain.rb', line 8815

def mfa_provider
  @mfa_provider
end

#nameObject

The Organization's name.



8817
8818
8819
# File 'lib/models/porcelain.rb', line 8817

def name
  @name
end

#require_secret_storeObject

Indicates if the Organization requires secret stores.



8819
8820
8821
# File 'lib/models/porcelain.rb', line 8819

def require_secret_store
  @require_secret_store
end

#saml_metadata_urlObject

The Organization's URL for SAML metadata.



8821
8822
8823
# File 'lib/models/porcelain.rb', line 8821

def 
  @saml_metadata_url
end

#scim_providerObject

The Organization's SCIM provider, one of the SCIMProvider constants.



8823
8824
8825
# File 'lib/models/porcelain.rb', line 8823

def scim_provider
  @scim_provider
end

#sensitive_labelObject

The Organization's label for sensitive resources.



8825
8826
8827
# File 'lib/models/porcelain.rb', line 8825

def sensitive_label
  @sensitive_label
end

#session_timeoutObject

The Organization's session timeout, if enabled.



8827
8828
8829
# File 'lib/models/porcelain.rb', line 8827

def session_timeout
  @session_timeout
end

#session_timeout_enabledObject

Indicates if the Organization has session timeouts enabled.



8829
8830
8831
# File 'lib/models/porcelain.rb', line 8829

def session_timeout_enabled
  @session_timeout_enabled
end

#ssh_certificate_authority_public_keyObject

The Organization's SSH certificate authority public key.



8831
8832
8833
# File 'lib/models/porcelain.rb', line 8831

def ssh_certificate_authority_public_key
  @ssh_certificate_authority_public_key
end

#ssh_certificate_authority_updated_atObject

The time at which the Organization's SSH certificate authority was last updated.



8833
8834
8835
# File 'lib/models/porcelain.rb', line 8833

def ssh_certificate_authority_updated_at
  @ssh_certificate_authority_updated_at
end

#updated_atObject

The time at which the Organization was last updated.



8835
8836
8837
# File 'lib/models/porcelain.rb', line 8835

def updated_at
  @updated_at
end

#websites_subdomainObject

The Organization's web site domain.



8837
8838
8839
# File 'lib/models/porcelain.rb', line 8837

def websites_subdomain
  @websites_subdomain
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8899
8900
8901
8902
8903
8904
8905
# File 'lib/models/porcelain.rb', line 8899

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end