Class: SDM::Organization
- Inherits:
-
Object
- Object
- SDM::Organization
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_provider ⇒ Object
The Organization's authentication provider, one of the AuthProvider constants.
-
#created_at ⇒ Object
The time at which the Organization was created.
-
#device_trust_enabled ⇒ Object
Indicates if the Organization has device trust enabled.
-
#device_trust_provider ⇒ Object
The Organization's device trust provider, one of the DeviceTrustProvider constants.
-
#enforce_single_session ⇒ Object
Indicates if the Organization enforces a single session per user for the CLI and AdminUI.
-
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
-
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
-
#kind ⇒ Object
The Organization's type, one of the OrgKind constants.
-
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
-
#log_local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
-
#log_local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
-
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.
-
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
-
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
-
#loopback_range ⇒ Object
The Organization's loopback range.
-
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
-
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, one of the MFAProvider constants.
-
#name ⇒ Object
The Organization's name.
-
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
-
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
-
#scim_provider ⇒ Object
The Organization's SCIM provider, one of the SCIMProvider constants.
-
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
-
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
-
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
-
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
-
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
-
#updated_at ⇒ Object
The time at which the Organization was last updated.
-
#websites_subdomain ⇒ Object
The Organization's web site domain.
Instance Method Summary collapse
-
#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
constructor
A new instance of Organization.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
Returns a new instance of Organization.
8689 8690 8691 8692 8693 8694 8695 8696 8697 8698 8699 8700 8701 8702 8703 8704 8705 8706 8707 8708 8709 8710 8711 8712 8713 8714 8715 8716 8717 8718 8719 8720 8721 8722 8723 8724 8725 8726 8727 8728 8729 8730 8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 |
# File 'lib/models/porcelain.rb', line 8689 def initialize( auth_provider: nil, created_at: nil, device_trust_enabled: nil, device_trust_provider: nil, enforce_single_session: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, loopback_range: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil ) @auth_provider = auth_provider == nil ? "" : auth_provider @created_at = created_at == nil ? nil : created_at @device_trust_enabled = device_trust_enabled == nil ? false : device_trust_enabled @device_trust_provider = device_trust_provider == nil ? "" : device_trust_provider @enforce_single_session = enforce_single_session == nil ? false : enforce_single_session @idle_timeout = idle_timeout == nil ? nil : idle_timeout @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled @kind = kind == nil ? "" : kind @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder @log_local_format = log_local_format == nil ? "" : log_local_format @log_local_storage = log_local_storage == nil ? "" : log_local_storage @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder @log_socket_path = log_socket_path == nil ? "" : log_socket_path @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address @loopback_range = loopback_range == nil ? "" : loopback_range @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled @mfa_provider = mfa_provider == nil ? "" : mfa_provider @name = name == nil ? "" : name @require_secret_store = require_secret_store == nil ? false : require_secret_store @saml_metadata_url = == nil ? "" : @scim_provider = scim_provider == nil ? "" : scim_provider @sensitive_label = sensitive_label == nil ? "" : sensitive_label @session_timeout = session_timeout == nil ? nil : session_timeout @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled @ssh_certificate_authority_public_key = == nil ? "" : @ssh_certificate_authority_updated_at = == nil ? nil : @updated_at = updated_at == nil ? nil : updated_at @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain end |
Instance Attribute Details
#auth_provider ⇒ Object
The Organization's authentication provider, one of the AuthProvider constants.
8633 8634 8635 |
# File 'lib/models/porcelain.rb', line 8633 def auth_provider @auth_provider end |
#created_at ⇒ Object
The time at which the Organization was created.
8635 8636 8637 |
# File 'lib/models/porcelain.rb', line 8635 def created_at @created_at end |
#device_trust_enabled ⇒ Object
Indicates if the Organization has device trust enabled.
8637 8638 8639 |
# File 'lib/models/porcelain.rb', line 8637 def device_trust_enabled @device_trust_enabled end |
#device_trust_provider ⇒ Object
The Organization's device trust provider, one of the DeviceTrustProvider constants.
8639 8640 8641 |
# File 'lib/models/porcelain.rb', line 8639 def device_trust_provider @device_trust_provider end |
#enforce_single_session ⇒ Object
Indicates if the Organization enforces a single session per user for the CLI and AdminUI.
8641 8642 8643 |
# File 'lib/models/porcelain.rb', line 8641 def enforce_single_session @enforce_single_session end |
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
8643 8644 8645 |
# File 'lib/models/porcelain.rb', line 8643 def idle_timeout @idle_timeout end |
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
8645 8646 8647 |
# File 'lib/models/porcelain.rb', line 8645 def idle_timeout_enabled @idle_timeout_enabled end |
#kind ⇒ Object
The Organization's type, one of the OrgKind constants.
8647 8648 8649 |
# File 'lib/models/porcelain.rb', line 8647 def kind @kind end |
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder, one of the LogLocalEncoder constants.
8649 8650 8651 |
# File 'lib/models/porcelain.rb', line 8649 def log_local_encoder @log_local_encoder end |
#log_local_format ⇒ Object
The Organization's local log format, one of the LogLocalFormat constants.
8651 8652 8653 |
# File 'lib/models/porcelain.rb', line 8651 def log_local_format @log_local_format end |
#log_local_storage ⇒ Object
The Organization's local log storage, one of the LogLocalStorage constants.
8653 8654 8655 |
# File 'lib/models/porcelain.rb', line 8653 def log_local_storage @log_local_storage end |
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder, one of the LogRemoteEncoder constants.
8655 8656 8657 |
# File 'lib/models/porcelain.rb', line 8655 def log_remote_encoder @log_remote_encoder end |
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
8657 8658 8659 |
# File 'lib/models/porcelain.rb', line 8657 def log_socket_path @log_socket_path end |
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
8659 8660 8661 |
# File 'lib/models/porcelain.rb', line 8659 def log_tcp_address @log_tcp_address end |
#loopback_range ⇒ Object
The Organization's loopback range.
8661 8662 8663 |
# File 'lib/models/porcelain.rb', line 8661 def loopback_range @loopback_range end |
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
8663 8664 8665 |
# File 'lib/models/porcelain.rb', line 8663 def mfa_enabled @mfa_enabled end |
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, one of the MFAProvider constants.
8665 8666 8667 |
# File 'lib/models/porcelain.rb', line 8665 def mfa_provider @mfa_provider end |
#name ⇒ Object
The Organization's name.
8667 8668 8669 |
# File 'lib/models/porcelain.rb', line 8667 def name @name end |
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
8669 8670 8671 |
# File 'lib/models/porcelain.rb', line 8669 def require_secret_store @require_secret_store end |
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
8671 8672 8673 |
# File 'lib/models/porcelain.rb', line 8671 def @saml_metadata_url end |
#scim_provider ⇒ Object
The Organization's SCIM provider, one of the SCIMProvider constants.
8673 8674 8675 |
# File 'lib/models/porcelain.rb', line 8673 def scim_provider @scim_provider end |
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
8675 8676 8677 |
# File 'lib/models/porcelain.rb', line 8675 def sensitive_label @sensitive_label end |
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
8677 8678 8679 |
# File 'lib/models/porcelain.rb', line 8677 def session_timeout @session_timeout end |
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
8679 8680 8681 |
# File 'lib/models/porcelain.rb', line 8679 def session_timeout_enabled @session_timeout_enabled end |
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
8681 8682 8683 |
# File 'lib/models/porcelain.rb', line 8681 def @ssh_certificate_authority_public_key end |
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
8683 8684 8685 |
# File 'lib/models/porcelain.rb', line 8683 def @ssh_certificate_authority_updated_at end |
#updated_at ⇒ Object
The time at which the Organization was last updated.
8685 8686 8687 |
# File 'lib/models/porcelain.rb', line 8685 def updated_at @updated_at end |
#websites_subdomain ⇒ Object
The Organization's web site domain.
8687 8688 8689 |
# File 'lib/models/porcelain.rb', line 8687 def websites_subdomain @websites_subdomain end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8749 8750 8751 8752 8753 8754 8755 |
# File 'lib/models/porcelain.rb', line 8749 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |