Class: SDM::Organization
- Inherits:
-
Object
- Object
- SDM::Organization
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_provider ⇒ Object
The Organization's authentication provider.
-
#created_at ⇒ Object
The time at which the Organization was created.
-
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
-
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
-
#kind ⇒ Object
The Organization's type.
-
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder.
-
#log_local_format ⇒ Object
The Organization's local log format.
-
#log_local_storage ⇒ Object
The Organization's local log storage.
-
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder.
-
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
-
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
-
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
-
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, if enabled.
-
#name ⇒ Object
The Organization's name.
-
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
-
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
-
#scim_provider ⇒ Object
The Organization's SCIM provider.
-
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
-
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
-
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
-
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
-
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
-
#updated_at ⇒ Object
The time at which the Organization was last updated.
-
#websites_subdomain ⇒ Object
The Organization's web site domain.
Instance Method Summary collapse
-
#initialize(auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
constructor
A new instance of Organization.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
Returns a new instance of Organization.
6120 6121 6122 6123 6124 6125 6126 6127 6128 6129 6130 6131 6132 6133 6134 6135 6136 6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 6167 6168 6169 6170 |
# File 'lib/models/porcelain.rb', line 6120 def initialize( auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil ) @auth_provider = auth_provider == nil ? "" : auth_provider @created_at = created_at == nil ? nil : created_at @idle_timeout = idle_timeout == nil ? nil : idle_timeout @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled @kind = kind == nil ? "" : kind @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder @log_local_format = log_local_format == nil ? "" : log_local_format @log_local_storage = log_local_storage == nil ? "" : log_local_storage @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder @log_socket_path = log_socket_path == nil ? "" : log_socket_path @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled @mfa_provider = mfa_provider == nil ? "" : mfa_provider @name = name == nil ? "" : name @require_secret_store = require_secret_store == nil ? false : require_secret_store @saml_metadata_url = == nil ? "" : @scim_provider = scim_provider == nil ? "" : scim_provider @sensitive_label = sensitive_label == nil ? "" : sensitive_label @session_timeout = session_timeout == nil ? nil : session_timeout @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled @ssh_certificate_authority_public_key = == nil ? "" : @ssh_certificate_authority_updated_at = == nil ? nil : @updated_at = updated_at == nil ? nil : updated_at @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain end |
Instance Attribute Details
#auth_provider ⇒ Object
The Organization's authentication provider.
6072 6073 6074 |
# File 'lib/models/porcelain.rb', line 6072 def auth_provider @auth_provider end |
#created_at ⇒ Object
The time at which the Organization was created.
6074 6075 6076 |
# File 'lib/models/porcelain.rb', line 6074 def created_at @created_at end |
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
6076 6077 6078 |
# File 'lib/models/porcelain.rb', line 6076 def idle_timeout @idle_timeout end |
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
6078 6079 6080 |
# File 'lib/models/porcelain.rb', line 6078 def idle_timeout_enabled @idle_timeout_enabled end |
#kind ⇒ Object
The Organization's type.
6080 6081 6082 |
# File 'lib/models/porcelain.rb', line 6080 def kind @kind end |
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder.
6082 6083 6084 |
# File 'lib/models/porcelain.rb', line 6082 def log_local_encoder @log_local_encoder end |
#log_local_format ⇒ Object
The Organization's local log format.
6084 6085 6086 |
# File 'lib/models/porcelain.rb', line 6084 def log_local_format @log_local_format end |
#log_local_storage ⇒ Object
The Organization's local log storage.
6086 6087 6088 |
# File 'lib/models/porcelain.rb', line 6086 def log_local_storage @log_local_storage end |
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder.
6088 6089 6090 |
# File 'lib/models/porcelain.rb', line 6088 def log_remote_encoder @log_remote_encoder end |
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
6090 6091 6092 |
# File 'lib/models/porcelain.rb', line 6090 def log_socket_path @log_socket_path end |
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
6092 6093 6094 |
# File 'lib/models/porcelain.rb', line 6092 def log_tcp_address @log_tcp_address end |
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
6094 6095 6096 |
# File 'lib/models/porcelain.rb', line 6094 def mfa_enabled @mfa_enabled end |
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, if enabled.
6096 6097 6098 |
# File 'lib/models/porcelain.rb', line 6096 def mfa_provider @mfa_provider end |
#name ⇒ Object
The Organization's name.
6098 6099 6100 |
# File 'lib/models/porcelain.rb', line 6098 def name @name end |
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
6100 6101 6102 |
# File 'lib/models/porcelain.rb', line 6100 def require_secret_store @require_secret_store end |
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
6102 6103 6104 |
# File 'lib/models/porcelain.rb', line 6102 def @saml_metadata_url end |
#scim_provider ⇒ Object
The Organization's SCIM provider.
6104 6105 6106 |
# File 'lib/models/porcelain.rb', line 6104 def scim_provider @scim_provider end |
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
6106 6107 6108 |
# File 'lib/models/porcelain.rb', line 6106 def sensitive_label @sensitive_label end |
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
6108 6109 6110 |
# File 'lib/models/porcelain.rb', line 6108 def session_timeout @session_timeout end |
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
6110 6111 6112 |
# File 'lib/models/porcelain.rb', line 6110 def session_timeout_enabled @session_timeout_enabled end |
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
6112 6113 6114 |
# File 'lib/models/porcelain.rb', line 6112 def @ssh_certificate_authority_public_key end |
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
6114 6115 6116 |
# File 'lib/models/porcelain.rb', line 6114 def @ssh_certificate_authority_updated_at end |
#updated_at ⇒ Object
The time at which the Organization was last updated.
6116 6117 6118 |
# File 'lib/models/porcelain.rb', line 6116 def updated_at @updated_at end |
#websites_subdomain ⇒ Object
The Organization's web site domain.
6118 6119 6120 |
# File 'lib/models/porcelain.rb', line 6118 def websites_subdomain @websites_subdomain end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/models/porcelain.rb', line 6172 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |