Class: SDM::Organization
- Inherits:
-
Object
- Object
- SDM::Organization
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_provider ⇒ Object
The Organization's authentication provider.
-
#created_at ⇒ Object
The time at which the Organization was created.
-
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
-
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
-
#kind ⇒ Object
The Organization's type.
-
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder.
-
#log_local_format ⇒ Object
The Organization's local log format.
-
#log_local_storage ⇒ Object
The Organization's local log storage.
-
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder.
-
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
-
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
-
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
-
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, if enabled.
-
#name ⇒ Object
The Organization's name.
-
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
-
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
-
#scim_provider ⇒ Object
The Organization's SCIM provider.
-
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
-
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
-
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
-
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
-
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
-
#updated_at ⇒ Object
The time at which the Organization was last updated.
-
#websites_subdomain ⇒ Object
The Organization's web site domain.
Instance Method Summary collapse
-
#initialize(auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
constructor
A new instance of Organization.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
Returns a new instance of Organization.
5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 |
# File 'lib/models/porcelain.rb', line 5956 def initialize( auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil ) @auth_provider = auth_provider == nil ? "" : auth_provider @created_at = created_at == nil ? nil : created_at @idle_timeout = idle_timeout == nil ? nil : idle_timeout @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled @kind = kind == nil ? "" : kind @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder @log_local_format = log_local_format == nil ? "" : log_local_format @log_local_storage = log_local_storage == nil ? "" : log_local_storage @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder @log_socket_path = log_socket_path == nil ? "" : log_socket_path @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled @mfa_provider = mfa_provider == nil ? "" : mfa_provider @name = name == nil ? "" : name @require_secret_store = require_secret_store == nil ? false : require_secret_store @saml_metadata_url = == nil ? "" : @scim_provider = scim_provider == nil ? "" : scim_provider @sensitive_label = sensitive_label == nil ? "" : sensitive_label @session_timeout = session_timeout == nil ? nil : session_timeout @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled @ssh_certificate_authority_public_key = == nil ? "" : @ssh_certificate_authority_updated_at = == nil ? nil : @updated_at = updated_at == nil ? nil : updated_at @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain end |
Instance Attribute Details
#auth_provider ⇒ Object
The Organization's authentication provider.
5908 5909 5910 |
# File 'lib/models/porcelain.rb', line 5908 def auth_provider @auth_provider end |
#created_at ⇒ Object
The time at which the Organization was created.
5910 5911 5912 |
# File 'lib/models/porcelain.rb', line 5910 def created_at @created_at end |
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
5912 5913 5914 |
# File 'lib/models/porcelain.rb', line 5912 def idle_timeout @idle_timeout end |
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
5914 5915 5916 |
# File 'lib/models/porcelain.rb', line 5914 def idle_timeout_enabled @idle_timeout_enabled end |
#kind ⇒ Object
The Organization's type.
5916 5917 5918 |
# File 'lib/models/porcelain.rb', line 5916 def kind @kind end |
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder.
5918 5919 5920 |
# File 'lib/models/porcelain.rb', line 5918 def log_local_encoder @log_local_encoder end |
#log_local_format ⇒ Object
The Organization's local log format.
5920 5921 5922 |
# File 'lib/models/porcelain.rb', line 5920 def log_local_format @log_local_format end |
#log_local_storage ⇒ Object
The Organization's local log storage.
5922 5923 5924 |
# File 'lib/models/porcelain.rb', line 5922 def log_local_storage @log_local_storage end |
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder.
5924 5925 5926 |
# File 'lib/models/porcelain.rb', line 5924 def log_remote_encoder @log_remote_encoder end |
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
5926 5927 5928 |
# File 'lib/models/porcelain.rb', line 5926 def log_socket_path @log_socket_path end |
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
5928 5929 5930 |
# File 'lib/models/porcelain.rb', line 5928 def log_tcp_address @log_tcp_address end |
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
5930 5931 5932 |
# File 'lib/models/porcelain.rb', line 5930 def mfa_enabled @mfa_enabled end |
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, if enabled.
5932 5933 5934 |
# File 'lib/models/porcelain.rb', line 5932 def mfa_provider @mfa_provider end |
#name ⇒ Object
The Organization's name.
5934 5935 5936 |
# File 'lib/models/porcelain.rb', line 5934 def name @name end |
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
5936 5937 5938 |
# File 'lib/models/porcelain.rb', line 5936 def require_secret_store @require_secret_store end |
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
5938 5939 5940 |
# File 'lib/models/porcelain.rb', line 5938 def @saml_metadata_url end |
#scim_provider ⇒ Object
The Organization's SCIM provider.
5940 5941 5942 |
# File 'lib/models/porcelain.rb', line 5940 def scim_provider @scim_provider end |
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
5942 5943 5944 |
# File 'lib/models/porcelain.rb', line 5942 def sensitive_label @sensitive_label end |
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
5944 5945 5946 |
# File 'lib/models/porcelain.rb', line 5944 def session_timeout @session_timeout end |
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
5946 5947 5948 |
# File 'lib/models/porcelain.rb', line 5946 def session_timeout_enabled @session_timeout_enabled end |
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
5948 5949 5950 |
# File 'lib/models/porcelain.rb', line 5948 def @ssh_certificate_authority_public_key end |
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
5950 5951 5952 |
# File 'lib/models/porcelain.rb', line 5950 def @ssh_certificate_authority_updated_at end |
#updated_at ⇒ Object
The time at which the Organization was last updated.
5952 5953 5954 |
# File 'lib/models/porcelain.rb', line 5952 def updated_at @updated_at end |
#websites_subdomain ⇒ Object
The Organization's web site domain.
5954 5955 5956 |
# File 'lib/models/porcelain.rb', line 5954 def websites_subdomain @websites_subdomain end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6008 6009 6010 6011 6012 6013 6014 |
# File 'lib/models/porcelain.rb', line 6008 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |