Class: SDM::Organization
- Inherits:
-
Object
- Object
- SDM::Organization
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#auth_provider ⇒ Object
The Organization's authentication provider.
-
#created_at ⇒ Object
The time at which the Organization was created.
-
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
-
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
-
#kind ⇒ Object
The Organization's type.
-
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder.
-
#log_local_format ⇒ Object
The Organization's local log format.
-
#log_local_storage ⇒ Object
The Organization's local log storage.
-
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder.
-
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
-
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
-
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
-
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, if enabled.
-
#name ⇒ Object
The Organization's name.
-
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
-
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
-
#scim_provider ⇒ Object
The Organization's SCIM provider.
-
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
-
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
-
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
-
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
-
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
-
#updated_at ⇒ Object
The time at which the Organization was last updated.
-
#websites_subdomain ⇒ Object
The Organization's web site domain.
Instance Method Summary collapse
-
#initialize(auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
constructor
A new instance of Organization.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil) ⇒ Organization
Returns a new instance of Organization.
5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 5806 5807 5808 5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 5838 5839 5840 5841 5842 5843 5844 5845 |
# File 'lib/models/porcelain.rb', line 5795 def initialize( auth_provider: nil, created_at: nil, idle_timeout: nil, idle_timeout_enabled: nil, kind: nil, log_local_encoder: nil, log_local_format: nil, log_local_storage: nil, log_remote_encoder: nil, log_socket_path: nil, log_tcp_address: nil, mfa_enabled: nil, mfa_provider: nil, name: nil, require_secret_store: nil, saml_metadata_url: nil, scim_provider: nil, sensitive_label: nil, session_timeout: nil, session_timeout_enabled: nil, ssh_certificate_authority_public_key: nil, ssh_certificate_authority_updated_at: nil, updated_at: nil, websites_subdomain: nil ) @auth_provider = auth_provider == nil ? "" : auth_provider @created_at = created_at == nil ? nil : created_at @idle_timeout = idle_timeout == nil ? nil : idle_timeout @idle_timeout_enabled = idle_timeout_enabled == nil ? false : idle_timeout_enabled @kind = kind == nil ? "" : kind @log_local_encoder = log_local_encoder == nil ? "" : log_local_encoder @log_local_format = log_local_format == nil ? "" : log_local_format @log_local_storage = log_local_storage == nil ? "" : log_local_storage @log_remote_encoder = log_remote_encoder == nil ? "" : log_remote_encoder @log_socket_path = log_socket_path == nil ? "" : log_socket_path @log_tcp_address = log_tcp_address == nil ? "" : log_tcp_address @mfa_enabled = mfa_enabled == nil ? false : mfa_enabled @mfa_provider = mfa_provider == nil ? "" : mfa_provider @name = name == nil ? "" : name @require_secret_store = require_secret_store == nil ? false : require_secret_store @saml_metadata_url = == nil ? "" : @scim_provider = scim_provider == nil ? "" : scim_provider @sensitive_label = sensitive_label == nil ? "" : sensitive_label @session_timeout = session_timeout == nil ? nil : session_timeout @session_timeout_enabled = session_timeout_enabled == nil ? false : session_timeout_enabled @ssh_certificate_authority_public_key = == nil ? "" : @ssh_certificate_authority_updated_at = == nil ? nil : @updated_at = updated_at == nil ? nil : updated_at @websites_subdomain = websites_subdomain == nil ? "" : websites_subdomain end |
Instance Attribute Details
#auth_provider ⇒ Object
The Organization's authentication provider.
5747 5748 5749 |
# File 'lib/models/porcelain.rb', line 5747 def auth_provider @auth_provider end |
#created_at ⇒ Object
The time at which the Organization was created.
5749 5750 5751 |
# File 'lib/models/porcelain.rb', line 5749 def created_at @created_at end |
#idle_timeout ⇒ Object
The Organization's idle timeout, if enabled.
5751 5752 5753 |
# File 'lib/models/porcelain.rb', line 5751 def idle_timeout @idle_timeout end |
#idle_timeout_enabled ⇒ Object
Indicates if the Organization has idle timeouts enabled.
5753 5754 5755 |
# File 'lib/models/porcelain.rb', line 5753 def idle_timeout_enabled @idle_timeout_enabled end |
#kind ⇒ Object
The Organization's type.
5755 5756 5757 |
# File 'lib/models/porcelain.rb', line 5755 def kind @kind end |
#log_local_encoder ⇒ Object
The Organization's local log encryption encoder.
5757 5758 5759 |
# File 'lib/models/porcelain.rb', line 5757 def log_local_encoder @log_local_encoder end |
#log_local_format ⇒ Object
The Organization's local log format.
5759 5760 5761 |
# File 'lib/models/porcelain.rb', line 5759 def log_local_format @log_local_format end |
#log_local_storage ⇒ Object
The Organization's local log storage.
5761 5762 5763 |
# File 'lib/models/porcelain.rb', line 5761 def log_local_storage @log_local_storage end |
#log_remote_encoder ⇒ Object
The Organization's remote log encryption encoder.
5763 5764 5765 |
# File 'lib/models/porcelain.rb', line 5763 def log_remote_encoder @log_remote_encoder end |
#log_socket_path ⇒ Object
The Organization's socket path for Socket local log storage.
5765 5766 5767 |
# File 'lib/models/porcelain.rb', line 5765 def log_socket_path @log_socket_path end |
#log_tcp_address ⇒ Object
The Organization's TCP address for TCP or Syslog local log storage.
5767 5768 5769 |
# File 'lib/models/porcelain.rb', line 5767 def log_tcp_address @log_tcp_address end |
#mfa_enabled ⇒ Object
Indicates if the Organization has multi-factor authentication enabled.
5769 5770 5771 |
# File 'lib/models/porcelain.rb', line 5769 def mfa_enabled @mfa_enabled end |
#mfa_provider ⇒ Object
The Organization's multi-factor authentication provider, if enabled.
5771 5772 5773 |
# File 'lib/models/porcelain.rb', line 5771 def mfa_provider @mfa_provider end |
#name ⇒ Object
The Organization's name.
5773 5774 5775 |
# File 'lib/models/porcelain.rb', line 5773 def name @name end |
#require_secret_store ⇒ Object
Indicates if the Organization requires secret stores.
5775 5776 5777 |
# File 'lib/models/porcelain.rb', line 5775 def require_secret_store @require_secret_store end |
#saml_metadata_url ⇒ Object
The Organization's URL for SAML metadata.
5777 5778 5779 |
# File 'lib/models/porcelain.rb', line 5777 def @saml_metadata_url end |
#scim_provider ⇒ Object
The Organization's SCIM provider.
5779 5780 5781 |
# File 'lib/models/porcelain.rb', line 5779 def scim_provider @scim_provider end |
#sensitive_label ⇒ Object
The Organization's label for sensitive resources.
5781 5782 5783 |
# File 'lib/models/porcelain.rb', line 5781 def sensitive_label @sensitive_label end |
#session_timeout ⇒ Object
The Organization's session timeout, if enabled.
5783 5784 5785 |
# File 'lib/models/porcelain.rb', line 5783 def session_timeout @session_timeout end |
#session_timeout_enabled ⇒ Object
Indicates if the Organization has session timeouts enabled.
5785 5786 5787 |
# File 'lib/models/porcelain.rb', line 5785 def session_timeout_enabled @session_timeout_enabled end |
#ssh_certificate_authority_public_key ⇒ Object
The Organization's SSH certificate authority public key.
5787 5788 5789 |
# File 'lib/models/porcelain.rb', line 5787 def @ssh_certificate_authority_public_key end |
#ssh_certificate_authority_updated_at ⇒ Object
The time at which the Organization's SSH certificate authority was last updated.
5789 5790 5791 |
# File 'lib/models/porcelain.rb', line 5789 def @ssh_certificate_authority_updated_at end |
#updated_at ⇒ Object
The time at which the Organization was last updated.
5791 5792 5793 |
# File 'lib/models/porcelain.rb', line 5791 def updated_at @updated_at end |
#websites_subdomain ⇒ Object
The Organization's web site domain.
5793 5794 5795 |
# File 'lib/models/porcelain.rb', line 5793 def websites_subdomain @websites_subdomain end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5847 5848 5849 5850 5851 5852 5853 |
# File 'lib/models/porcelain.rb', line 5847 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |