Class: SDM::OrganizationHistoryRecord
- Inherits:
-
Object
- Object
- SDM::OrganizationHistoryRecord
- Defined in:
- lib/models/porcelain.rb
Overview
OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Organization.
-
#organization ⇒ Object
The complete Organization state at this time.
-
#timestamp ⇒ Object
The time at which the Organization state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord
constructor
A new instance of OrganizationHistoryRecord.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord
Returns a new instance of OrganizationHistoryRecord.
13317 13318 13319 13320 13321 13322 13323 13324 13325 |
# File 'lib/models/porcelain.rb', line 13317 def initialize( activity_id: nil, organization: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @organization = organization == nil ? nil : organization @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.
13311 13312 13313 |
# File 'lib/models/porcelain.rb', line 13311 def activity_id @activity_id end |
#organization ⇒ Object
The complete Organization state at this time.
13313 13314 13315 |
# File 'lib/models/porcelain.rb', line 13313 def organization @organization end |
#timestamp ⇒ Object
The time at which the Organization state was recorded.
13315 13316 13317 |
# File 'lib/models/porcelain.rb', line 13315 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13327 13328 13329 13330 13331 13332 13333 |
# File 'lib/models/porcelain.rb', line 13327 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |