Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



13269
13270
13271
13272
13273
13274
13275
13276
13277
# File 'lib/models/porcelain.rb', line 13269

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



13263
13264
13265
# File 'lib/models/porcelain.rb', line 13263

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



13265
13266
13267
# File 'lib/models/porcelain.rb', line 13265

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



13267
13268
13269
# File 'lib/models/porcelain.rb', line 13267

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13279
13280
13281
13282
13283
13284
13285
# File 'lib/models/porcelain.rb', line 13279

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end