Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



13189
13190
13191
13192
13193
13194
13195
13196
13197
# File 'lib/models/porcelain.rb', line 13189

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



13183
13184
13185
# File 'lib/models/porcelain.rb', line 13183

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



13185
13186
13187
# File 'lib/models/porcelain.rb', line 13185

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



13187
13188
13189
# File 'lib/models/porcelain.rb', line 13187

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13199
13200
13201
13202
13203
13204
13205
# File 'lib/models/porcelain.rb', line 13199

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end