Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



12685
12686
12687
12688
12689
12690
12691
12692
12693
# File 'lib/models/porcelain.rb', line 12685

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



12679
12680
12681
# File 'lib/models/porcelain.rb', line 12679

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



12681
12682
12683
# File 'lib/models/porcelain.rb', line 12681

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



12683
12684
12685
# File 'lib/models/porcelain.rb', line 12683

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12695
12696
12697
12698
12699
12700
12701
# File 'lib/models/porcelain.rb', line 12695

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end