Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



12612
12613
12614
12615
12616
12617
12618
12619
12620
# File 'lib/models/porcelain.rb', line 12612

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



12606
12607
12608
# File 'lib/models/porcelain.rb', line 12606

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



12608
12609
12610
# File 'lib/models/porcelain.rb', line 12608

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



12610
12611
12612
# File 'lib/models/porcelain.rb', line 12610

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12622
12623
12624
12625
12626
12627
12628
# File 'lib/models/porcelain.rb', line 12622

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end