Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



9989
9990
9991
9992
9993
9994
9995
9996
9997
# File 'lib/models/porcelain.rb', line 9989

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



9983
9984
9985
# File 'lib/models/porcelain.rb', line 9983

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



9985
9986
9987
# File 'lib/models/porcelain.rb', line 9985

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



9987
9988
9989
# File 'lib/models/porcelain.rb', line 9987

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9999
10000
10001
10002
10003
10004
10005
# File 'lib/models/porcelain.rb', line 9999

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end