Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



9845
9846
9847
9848
9849
9850
9851
9852
9853
# File 'lib/models/porcelain.rb', line 9845

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



9839
9840
9841
# File 'lib/models/porcelain.rb', line 9839

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



9841
9842
9843
# File 'lib/models/porcelain.rb', line 9841

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



9843
9844
9845
# File 'lib/models/porcelain.rb', line 9843

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9855
9856
9857
9858
9859
9860
9861
# File 'lib/models/porcelain.rb', line 9855

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end