Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



8995
8996
8997
8998
8999
9000
9001
9002
9003
# File 'lib/models/porcelain.rb', line 8995

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



8989
8990
8991
# File 'lib/models/porcelain.rb', line 8989

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



8991
8992
8993
# File 'lib/models/porcelain.rb', line 8991

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



8993
8994
8995
# File 'lib/models/porcelain.rb', line 8993

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9005
9006
9007
9008
9009
9010
9011
# File 'lib/models/porcelain.rb', line 9005

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end