Class: SDM::OrganizationHistoryRecord
- Inherits:
-
Object
- Object
- SDM::OrganizationHistoryRecord
- Defined in:
- lib/models/porcelain.rb
Overview
OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Organization.
-
#organization ⇒ Object
The complete Organization state at this time.
-
#timestamp ⇒ Object
The time at which the Organization state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord
constructor
A new instance of OrganizationHistoryRecord.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord
Returns a new instance of OrganizationHistoryRecord.
8919 8920 8921 8922 8923 8924 8925 8926 8927 |
# File 'lib/models/porcelain.rb', line 8919 def initialize( activity_id: nil, organization: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @organization = organization == nil ? nil : organization @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.
8913 8914 8915 |
# File 'lib/models/porcelain.rb', line 8913 def activity_id @activity_id end |
#organization ⇒ Object
The complete Organization state at this time.
8915 8916 8917 |
# File 'lib/models/porcelain.rb', line 8915 def organization @organization end |
#timestamp ⇒ Object
The time at which the Organization state was recorded.
8917 8918 8919 |
# File 'lib/models/porcelain.rb', line 8917 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8929 8930 8931 8932 8933 8934 8935 |
# File 'lib/models/porcelain.rb', line 8929 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |