Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



8840
8841
8842
8843
8844
8845
8846
8847
8848
# File 'lib/models/porcelain.rb', line 8840

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



8834
8835
8836
# File 'lib/models/porcelain.rb', line 8834

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



8836
8837
8838
# File 'lib/models/porcelain.rb', line 8836

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



8838
8839
8840
# File 'lib/models/porcelain.rb', line 8838

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8850
8851
8852
8853
8854
8855
8856
# File 'lib/models/porcelain.rb', line 8850

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end