Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



8088
8089
8090
8091
8092
8093
8094
8095
8096
# File 'lib/models/porcelain.rb', line 8088

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



8082
8083
8084
# File 'lib/models/porcelain.rb', line 8082

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



8084
8085
8086
# File 'lib/models/porcelain.rb', line 8084

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



8086
8087
8088
# File 'lib/models/porcelain.rb', line 8086

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8098
8099
8100
8101
8102
8103
8104
# File 'lib/models/porcelain.rb', line 8098

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end