Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/models/porcelain.rb', line 7763

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



7757
7758
7759
# File 'lib/models/porcelain.rb', line 7757

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



7759
7760
7761
# File 'lib/models/porcelain.rb', line 7759

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



7761
7762
7763
# File 'lib/models/porcelain.rb', line 7761

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7773
7774
7775
7776
7777
7778
7779
# File 'lib/models/porcelain.rb', line 7773

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end