Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



6192
6193
6194
6195
6196
6197
6198
6199
6200
# File 'lib/models/porcelain.rb', line 6192

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



6186
6187
6188
# File 'lib/models/porcelain.rb', line 6186

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



6188
6189
6190
# File 'lib/models/porcelain.rb', line 6188

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



6190
6191
6192
# File 'lib/models/porcelain.rb', line 6190

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6202
6203
6204
6205
6206
6207
6208
# File 'lib/models/porcelain.rb', line 6202

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end