Class: SDM::OrganizationHistoryRecord
- Inherits:
-
Object
- Object
- SDM::OrganizationHistoryRecord
- Defined in:
- lib/models/porcelain.rb
Overview
OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Organization.
-
#organization ⇒ Object
The complete Organization state at this time.
-
#timestamp ⇒ Object
The time at which the Organization state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord
constructor
A new instance of OrganizationHistoryRecord.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord
Returns a new instance of OrganizationHistoryRecord.
6028 6029 6030 6031 6032 6033 6034 6035 6036 |
# File 'lib/models/porcelain.rb', line 6028 def initialize( activity_id: nil, organization: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @organization = organization == nil ? nil : organization @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.
6022 6023 6024 |
# File 'lib/models/porcelain.rb', line 6022 def activity_id @activity_id end |
#organization ⇒ Object
The complete Organization state at this time.
6024 6025 6026 |
# File 'lib/models/porcelain.rb', line 6024 def organization @organization end |
#timestamp ⇒ Object
The time at which the Organization state was recorded.
6026 6027 6028 |
# File 'lib/models/porcelain.rb', line 6026 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6038 6039 6040 6041 6042 6043 6044 |
# File 'lib/models/porcelain.rb', line 6038 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |