Class: SDM::OrganizationHistoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord

Returns a new instance of OrganizationHistoryRecord.



6020
6021
6022
6023
6024
6025
6026
6027
6028
# File 'lib/models/porcelain.rb', line 6020

def initialize(
  activity_id: nil,
  organization: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @organization = organization == nil ? nil : organization
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.



6014
6015
6016
# File 'lib/models/porcelain.rb', line 6014

def activity_id
  @activity_id
end

#organizationObject

The complete Organization state at this time.



6016
6017
6018
# File 'lib/models/porcelain.rb', line 6016

def organization
  @organization
end

#timestampObject

The time at which the Organization state was recorded.



6018
6019
6020
# File 'lib/models/porcelain.rb', line 6018

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6030
6031
6032
6033
6034
6035
6036
# File 'lib/models/porcelain.rb', line 6030

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end