Class: SDM::OrganizationHistoryRecord
- Inherits:
-
Object
- Object
- SDM::OrganizationHistoryRecord
- Defined in:
- lib/models/porcelain.rb
Overview
OrganizationHistoryRecord records the state of an Organization at a given point in time, where every change to an Organization produces an OrganizationHistoryRecord.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Organization.
-
#organization ⇒ Object
The complete Organization state at this time.
-
#timestamp ⇒ Object
The time at which the Organization state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord
constructor
A new instance of OrganizationHistoryRecord.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, organization: nil, timestamp: nil) ⇒ OrganizationHistoryRecord
12837 12838 12839 12840 12841 12842 12843 12844 12845 |
# File 'lib/models/porcelain.rb', line 12837 def initialize( activity_id: nil, organization: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @organization = organization == nil ? nil : organization = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Organization. May be empty for some system-initiated organization updates.
12831 12832 12833 |
# File 'lib/models/porcelain.rb', line 12831 def activity_id @activity_id end |
#organization ⇒ Object
The complete Organization state at this time.
12833 12834 12835 |
# File 'lib/models/porcelain.rb', line 12833 def organization @organization end |
#timestamp ⇒ Object
The time at which the Organization state was recorded.
12835 12836 12837 |
# File 'lib/models/porcelain.rb', line 12835 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12847 12848 12849 12850 12851 12852 12853 |
# File 'lib/models/porcelain.rb', line 12847 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |