Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
13444 13445 13446 13447 13448 13449 13450 13451 13452 |
# File 'lib/models/porcelain.rb', line 13444 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
13438 13439 13440 |
# File 'lib/models/porcelain.rb', line 13438 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
13440 13441 13442 |
# File 'lib/models/porcelain.rb', line 13440 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
13442 13443 13444 |
# File 'lib/models/porcelain.rb', line 13442 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13454 13455 13456 13457 13458 13459 13460 |
# File 'lib/models/porcelain.rb', line 13454 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |