Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
13364 13365 13366 13367 13368 13369 13370 13371 13372 |
# File 'lib/models/porcelain.rb', line 13364 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
13358 13359 13360 |
# File 'lib/models/porcelain.rb', line 13358 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
13360 13361 13362 |
# File 'lib/models/porcelain.rb', line 13360 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
13362 13363 13364 |
# File 'lib/models/porcelain.rb', line 13362 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13374 13375 13376 13377 13378 13379 13380 |
# File 'lib/models/porcelain.rb', line 13374 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |