Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
12745 12746 12747 12748 12749 12750 12751 12752 12753 |
# File 'lib/models/porcelain.rb', line 12745 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
12739 12740 12741 |
# File 'lib/models/porcelain.rb', line 12739 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
12741 12742 12743 |
# File 'lib/models/porcelain.rb', line 12741 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
12743 12744 12745 |
# File 'lib/models/porcelain.rb', line 12743 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12755 12756 12757 12758 12759 12760 12761 |
# File 'lib/models/porcelain.rb', line 12755 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |