Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
12447 12448 12449 12450 12451 12452 12453 12454 12455 |
# File 'lib/models/porcelain.rb', line 12447 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
12441 12442 12443 |
# File 'lib/models/porcelain.rb', line 12441 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
12443 12444 12445 |
# File 'lib/models/porcelain.rb', line 12443 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
12445 12446 12447 |
# File 'lib/models/porcelain.rb', line 12445 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12457 12458 12459 12460 12461 12462 12463 |
# File 'lib/models/porcelain.rb', line 12457 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |