Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
9120 9121 9122 9123 9124 9125 9126 9127 9128 |
# File 'lib/models/porcelain.rb', line 9120 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
9114 9115 9116 |
# File 'lib/models/porcelain.rb', line 9114 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
9116 9117 9118 |
# File 'lib/models/porcelain.rb', line 9116 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
9118 9119 9120 |
# File 'lib/models/porcelain.rb', line 9118 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9130 9131 9132 9133 9134 9135 9136 |
# File 'lib/models/porcelain.rb', line 9130 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |