Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
9053 9054 9055 9056 9057 9058 9059 9060 9061 |
# File 'lib/models/porcelain.rb', line 9053 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
9047 9048 9049 |
# File 'lib/models/porcelain.rb', line 9047 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
9049 9050 9051 |
# File 'lib/models/porcelain.rb', line 9049 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
9051 9052 9053 |
# File 'lib/models/porcelain.rb', line 9051 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9063 9064 9065 9066 9067 9068 9069 |
# File 'lib/models/porcelain.rb', line 9063 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |