Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
8902 8903 8904 8905 8906 8907 8908 8909 8910 |
# File 'lib/models/porcelain.rb', line 8902 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
8896 8897 8898 |
# File 'lib/models/porcelain.rb', line 8896 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
8898 8899 8900 |
# File 'lib/models/porcelain.rb', line 8898 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
8900 8901 8902 |
# File 'lib/models/porcelain.rb', line 8900 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8912 8913 8914 8915 8916 8917 8918 |
# File 'lib/models/porcelain.rb', line 8912 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |