Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
8539 8540 8541 8542 8543 8544 8545 8546 8547 |
# File 'lib/models/porcelain.rb', line 8539 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
8533 8534 8535 |
# File 'lib/models/porcelain.rb', line 8533 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
8535 8536 8537 |
# File 'lib/models/porcelain.rb', line 8535 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
8537 8538 8539 |
# File 'lib/models/porcelain.rb', line 8537 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8549 8550 8551 8552 8553 8554 8555 |
# File 'lib/models/porcelain.rb', line 8549 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |