Class: SDM::PeeringGroupNode
- Inherits:
-
Object
- Object
- SDM::PeeringGroupNode
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupNode represents the attachment between a PeeringGroup and a Node.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#node_id ⇒ Object
Node ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
constructor
A new instance of PeeringGroupNode.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, node_id: nil) ⇒ PeeringGroupNode
Returns a new instance of PeeringGroupNode.
6325 6326 6327 6328 6329 6330 6331 6332 6333 |
# File 'lib/models/porcelain.rb', line 6325 def initialize( group_id: nil, id: nil, node_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @node_id = node_id == nil ? "" : node_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the node will be attached to.
6319 6320 6321 |
# File 'lib/models/porcelain.rb', line 6319 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
6321 6322 6323 |
# File 'lib/models/porcelain.rb', line 6321 def id @id end |
#node_id ⇒ Object
Node ID to be attached.
6323 6324 6325 |
# File 'lib/models/porcelain.rb', line 6323 def node_id @node_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6335 6336 6337 6338 6339 6340 6341 |
# File 'lib/models/porcelain.rb', line 6335 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |