Class: SDM::PeeringGroupResource
- Inherits:
-
Object
- Object
- SDM::PeeringGroupResource
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupResource represents the attachment between a PeeringGroup and a Resource.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#resource_id ⇒ Object
Resource ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
constructor
A new instance of PeeringGroupResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
Returns a new instance of PeeringGroupResource.
12961 12962 12963 12964 12965 12966 12967 12968 12969 |
# File 'lib/models/porcelain.rb', line 12961 def initialize( group_id: nil, id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
12955 12956 12957 |
# File 'lib/models/porcelain.rb', line 12955 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
12957 12958 12959 |
# File 'lib/models/porcelain.rb', line 12957 def id @id end |
#resource_id ⇒ Object
Resource ID to be attached.
12959 12960 12961 |
# File 'lib/models/porcelain.rb', line 12959 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12971 12972 12973 12974 12975 12976 12977 |
# File 'lib/models/porcelain.rb', line 12971 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |