Class: SDM::PeeringGroupResource
- Inherits:
-
Object
- Object
- SDM::PeeringGroupResource
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupResource represents the attachment between a PeeringGroup and a Resource.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#resource_id ⇒ Object
Resource ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
constructor
A new instance of PeeringGroupResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
Returns a new instance of PeeringGroupResource.
12663 12664 12665 12666 12667 12668 12669 12670 12671 |
# File 'lib/models/porcelain.rb', line 12663 def initialize( group_id: nil, id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
12657 12658 12659 |
# File 'lib/models/porcelain.rb', line 12657 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
12659 12660 12661 |
# File 'lib/models/porcelain.rb', line 12659 def id @id end |
#resource_id ⇒ Object
Resource ID to be attached.
12661 12662 12663 |
# File 'lib/models/porcelain.rb', line 12661 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12673 12674 12675 12676 12677 12678 12679 |
# File 'lib/models/porcelain.rb', line 12673 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |