Class: SDM::PeeringGroupResource
- Inherits:
-
Object
- Object
- SDM::PeeringGroupResource
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupResource represents the attachment between a PeeringGroup and a Resource.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#resource_id ⇒ Object
Resource ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
constructor
A new instance of PeeringGroupResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
Returns a new instance of PeeringGroupResource.
9344 9345 9346 9347 9348 9349 9350 9351 9352 |
# File 'lib/models/porcelain.rb', line 9344 def initialize( group_id: nil, id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
9338 9339 9340 |
# File 'lib/models/porcelain.rb', line 9338 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
9340 9341 9342 |
# File 'lib/models/porcelain.rb', line 9340 def id @id end |
#resource_id ⇒ Object
Resource ID to be attached.
9342 9343 9344 |
# File 'lib/models/porcelain.rb', line 9342 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9354 9355 9356 9357 9358 9359 9360 |
# File 'lib/models/porcelain.rb', line 9354 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |