Class: SDM::PeeringGroupResource
- Inherits:
-
Object
- Object
- SDM::PeeringGroupResource
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupResource represents the attachment between a PeeringGroup and a Resource.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#resource_id ⇒ Object
Resource ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
constructor
A new instance of PeeringGroupResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
Returns a new instance of PeeringGroupResource.
9189 9190 9191 9192 9193 9194 9195 9196 9197 |
# File 'lib/models/porcelain.rb', line 9189 def initialize( group_id: nil, id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
9183 9184 9185 |
# File 'lib/models/porcelain.rb', line 9183 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
9185 9186 9187 |
# File 'lib/models/porcelain.rb', line 9185 def id @id end |
#resource_id ⇒ Object
Resource ID to be attached.
9187 9188 9189 |
# File 'lib/models/porcelain.rb', line 9187 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9199 9200 9201 9202 9203 9204 9205 |
# File 'lib/models/porcelain.rb', line 9199 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |