Class: SDM::PeeringGroupResource
- Inherits:
-
Object
- Object
- SDM::PeeringGroupResource
- Defined in:
- lib/models/porcelain.rb
Overview
PeeringGroupResource represents the attachment between a PeeringGroup and a Resource.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
-
#id ⇒ Object
Unique identifier of the Attachment.
-
#resource_id ⇒ Object
Resource ID to be attached.
Instance Method Summary collapse
-
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
constructor
A new instance of PeeringGroupResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, id: nil, resource_id: nil) ⇒ PeeringGroupResource
Returns a new instance of PeeringGroupResource.
6541 6542 6543 6544 6545 6546 6547 6548 6549 |
# File 'lib/models/porcelain.rb', line 6541 def initialize( group_id: nil, id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @id = id == nil ? "" : id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
Peering Group ID to which the resource will be attached to.
6535 6536 6537 |
# File 'lib/models/porcelain.rb', line 6535 def group_id @group_id end |
#id ⇒ Object
Unique identifier of the Attachment.
6537 6538 6539 |
# File 'lib/models/porcelain.rb', line 6537 def id @id end |
#resource_id ⇒ Object
Resource ID to be attached.
6539 6540 6541 |
# File 'lib/models/porcelain.rb', line 6539 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6551 6552 6553 6554 6555 6556 6557 |
# File 'lib/models/porcelain.rb', line 6551 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |