Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
13829
# File 'lib/models/porcelain.rb', line 13819

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



13811
13812
13813
# File 'lib/models/porcelain.rb', line 13811

def description
  @description
end

#idObject

Unique identifier of the Policy.



13813
13814
13815
# File 'lib/models/porcelain.rb', line 13813

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



13815
13816
13817
# File 'lib/models/porcelain.rb', line 13815

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



13817
13818
13819
# File 'lib/models/porcelain.rb', line 13817

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13831
13832
13833
13834
13835
13836
13837
# File 'lib/models/porcelain.rb', line 13831

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end