Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



13771
13772
13773
13774
13775
13776
13777
13778
13779
13780
13781
# File 'lib/models/porcelain.rb', line 13771

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



13763
13764
13765
# File 'lib/models/porcelain.rb', line 13763

def description
  @description
end

#idObject

Unique identifier of the Policy.



13765
13766
13767
# File 'lib/models/porcelain.rb', line 13765

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



13767
13768
13769
# File 'lib/models/porcelain.rb', line 13767

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



13769
13770
13771
# File 'lib/models/porcelain.rb', line 13769

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13783
13784
13785
13786
13787
13788
13789
# File 'lib/models/porcelain.rb', line 13783

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end