Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
13691 13692 13693 13694 13695 13696 13697 13698 13699 13700 13701 |
# File 'lib/models/porcelain.rb', line 13691 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
13683 13684 13685 |
# File 'lib/models/porcelain.rb', line 13683 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
13685 13686 13687 |
# File 'lib/models/porcelain.rb', line 13685 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
13687 13688 13689 |
# File 'lib/models/porcelain.rb', line 13687 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
13689 13690 13691 |
# File 'lib/models/porcelain.rb', line 13689 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13703 13704 13705 13706 13707 13708 13709 |
# File 'lib/models/porcelain.rb', line 13703 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |