Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



13465
13466
13467
13468
13469
13470
13471
13472
13473
13474
13475
# File 'lib/models/porcelain.rb', line 13465

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



13457
13458
13459
# File 'lib/models/porcelain.rb', line 13457

def description
  @description
end

#idObject

Unique identifier of the Policy.



13459
13460
13461
# File 'lib/models/porcelain.rb', line 13459

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



13461
13462
13463
# File 'lib/models/porcelain.rb', line 13461

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



13463
13464
13465
# File 'lib/models/porcelain.rb', line 13463

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13477
13478
13479
13480
13481
13482
13483
# File 'lib/models/porcelain.rb', line 13477

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end