Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



13072
13073
13074
13075
13076
13077
13078
13079
13080
13081
13082
# File 'lib/models/porcelain.rb', line 13072

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



13064
13065
13066
# File 'lib/models/porcelain.rb', line 13064

def description
  @description
end

#idObject

Unique identifier of the Policy.



13066
13067
13068
# File 'lib/models/porcelain.rb', line 13066

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



13068
13069
13070
# File 'lib/models/porcelain.rb', line 13068

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



13070
13071
13072
# File 'lib/models/porcelain.rb', line 13070

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13084
13085
13086
13087
13088
13089
13090
# File 'lib/models/porcelain.rb', line 13084

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end