Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 |
# File 'lib/models/porcelain.rb', line 11899 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
11891 11892 11893 |
# File 'lib/models/porcelain.rb', line 11891 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
11893 11894 11895 |
# File 'lib/models/porcelain.rb', line 11893 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
11895 11896 11897 |
# File 'lib/models/porcelain.rb', line 11895 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
11897 11898 11899 |
# File 'lib/models/porcelain.rb', line 11897 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11911 11912 11913 11914 11915 11916 11917 |
# File 'lib/models/porcelain.rb', line 11911 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |