Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 10717 |
# File 'lib/models/porcelain.rb', line 10707 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
10699 10700 10701 |
# File 'lib/models/porcelain.rb', line 10699 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
10701 10702 10703 |
# File 'lib/models/porcelain.rb', line 10701 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
10703 10704 10705 |
# File 'lib/models/porcelain.rb', line 10703 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
10705 10706 10707 |
# File 'lib/models/porcelain.rb', line 10705 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10719 10720 10721 10722 10723 10724 10725 |
# File 'lib/models/porcelain.rb', line 10719 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |