Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



10692
10693
10694
10695
10696
10697
10698
10699
10700
10701
10702
# File 'lib/models/porcelain.rb', line 10692

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



10684
10685
10686
# File 'lib/models/porcelain.rb', line 10684

def description
  @description
end

#idObject

Unique identifier of the Policy.



10686
10687
10688
# File 'lib/models/porcelain.rb', line 10686

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



10688
10689
10690
# File 'lib/models/porcelain.rb', line 10688

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



10690
10691
10692
# File 'lib/models/porcelain.rb', line 10690

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10704
10705
10706
10707
10708
10709
10710
# File 'lib/models/porcelain.rb', line 10704

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end