Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



10620
10621
10622
10623
10624
10625
10626
10627
10628
10629
10630
# File 'lib/models/porcelain.rb', line 10620

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



10612
10613
10614
# File 'lib/models/porcelain.rb', line 10612

def description
  @description
end

#idObject

Unique identifier of the Policy.



10614
10615
10616
# File 'lib/models/porcelain.rb', line 10614

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



10616
10617
10618
# File 'lib/models/porcelain.rb', line 10616

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



10618
10619
10620
# File 'lib/models/porcelain.rb', line 10618

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10632
10633
10634
10635
10636
10637
10638
# File 'lib/models/porcelain.rb', line 10632

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end