Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



10528
10529
10530
10531
10532
10533
10534
10535
10536
10537
10538
# File 'lib/models/porcelain.rb', line 10528

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



10520
10521
10522
# File 'lib/models/porcelain.rb', line 10520

def description
  @description
end

#idObject

Unique identifier of the Policy.



10522
10523
10524
# File 'lib/models/porcelain.rb', line 10522

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



10524
10525
10526
# File 'lib/models/porcelain.rb', line 10524

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



10526
10527
10528
# File 'lib/models/porcelain.rb', line 10526

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10540
10541
10542
10543
10544
10545
10546
# File 'lib/models/porcelain.rb', line 10540

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end