Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
10517 10518 10519 10520 10521 10522 10523 10524 10525 10526 10527 |
# File 'lib/models/porcelain.rb', line 10517 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
10509 10510 10511 |
# File 'lib/models/porcelain.rb', line 10509 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
10511 10512 10513 |
# File 'lib/models/porcelain.rb', line 10511 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
10513 10514 10515 |
# File 'lib/models/porcelain.rb', line 10513 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
10515 10516 10517 |
# File 'lib/models/porcelain.rb', line 10515 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10529 10530 10531 10532 10533 10534 10535 |
# File 'lib/models/porcelain.rb', line 10529 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |