Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 |
# File 'lib/models/porcelain.rb', line 10305 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
10297 10298 10299 |
# File 'lib/models/porcelain.rb', line 10297 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
10299 10300 10301 |
# File 'lib/models/porcelain.rb', line 10299 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
10301 10302 10303 |
# File 'lib/models/porcelain.rb', line 10301 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
10303 10304 10305 |
# File 'lib/models/porcelain.rb', line 10303 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10317 10318 10319 10320 10321 10322 10323 |
# File 'lib/models/porcelain.rb', line 10317 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |