Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/models/porcelain.rb', line 9454 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
9446 9447 9448 |
# File 'lib/models/porcelain.rb', line 9446 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
9448 9449 9450 |
# File 'lib/models/porcelain.rb', line 9448 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
9450 9451 9452 |
# File 'lib/models/porcelain.rb', line 9450 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
9452 9453 9454 |
# File 'lib/models/porcelain.rb', line 9452 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9466 9467 9468 9469 9470 9471 9472 |
# File 'lib/models/porcelain.rb', line 9466 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |