Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



9455
9456
9457
9458
9459
9460
9461
9462
9463
9464
9465
# File 'lib/models/porcelain.rb', line 9455

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



9447
9448
9449
# File 'lib/models/porcelain.rb', line 9447

def description
  @description
end

#idObject

Unique identifier of the Policy.



9449
9450
9451
# File 'lib/models/porcelain.rb', line 9449

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



9451
9452
9453
# File 'lib/models/porcelain.rb', line 9451

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



9453
9454
9455
# File 'lib/models/porcelain.rb', line 9453

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9467
9468
9469
9470
9471
9472
9473
# File 'lib/models/porcelain.rb', line 9467

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end