Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



9379
9380
9381
9382
9383
9384
9385
9386
9387
9388
9389
# File 'lib/models/porcelain.rb', line 9379

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



9371
9372
9373
# File 'lib/models/porcelain.rb', line 9371

def description
  @description
end

#idObject

Unique identifier of the Policy.



9373
9374
9375
# File 'lib/models/porcelain.rb', line 9373

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



9375
9376
9377
# File 'lib/models/porcelain.rb', line 9375

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



9377
9378
9379
# File 'lib/models/porcelain.rb', line 9377

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9391
9392
9393
9394
9395
9396
9397
# File 'lib/models/porcelain.rb', line 9391

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end