Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
9380 9381 9382 9383 9384 9385 9386 9387 9388 9389 9390 |
# File 'lib/models/porcelain.rb', line 9380 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
9372 9373 9374 |
# File 'lib/models/porcelain.rb', line 9372 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
9374 9375 9376 |
# File 'lib/models/porcelain.rb', line 9374 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
9376 9377 9378 |
# File 'lib/models/porcelain.rb', line 9376 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
9378 9379 9380 |
# File 'lib/models/porcelain.rb', line 9378 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9392 9393 9394 9395 9396 9397 9398 |
# File 'lib/models/porcelain.rb', line 9392 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |