Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 |
# File 'lib/models/porcelain.rb', line 9300 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
9292 9293 9294 |
# File 'lib/models/porcelain.rb', line 9292 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
9294 9295 9296 |
# File 'lib/models/porcelain.rb', line 9294 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
9296 9297 9298 |
# File 'lib/models/porcelain.rb', line 9296 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
9298 9299 9300 |
# File 'lib/models/porcelain.rb', line 9298 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9312 9313 9314 9315 9316 9317 9318 |
# File 'lib/models/porcelain.rb', line 9312 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |