Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



9229
9230
9231
9232
9233
9234
9235
9236
9237
9238
9239
# File 'lib/models/porcelain.rb', line 9229

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



9221
9222
9223
# File 'lib/models/porcelain.rb', line 9221

def description
  @description
end

#idObject

Unique identifier of the Policy.



9223
9224
9225
# File 'lib/models/porcelain.rb', line 9223

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



9225
9226
9227
# File 'lib/models/porcelain.rb', line 9225

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



9227
9228
9229
# File 'lib/models/porcelain.rb', line 9227

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9241
9242
9243
9244
9245
9246
9247
# File 'lib/models/porcelain.rb', line 9241

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end