Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
8548 8549 8550 8551 8552 8553 8554 8555 8556 8557 8558 |
# File 'lib/models/porcelain.rb', line 8548 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
8540 8541 8542 |
# File 'lib/models/porcelain.rb', line 8540 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
8542 8543 8544 |
# File 'lib/models/porcelain.rb', line 8542 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
8544 8545 8546 |
# File 'lib/models/porcelain.rb', line 8544 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
8546 8547 8548 |
# File 'lib/models/porcelain.rb', line 8546 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8560 8561 8562 8563 8564 8565 8566 |
# File 'lib/models/porcelain.rb', line 8560 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |