Class: SDM::Policy

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy

Returns a new instance of Policy.



13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
# File 'lib/models/porcelain.rb', line 13445

def initialize(
  description: nil,
  id: nil,
  name: nil,
  policy: nil
)
  @description = description == nil ? "" : description
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @policy = policy == nil ? "" : policy
end

Instance Attribute Details

#descriptionObject

Optional description of the Policy.



13437
13438
13439
# File 'lib/models/porcelain.rb', line 13437

def description
  @description
end

#idObject

Unique identifier of the Policy.



13439
13440
13441
# File 'lib/models/porcelain.rb', line 13439

def id
  @id
end

#nameObject

Unique human-readable name of the Policy.



13441
13442
13443
# File 'lib/models/porcelain.rb', line 13441

def name
  @name
end

#policyObject

The content of the Policy, in Cedar policy language.



13443
13444
13445
# File 'lib/models/porcelain.rb', line 13443

def policy
  @policy
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13457
13458
13459
13460
13461
13462
13463
# File 'lib/models/porcelain.rb', line 13457

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end