Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
13145 13146 13147 13148 13149 13150 13151 13152 13153 13154 13155 |
# File 'lib/models/porcelain.rb', line 13145 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
13137 13138 13139 |
# File 'lib/models/porcelain.rb', line 13137 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
13139 13140 13141 |
# File 'lib/models/porcelain.rb', line 13139 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
13141 13142 13143 |
# File 'lib/models/porcelain.rb', line 13141 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
13143 13144 13145 |
# File 'lib/models/porcelain.rb', line 13143 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13157 13158 13159 13160 13161 13162 13163 |
# File 'lib/models/porcelain.rb', line 13157 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |