Class: SDM::Policy
- Inherits:
-
Object
- Object
- SDM::Policy
- Defined in:
- lib/models/porcelain.rb
Overview
Policy is a collection of one or more statements that enforce fine-grained access control for the users of an organization.
Instance Attribute Summary collapse
-
#description ⇒ Object
Optional description of the Policy.
-
#id ⇒ Object
Unique identifier of the Policy.
-
#name ⇒ Object
Unique human-readable name of the Policy.
-
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
Instance Method Summary collapse
-
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
constructor
A new instance of Policy.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(description: nil, id: nil, name: nil, policy: nil) ⇒ Policy
Returns a new instance of Policy.
13878 13879 13880 13881 13882 13883 13884 13885 13886 13887 13888 |
# File 'lib/models/porcelain.rb', line 13878 def initialize( description: nil, id: nil, name: nil, policy: nil ) @description = description == nil ? "" : description @id = id == nil ? "" : id @name = name == nil ? "" : name @policy = policy == nil ? "" : policy end |
Instance Attribute Details
#description ⇒ Object
Optional description of the Policy.
13870 13871 13872 |
# File 'lib/models/porcelain.rb', line 13870 def description @description end |
#id ⇒ Object
Unique identifier of the Policy.
13872 13873 13874 |
# File 'lib/models/porcelain.rb', line 13872 def id @id end |
#name ⇒ Object
Unique human-readable name of the Policy.
13874 13875 13876 |
# File 'lib/models/porcelain.rb', line 13874 def name @name end |
#policy ⇒ Object
The content of the Policy, in Cedar policy language.
13876 13877 13878 |
# File 'lib/models/porcelain.rb', line 13876 def policy @policy end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13890 13891 13892 13893 13894 13895 13896 |
# File 'lib/models/porcelain.rb', line 13890 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |