Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



13926
13927
13928
13929
13930
13931
13932
13933
13934
13935
13936
# File 'lib/models/porcelain.rb', line 13926

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



13918
13919
13920
# File 'lib/models/porcelain.rb', line 13918

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



13920
13921
13922
# File 'lib/models/porcelain.rb', line 13920

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



13922
13923
13924
# File 'lib/models/porcelain.rb', line 13922

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



13924
13925
13926
# File 'lib/models/porcelain.rb', line 13924

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13938
13939
13940
13941
13942
13943
13944
# File 'lib/models/porcelain.rb', line 13938

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end