Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



13878
13879
13880
13881
13882
13883
13884
13885
13886
13887
13888
# File 'lib/models/porcelain.rb', line 13878

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



13870
13871
13872
# File 'lib/models/porcelain.rb', line 13870

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



13872
13873
13874
# File 'lib/models/porcelain.rb', line 13872

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



13874
13875
13876
# File 'lib/models/porcelain.rb', line 13874

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



13876
13877
13878
# File 'lib/models/porcelain.rb', line 13876

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13890
13891
13892
13893
13894
13895
13896
# File 'lib/models/porcelain.rb', line 13890

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end