Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



13798
13799
13800
13801
13802
13803
13804
13805
13806
13807
13808
# File 'lib/models/porcelain.rb', line 13798

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



13790
13791
13792
# File 'lib/models/porcelain.rb', line 13790

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



13792
13793
13794
# File 'lib/models/porcelain.rb', line 13792

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



13794
13795
13796
# File 'lib/models/porcelain.rb', line 13794

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



13796
13797
13798
# File 'lib/models/porcelain.rb', line 13796

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13810
13811
13812
13813
13814
13815
13816
# File 'lib/models/porcelain.rb', line 13810

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end