Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



13572
13573
13574
13575
13576
13577
13578
13579
13580
13581
13582
# File 'lib/models/porcelain.rb', line 13572

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



13564
13565
13566
# File 'lib/models/porcelain.rb', line 13564

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



13566
13567
13568
# File 'lib/models/porcelain.rb', line 13566

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



13568
13569
13570
# File 'lib/models/porcelain.rb', line 13568

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



13570
13571
13572
# File 'lib/models/porcelain.rb', line 13570

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13584
13585
13586
13587
13588
13589
13590
# File 'lib/models/porcelain.rb', line 13584

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end