Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



13552
13553
13554
13555
13556
13557
13558
13559
13560
13561
13562
# File 'lib/models/porcelain.rb', line 13552

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



13544
13545
13546
# File 'lib/models/porcelain.rb', line 13544

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



13546
13547
13548
# File 'lib/models/porcelain.rb', line 13546

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



13548
13549
13550
# File 'lib/models/porcelain.rb', line 13548

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



13550
13551
13552
# File 'lib/models/porcelain.rb', line 13550

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13564
13565
13566
13567
13568
13569
13570
# File 'lib/models/porcelain.rb', line 13564

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end