Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



13252
13253
13254
13255
13256
13257
13258
13259
13260
13261
13262
# File 'lib/models/porcelain.rb', line 13252

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



13244
13245
13246
# File 'lib/models/porcelain.rb', line 13244

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



13246
13247
13248
# File 'lib/models/porcelain.rb', line 13246

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



13248
13249
13250
# File 'lib/models/porcelain.rb', line 13248

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



13250
13251
13252
# File 'lib/models/porcelain.rb', line 13250

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13264
13265
13266
13267
13268
13269
13270
# File 'lib/models/porcelain.rb', line 13264

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end