Class: SDM::PolicyHistory
- Inherits:
-
Object
- Object
- SDM::PolicyHistory
- Defined in:
- lib/models/porcelain.rb
Overview
PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy.
-
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
-
#policy ⇒ Object
The complete Policy state at this time.
-
#timestamp ⇒ Object
The time at which the Policy state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
constructor
A new instance of PolicyHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
Returns a new instance of PolicyHistory.
13179 13180 13181 13182 13183 13184 13185 13186 13187 13188 13189 |
# File 'lib/models/porcelain.rb', line 13179 def initialize( activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @policy = policy == nil ? nil : policy @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.
13171 13172 13173 |
# File 'lib/models/porcelain.rb', line 13171 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
13173 13174 13175 |
# File 'lib/models/porcelain.rb', line 13173 def deleted_at @deleted_at end |
#policy ⇒ Object
The complete Policy state at this time.
13175 13176 13177 |
# File 'lib/models/porcelain.rb', line 13175 def policy @policy end |
#timestamp ⇒ Object
The time at which the Policy state was recorded.
13177 13178 13179 |
# File 'lib/models/porcelain.rb', line 13177 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13191 13192 13193 13194 13195 13196 13197 |
# File 'lib/models/porcelain.rb', line 13191 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |