Class: SDM::PolicyHistory
- Inherits:
-
Object
- Object
- SDM::PolicyHistory
- Defined in:
- lib/models/porcelain.rb
Overview
PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy.
-
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
-
#policy ⇒ Object
The complete Policy state at this time.
-
#timestamp ⇒ Object
The time at which the Policy state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
constructor
A new instance of PolicyHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
Returns a new instance of PolicyHistory.
12817 12818 12819 12820 12821 12822 12823 12824 12825 12826 12827 |
# File 'lib/models/porcelain.rb', line 12817 def initialize( activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @policy = policy == nil ? nil : policy @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.
12809 12810 12811 |
# File 'lib/models/porcelain.rb', line 12809 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
12811 12812 12813 |
# File 'lib/models/porcelain.rb', line 12811 def deleted_at @deleted_at end |
#policy ⇒ Object
The complete Policy state at this time.
12813 12814 12815 |
# File 'lib/models/porcelain.rb', line 12813 def policy @policy end |
#timestamp ⇒ Object
The time at which the Policy state was recorded.
12815 12816 12817 |
# File 'lib/models/porcelain.rb', line 12815 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12829 12830 12831 12832 12833 12834 12835 |
# File 'lib/models/porcelain.rb', line 12829 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |