Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



10814
10815
10816
10817
10818
10819
10820
10821
10822
10823
10824
# File 'lib/models/porcelain.rb', line 10814

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



10806
10807
10808
# File 'lib/models/porcelain.rb', line 10806

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



10808
10809
10810
# File 'lib/models/porcelain.rb', line 10808

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



10810
10811
10812
# File 'lib/models/porcelain.rb', line 10810

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



10812
10813
10814
# File 'lib/models/porcelain.rb', line 10812

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10826
10827
10828
10829
10830
10831
10832
# File 'lib/models/porcelain.rb', line 10826

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end