Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



10624
10625
10626
10627
10628
10629
10630
10631
10632
10633
10634
# File 'lib/models/porcelain.rb', line 10624

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



10616
10617
10618
# File 'lib/models/porcelain.rb', line 10616

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



10618
10619
10620
# File 'lib/models/porcelain.rb', line 10618

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



10620
10621
10622
# File 'lib/models/porcelain.rb', line 10620

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



10622
10623
10624
# File 'lib/models/porcelain.rb', line 10622

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10636
10637
10638
10639
10640
10641
10642
# File 'lib/models/porcelain.rb', line 10636

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end