Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
# File 'lib/models/porcelain.rb', line 10556

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



10548
10549
10550
# File 'lib/models/porcelain.rb', line 10548

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



10550
10551
10552
# File 'lib/models/porcelain.rb', line 10550

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



10552
10553
10554
# File 'lib/models/porcelain.rb', line 10552

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



10554
10555
10556
# File 'lib/models/porcelain.rb', line 10554

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10568
10569
10570
10571
10572
10573
10574
# File 'lib/models/porcelain.rb', line 10568

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end