Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
# File 'lib/models/porcelain.rb', line 10412

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



10404
10405
10406
# File 'lib/models/porcelain.rb', line 10404

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



10406
10407
10408
# File 'lib/models/porcelain.rb', line 10406

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



10408
10409
10410
# File 'lib/models/porcelain.rb', line 10408

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



10410
10411
10412
# File 'lib/models/porcelain.rb', line 10410

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10424
10425
10426
10427
10428
10429
10430
# File 'lib/models/porcelain.rb', line 10424

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end