Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
# File 'lib/models/porcelain.rb', line 9486

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



9478
9479
9480
# File 'lib/models/porcelain.rb', line 9478

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



9480
9481
9482
# File 'lib/models/porcelain.rb', line 9480

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



9482
9483
9484
# File 'lib/models/porcelain.rb', line 9482

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



9484
9485
9486
# File 'lib/models/porcelain.rb', line 9484

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9498
9499
9500
9501
9502
9503
9504
# File 'lib/models/porcelain.rb', line 9498

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end