Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/models/porcelain.rb', line 9407

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



9399
9400
9401
# File 'lib/models/porcelain.rb', line 9399

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



9401
9402
9403
# File 'lib/models/porcelain.rb', line 9401

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



9403
9404
9405
# File 'lib/models/porcelain.rb', line 9403

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



9405
9406
9407
# File 'lib/models/porcelain.rb', line 9405

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9419
9420
9421
9422
9423
9424
9425
# File 'lib/models/porcelain.rb', line 9419

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end