Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



9270
9271
9272
9273
9274
9275
9276
9277
9278
9279
9280
# File 'lib/models/porcelain.rb', line 9270

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



9262
9263
9264
# File 'lib/models/porcelain.rb', line 9262

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



9264
9265
9266
# File 'lib/models/porcelain.rb', line 9264

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



9266
9267
9268
# File 'lib/models/porcelain.rb', line 9266

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



9268
9269
9270
# File 'lib/models/porcelain.rb', line 9268

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9282
9283
9284
9285
9286
9287
9288
# File 'lib/models/porcelain.rb', line 9282

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end