Class: SDM::PolicyHistory
- Inherits:
-
Object
- Object
- SDM::PolicyHistory
- Defined in:
- lib/models/porcelain.rb
Overview
PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy.
-
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
-
#policy ⇒ Object
The complete Policy state at this time.
-
#timestamp ⇒ Object
The time at which the Policy state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
constructor
A new instance of PolicyHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
Returns a new instance of PolicyHistory.
8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 |
# File 'lib/models/porcelain.rb', line 8973 def initialize( activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @policy = policy == nil ? nil : policy @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.
8965 8966 8967 |
# File 'lib/models/porcelain.rb', line 8965 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
8967 8968 8969 |
# File 'lib/models/porcelain.rb', line 8967 def deleted_at @deleted_at end |
#policy ⇒ Object
The complete Policy state at this time.
8969 8970 8971 |
# File 'lib/models/porcelain.rb', line 8969 def policy @policy end |
#timestamp ⇒ Object
The time at which the Policy state was recorded.
8971 8972 8973 |
# File 'lib/models/porcelain.rb', line 8971 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8985 8986 8987 8988 8989 8990 8991 |
# File 'lib/models/porcelain.rb', line 8985 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |