Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



8975
8976
8977
8978
8979
8980
8981
8982
8983
8984
8985
# File 'lib/models/porcelain.rb', line 8975

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



8967
8968
8969
# File 'lib/models/porcelain.rb', line 8967

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



8969
8970
8971
# File 'lib/models/porcelain.rb', line 8969

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



8971
8972
8973
# File 'lib/models/porcelain.rb', line 8971

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



8973
8974
8975
# File 'lib/models/porcelain.rb', line 8973

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8987
8988
8989
8990
8991
8992
8993
# File 'lib/models/porcelain.rb', line 8987

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end