Class: SDM::PolicyHistory
- Inherits:
-
Object
- Object
- SDM::PolicyHistory
- Defined in:
- lib/models/porcelain.rb
Overview
PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy.
-
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
-
#policy ⇒ Object
The complete Policy state at this time.
-
#timestamp ⇒ Object
The time at which the Policy state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
constructor
A new instance of PolicyHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
Returns a new instance of PolicyHistory.
8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/models/porcelain.rb', line 8655 def initialize( activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @policy = policy == nil ? nil : policy @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.
8647 8648 8649 |
# File 'lib/models/porcelain.rb', line 8647 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
8649 8650 8651 |
# File 'lib/models/porcelain.rb', line 8649 def deleted_at @deleted_at end |
#policy ⇒ Object
The complete Policy state at this time.
8651 8652 8653 |
# File 'lib/models/porcelain.rb', line 8651 def policy @policy end |
#timestamp ⇒ Object
The time at which the Policy state was recorded.
8653 8654 8655 |
# File 'lib/models/porcelain.rb', line 8653 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8667 8668 8669 8670 8671 8672 8673 |
# File 'lib/models/porcelain.rb', line 8667 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |