Class: SDM::PolicyHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory

Returns a new instance of PolicyHistory.



8330
8331
8332
8333
8334
8335
8336
8337
8338
8339
8340
# File 'lib/models/porcelain.rb', line 8330

def initialize(
  activity_id: nil,
  deleted_at: nil,
  policy: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @policy = policy == nil ? nil : policy
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.



8322
8323
8324
# File 'lib/models/porcelain.rb', line 8322

def activity_id
  @activity_id
end

#deleted_atObject

If this Policy was deleted, the time it was deleted.



8324
8325
8326
# File 'lib/models/porcelain.rb', line 8324

def deleted_at
  @deleted_at
end

#policyObject

The complete Policy state at this time.



8326
8327
8328
# File 'lib/models/porcelain.rb', line 8326

def policy
  @policy
end

#timestampObject

The time at which the Policy state was recorded.



8328
8329
8330
# File 'lib/models/porcelain.rb', line 8328

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8342
8343
8344
8345
8346
8347
8348
# File 'lib/models/porcelain.rb', line 8342

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end