Class: SDM::PolicyHistory
- Inherits:
-
Object
- Object
- SDM::PolicyHistory
- Defined in:
- lib/models/porcelain.rb
Overview
PolicyHistory records the state of a Policy at a given point in time, where every change (create, update and delete) to a Policy produces a PolicyHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy.
-
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
-
#policy ⇒ Object
The complete Policy state at this time.
-
#timestamp ⇒ Object
The time at which the Policy state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
constructor
A new instance of PolicyHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil) ⇒ PolicyHistory
13404 13405 13406 13407 13408 13409 13410 13411 13412 13413 13414 |
# File 'lib/models/porcelain.rb', line 13404 def initialize( activity_id: nil, deleted_at: nil, policy: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @policy = policy == nil ? nil : policy = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Policy. May be empty for some system-initiated updates.
13396 13397 13398 |
# File 'lib/models/porcelain.rb', line 13396 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Policy was deleted, the time it was deleted.
13398 13399 13400 |
# File 'lib/models/porcelain.rb', line 13398 def deleted_at @deleted_at end |
#policy ⇒ Object
The complete Policy state at this time.
13400 13401 13402 |
# File 'lib/models/porcelain.rb', line 13400 def policy @policy end |
#timestamp ⇒ Object
The time at which the Policy state was recorded.
13402 13403 13404 |
# File 'lib/models/porcelain.rb', line 13402 def end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13416 13417 13418 13419 13420 13421 13422 |
# File 'lib/models/porcelain.rb', line 13416 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |