Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



14027
14028
14029
14030
14031
14032
14033
14034
14035
14036
14037
14038
14039
14040
14041
14042
14043
14044
14045
14046
14047
14048
14049
14050
14051
14052
14053
14054
14055
14056
14057
14058
14059
14060
14061
# File 'lib/models/porcelain.rb', line 14027

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13995
13996
13997
# File 'lib/models/porcelain.rb', line 13995

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13997
13998
13999
# File 'lib/models/porcelain.rb', line 13997

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13999
14000
14001
# File 'lib/models/porcelain.rb', line 13999

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14001
14002
14003
# File 'lib/models/porcelain.rb', line 14001

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14003
14004
14005
# File 'lib/models/porcelain.rb', line 14003

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14005
14006
14007
# File 'lib/models/porcelain.rb', line 14005

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14007
14008
14009
# File 'lib/models/porcelain.rb', line 14007

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14009
14010
14011
# File 'lib/models/porcelain.rb', line 14009

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



14011
14012
14013
# File 'lib/models/porcelain.rb', line 14011

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14013
14014
14015
# File 'lib/models/porcelain.rb', line 14013

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14015
14016
14017
# File 'lib/models/porcelain.rb', line 14015

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14017
14018
14019
# File 'lib/models/porcelain.rb', line 14017

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14019
14020
14021
# File 'lib/models/porcelain.rb', line 14019

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14021
14022
14023
# File 'lib/models/porcelain.rb', line 14021

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14023
14024
14025
# File 'lib/models/porcelain.rb', line 14023

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14025
14026
14027
# File 'lib/models/porcelain.rb', line 14025

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14063
14064
14065
14066
14067
14068
14069
# File 'lib/models/porcelain.rb', line 14063

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end