Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



13899
13900
13901
13902
13903
13904
13905
13906
13907
13908
13909
13910
13911
13912
13913
13914
13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
13926
13927
13928
13929
13930
13931
13932
13933
# File 'lib/models/porcelain.rb', line 13899

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13867
13868
13869
# File 'lib/models/porcelain.rb', line 13867

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13869
13870
13871
# File 'lib/models/porcelain.rb', line 13869

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13871
13872
13873
# File 'lib/models/porcelain.rb', line 13871

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13873
13874
13875
# File 'lib/models/porcelain.rb', line 13873

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13875
13876
13877
# File 'lib/models/porcelain.rb', line 13875

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13877
13878
13879
# File 'lib/models/porcelain.rb', line 13877

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13879
13880
13881
# File 'lib/models/porcelain.rb', line 13879

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13881
13882
13883
# File 'lib/models/porcelain.rb', line 13881

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



13883
13884
13885
# File 'lib/models/porcelain.rb', line 13883

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13885
13886
13887
# File 'lib/models/porcelain.rb', line 13885

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13887
13888
13889
# File 'lib/models/porcelain.rb', line 13887

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13889
13890
13891
# File 'lib/models/porcelain.rb', line 13889

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13891
13892
13893
# File 'lib/models/porcelain.rb', line 13891

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13893
13894
13895
# File 'lib/models/porcelain.rb', line 13893

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13895
13896
13897
# File 'lib/models/porcelain.rb', line 13895

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13897
13898
13899
# File 'lib/models/porcelain.rb', line 13897

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13935
13936
13937
13938
13939
13940
13941
# File 'lib/models/porcelain.rb', line 13935

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end