Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



13354
13355
13356
13357
13358
13359
13360
13361
13362
13363
13364
13365
13366
13367
13368
13369
13370
13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
13384
13385
13386
13387
13388
# File 'lib/models/porcelain.rb', line 13354

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13322
13323
13324
# File 'lib/models/porcelain.rb', line 13322

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13324
13325
13326
# File 'lib/models/porcelain.rb', line 13324

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13326
13327
13328
# File 'lib/models/porcelain.rb', line 13326

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13328
13329
13330
# File 'lib/models/porcelain.rb', line 13328

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13330
13331
13332
# File 'lib/models/porcelain.rb', line 13330

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13332
13333
13334
# File 'lib/models/porcelain.rb', line 13332

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13334
13335
13336
# File 'lib/models/porcelain.rb', line 13334

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13336
13337
13338
# File 'lib/models/porcelain.rb', line 13336

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



13338
13339
13340
# File 'lib/models/porcelain.rb', line 13338

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13340
13341
13342
# File 'lib/models/porcelain.rb', line 13340

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13342
13343
13344
# File 'lib/models/porcelain.rb', line 13342

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13344
13345
13346
# File 'lib/models/porcelain.rb', line 13344

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13346
13347
13348
# File 'lib/models/porcelain.rb', line 13346

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13348
13349
13350
# File 'lib/models/porcelain.rb', line 13348

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13350
13351
13352
# File 'lib/models/porcelain.rb', line 13350

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13352
13353
13354
# File 'lib/models/porcelain.rb', line 13352

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13390
13391
13392
13393
13394
13395
13396
# File 'lib/models/porcelain.rb', line 13390

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end