Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



13280
13281
13282
13283
13284
13285
13286
13287
13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
13309
13310
13311
13312
13313
13314
# File 'lib/models/porcelain.rb', line 13280

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13248
13249
13250
# File 'lib/models/porcelain.rb', line 13248

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13250
13251
13252
# File 'lib/models/porcelain.rb', line 13250

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13252
13253
13254
# File 'lib/models/porcelain.rb', line 13252

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13254
13255
13256
# File 'lib/models/porcelain.rb', line 13254

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13256
13257
13258
# File 'lib/models/porcelain.rb', line 13256

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13258
13259
13260
# File 'lib/models/porcelain.rb', line 13258

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13260
13261
13262
# File 'lib/models/porcelain.rb', line 13260

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13262
13263
13264
# File 'lib/models/porcelain.rb', line 13262

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



13264
13265
13266
# File 'lib/models/porcelain.rb', line 13264

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13266
13267
13268
# File 'lib/models/porcelain.rb', line 13266

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13268
13269
13270
# File 'lib/models/porcelain.rb', line 13268

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13270
13271
13272
# File 'lib/models/porcelain.rb', line 13270

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13272
13273
13274
# File 'lib/models/porcelain.rb', line 13272

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13274
13275
13276
# File 'lib/models/porcelain.rb', line 13274

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13276
13277
13278
# File 'lib/models/porcelain.rb', line 13276

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13278
13279
13280
# File 'lib/models/porcelain.rb', line 13278

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13316
13317
13318
13319
13320
13321
13322
# File 'lib/models/porcelain.rb', line 13316

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end