Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
12931
12932
12933
12934
12935
12936
12937
12938
12939
12940
12941
12942
12943
12944
12945
12946
12947
12948
12949
12950
12951
12952
# File 'lib/models/porcelain.rb', line 12918

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12886
12887
12888
# File 'lib/models/porcelain.rb', line 12886

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12888
12889
12890
# File 'lib/models/porcelain.rb', line 12888

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12890
12891
12892
# File 'lib/models/porcelain.rb', line 12890

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12892
12893
12894
# File 'lib/models/porcelain.rb', line 12892

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12894
12895
12896
# File 'lib/models/porcelain.rb', line 12894

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12896
12897
12898
# File 'lib/models/porcelain.rb', line 12896

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12898
12899
12900
# File 'lib/models/porcelain.rb', line 12898

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12900
12901
12902
# File 'lib/models/porcelain.rb', line 12900

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



12902
12903
12904
# File 'lib/models/porcelain.rb', line 12902

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12904
12905
12906
# File 'lib/models/porcelain.rb', line 12904

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12906
12907
12908
# File 'lib/models/porcelain.rb', line 12906

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12908
12909
12910
# File 'lib/models/porcelain.rb', line 12908

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12910
12911
12912
# File 'lib/models/porcelain.rb', line 12910

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12912
12913
12914
# File 'lib/models/porcelain.rb', line 12912

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12914
12915
12916
# File 'lib/models/porcelain.rb', line 12914

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12916
12917
12918
# File 'lib/models/porcelain.rb', line 12916

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12954
12955
12956
12957
12958
12959
12960
# File 'lib/models/porcelain.rb', line 12954

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end