Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



12107
12108
12109
12110
12111
12112
12113
12114
12115
12116
12117
12118
12119
12120
12121
12122
12123
12124
12125
12126
12127
12128
12129
12130
12131
12132
12133
12134
12135
12136
12137
12138
12139
12140
12141
# File 'lib/models/porcelain.rb', line 12107

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12075
12076
12077
# File 'lib/models/porcelain.rb', line 12075

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12077
12078
12079
# File 'lib/models/porcelain.rb', line 12077

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12079
12080
12081
# File 'lib/models/porcelain.rb', line 12079

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12081
12082
12083
# File 'lib/models/porcelain.rb', line 12081

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12083
12084
12085
# File 'lib/models/porcelain.rb', line 12083

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12085
12086
12087
# File 'lib/models/porcelain.rb', line 12085

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12087
12088
12089
# File 'lib/models/porcelain.rb', line 12087

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12089
12090
12091
# File 'lib/models/porcelain.rb', line 12089

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



12091
12092
12093
# File 'lib/models/porcelain.rb', line 12091

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12093
12094
12095
# File 'lib/models/porcelain.rb', line 12093

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12095
12096
12097
# File 'lib/models/porcelain.rb', line 12095

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12097
12098
12099
# File 'lib/models/porcelain.rb', line 12097

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12099
12100
12101
# File 'lib/models/porcelain.rb', line 12099

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12101
12102
12103
# File 'lib/models/porcelain.rb', line 12101

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12103
12104
12105
# File 'lib/models/porcelain.rb', line 12103

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12105
12106
12107
# File 'lib/models/porcelain.rb', line 12105

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12143
12144
12145
12146
12147
12148
12149
# File 'lib/models/porcelain.rb', line 12143

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end