Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
10530
10531
10532
10533
10534
10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
10547
# File 'lib/models/porcelain.rb', line 10513

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10481
10482
10483
# File 'lib/models/porcelain.rb', line 10481

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10483
10484
10485
# File 'lib/models/porcelain.rb', line 10483

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10485
10486
10487
# File 'lib/models/porcelain.rb', line 10485

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10487
10488
10489
# File 'lib/models/porcelain.rb', line 10487

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10489
10490
10491
# File 'lib/models/porcelain.rb', line 10489

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10491
10492
10493
# File 'lib/models/porcelain.rb', line 10491

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10493
10494
10495
# File 'lib/models/porcelain.rb', line 10493

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10495
10496
10497
# File 'lib/models/porcelain.rb', line 10495

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10497
10498
10499
# File 'lib/models/porcelain.rb', line 10497

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10499
10500
10501
# File 'lib/models/porcelain.rb', line 10499

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10501
10502
10503
# File 'lib/models/porcelain.rb', line 10501

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10503
10504
10505
# File 'lib/models/porcelain.rb', line 10503

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10505
10506
10507
# File 'lib/models/porcelain.rb', line 10505

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10507
10508
10509
# File 'lib/models/porcelain.rb', line 10507

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10509
10510
10511
# File 'lib/models/porcelain.rb', line 10509

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10511
10512
10513
# File 'lib/models/porcelain.rb', line 10511

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10549
10550
10551
10552
10553
10554
10555
# File 'lib/models/porcelain.rb', line 10549

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end