Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
9596
9597
9598
9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
9613
9614
9615
9616
9617
9618
# File 'lib/models/porcelain.rb', line 9584

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9552
9553
9554
# File 'lib/models/porcelain.rb', line 9552

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9554
9555
9556
# File 'lib/models/porcelain.rb', line 9554

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9556
9557
9558
# File 'lib/models/porcelain.rb', line 9556

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9558
9559
9560
# File 'lib/models/porcelain.rb', line 9558

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9560
9561
9562
# File 'lib/models/porcelain.rb', line 9560

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9562
9563
9564
# File 'lib/models/porcelain.rb', line 9562

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9564
9565
9566
# File 'lib/models/porcelain.rb', line 9564

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



9566
9567
9568
# File 'lib/models/porcelain.rb', line 9566

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



9568
9569
9570
# File 'lib/models/porcelain.rb', line 9568

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9570
9571
9572
# File 'lib/models/porcelain.rb', line 9570

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9572
9573
9574
# File 'lib/models/porcelain.rb', line 9572

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9574
9575
9576
# File 'lib/models/porcelain.rb', line 9574

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9576
9577
9578
# File 'lib/models/porcelain.rb', line 9576

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9578
9579
9580
# File 'lib/models/porcelain.rb', line 9578

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9580
9581
9582
# File 'lib/models/porcelain.rb', line 9580

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9582
9583
9584
# File 'lib/models/porcelain.rb', line 9582

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9620
9621
9622
9623
9624
9625
9626
# File 'lib/models/porcelain.rb', line 9620

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end