Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



8425
8426
8427
8428
8429
8430
8431
8432
8433
8434
8435
8436
8437
8438
8439
8440
8441
8442
8443
8444
8445
8446
8447
8448
8449
8450
8451
8452
8453
8454
8455
8456
8457
# File 'lib/models/porcelain.rb', line 8425

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8395
8396
8397
# File 'lib/models/porcelain.rb', line 8395

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8397
8398
8399
# File 'lib/models/porcelain.rb', line 8397

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8399
8400
8401
# File 'lib/models/porcelain.rb', line 8399

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8401
8402
8403
# File 'lib/models/porcelain.rb', line 8401

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8403
8404
8405
# File 'lib/models/porcelain.rb', line 8403

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8405
8406
8407
# File 'lib/models/porcelain.rb', line 8405

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8407
8408
8409
# File 'lib/models/porcelain.rb', line 8407

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8409
8410
8411
# File 'lib/models/porcelain.rb', line 8409

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



8411
8412
8413
# File 'lib/models/porcelain.rb', line 8411

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8413
8414
8415
# File 'lib/models/porcelain.rb', line 8413

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8415
8416
8417
# File 'lib/models/porcelain.rb', line 8415

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8417
8418
8419
# File 'lib/models/porcelain.rb', line 8417

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8419
8420
8421
# File 'lib/models/porcelain.rb', line 8419

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8421
8422
8423
# File 'lib/models/porcelain.rb', line 8421

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8423
8424
8425
# File 'lib/models/porcelain.rb', line 8423

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8459
8460
8461
8462
8463
8464
8465
# File 'lib/models/porcelain.rb', line 8459

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end