Class: SDM::Postgres
- Inherits:
-
Object
- Object
- SDM::Postgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres
constructor
A new instance of Postgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres
Returns a new instance of Postgres.
6823 6824 6825 6826 6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 |
# File 'lib/models/porcelain.rb', line 6823 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6793 6794 6795 |
# File 'lib/models/porcelain.rb', line 6793 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
6795 6796 6797 |
# File 'lib/models/porcelain.rb', line 6795 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6797 6798 6799 |
# File 'lib/models/porcelain.rb', line 6797 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6799 6800 6801 |
# File 'lib/models/porcelain.rb', line 6799 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6801 6802 6803 |
# File 'lib/models/porcelain.rb', line 6801 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6803 6804 6805 |
# File 'lib/models/porcelain.rb', line 6803 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6805 6806 6807 |
# File 'lib/models/porcelain.rb', line 6805 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
6807 6808 6809 |
# File 'lib/models/porcelain.rb', line 6807 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
6809 6810 6811 |
# File 'lib/models/porcelain.rb', line 6809 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6811 6812 6813 |
# File 'lib/models/porcelain.rb', line 6811 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6813 6814 6815 |
# File 'lib/models/porcelain.rb', line 6813 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6815 6816 6817 |
# File 'lib/models/porcelain.rb', line 6815 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6817 6818 6819 |
# File 'lib/models/porcelain.rb', line 6817 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6819 6820 6821 |
# File 'lib/models/porcelain.rb', line 6819 def @tags end |
#username ⇒ Object
The username to authenticate with.
6821 6822 6823 |
# File 'lib/models/porcelain.rb', line 6821 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6857 6858 6859 6860 6861 6862 6863 |
# File 'lib/models/porcelain.rb', line 6857 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |