Class: SDM::Postgres
- Inherits:
-
Object
- Object
- SDM::Postgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres
constructor
A new instance of Postgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres
Returns a new instance of Postgres.
6672 6673 6674 6675 6676 6677 6678 6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 6700 6701 6702 6703 6704 |
# File 'lib/models/porcelain.rb', line 6672 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6642 6643 6644 |
# File 'lib/models/porcelain.rb', line 6642 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
6644 6645 6646 |
# File 'lib/models/porcelain.rb', line 6644 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6646 6647 6648 |
# File 'lib/models/porcelain.rb', line 6646 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6648 6649 6650 |
# File 'lib/models/porcelain.rb', line 6648 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6650 6651 6652 |
# File 'lib/models/porcelain.rb', line 6650 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6652 6653 6654 |
# File 'lib/models/porcelain.rb', line 6652 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6654 6655 6656 |
# File 'lib/models/porcelain.rb', line 6654 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
6656 6657 6658 |
# File 'lib/models/porcelain.rb', line 6656 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
6658 6659 6660 |
# File 'lib/models/porcelain.rb', line 6658 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6660 6661 6662 |
# File 'lib/models/porcelain.rb', line 6660 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6662 6663 6664 |
# File 'lib/models/porcelain.rb', line 6662 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6664 6665 6666 |
# File 'lib/models/porcelain.rb', line 6664 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6666 6667 6668 |
# File 'lib/models/porcelain.rb', line 6666 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6668 6669 6670 |
# File 'lib/models/porcelain.rb', line 6668 def @tags end |
#username ⇒ Object
The username to authenticate with.
6670 6671 6672 |
# File 'lib/models/porcelain.rb', line 6670 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6706 6707 6708 6709 6710 6711 6712 |
# File 'lib/models/porcelain.rb', line 6706 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |