Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



6508
6509
6510
6511
6512
6513
6514
6515
6516
6517
6518
6519
6520
6521
6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
6533
6534
6535
6536
6537
6538
6539
6540
# File 'lib/models/porcelain.rb', line 6508

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6478
6479
6480
# File 'lib/models/porcelain.rb', line 6478

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6480
6481
6482
# File 'lib/models/porcelain.rb', line 6480

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6482
6483
6484
# File 'lib/models/porcelain.rb', line 6482

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6484
6485
6486
# File 'lib/models/porcelain.rb', line 6484

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6486
6487
6488
# File 'lib/models/porcelain.rb', line 6486

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6488
6489
6490
# File 'lib/models/porcelain.rb', line 6488

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6490
6491
6492
# File 'lib/models/porcelain.rb', line 6490

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



6492
6493
6494
# File 'lib/models/porcelain.rb', line 6492

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



6494
6495
6496
# File 'lib/models/porcelain.rb', line 6494

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6496
6497
6498
# File 'lib/models/porcelain.rb', line 6496

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6498
6499
6500
# File 'lib/models/porcelain.rb', line 6498

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6500
6501
6502
# File 'lib/models/porcelain.rb', line 6500

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6502
6503
6504
# File 'lib/models/porcelain.rb', line 6502

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6504
6505
6506
# File 'lib/models/porcelain.rb', line 6504

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6506
6507
6508
# File 'lib/models/porcelain.rb', line 6506

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6542
6543
6544
6545
6546
6547
6548
# File 'lib/models/porcelain.rb', line 6542

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end