Class: SDM::Postgres
- Inherits:
-
Object
- Object
- SDM::Postgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres
constructor
A new instance of Postgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres
Returns a new instance of Postgres.
6500 6501 6502 6503 6504 6505 6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 6529 6530 6531 6532 |
# File 'lib/models/porcelain.rb', line 6500 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6470 6471 6472 |
# File 'lib/models/porcelain.rb', line 6470 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
6472 6473 6474 |
# File 'lib/models/porcelain.rb', line 6472 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6474 6475 6476 |
# File 'lib/models/porcelain.rb', line 6474 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6476 6477 6478 |
# File 'lib/models/porcelain.rb', line 6476 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6478 6479 6480 |
# File 'lib/models/porcelain.rb', line 6478 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6480 6481 6482 |
# File 'lib/models/porcelain.rb', line 6480 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6482 6483 6484 |
# File 'lib/models/porcelain.rb', line 6482 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
6484 6485 6486 |
# File 'lib/models/porcelain.rb', line 6484 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
6486 6487 6488 |
# File 'lib/models/porcelain.rb', line 6486 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6488 6489 6490 |
# File 'lib/models/porcelain.rb', line 6488 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6490 6491 6492 |
# File 'lib/models/porcelain.rb', line 6490 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6492 6493 6494 |
# File 'lib/models/porcelain.rb', line 6492 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6494 6495 6496 |
# File 'lib/models/porcelain.rb', line 6494 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6496 6497 6498 |
# File 'lib/models/porcelain.rb', line 6496 def @tags end |
#username ⇒ Object
The username to authenticate with.
6498 6499 6500 |
# File 'lib/models/porcelain.rb', line 6498 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6534 6535 6536 6537 6538 6539 6540 |
# File 'lib/models/porcelain.rb', line 6534 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |