Class: SDM::Postgres
- Inherits:
-
Object
- Object
- SDM::Postgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres
constructor
A new instance of Postgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres
Returns a new instance of Postgres.
6071 6072 6073 6074 6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 6088 6089 6090 6091 6092 6093 6094 6095 6096 6097 6098 6099 6100 6101 6102 6103 |
# File 'lib/models/porcelain.rb', line 6071 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6041 6042 6043 |
# File 'lib/models/porcelain.rb', line 6041 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
6043 6044 6045 |
# File 'lib/models/porcelain.rb', line 6043 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6045 6046 6047 |
# File 'lib/models/porcelain.rb', line 6045 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6047 6048 6049 |
# File 'lib/models/porcelain.rb', line 6047 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6049 6050 6051 |
# File 'lib/models/porcelain.rb', line 6049 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6051 6052 6053 |
# File 'lib/models/porcelain.rb', line 6051 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6053 6054 6055 |
# File 'lib/models/porcelain.rb', line 6053 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
6055 6056 6057 |
# File 'lib/models/porcelain.rb', line 6055 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
6057 6058 6059 |
# File 'lib/models/porcelain.rb', line 6057 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6059 6060 6061 |
# File 'lib/models/porcelain.rb', line 6059 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6061 6062 6063 |
# File 'lib/models/porcelain.rb', line 6061 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6063 6064 6065 |
# File 'lib/models/porcelain.rb', line 6063 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6065 6066 6067 |
# File 'lib/models/porcelain.rb', line 6065 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6067 6068 6069 |
# File 'lib/models/porcelain.rb', line 6067 def @tags end |
#username ⇒ Object
The username to authenticate with.
6069 6070 6071 |
# File 'lib/models/porcelain.rb', line 6069 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6105 6106 6107 6108 6109 6110 6111 |
# File 'lib/models/porcelain.rb', line 6105 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |