Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
6093
6094
6095
6096
6097
6098
6099
6100
6101
6102
6103
6104
6105
6106
6107
6108
# File 'lib/models/porcelain.rb', line 6076

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6046
6047
6048
# File 'lib/models/porcelain.rb', line 6046

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6048
6049
6050
# File 'lib/models/porcelain.rb', line 6048

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6050
6051
6052
# File 'lib/models/porcelain.rb', line 6050

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6052
6053
6054
# File 'lib/models/porcelain.rb', line 6052

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6054
6055
6056
# File 'lib/models/porcelain.rb', line 6054

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6056
6057
6058
# File 'lib/models/porcelain.rb', line 6056

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6058
6059
6060
# File 'lib/models/porcelain.rb', line 6058

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



6060
6061
6062
# File 'lib/models/porcelain.rb', line 6060

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



6062
6063
6064
# File 'lib/models/porcelain.rb', line 6062

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6064
6065
6066
# File 'lib/models/porcelain.rb', line 6064

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6066
6067
6068
# File 'lib/models/porcelain.rb', line 6066

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6068
6069
6070
# File 'lib/models/porcelain.rb', line 6068

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6070
6071
6072
# File 'lib/models/porcelain.rb', line 6070

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6072
6073
6074
# File 'lib/models/porcelain.rb', line 6072

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6074
6075
6076
# File 'lib/models/porcelain.rb', line 6074

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6110
6111
6112
6113
6114
6115
6116
# File 'lib/models/porcelain.rb', line 6110

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end