Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
5893
5894
# File 'lib/models/porcelain.rb', line 5862

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5832
5833
5834
# File 'lib/models/porcelain.rb', line 5832

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



5834
5835
5836
# File 'lib/models/porcelain.rb', line 5834

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5836
5837
5838
# File 'lib/models/porcelain.rb', line 5836

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5838
5839
5840
# File 'lib/models/porcelain.rb', line 5838

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5840
5841
5842
# File 'lib/models/porcelain.rb', line 5840

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5842
5843
5844
# File 'lib/models/porcelain.rb', line 5842

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5844
5845
5846
# File 'lib/models/porcelain.rb', line 5844

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



5846
5847
5848
# File 'lib/models/porcelain.rb', line 5846

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



5848
5849
5850
# File 'lib/models/porcelain.rb', line 5848

def password
  @password
end

#portObject

Returns the value of attribute port.



5850
5851
5852
# File 'lib/models/porcelain.rb', line 5850

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5852
5853
5854
# File 'lib/models/porcelain.rb', line 5852

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5854
5855
5856
# File 'lib/models/porcelain.rb', line 5854

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5856
5857
5858
# File 'lib/models/porcelain.rb', line 5856

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5858
5859
5860
# File 'lib/models/porcelain.rb', line 5858

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5860
5861
5862
# File 'lib/models/porcelain.rb', line 5860

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5896
5897
5898
5899
5900
5901
5902
# File 'lib/models/porcelain.rb', line 5896

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end