Class: SDM::Postgres
- Inherits:
-
Object
- Object
- SDM::Postgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres
constructor
A new instance of Postgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres
Returns a new instance of Postgres.
5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 |
# File 'lib/models/porcelain.rb', line 5490 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5462 5463 5464 |
# File 'lib/models/porcelain.rb', line 5462 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5464 5465 5466 |
# File 'lib/models/porcelain.rb', line 5464 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5466 5467 5468 |
# File 'lib/models/porcelain.rb', line 5466 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5468 5469 5470 |
# File 'lib/models/porcelain.rb', line 5468 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5470 5471 5472 |
# File 'lib/models/porcelain.rb', line 5470 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5472 5473 5474 |
# File 'lib/models/porcelain.rb', line 5472 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5474 5475 5476 |
# File 'lib/models/porcelain.rb', line 5474 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5476 5477 5478 |
# File 'lib/models/porcelain.rb', line 5476 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5478 5479 5480 |
# File 'lib/models/porcelain.rb', line 5478 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5480 5481 5482 |
# File 'lib/models/porcelain.rb', line 5480 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5482 5483 5484 |
# File 'lib/models/porcelain.rb', line 5482 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5484 5485 5486 |
# File 'lib/models/porcelain.rb', line 5484 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5486 5487 5488 |
# File 'lib/models/porcelain.rb', line 5486 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5488 5489 5490 |
# File 'lib/models/porcelain.rb', line 5488 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5522 5523 5524 5525 5526 5527 5528 |
# File 'lib/models/porcelain.rb', line 5522 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |