Class: SDM::Postgres
- Inherits:
-
Object
- Object
- SDM::Postgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres
constructor
A new instance of Postgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres
Returns a new instance of Postgres.
4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 |
# File 'lib/models/porcelain.rb', line 4977 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4949 4950 4951 |
# File 'lib/models/porcelain.rb', line 4949 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4951 4952 4953 |
# File 'lib/models/porcelain.rb', line 4951 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4953 4954 4955 |
# File 'lib/models/porcelain.rb', line 4953 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4955 4956 4957 |
# File 'lib/models/porcelain.rb', line 4955 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4957 4958 4959 |
# File 'lib/models/porcelain.rb', line 4957 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4959 4960 4961 |
# File 'lib/models/porcelain.rb', line 4959 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4961 4962 4963 |
# File 'lib/models/porcelain.rb', line 4961 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
4963 4964 4965 |
# File 'lib/models/porcelain.rb', line 4963 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
4965 4966 4967 |
# File 'lib/models/porcelain.rb', line 4965 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4967 4968 4969 |
# File 'lib/models/porcelain.rb', line 4967 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4969 4970 4971 |
# File 'lib/models/porcelain.rb', line 4969 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4971 4972 4973 |
# File 'lib/models/porcelain.rb', line 4971 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4973 4974 4975 |
# File 'lib/models/porcelain.rb', line 4973 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4975 4976 4977 |
# File 'lib/models/porcelain.rb', line 4975 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5009 5010 5011 5012 5013 5014 5015 |
# File 'lib/models/porcelain.rb', line 5009 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |