Class: SDM::Postgres
- Inherits:
-
Object
- Object
- SDM::Postgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres
constructor
A new instance of Postgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres
Returns a new instance of Postgres.
4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 |
# File 'lib/models/porcelain.rb', line 4865 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4837 4838 4839 |
# File 'lib/models/porcelain.rb', line 4837 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
4839 4840 4841 |
# File 'lib/models/porcelain.rb', line 4839 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4841 4842 4843 |
# File 'lib/models/porcelain.rb', line 4841 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4843 4844 4845 |
# File 'lib/models/porcelain.rb', line 4843 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4845 4846 4847 |
# File 'lib/models/porcelain.rb', line 4845 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4847 4848 4849 |
# File 'lib/models/porcelain.rb', line 4847 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4849 4850 4851 |
# File 'lib/models/porcelain.rb', line 4849 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
4851 4852 4853 |
# File 'lib/models/porcelain.rb', line 4851 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
4853 4854 4855 |
# File 'lib/models/porcelain.rb', line 4853 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4855 4856 4857 |
# File 'lib/models/porcelain.rb', line 4855 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4857 4858 4859 |
# File 'lib/models/porcelain.rb', line 4857 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4859 4860 4861 |
# File 'lib/models/porcelain.rb', line 4859 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4861 4862 4863 |
# File 'lib/models/porcelain.rb', line 4861 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4863 4864 4865 |
# File 'lib/models/porcelain.rb', line 4863 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4897 4898 4899 4900 4901 4902 4903 |
# File 'lib/models/porcelain.rb', line 4897 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |