Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
4879
4880
# File 'lib/models/porcelain.rb', line 4850

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



4822
4823
4824
# File 'lib/models/porcelain.rb', line 4822

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



4824
4825
4826
# File 'lib/models/porcelain.rb', line 4824

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



4826
4827
4828
# File 'lib/models/porcelain.rb', line 4826

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



4828
4829
4830
# File 'lib/models/porcelain.rb', line 4828

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



4830
4831
4832
# File 'lib/models/porcelain.rb', line 4830

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



4832
4833
4834
# File 'lib/models/porcelain.rb', line 4832

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



4834
4835
4836
# File 'lib/models/porcelain.rb', line 4834

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



4836
4837
4838
# File 'lib/models/porcelain.rb', line 4836

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



4838
4839
4840
# File 'lib/models/porcelain.rb', line 4838

def password
  @password
end

#portObject

Returns the value of attribute port.



4840
4841
4842
# File 'lib/models/porcelain.rb', line 4840

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



4842
4843
4844
# File 'lib/models/porcelain.rb', line 4842

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



4844
4845
4846
# File 'lib/models/porcelain.rb', line 4844

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



4846
4847
4848
# File 'lib/models/porcelain.rb', line 4846

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



4848
4849
4850
# File 'lib/models/porcelain.rb', line 4848

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



4882
4883
4884
4885
4886
4887
4888
# File 'lib/models/porcelain.rb', line 4882

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end