Class: SDM::Postgres
- Inherits:
-
Object
- Object
- SDM::Postgres
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres
constructor
A new instance of Postgres.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Postgres
Returns a new instance of Postgres.
5379 5380 5381 5382 5383 5384 5385 5386 5387 5388 5389 5390 5391 5392 5393 5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 |
# File 'lib/models/porcelain.rb', line 5379 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if override_database != nil @override_database = override_database end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
5353 5354 5355 |
# File 'lib/models/porcelain.rb', line 5353 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5355 5356 5357 |
# File 'lib/models/porcelain.rb', line 5355 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5357 5358 5359 |
# File 'lib/models/porcelain.rb', line 5357 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5359 5360 5361 |
# File 'lib/models/porcelain.rb', line 5359 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5361 5362 5363 |
# File 'lib/models/porcelain.rb', line 5361 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5363 5364 5365 |
# File 'lib/models/porcelain.rb', line 5363 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5365 5366 5367 |
# File 'lib/models/porcelain.rb', line 5365 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5367 5368 5369 |
# File 'lib/models/porcelain.rb', line 5367 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5369 5370 5371 |
# File 'lib/models/porcelain.rb', line 5369 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5371 5372 5373 |
# File 'lib/models/porcelain.rb', line 5371 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5373 5374 5375 |
# File 'lib/models/porcelain.rb', line 5373 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5375 5376 5377 |
# File 'lib/models/porcelain.rb', line 5375 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5377 5378 5379 |
# File 'lib/models/porcelain.rb', line 5377 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5435 5436 5437 5438 5439 5440 5441 |
# File 'lib/models/porcelain.rb', line 5435 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |