Class: SDM::Postgres

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Postgres

Returns a new instance of Postgres.



14087
14088
14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
# File 'lib/models/porcelain.rb', line 14087

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14055
14056
14057
# File 'lib/models/porcelain.rb', line 14055

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14057
14058
14059
# File 'lib/models/porcelain.rb', line 14057

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



14059
14060
14061
# File 'lib/models/porcelain.rb', line 14059

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



14061
14062
14063
# File 'lib/models/porcelain.rb', line 14061

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



14063
14064
14065
# File 'lib/models/porcelain.rb', line 14063

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



14065
14066
14067
# File 'lib/models/porcelain.rb', line 14065

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



14067
14068
14069
# File 'lib/models/porcelain.rb', line 14067

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14069
14070
14071
# File 'lib/models/porcelain.rb', line 14069

def override_database
  @override_database
end

#password ⇒ Object

The password to authenticate with.



14071
14072
14073
# File 'lib/models/porcelain.rb', line 14071

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



14073
14074
14075
# File 'lib/models/porcelain.rb', line 14073

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14075
14076
14077
# File 'lib/models/porcelain.rb', line 14075

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



14077
14078
14079
# File 'lib/models/porcelain.rb', line 14077

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



14079
14080
14081
# File 'lib/models/porcelain.rb', line 14079

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14081
14082
14083
# File 'lib/models/porcelain.rb', line 14081

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



14083
14084
14085
# File 'lib/models/porcelain.rb', line 14083

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



14085
14086
14087
# File 'lib/models/porcelain.rb', line 14085

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14123
14124
14125
14126
14127
14128
14129
# File 'lib/models/porcelain.rb', line 14123

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end