Class: SDM::PostgresEngine

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, ttl: nil, username: nil) ⇒ PostgresEngine

Returns a new instance of PostgresEngine.



13980
13981
13982
13983
13984
13985
13986
13987
13988
13989
13990
13991
13992
13993
13994
13995
13996
13997
13998
13999
14000
14001
14002
14003
14004
14005
14006
14007
14008
14009
14010
14011
14012
14013
14014
14015
14016
# File 'lib/models/porcelain.rb', line 13980

def initialize(
  after_read_ttl: nil,
  database: nil,
  hostname: nil,
  id: nil,
  key_rotation_interval_days: nil,
  name: nil,
  node_selector: nil,
  password: nil,
  policy: nil,
  port: nil,
  public_key: nil,
  secret_store_id: nil,
  secret_store_root_path: nil,
  tags: nil,
  tls: nil,
  ttl: nil,
  username: nil
)
  @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl
  @database = database == nil ? "" : database
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days
  @name = name == nil ? "" : name
  @node_selector = node_selector == nil ? "" : node_selector
  @password = password == nil ? "" : password
  @policy = policy == nil ? nil : policy
  @port = port == nil ? 0 : port
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls = tls == nil ? false : tls
  @ttl = ttl == nil ? nil : ttl
  @username = username == nil ? "" : username
end

Instance Attribute Details

#after_read_ttlObject

The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.



13946
13947
13948
# File 'lib/models/porcelain.rb', line 13946

def after_read_ttl
  @after_read_ttl
end

#databaseObject

Database is the database to verify credential against.



13948
13949
13950
# File 'lib/models/porcelain.rb', line 13948

def database
  @database
end

#hostnameObject

Hostname is the hostname or IP address of the Postgres server.



13950
13951
13952
# File 'lib/models/porcelain.rb', line 13950

def hostname
  @hostname
end

#idObject

Unique identifier of the Secret Engine.



13952
13953
13954
# File 'lib/models/porcelain.rb', line 13952

def id
  @id
end

#key_rotation_interval_daysObject

An interval of public/private key rotation for secret engine in days



13954
13955
13956
# File 'lib/models/porcelain.rb', line 13954

def key_rotation_interval_days
  @key_rotation_interval_days
end

#nameObject

Unique human-readable name of the Secret Engine.



13956
13957
13958
# File 'lib/models/porcelain.rb', line 13956

def name
  @name
end

#node_selectorObject

node selector is used to narrow down the nodes used to communicate with with secret engine



13958
13959
13960
# File 'lib/models/porcelain.rb', line 13958

def node_selector
  @node_selector
end

#passwordObject

Password is the password to connect to the Postgres server.



13960
13961
13962
# File 'lib/models/porcelain.rb', line 13960

def password
  @password
end

#policyObject

Policy for password creation



13962
13963
13964
# File 'lib/models/porcelain.rb', line 13962

def policy
  @policy
end

#portObject

Port is the port number of the Postgres server.



13964
13965
13966
# File 'lib/models/porcelain.rb', line 13964

def port
  @port
end

#public_keyObject

Public key linked with a secret engine



13966
13967
13968
# File 'lib/models/porcelain.rb', line 13966

def public_key
  @public_key
end

#secret_store_idObject

Backing secret store identifier



13968
13969
13970
# File 'lib/models/porcelain.rb', line 13968

def secret_store_id
  @secret_store_id
end

#secret_store_root_pathObject

Backing Secret Store root path where managed secrets are going to be stored



13970
13971
13972
# File 'lib/models/porcelain.rb', line 13970

def secret_store_root_path
  @secret_store_root_path
end

#tagsObject

Tags is a map of key, value pairs.



13972
13973
13974
# File 'lib/models/porcelain.rb', line 13972

def tags
  @tags
end

#tlsObject

TLS enables TLS/SSL when connecting to the Postgres server.



13974
13975
13976
# File 'lib/models/porcelain.rb', line 13974

def tls
  @tls
end

#ttlObject

The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.



13976
13977
13978
# File 'lib/models/porcelain.rb', line 13976

def ttl
  @ttl
end

#usernameObject

Username is the username to connect to the Postgres server.



13978
13979
13980
# File 'lib/models/porcelain.rb', line 13978

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14018
14019
14020
14021
14022
14023
14024
# File 'lib/models/porcelain.rb', line 14018

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end