Class: SDM::PostgresEngine
- Inherits:
-
Object
- Object
- SDM::PostgresEngine
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#after_read_ttl ⇒ Object
The default time-to-live duration of the password after it's read.
-
#database ⇒ Object
Database is the database to verify credential against.
-
#hostname ⇒ Object
Hostname is the hostname or IP address of the Postgres server.
-
#id ⇒ Object
Unique identifier of the Secret Engine.
-
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days.
-
#name ⇒ Object
Unique human-readable name of the Secret Engine.
-
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine.
-
#password ⇒ Object
Password is the password to connect to the Postgres server.
-
#policy ⇒ Object
Policy for password creation.
-
#port ⇒ Object
Port is the port number of the Postgres server.
-
#public_key ⇒ Object
Public key linked with a secret engine.
-
#secret_store_id ⇒ Object
Backing secret store identifier.
-
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls ⇒ Object
TLS enables TLS/SSL when connecting to the Postgres server.
-
#ttl ⇒ Object
The default password time-to-live duration.
-
#username ⇒ Object
Username is the username to connect to the Postgres server.
Instance Method Summary collapse
-
#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, ttl: nil, username: nil) ⇒ PostgresEngine
constructor
A new instance of PostgresEngine.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, ttl: nil, username: nil) ⇒ PostgresEngine
Returns a new instance of PostgresEngine.
13754 13755 13756 13757 13758 13759 13760 13761 13762 13763 13764 13765 13766 13767 13768 13769 13770 13771 13772 13773 13774 13775 13776 13777 13778 13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 13789 13790 |
# File 'lib/models/porcelain.rb', line 13754 def initialize( after_read_ttl: nil, database: nil, hostname: nil, id: nil, key_rotation_interval_days: nil, name: nil, node_selector: nil, password: nil, policy: nil, port: nil, public_key: nil, secret_store_id: nil, secret_store_root_path: nil, tags: nil, tls: nil, ttl: nil, username: nil ) @after_read_ttl = after_read_ttl == nil ? nil : after_read_ttl @database = database == nil ? "" : database @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_rotation_interval_days = key_rotation_interval_days == nil ? 0 : key_rotation_interval_days @name = name == nil ? "" : name @node_selector = node_selector == nil ? "" : node_selector @password = password == nil ? "" : password @policy = policy == nil ? nil : policy @port = port == nil ? 0 : port @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @secret_store_root_path = secret_store_root_path == nil ? "" : secret_store_root_path @tags = == nil ? SDM::() : @tls = tls == nil ? false : tls @ttl = ttl == nil ? nil : ttl @username = username == nil ? "" : username end |
Instance Attribute Details
#after_read_ttl ⇒ Object
The default time-to-live duration of the password after it's read. Once the ttl has passed, a password will be rotated.
13720 13721 13722 |
# File 'lib/models/porcelain.rb', line 13720 def after_read_ttl @after_read_ttl end |
#database ⇒ Object
Database is the database to verify credential against.
13722 13723 13724 |
# File 'lib/models/porcelain.rb', line 13722 def database @database end |
#hostname ⇒ Object
Hostname is the hostname or IP address of the Postgres server.
13724 13725 13726 |
# File 'lib/models/porcelain.rb', line 13724 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Secret Engine.
13726 13727 13728 |
# File 'lib/models/porcelain.rb', line 13726 def id @id end |
#key_rotation_interval_days ⇒ Object
An interval of public/private key rotation for secret engine in days
13728 13729 13730 |
# File 'lib/models/porcelain.rb', line 13728 def key_rotation_interval_days @key_rotation_interval_days end |
#name ⇒ Object
Unique human-readable name of the Secret Engine.
13730 13731 13732 |
# File 'lib/models/porcelain.rb', line 13730 def name @name end |
#node_selector ⇒ Object
node selector is used to narrow down the nodes used to communicate with with secret engine
13732 13733 13734 |
# File 'lib/models/porcelain.rb', line 13732 def node_selector @node_selector end |
#password ⇒ Object
Password is the password to connect to the Postgres server.
13734 13735 13736 |
# File 'lib/models/porcelain.rb', line 13734 def password @password end |
#policy ⇒ Object
Policy for password creation
13736 13737 13738 |
# File 'lib/models/porcelain.rb', line 13736 def policy @policy end |
#port ⇒ Object
Port is the port number of the Postgres server.
13738 13739 13740 |
# File 'lib/models/porcelain.rb', line 13738 def port @port end |
#public_key ⇒ Object
Public key linked with a secret engine
13740 13741 13742 |
# File 'lib/models/porcelain.rb', line 13740 def public_key @public_key end |
#secret_store_id ⇒ Object
Backing secret store identifier
13742 13743 13744 |
# File 'lib/models/porcelain.rb', line 13742 def secret_store_id @secret_store_id end |
#secret_store_root_path ⇒ Object
Backing Secret Store root path where managed secrets are going to be stored
13744 13745 13746 |
# File 'lib/models/porcelain.rb', line 13744 def secret_store_root_path @secret_store_root_path end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13746 13747 13748 |
# File 'lib/models/porcelain.rb', line 13746 def @tags end |
#tls ⇒ Object
TLS enables TLS/SSL when connecting to the Postgres server.
13748 13749 13750 |
# File 'lib/models/porcelain.rb', line 13748 def tls @tls end |
#ttl ⇒ Object
The default password time-to-live duration. Once the ttl has passed, a password will be rotated the next time it's requested.
13750 13751 13752 |
# File 'lib/models/porcelain.rb', line 13750 def ttl @ttl end |
#username ⇒ Object
Username is the username to connect to the Postgres server.
13752 13753 13754 |
# File 'lib/models/porcelain.rb', line 13752 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13792 13793 13794 13795 13796 13797 13798 |
# File 'lib/models/porcelain.rb', line 13792 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |