Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
13847
13848
13849
13850
13851
13852
13853
13854
13855
13856
13857
13858
13859
13860
13861
13862
13863
13864
13865
13866
13867
13868
13869
# File 'lib/models/porcelain.rb', line 13835

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13803
13804
13805
# File 'lib/models/porcelain.rb', line 13803

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13805
13806
13807
# File 'lib/models/porcelain.rb', line 13805

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13807
13808
13809
# File 'lib/models/porcelain.rb', line 13807

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13809
13810
13811
# File 'lib/models/porcelain.rb', line 13809

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13811
13812
13813
# File 'lib/models/porcelain.rb', line 13811

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13813
13814
13815
# File 'lib/models/porcelain.rb', line 13813

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13815
13816
13817
# File 'lib/models/porcelain.rb', line 13815

def name
  @name
end

#passwordObject

The password to authenticate with.



13817
13818
13819
# File 'lib/models/porcelain.rb', line 13817

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13819
13820
13821
# File 'lib/models/porcelain.rb', line 13819

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13821
13822
13823
# File 'lib/models/porcelain.rb', line 13821

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13823
13824
13825
# File 'lib/models/porcelain.rb', line 13823

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13825
13826
13827
# File 'lib/models/porcelain.rb', line 13825

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13827
13828
13829
# File 'lib/models/porcelain.rb', line 13827

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13829
13830
13831
# File 'lib/models/porcelain.rb', line 13829

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



13831
13832
13833
# File 'lib/models/porcelain.rb', line 13831

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



13833
13834
13835
# File 'lib/models/porcelain.rb', line 13833

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13871
13872
13873
13874
13875
13876
13877
# File 'lib/models/porcelain.rb', line 13871

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end