Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



13426
13427
13428
13429
13430
13431
13432
13433
13434
13435
13436
13437
13438
13439
13440
13441
13442
13443
13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
13458
13459
13460
# File 'lib/models/porcelain.rb', line 13426

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13394
13395
13396
# File 'lib/models/porcelain.rb', line 13394

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13396
13397
13398
# File 'lib/models/porcelain.rb', line 13396

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13398
13399
13400
# File 'lib/models/porcelain.rb', line 13398

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13400
13401
13402
# File 'lib/models/porcelain.rb', line 13400

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13402
13403
13404
# File 'lib/models/porcelain.rb', line 13402

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13404
13405
13406
# File 'lib/models/porcelain.rb', line 13404

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13406
13407
13408
# File 'lib/models/porcelain.rb', line 13406

def name
  @name
end

#passwordObject

The password to authenticate with.



13408
13409
13410
# File 'lib/models/porcelain.rb', line 13408

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13410
13411
13412
# File 'lib/models/porcelain.rb', line 13410

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13412
13413
13414
# File 'lib/models/porcelain.rb', line 13412

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13414
13415
13416
# File 'lib/models/porcelain.rb', line 13414

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13416
13417
13418
# File 'lib/models/porcelain.rb', line 13416

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13418
13419
13420
# File 'lib/models/porcelain.rb', line 13418

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13420
13421
13422
# File 'lib/models/porcelain.rb', line 13420

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



13422
13423
13424
# File 'lib/models/porcelain.rb', line 13422

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



13424
13425
13426
# File 'lib/models/porcelain.rb', line 13424

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13462
13463
13464
13465
13466
13467
13468
# File 'lib/models/porcelain.rb', line 13462

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end