Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



11249
11250
11251
11252
11253
11254
11255
11256
11257
11258
11259
11260
11261
11262
11263
11264
11265
11266
11267
11268
11269
11270
11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
# File 'lib/models/porcelain.rb', line 11249

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11217
11218
11219
# File 'lib/models/porcelain.rb', line 11217

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11219
11220
11221
# File 'lib/models/porcelain.rb', line 11219

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11221
11222
11223
# File 'lib/models/porcelain.rb', line 11221

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11223
11224
11225
# File 'lib/models/porcelain.rb', line 11223

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11225
11226
11227
# File 'lib/models/porcelain.rb', line 11225

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11227
11228
11229
# File 'lib/models/porcelain.rb', line 11227

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11229
11230
11231
# File 'lib/models/porcelain.rb', line 11229

def name
  @name
end

#passwordObject

The password to authenticate with.



11231
11232
11233
# File 'lib/models/porcelain.rb', line 11231

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11233
11234
11235
# File 'lib/models/porcelain.rb', line 11233

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11235
11236
11237
# File 'lib/models/porcelain.rb', line 11235

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11237
11238
11239
# File 'lib/models/porcelain.rb', line 11237

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11239
11240
11241
# File 'lib/models/porcelain.rb', line 11239

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11241
11242
11243
# File 'lib/models/porcelain.rb', line 11241

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11243
11244
11245
# File 'lib/models/porcelain.rb', line 11243

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11245
11246
11247
# File 'lib/models/porcelain.rb', line 11245

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11247
11248
11249
# File 'lib/models/porcelain.rb', line 11247

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11285
11286
11287
11288
11289
11290
11291
# File 'lib/models/porcelain.rb', line 11285

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end