Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
10815 10816 10817 10818 10819 10820 10821 10822 10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 10840 10841 10842 10843 10844 10845 10846 10847 10848 10849 |
# File 'lib/models/porcelain.rb', line 10815 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10783 10784 10785 |
# File 'lib/models/porcelain.rb', line 10783 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
10785 10786 10787 |
# File 'lib/models/porcelain.rb', line 10785 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10787 10788 10789 |
# File 'lib/models/porcelain.rb', line 10787 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10789 10790 10791 |
# File 'lib/models/porcelain.rb', line 10789 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10791 10792 10793 |
# File 'lib/models/porcelain.rb', line 10791 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10793 10794 10795 |
# File 'lib/models/porcelain.rb', line 10793 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10795 10796 10797 |
# File 'lib/models/porcelain.rb', line 10795 def name @name end |
#password ⇒ Object
The password to authenticate with.
10797 10798 10799 |
# File 'lib/models/porcelain.rb', line 10797 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10799 10800 10801 |
# File 'lib/models/porcelain.rb', line 10799 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10801 10802 10803 |
# File 'lib/models/porcelain.rb', line 10801 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10803 10804 10805 |
# File 'lib/models/porcelain.rb', line 10803 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10805 10806 10807 |
# File 'lib/models/porcelain.rb', line 10805 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10807 10808 10809 |
# File 'lib/models/porcelain.rb', line 10807 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10809 10810 10811 |
# File 'lib/models/porcelain.rb', line 10809 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
10811 10812 10813 |
# File 'lib/models/porcelain.rb', line 10811 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
10813 10814 10815 |
# File 'lib/models/porcelain.rb', line 10813 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10851 10852 10853 10854 10855 10856 10857 |
# File 'lib/models/porcelain.rb', line 10851 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |