Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



10804
10805
10806
10807
10808
10809
10810
10811
10812
10813
10814
10815
10816
10817
10818
10819
10820
10821
10822
10823
10824
10825
10826
10827
10828
10829
10830
10831
10832
10833
10834
10835
10836
10837
10838
# File 'lib/models/porcelain.rb', line 10804

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10772
10773
10774
# File 'lib/models/porcelain.rb', line 10772

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10774
10775
10776
# File 'lib/models/porcelain.rb', line 10774

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10776
10777
10778
# File 'lib/models/porcelain.rb', line 10776

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10778
10779
10780
# File 'lib/models/porcelain.rb', line 10778

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10780
10781
10782
# File 'lib/models/porcelain.rb', line 10780

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10782
10783
10784
# File 'lib/models/porcelain.rb', line 10782

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10784
10785
10786
# File 'lib/models/porcelain.rb', line 10784

def name
  @name
end

#passwordObject

The password to authenticate with.



10786
10787
10788
# File 'lib/models/porcelain.rb', line 10786

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10788
10789
10790
# File 'lib/models/porcelain.rb', line 10788

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10790
10791
10792
# File 'lib/models/porcelain.rb', line 10790

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10792
10793
10794
# File 'lib/models/porcelain.rb', line 10792

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10794
10795
10796
# File 'lib/models/porcelain.rb', line 10794

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10796
10797
10798
# File 'lib/models/porcelain.rb', line 10796

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10798
10799
10800
# File 'lib/models/porcelain.rb', line 10798

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



10800
10801
10802
# File 'lib/models/porcelain.rb', line 10800

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



10802
10803
10804
# File 'lib/models/porcelain.rb', line 10802

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10840
10841
10842
10843
10844
10845
10846
# File 'lib/models/porcelain.rb', line 10840

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end