Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



10736
10737
10738
10739
10740
10741
10742
10743
10744
10745
10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
# File 'lib/models/porcelain.rb', line 10736

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10704
10705
10706
# File 'lib/models/porcelain.rb', line 10704

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10706
10707
10708
# File 'lib/models/porcelain.rb', line 10706

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10708
10709
10710
# File 'lib/models/porcelain.rb', line 10708

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10710
10711
10712
# File 'lib/models/porcelain.rb', line 10710

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10712
10713
10714
# File 'lib/models/porcelain.rb', line 10712

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10714
10715
10716
# File 'lib/models/porcelain.rb', line 10714

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10716
10717
10718
# File 'lib/models/porcelain.rb', line 10716

def name
  @name
end

#passwordObject

The password to authenticate with.



10718
10719
10720
# File 'lib/models/porcelain.rb', line 10718

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10720
10721
10722
# File 'lib/models/porcelain.rb', line 10720

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10722
10723
10724
# File 'lib/models/porcelain.rb', line 10722

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10724
10725
10726
# File 'lib/models/porcelain.rb', line 10724

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10726
10727
10728
# File 'lib/models/porcelain.rb', line 10726

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10728
10729
10730
# File 'lib/models/porcelain.rb', line 10728

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10730
10731
10732
# File 'lib/models/porcelain.rb', line 10730

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



10732
10733
10734
# File 'lib/models/porcelain.rb', line 10732

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



10734
10735
10736
# File 'lib/models/porcelain.rb', line 10734

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10772
10773
10774
10775
10776
10777
10778
# File 'lib/models/porcelain.rb', line 10772

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end