Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
10592 10593 10594 10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 10621 10622 10623 10624 10625 10626 |
# File 'lib/models/porcelain.rb', line 10592 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10560 10561 10562 |
# File 'lib/models/porcelain.rb', line 10560 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
10562 10563 10564 |
# File 'lib/models/porcelain.rb', line 10562 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10564 10565 10566 |
# File 'lib/models/porcelain.rb', line 10564 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10566 10567 10568 |
# File 'lib/models/porcelain.rb', line 10566 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10568 10569 10570 |
# File 'lib/models/porcelain.rb', line 10568 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10570 10571 10572 |
# File 'lib/models/porcelain.rb', line 10570 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10572 10573 10574 |
# File 'lib/models/porcelain.rb', line 10572 def name @name end |
#password ⇒ Object
The password to authenticate with.
10574 10575 10576 |
# File 'lib/models/porcelain.rb', line 10574 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10576 10577 10578 |
# File 'lib/models/porcelain.rb', line 10576 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10578 10579 10580 |
# File 'lib/models/porcelain.rb', line 10578 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10580 10581 10582 |
# File 'lib/models/porcelain.rb', line 10580 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10582 10583 10584 |
# File 'lib/models/porcelain.rb', line 10582 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10584 10585 10586 |
# File 'lib/models/porcelain.rb', line 10584 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10586 10587 10588 |
# File 'lib/models/porcelain.rb', line 10586 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
10588 10589 10590 |
# File 'lib/models/porcelain.rb', line 10588 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
10590 10591 10592 |
# File 'lib/models/porcelain.rb', line 10590 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10628 10629 10630 10631 10632 10633 10634 |
# File 'lib/models/porcelain.rb', line 10628 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |