Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 9763 9764 9765 9766 9767 9768 9769 9770 9771 9772 9773 9774 9775 9776 |
# File 'lib/models/porcelain.rb', line 9742 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9710 9711 9712 |
# File 'lib/models/porcelain.rb', line 9710 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9712 9713 9714 |
# File 'lib/models/porcelain.rb', line 9712 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9714 9715 9716 |
# File 'lib/models/porcelain.rb', line 9714 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9716 9717 9718 |
# File 'lib/models/porcelain.rb', line 9716 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9718 9719 9720 |
# File 'lib/models/porcelain.rb', line 9718 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9720 9721 9722 |
# File 'lib/models/porcelain.rb', line 9720 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9722 9723 9724 |
# File 'lib/models/porcelain.rb', line 9722 def name @name end |
#password ⇒ Object
The password to authenticate with.
9724 9725 9726 |
# File 'lib/models/porcelain.rb', line 9724 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9726 9727 9728 |
# File 'lib/models/porcelain.rb', line 9726 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9728 9729 9730 |
# File 'lib/models/porcelain.rb', line 9728 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9730 9731 9732 |
# File 'lib/models/porcelain.rb', line 9730 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9732 9733 9734 |
# File 'lib/models/porcelain.rb', line 9732 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9734 9735 9736 |
# File 'lib/models/porcelain.rb', line 9734 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9736 9737 9738 |
# File 'lib/models/porcelain.rb', line 9736 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9738 9739 9740 |
# File 'lib/models/porcelain.rb', line 9738 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9740 9741 9742 |
# File 'lib/models/porcelain.rb', line 9740 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9778 9779 9780 9781 9782 9783 9784 |
# File 'lib/models/porcelain.rb', line 9778 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |