Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 |
# File 'lib/models/porcelain.rb', line 9666 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9634 9635 9636 |
# File 'lib/models/porcelain.rb', line 9634 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9636 9637 9638 |
# File 'lib/models/porcelain.rb', line 9636 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9638 9639 9640 |
# File 'lib/models/porcelain.rb', line 9638 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9640 9641 9642 |
# File 'lib/models/porcelain.rb', line 9640 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9642 9643 9644 |
# File 'lib/models/porcelain.rb', line 9642 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9644 9645 9646 |
# File 'lib/models/porcelain.rb', line 9644 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9646 9647 9648 |
# File 'lib/models/porcelain.rb', line 9646 def name @name end |
#password ⇒ Object
The password to authenticate with.
9648 9649 9650 |
# File 'lib/models/porcelain.rb', line 9648 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9650 9651 9652 |
# File 'lib/models/porcelain.rb', line 9650 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9652 9653 9654 |
# File 'lib/models/porcelain.rb', line 9652 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9654 9655 9656 |
# File 'lib/models/porcelain.rb', line 9654 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9656 9657 9658 |
# File 'lib/models/porcelain.rb', line 9656 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9658 9659 9660 |
# File 'lib/models/porcelain.rb', line 9658 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9660 9661 9662 |
# File 'lib/models/porcelain.rb', line 9660 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9662 9663 9664 |
# File 'lib/models/porcelain.rb', line 9662 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9664 9665 9666 |
# File 'lib/models/porcelain.rb', line 9664 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9702 9703 9704 9705 9706 9707 9708 |
# File 'lib/models/porcelain.rb', line 9702 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |