Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



9667
9668
9669
9670
9671
9672
9673
9674
9675
9676
9677
9678
9679
9680
9681
9682
9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
9694
9695
9696
9697
9698
9699
9700
9701
# File 'lib/models/porcelain.rb', line 9667

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9635
9636
9637
# File 'lib/models/porcelain.rb', line 9635

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9637
9638
9639
# File 'lib/models/porcelain.rb', line 9637

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9639
9640
9641
# File 'lib/models/porcelain.rb', line 9639

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9641
9642
9643
# File 'lib/models/porcelain.rb', line 9641

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9643
9644
9645
# File 'lib/models/porcelain.rb', line 9643

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9645
9646
9647
# File 'lib/models/porcelain.rb', line 9645

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9647
9648
9649
# File 'lib/models/porcelain.rb', line 9647

def name
  @name
end

#passwordObject

The password to authenticate with.



9649
9650
9651
# File 'lib/models/porcelain.rb', line 9649

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9651
9652
9653
# File 'lib/models/porcelain.rb', line 9651

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9653
9654
9655
# File 'lib/models/porcelain.rb', line 9653

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9655
9656
9657
# File 'lib/models/porcelain.rb', line 9655

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9657
9658
9659
# File 'lib/models/porcelain.rb', line 9657

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9659
9660
9661
# File 'lib/models/porcelain.rb', line 9659

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9661
9662
9663
# File 'lib/models/porcelain.rb', line 9661

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9663
9664
9665
# File 'lib/models/porcelain.rb', line 9663

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9665
9666
9667
# File 'lib/models/porcelain.rb', line 9665

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9703
9704
9705
9706
9707
9708
9709
# File 'lib/models/porcelain.rb', line 9703

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end