Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 9684 9685 9686 9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 |
# File 'lib/models/porcelain.rb', line 9663 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9631 9632 9633 |
# File 'lib/models/porcelain.rb', line 9631 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9633 9634 9635 |
# File 'lib/models/porcelain.rb', line 9633 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9635 9636 9637 |
# File 'lib/models/porcelain.rb', line 9635 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9637 9638 9639 |
# File 'lib/models/porcelain.rb', line 9637 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9639 9640 9641 |
# File 'lib/models/porcelain.rb', line 9639 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9641 9642 9643 |
# File 'lib/models/porcelain.rb', line 9641 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9643 9644 9645 |
# File 'lib/models/porcelain.rb', line 9643 def name @name end |
#password ⇒ Object
The password to authenticate with.
9645 9646 9647 |
# File 'lib/models/porcelain.rb', line 9645 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9647 9648 9649 |
# File 'lib/models/porcelain.rb', line 9647 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9649 9650 9651 |
# File 'lib/models/porcelain.rb', line 9649 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9651 9652 9653 |
# File 'lib/models/porcelain.rb', line 9651 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9653 9654 9655 |
# File 'lib/models/porcelain.rb', line 9653 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9655 9656 9657 |
# File 'lib/models/porcelain.rb', line 9655 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9657 9658 9659 |
# File 'lib/models/porcelain.rb', line 9657 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9659 9660 9661 |
# File 'lib/models/porcelain.rb', line 9659 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9661 9662 9663 |
# File 'lib/models/porcelain.rb', line 9661 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9699 9700 9701 9702 9703 9704 9705 |
# File 'lib/models/porcelain.rb', line 9699 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |