Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 9610 9611 9612 9613 9614 9615 9616 9617 9618 9619 9620 9621 |
# File 'lib/models/porcelain.rb', line 9587 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9555 9556 9557 |
# File 'lib/models/porcelain.rb', line 9555 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9557 9558 9559 |
# File 'lib/models/porcelain.rb', line 9557 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9559 9560 9561 |
# File 'lib/models/porcelain.rb', line 9559 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9561 9562 9563 |
# File 'lib/models/porcelain.rb', line 9561 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9563 9564 9565 |
# File 'lib/models/porcelain.rb', line 9563 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9565 9566 9567 |
# File 'lib/models/porcelain.rb', line 9565 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9567 9568 9569 |
# File 'lib/models/porcelain.rb', line 9567 def name @name end |
#password ⇒ Object
The password to authenticate with.
9569 9570 9571 |
# File 'lib/models/porcelain.rb', line 9569 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9571 9572 9573 |
# File 'lib/models/porcelain.rb', line 9571 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9573 9574 9575 |
# File 'lib/models/porcelain.rb', line 9573 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9575 9576 9577 |
# File 'lib/models/porcelain.rb', line 9575 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9577 9578 9579 |
# File 'lib/models/porcelain.rb', line 9577 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9579 9580 9581 |
# File 'lib/models/porcelain.rb', line 9579 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9581 9582 9583 |
# File 'lib/models/porcelain.rb', line 9581 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9583 9584 9585 |
# File 'lib/models/porcelain.rb', line 9583 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9585 9586 9587 |
# File 'lib/models/porcelain.rb', line 9585 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9623 9624 9625 9626 9627 9628 9629 |
# File 'lib/models/porcelain.rb', line 9623 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |