Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
9516 9517 9518 9519 9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 |
# File 'lib/models/porcelain.rb', line 9516 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9484 9485 9486 |
# File 'lib/models/porcelain.rb', line 9484 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9486 9487 9488 |
# File 'lib/models/porcelain.rb', line 9486 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9488 9489 9490 |
# File 'lib/models/porcelain.rb', line 9488 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9490 9491 9492 |
# File 'lib/models/porcelain.rb', line 9490 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9492 9493 9494 |
# File 'lib/models/porcelain.rb', line 9492 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9494 9495 9496 |
# File 'lib/models/porcelain.rb', line 9494 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9496 9497 9498 |
# File 'lib/models/porcelain.rb', line 9496 def name @name end |
#password ⇒ Object
The password to authenticate with.
9498 9499 9500 |
# File 'lib/models/porcelain.rb', line 9498 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9500 9501 9502 |
# File 'lib/models/porcelain.rb', line 9500 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9502 9503 9504 |
# File 'lib/models/porcelain.rb', line 9502 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9504 9505 9506 |
# File 'lib/models/porcelain.rb', line 9504 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9506 9507 9508 |
# File 'lib/models/porcelain.rb', line 9506 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9508 9509 9510 |
# File 'lib/models/porcelain.rb', line 9508 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9510 9511 9512 |
# File 'lib/models/porcelain.rb', line 9510 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9512 9513 9514 |
# File 'lib/models/porcelain.rb', line 9512 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9514 9515 9516 |
# File 'lib/models/porcelain.rb', line 9514 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9552 9553 9554 9555 9556 9557 9558 |
# File 'lib/models/porcelain.rb', line 9552 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |