Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 |
# File 'lib/models/porcelain.rb', line 9450 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9418 9419 9420 |
# File 'lib/models/porcelain.rb', line 9418 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9420 9421 9422 |
# File 'lib/models/porcelain.rb', line 9420 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9422 9423 9424 |
# File 'lib/models/porcelain.rb', line 9422 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9424 9425 9426 |
# File 'lib/models/porcelain.rb', line 9424 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9426 9427 9428 |
# File 'lib/models/porcelain.rb', line 9426 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9428 9429 9430 |
# File 'lib/models/porcelain.rb', line 9428 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9430 9431 9432 |
# File 'lib/models/porcelain.rb', line 9430 def name @name end |
#password ⇒ Object
The password to authenticate with.
9432 9433 9434 |
# File 'lib/models/porcelain.rb', line 9432 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9434 9435 9436 |
# File 'lib/models/porcelain.rb', line 9434 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9436 9437 9438 |
# File 'lib/models/porcelain.rb', line 9436 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9438 9439 9440 |
# File 'lib/models/porcelain.rb', line 9438 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9440 9441 9442 |
# File 'lib/models/porcelain.rb', line 9440 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9442 9443 9444 |
# File 'lib/models/porcelain.rb', line 9442 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9444 9445 9446 |
# File 'lib/models/porcelain.rb', line 9444 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9446 9447 9448 |
# File 'lib/models/porcelain.rb', line 9446 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9448 9449 9450 |
# File 'lib/models/porcelain.rb', line 9448 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9486 9487 9488 9489 9490 9491 9492 |
# File 'lib/models/porcelain.rb', line 9486 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |