Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
8906 8907 8908 8909 8910 8911 8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 8935 8936 8937 8938 8939 8940 |
# File 'lib/models/porcelain.rb', line 8906 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8874 8875 8876 |
# File 'lib/models/porcelain.rb', line 8874 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8876 8877 8878 |
# File 'lib/models/porcelain.rb', line 8876 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8878 8879 8880 |
# File 'lib/models/porcelain.rb', line 8878 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8880 8881 8882 |
# File 'lib/models/porcelain.rb', line 8880 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8882 8883 8884 |
# File 'lib/models/porcelain.rb', line 8882 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8884 8885 8886 |
# File 'lib/models/porcelain.rb', line 8884 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8886 8887 8888 |
# File 'lib/models/porcelain.rb', line 8886 def name @name end |
#password ⇒ Object
The password to authenticate with.
8888 8889 8890 |
# File 'lib/models/porcelain.rb', line 8888 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8890 8891 8892 |
# File 'lib/models/porcelain.rb', line 8890 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8892 8893 8894 |
# File 'lib/models/porcelain.rb', line 8892 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8894 8895 8896 |
# File 'lib/models/porcelain.rb', line 8894 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8896 8897 8898 |
# File 'lib/models/porcelain.rb', line 8896 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8898 8899 8900 |
# File 'lib/models/porcelain.rb', line 8898 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8900 8901 8902 |
# File 'lib/models/porcelain.rb', line 8900 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8902 8903 8904 |
# File 'lib/models/porcelain.rb', line 8902 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8904 8905 8906 |
# File 'lib/models/porcelain.rb', line 8904 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8942 8943 8944 8945 8946 8947 8948 |
# File 'lib/models/porcelain.rb', line 8942 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |