Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 |
# File 'lib/models/porcelain.rb', line 8835 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8803 8804 8805 |
# File 'lib/models/porcelain.rb', line 8803 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8805 8806 8807 |
# File 'lib/models/porcelain.rb', line 8805 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8807 8808 8809 |
# File 'lib/models/porcelain.rb', line 8807 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8809 8810 8811 |
# File 'lib/models/porcelain.rb', line 8809 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8811 8812 8813 |
# File 'lib/models/porcelain.rb', line 8811 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8813 8814 8815 |
# File 'lib/models/porcelain.rb', line 8813 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8815 8816 8817 |
# File 'lib/models/porcelain.rb', line 8815 def name @name end |
#password ⇒ Object
The password to authenticate with.
8817 8818 8819 |
# File 'lib/models/porcelain.rb', line 8817 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8819 8820 8821 |
# File 'lib/models/porcelain.rb', line 8819 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8821 8822 8823 |
# File 'lib/models/porcelain.rb', line 8821 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
8823 8824 8825 |
# File 'lib/models/porcelain.rb', line 8823 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8825 8826 8827 |
# File 'lib/models/porcelain.rb', line 8825 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8827 8828 8829 |
# File 'lib/models/porcelain.rb', line 8827 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8829 8830 8831 |
# File 'lib/models/porcelain.rb', line 8829 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8831 8832 8833 |
# File 'lib/models/porcelain.rb', line 8831 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8833 8834 8835 |
# File 'lib/models/porcelain.rb', line 8833 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8871 8872 8873 8874 8875 8876 8877 |
# File 'lib/models/porcelain.rb', line 8871 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |