Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
8500 8501 8502 8503 8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 |
# File 'lib/models/porcelain.rb', line 8500 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8470 8471 8472 |
# File 'lib/models/porcelain.rb', line 8470 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8472 8473 8474 |
# File 'lib/models/porcelain.rb', line 8472 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8474 8475 8476 |
# File 'lib/models/porcelain.rb', line 8474 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8476 8477 8478 |
# File 'lib/models/porcelain.rb', line 8476 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8478 8479 8480 |
# File 'lib/models/porcelain.rb', line 8478 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8480 8481 8482 |
# File 'lib/models/porcelain.rb', line 8480 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8482 8483 8484 |
# File 'lib/models/porcelain.rb', line 8482 def name @name end |
#password ⇒ Object
The password to authenticate with.
8484 8485 8486 |
# File 'lib/models/porcelain.rb', line 8484 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8486 8487 8488 |
# File 'lib/models/porcelain.rb', line 8486 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8488 8489 8490 |
# File 'lib/models/porcelain.rb', line 8488 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8490 8491 8492 |
# File 'lib/models/porcelain.rb', line 8490 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8492 8493 8494 |
# File 'lib/models/porcelain.rb', line 8492 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8494 8495 8496 |
# File 'lib/models/porcelain.rb', line 8494 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8496 8497 8498 |
# File 'lib/models/porcelain.rb', line 8496 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8498 8499 8500 |
# File 'lib/models/porcelain.rb', line 8498 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8534 8535 8536 8537 8538 8539 8540 |
# File 'lib/models/porcelain.rb', line 8534 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |