Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 6761 6762 6763 6764 6765 6766 6767 6768 6769 6770 6771 6772 6773 6774 6775 6776 6777 6778 6779 |
# File 'lib/models/porcelain.rb', line 6747 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6717 6718 6719 |
# File 'lib/models/porcelain.rb', line 6717 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
6719 6720 6721 |
# File 'lib/models/porcelain.rb', line 6719 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6721 6722 6723 |
# File 'lib/models/porcelain.rb', line 6721 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6723 6724 6725 |
# File 'lib/models/porcelain.rb', line 6723 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6725 6726 6727 |
# File 'lib/models/porcelain.rb', line 6725 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6727 6728 6729 |
# File 'lib/models/porcelain.rb', line 6727 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6729 6730 6731 |
# File 'lib/models/porcelain.rb', line 6729 def name @name end |
#password ⇒ Object
The password to authenticate with.
6731 6732 6733 |
# File 'lib/models/porcelain.rb', line 6731 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6733 6734 6735 |
# File 'lib/models/porcelain.rb', line 6733 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6735 6736 6737 |
# File 'lib/models/porcelain.rb', line 6735 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6737 6738 6739 |
# File 'lib/models/porcelain.rb', line 6737 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6739 6740 6741 |
# File 'lib/models/porcelain.rb', line 6739 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6741 6742 6743 |
# File 'lib/models/porcelain.rb', line 6741 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
6743 6744 6745 |
# File 'lib/models/porcelain.rb', line 6743 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
6745 6746 6747 |
# File 'lib/models/porcelain.rb', line 6745 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6781 6782 6783 6784 6785 6786 6787 |
# File 'lib/models/porcelain.rb', line 6781 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |