Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
6600
6601
6602
6603
6604
6605
6606
6607
6608
6609
6610
6611
6612
6613
6614
6615
# File 'lib/models/porcelain.rb', line 6583

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6553
6554
6555
# File 'lib/models/porcelain.rb', line 6553

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



6555
6556
6557
# File 'lib/models/porcelain.rb', line 6555

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6557
6558
6559
# File 'lib/models/porcelain.rb', line 6557

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6559
6560
6561
# File 'lib/models/porcelain.rb', line 6559

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6561
6562
6563
# File 'lib/models/porcelain.rb', line 6561

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6563
6564
6565
# File 'lib/models/porcelain.rb', line 6563

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6565
6566
6567
# File 'lib/models/porcelain.rb', line 6565

def name
  @name
end

#passwordObject

The password to authenticate with.



6567
6568
6569
# File 'lib/models/porcelain.rb', line 6567

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6569
6570
6571
# File 'lib/models/porcelain.rb', line 6569

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6571
6572
6573
# File 'lib/models/porcelain.rb', line 6571

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6573
6574
6575
# File 'lib/models/porcelain.rb', line 6573

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6575
6576
6577
# File 'lib/models/porcelain.rb', line 6575

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6577
6578
6579
# File 'lib/models/porcelain.rb', line 6577

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



6579
6580
6581
# File 'lib/models/porcelain.rb', line 6579

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



6581
6582
6583
# File 'lib/models/porcelain.rb', line 6581

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6617
6618
6619
6620
6621
6622
6623
# File 'lib/models/porcelain.rb', line 6617

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end