Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 6177 6178 |
# File 'lib/models/porcelain.rb', line 6146 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6116 6117 6118 |
# File 'lib/models/porcelain.rb', line 6116 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
6118 6119 6120 |
# File 'lib/models/porcelain.rb', line 6118 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6120 6121 6122 |
# File 'lib/models/porcelain.rb', line 6120 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6122 6123 6124 |
# File 'lib/models/porcelain.rb', line 6122 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6124 6125 6126 |
# File 'lib/models/porcelain.rb', line 6124 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6126 6127 6128 |
# File 'lib/models/porcelain.rb', line 6126 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6128 6129 6130 |
# File 'lib/models/porcelain.rb', line 6128 def name @name end |
#password ⇒ Object
The password to authenticate with.
6130 6131 6132 |
# File 'lib/models/porcelain.rb', line 6130 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6132 6133 6134 |
# File 'lib/models/porcelain.rb', line 6132 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6134 6135 6136 |
# File 'lib/models/porcelain.rb', line 6134 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6136 6137 6138 |
# File 'lib/models/porcelain.rb', line 6136 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6138 6139 6140 |
# File 'lib/models/porcelain.rb', line 6138 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6140 6141 6142 |
# File 'lib/models/porcelain.rb', line 6140 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
6142 6143 6144 |
# File 'lib/models/porcelain.rb', line 6142 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
6144 6145 6146 |
# File 'lib/models/porcelain.rb', line 6144 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6180 6181 6182 6183 6184 6185 6186 |
# File 'lib/models/porcelain.rb', line 6180 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |