Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 |
# File 'lib/models/porcelain.rb', line 5993 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5963 5964 5965 |
# File 'lib/models/porcelain.rb', line 5963 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5965 5966 5967 |
# File 'lib/models/porcelain.rb', line 5965 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5967 5968 5969 |
# File 'lib/models/porcelain.rb', line 5967 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5969 5970 5971 |
# File 'lib/models/porcelain.rb', line 5969 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5971 5972 5973 |
# File 'lib/models/porcelain.rb', line 5971 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5973 5974 5975 |
# File 'lib/models/porcelain.rb', line 5973 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5975 5976 5977 |
# File 'lib/models/porcelain.rb', line 5975 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5977 5978 5979 |
# File 'lib/models/porcelain.rb', line 5977 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5979 5980 5981 |
# File 'lib/models/porcelain.rb', line 5979 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5981 5982 5983 |
# File 'lib/models/porcelain.rb', line 5981 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5983 5984 5985 |
# File 'lib/models/porcelain.rb', line 5983 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5985 5986 5987 |
# File 'lib/models/porcelain.rb', line 5985 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5987 5988 5989 |
# File 'lib/models/porcelain.rb', line 5987 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5989 5990 5991 |
# File 'lib/models/porcelain.rb', line 5989 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5991 5992 5993 |
# File 'lib/models/porcelain.rb', line 5991 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/models/porcelain.rb', line 6027 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |