Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
5926
5927
5928
5929
5930
5931
5932
5933
5934
5935
5936
5937
5938
5939
5940
5941
5942
5943
5944
5945
5946
5947
5948
# File 'lib/models/porcelain.rb', line 5916

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5886
5887
5888
# File 'lib/models/porcelain.rb', line 5886

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



5888
5889
5890
# File 'lib/models/porcelain.rb', line 5888

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5890
5891
5892
# File 'lib/models/porcelain.rb', line 5890

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5892
5893
5894
# File 'lib/models/porcelain.rb', line 5892

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5894
5895
5896
# File 'lib/models/porcelain.rb', line 5894

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5896
5897
5898
# File 'lib/models/porcelain.rb', line 5896

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5898
5899
5900
# File 'lib/models/porcelain.rb', line 5898

def name
  @name
end

#passwordObject

Returns the value of attribute password.



5900
5901
5902
# File 'lib/models/porcelain.rb', line 5900

def password
  @password
end

#portObject

Returns the value of attribute port.



5902
5903
5904
# File 'lib/models/porcelain.rb', line 5902

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5904
5905
5906
# File 'lib/models/porcelain.rb', line 5904

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5906
5907
5908
# File 'lib/models/porcelain.rb', line 5906

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



5908
5909
5910
# File 'lib/models/porcelain.rb', line 5908

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



5910
5911
5912
# File 'lib/models/porcelain.rb', line 5910

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



5912
5913
5914
# File 'lib/models/porcelain.rb', line 5912

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



5914
5915
5916
# File 'lib/models/porcelain.rb', line 5914

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5950
5951
5952
5953
5954
5955
5956
# File 'lib/models/porcelain.rb', line 5950

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end