Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
5561 5562 5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 5581 5582 5583 5584 5585 5586 5587 5588 5589 5590 5591 |
# File 'lib/models/porcelain.rb', line 5561 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5533 5534 5535 |
# File 'lib/models/porcelain.rb', line 5533 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5535 5536 5537 |
# File 'lib/models/porcelain.rb', line 5535 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5537 5538 5539 |
# File 'lib/models/porcelain.rb', line 5537 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5539 5540 5541 |
# File 'lib/models/porcelain.rb', line 5539 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5541 5542 5543 |
# File 'lib/models/porcelain.rb', line 5541 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5543 5544 5545 |
# File 'lib/models/porcelain.rb', line 5543 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5545 5546 5547 |
# File 'lib/models/porcelain.rb', line 5545 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5547 5548 5549 |
# File 'lib/models/porcelain.rb', line 5547 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5549 5550 5551 |
# File 'lib/models/porcelain.rb', line 5549 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5551 5552 5553 |
# File 'lib/models/porcelain.rb', line 5551 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5553 5554 5555 |
# File 'lib/models/porcelain.rb', line 5553 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5555 5556 5557 |
# File 'lib/models/porcelain.rb', line 5555 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5557 5558 5559 |
# File 'lib/models/porcelain.rb', line 5557 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5559 5560 5561 |
# File 'lib/models/porcelain.rb', line 5559 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5593 5594 5595 5596 5597 5598 5599 |
# File 'lib/models/porcelain.rb', line 5593 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |