Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
5047 5048 5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 |
# File 'lib/models/porcelain.rb', line 5047 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5019 5020 5021 |
# File 'lib/models/porcelain.rb', line 5019 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5021 5022 5023 |
# File 'lib/models/porcelain.rb', line 5021 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5023 5024 5025 |
# File 'lib/models/porcelain.rb', line 5023 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5025 5026 5027 |
# File 'lib/models/porcelain.rb', line 5025 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5027 5028 5029 |
# File 'lib/models/porcelain.rb', line 5027 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5029 5030 5031 |
# File 'lib/models/porcelain.rb', line 5029 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5031 5032 5033 |
# File 'lib/models/porcelain.rb', line 5031 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5033 5034 5035 |
# File 'lib/models/porcelain.rb', line 5033 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5035 5036 5037 |
# File 'lib/models/porcelain.rb', line 5035 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5037 5038 5039 |
# File 'lib/models/porcelain.rb', line 5037 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5039 5040 5041 |
# File 'lib/models/porcelain.rb', line 5039 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5041 5042 5043 |
# File 'lib/models/porcelain.rb', line 5041 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5043 5044 5045 |
# File 'lib/models/porcelain.rb', line 5043 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5045 5046 5047 |
# File 'lib/models/porcelain.rb', line 5045 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5079 5080 5081 5082 5083 5084 5085 |
# File 'lib/models/porcelain.rb', line 5079 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |