Class: SDM::Presto
- Inherits:
-
Object
- Object
- SDM::Presto
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
constructor
A new instance of Presto.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto
Returns a new instance of Presto.
5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 |
# File 'lib/models/porcelain.rb', line 5471 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
5445 5446 5447 |
# File 'lib/models/porcelain.rb', line 5445 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5447 5448 5449 |
# File 'lib/models/porcelain.rb', line 5447 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5449 5450 5451 |
# File 'lib/models/porcelain.rb', line 5449 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5451 5452 5453 |
# File 'lib/models/porcelain.rb', line 5451 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5453 5454 5455 |
# File 'lib/models/porcelain.rb', line 5453 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5455 5456 5457 |
# File 'lib/models/porcelain.rb', line 5455 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5457 5458 5459 |
# File 'lib/models/porcelain.rb', line 5457 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5459 5460 5461 |
# File 'lib/models/porcelain.rb', line 5459 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5461 5462 5463 |
# File 'lib/models/porcelain.rb', line 5461 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5463 5464 5465 |
# File 'lib/models/porcelain.rb', line 5463 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5465 5466 5467 |
# File 'lib/models/porcelain.rb', line 5465 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5467 5468 5469 |
# File 'lib/models/porcelain.rb', line 5467 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5469 5470 5471 |
# File 'lib/models/porcelain.rb', line 5469 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5527 5528 5529 5530 5531 5532 5533 |
# File 'lib/models/porcelain.rb', line 5527 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |