Class: SDM::Presto

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Presto

Returns a new instance of Presto.



13667
13668
13669
13670
13671
13672
13673
13674
13675
13676
13677
13678
13679
13680
13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
13694
13695
13696
13697
13698
13699
13700
13701
# File 'lib/models/porcelain.rb', line 13667

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13635
13636
13637
# File 'lib/models/porcelain.rb', line 13635

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13637
13638
13639
# File 'lib/models/porcelain.rb', line 13637

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13639
13640
13641
# File 'lib/models/porcelain.rb', line 13639

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13641
13642
13643
# File 'lib/models/porcelain.rb', line 13641

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13643
13644
13645
# File 'lib/models/porcelain.rb', line 13643

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13645
13646
13647
# File 'lib/models/porcelain.rb', line 13645

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13647
13648
13649
# File 'lib/models/porcelain.rb', line 13647

def name
  @name
end

#passwordObject

The password to authenticate with.



13649
13650
13651
# File 'lib/models/porcelain.rb', line 13649

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13651
13652
13653
# File 'lib/models/porcelain.rb', line 13651

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13653
13654
13655
# File 'lib/models/porcelain.rb', line 13653

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13655
13656
13657
# File 'lib/models/porcelain.rb', line 13655

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13657
13658
13659
# File 'lib/models/porcelain.rb', line 13657

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13659
13660
13661
# File 'lib/models/porcelain.rb', line 13659

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13661
13662
13663
# File 'lib/models/porcelain.rb', line 13661

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



13663
13664
13665
# File 'lib/models/porcelain.rb', line 13663

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



13665
13666
13667
# File 'lib/models/porcelain.rb', line 13665

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13703
13704
13705
13706
13707
13708
13709
# File 'lib/models/porcelain.rb', line 13703

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end