Class: SDM::ProxyCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ProxyCluster represents a cluster of StrongDM proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster

Returns a new instance of ProxyCluster.



13212
13213
13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
# File 'lib/models/porcelain.rb', line 13212

def initialize(
  address: nil,
  id: nil,
  maintenance_windows: nil,
  name: nil,
  tags: nil
)
  @address = address == nil ? "" : address
  @id = id == nil ? "" : id
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#addressObject

The public hostname/port tuple at which the proxy cluster will be accessible to clients.



13189
13190
13191
# File 'lib/models/porcelain.rb', line 13189

def address
  @address
end

#idObject

Unique identifier of the Proxy Cluster.



13191
13192
13193
# File 'lib/models/porcelain.rb', line 13191

def id
  @id
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



13204
13205
13206
# File 'lib/models/porcelain.rb', line 13204

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the proxy cluster. Names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



13208
13209
13210
# File 'lib/models/porcelain.rb', line 13208

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



13210
13211
13212
# File 'lib/models/porcelain.rb', line 13210

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13226
13227
13228
13229
13230
13231
13232
# File 'lib/models/porcelain.rb', line 13226

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end