Class: SDM::ProxyCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ProxyCluster represents a cluster of StrongDM proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster

Returns a new instance of ProxyCluster.



10887
10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
10898
10899
# File 'lib/models/porcelain.rb', line 10887

def initialize(
  address: nil,
  id: nil,
  maintenance_windows: nil,
  name: nil,
  tags: nil
)
  @address = address == nil ? "" : address
  @id = id == nil ? "" : id
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#addressObject

The public hostname/port tuple at which the proxy cluster will be accessible to clients.



10864
10865
10866
# File 'lib/models/porcelain.rb', line 10864

def address
  @address
end

#idObject

Unique identifier of the Proxy Cluster.



10866
10867
10868
# File 'lib/models/porcelain.rb', line 10866

def id
  @id
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10879
10880
10881
# File 'lib/models/porcelain.rb', line 10879

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the proxy cluster. Names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10883
10884
10885
# File 'lib/models/porcelain.rb', line 10883

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



10885
10886
10887
# File 'lib/models/porcelain.rb', line 10885

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10901
10902
10903
10904
10905
10906
10907
# File 'lib/models/porcelain.rb', line 10901

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end