Class: SDM::ProxyCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ProxyCluster represents a cluster of StrongDM proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster

Returns a new instance of ProxyCluster.



10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
# File 'lib/models/porcelain.rb', line 10876

def initialize(
  address: nil,
  id: nil,
  maintenance_windows: nil,
  name: nil,
  tags: nil
)
  @address = address == nil ? "" : address
  @id = id == nil ? "" : id
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#addressObject

The public hostname/port tuple at which the proxy cluster will be accessible to clients.



10853
10854
10855
# File 'lib/models/porcelain.rb', line 10853

def address
  @address
end

#idObject

Unique identifier of the Proxy Cluster.



10855
10856
10857
# File 'lib/models/porcelain.rb', line 10855

def id
  @id
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10868
10869
10870
# File 'lib/models/porcelain.rb', line 10868

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the proxy cluster. Names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10872
10873
10874
# File 'lib/models/porcelain.rb', line 10872

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



10874
10875
10876
# File 'lib/models/porcelain.rb', line 10874

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10890
10891
10892
10893
10894
10895
10896
# File 'lib/models/porcelain.rb', line 10890

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end