Class: SDM::ProxyCluster
- Inherits:
-
Object
- Object
- SDM::ProxyCluster
- Defined in:
- lib/models/porcelain.rb
Overview
ProxyCluster represents a cluster of StrongDM proxies.
Instance Attribute Summary collapse
-
#address ⇒ Object
The public hostname/port tuple at which the proxy cluster will be accessible to clients.
-
#id ⇒ Object
Unique identifier of the Proxy Cluster.
-
#maintenance_windows ⇒ Object
Maintenance Windows define when this node is allowed to restart.
-
#name ⇒ Object
Unique human-readable name of the proxy cluster.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster
constructor
A new instance of ProxyCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster
Returns a new instance of ProxyCluster.
9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 9825 9826 |
# File 'lib/models/porcelain.rb', line 9814 def initialize( address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil ) @address = address == nil ? "" : address @id = id == nil ? "" : id @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows @name = name == nil ? "" : name @tags = == nil ? SDM::() : end |
Instance Attribute Details
#address ⇒ Object
The public hostname/port tuple at which the proxy cluster will be accessible to clients.
9791 9792 9793 |
# File 'lib/models/porcelain.rb', line 9791 def address @address end |
#id ⇒ Object
Unique identifier of the Proxy Cluster.
9793 9794 9795 |
# File 'lib/models/porcelain.rb', line 9793 def id @id end |
#maintenance_windows ⇒ Object
Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.
If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.
If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.
9806 9807 9808 |
# File 'lib/models/porcelain.rb', line 9806 def maintenance_windows @maintenance_windows end |
#name ⇒ Object
Unique human-readable name of the proxy cluster. Names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.
9810 9811 9812 |
# File 'lib/models/porcelain.rb', line 9810 def name @name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9812 9813 9814 |
# File 'lib/models/porcelain.rb', line 9812 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9828 9829 9830 9831 9832 9833 9834 |
# File 'lib/models/porcelain.rb', line 9828 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |