Class: SDM::ProxyCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ProxyCluster represents a cluster of StrongDM proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster

Returns a new instance of ProxyCluster.



9738
9739
9740
9741
9742
9743
9744
9745
9746
9747
9748
9749
9750
# File 'lib/models/porcelain.rb', line 9738

def initialize(
  address: nil,
  id: nil,
  maintenance_windows: nil,
  name: nil,
  tags: nil
)
  @address = address == nil ? "" : address
  @id = id == nil ? "" : id
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#addressObject

The public hostname/port tuple at which the proxy cluster will be accessible to clients.



9715
9716
9717
# File 'lib/models/porcelain.rb', line 9715

def address
  @address
end

#idObject

Unique identifier of the Proxy Cluster.



9717
9718
9719
# File 'lib/models/porcelain.rb', line 9717

def id
  @id
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



9730
9731
9732
# File 'lib/models/porcelain.rb', line 9730

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the proxy cluster. Names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



9734
9735
9736
# File 'lib/models/porcelain.rb', line 9734

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



9736
9737
9738
# File 'lib/models/porcelain.rb', line 9736

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9752
9753
9754
9755
9756
9757
9758
# File 'lib/models/porcelain.rb', line 9752

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end