Class: SDM::ProxyCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ProxyCluster represents a cluster of StrongDM proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster

Returns a new instance of ProxyCluster.



9227
9228
9229
9230
9231
9232
9233
9234
9235
9236
9237
9238
9239
# File 'lib/models/porcelain.rb', line 9227

def initialize(
  address: nil,
  id: nil,
  maintenance_windows: nil,
  name: nil,
  tags: nil
)
  @address = address == nil ? "" : address
  @id = id == nil ? "" : id
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#addressObject

The public hostname/port tuple at which the proxy cluster will be accessible to clients.



9204
9205
9206
# File 'lib/models/porcelain.rb', line 9204

def address
  @address
end

#idObject

Unique identifier of the Proxy Cluster.



9206
9207
9208
# File 'lib/models/porcelain.rb', line 9206

def id
  @id
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



9219
9220
9221
# File 'lib/models/porcelain.rb', line 9219

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the proxy cluster. Names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



9223
9224
9225
# File 'lib/models/porcelain.rb', line 9223

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



9225
9226
9227
# File 'lib/models/porcelain.rb', line 9225

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9241
9242
9243
9244
9245
9246
9247
# File 'lib/models/porcelain.rb', line 9241

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end