Class: SDM::ProxyCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ProxyCluster represents a cluster of StrongDM proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster

Returns a new instance of ProxyCluster.



13587
13588
13589
13590
13591
13592
13593
13594
13595
13596
13597
13598
13599
# File 'lib/models/porcelain.rb', line 13587

def initialize(
  address: nil,
  id: nil,
  maintenance_windows: nil,
  name: nil,
  tags: nil
)
  @address = address == nil ? "" : address
  @id = id == nil ? "" : id
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#addressObject

The public hostname/port tuple at which the proxy cluster will be accessible to clients.



13564
13565
13566
# File 'lib/models/porcelain.rb', line 13564

def address
  @address
end

#idObject

Unique identifier of the Proxy Cluster.



13566
13567
13568
# File 'lib/models/porcelain.rb', line 13566

def id
  @id
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



13579
13580
13581
# File 'lib/models/porcelain.rb', line 13579

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the proxy cluster. Names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



13583
13584
13585
# File 'lib/models/porcelain.rb', line 13583

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



13585
13586
13587
# File 'lib/models/porcelain.rb', line 13585

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13601
13602
13603
13604
13605
13606
13607
# File 'lib/models/porcelain.rb', line 13601

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end