Class: SDM::ProxyCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ProxyCluster represents a cluster of StrongDM proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(address: nil, id: nil, maintenance_windows: nil, name: nil, tags: nil) ⇒ ProxyCluster

Returns a new instance of ProxyCluster.



14321
14322
14323
14324
14325
14326
14327
14328
14329
14330
14331
14332
14333
# File 'lib/models/porcelain.rb', line 14321

def initialize(
  address: nil,
  id: nil,
  maintenance_windows: nil,
  name: nil,
  tags: nil
)
  @address = address == nil ? "" : address
  @id = id == nil ? "" : id
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#address ⇒ Object

The public hostname/port tuple at which the proxy cluster will be accessible to clients.



14298
14299
14300
# File 'lib/models/porcelain.rb', line 14298

def address
  @address
end

#id ⇒ Object

Unique identifier of the Proxy Cluster.



14300
14301
14302
# File 'lib/models/porcelain.rb', line 14300

def id
  @id
end

#maintenance_windows ⇒ Object

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



14313
14314
14315
# File 'lib/models/porcelain.rb', line 14313

def maintenance_windows
  @maintenance_windows
end

#name ⇒ Object

Unique human-readable name of the proxy cluster. Names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



14317
14318
14319
# File 'lib/models/porcelain.rb', line 14317

def name
  @name
end

#tags ⇒ Object

Tags is a map of key, value pairs.



14319
14320
14321
# File 'lib/models/porcelain.rb', line 14319

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14335
14336
14337
14338
14339
14340
14341
# File 'lib/models/porcelain.rb', line 14335

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end