Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



14297
14298
14299
14300
14301
14302
14303
14304
14305
14306
14307
# File 'lib/models/porcelain.rb', line 14297

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



14289
14290
14291
# File 'lib/models/porcelain.rb', line 14289

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



14291
14292
14293
# File 'lib/models/porcelain.rb', line 14291

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



14293
14294
14295
# File 'lib/models/porcelain.rb', line 14293

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



14295
14296
14297
# File 'lib/models/porcelain.rb', line 14295

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14309
14310
14311
14312
14313
14314
14315
# File 'lib/models/porcelain.rb', line 14309

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end