Class: SDM::ProxyClusterKey
- Inherits:
-
Object
- Object
- SDM::ProxyClusterKey
- Defined in:
- lib/models/porcelain.rb
Overview
Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
The timestamp when this key was created.
-
#id ⇒ Object
Unique identifier of the Relay.
-
#last_used_at ⇒ Object
The timestamp when this key was last used, if at all.
-
#proxy_cluster_id ⇒ Object
The ID of the proxy cluster which this key authenticates to.
Instance Method Summary collapse
-
#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey
constructor
A new instance of ProxyClusterKey.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey
Returns a new instance of ProxyClusterKey.
14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 |
# File 'lib/models/porcelain.rb', line 14169 def initialize( created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil ) @created_at = created_at == nil ? nil : created_at @id = id == nil ? "" : id @last_used_at = last_used_at == nil ? nil : last_used_at @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id end |
Instance Attribute Details
#created_at ⇒ Object
The timestamp when this key was created.
14161 14162 14163 |
# File 'lib/models/porcelain.rb', line 14161 def created_at @created_at end |
#id ⇒ Object
Unique identifier of the Relay.
14163 14164 14165 |
# File 'lib/models/porcelain.rb', line 14163 def id @id end |
#last_used_at ⇒ Object
The timestamp when this key was last used, if at all.
14165 14166 14167 |
# File 'lib/models/porcelain.rb', line 14165 def last_used_at @last_used_at end |
#proxy_cluster_id ⇒ Object
The ID of the proxy cluster which this key authenticates to.
14167 14168 14169 |
# File 'lib/models/porcelain.rb', line 14167 def proxy_cluster_id @proxy_cluster_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14181 14182 14183 14184 14185 14186 14187 |
# File 'lib/models/porcelain.rb', line 14181 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |