Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



13942
13943
13944
13945
13946
13947
13948
13949
13950
13951
13952
# File 'lib/models/porcelain.rb', line 13942

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



13934
13935
13936
# File 'lib/models/porcelain.rb', line 13934

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



13936
13937
13938
# File 'lib/models/porcelain.rb', line 13936

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



13938
13939
13940
# File 'lib/models/porcelain.rb', line 13938

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



13940
13941
13942
# File 'lib/models/porcelain.rb', line 13940

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13954
13955
13956
13957
13958
13959
13960
# File 'lib/models/porcelain.rb', line 13954

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end