Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



13248
13249
13250
13251
13252
13253
13254
13255
13256
13257
13258
# File 'lib/models/porcelain.rb', line 13248

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



13240
13241
13242
# File 'lib/models/porcelain.rb', line 13240

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



13242
13243
13244
# File 'lib/models/porcelain.rb', line 13242

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



13244
13245
13246
# File 'lib/models/porcelain.rb', line 13244

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



13246
13247
13248
# File 'lib/models/porcelain.rb', line 13246

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13260
13261
13262
13263
13264
13265
13266
# File 'lib/models/porcelain.rb', line 13260

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end