Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



13184
13185
13186
13187
13188
13189
13190
13191
13192
13193
13194
# File 'lib/models/porcelain.rb', line 13184

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



13176
13177
13178
# File 'lib/models/porcelain.rb', line 13176

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



13178
13179
13180
# File 'lib/models/porcelain.rb', line 13178

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



13180
13181
13182
# File 'lib/models/porcelain.rb', line 13180

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



13182
13183
13184
# File 'lib/models/porcelain.rb', line 13182

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13196
13197
13198
13199
13200
13201
13202
# File 'lib/models/porcelain.rb', line 13196

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end