Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



11087
11088
11089
11090
11091
11092
11093
11094
11095
11096
11097
# File 'lib/models/porcelain.rb', line 11087

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



11079
11080
11081
# File 'lib/models/porcelain.rb', line 11079

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



11081
11082
11083
# File 'lib/models/porcelain.rb', line 11081

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



11083
11084
11085
# File 'lib/models/porcelain.rb', line 11083

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



11085
11086
11087
# File 'lib/models/porcelain.rb', line 11085

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11099
11100
11101
11102
11103
11104
11105
# File 'lib/models/porcelain.rb', line 11099

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end