Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
# File 'lib/models/porcelain.rb', line 9849

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



9841
9842
9843
# File 'lib/models/porcelain.rb', line 9841

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



9843
9844
9845
# File 'lib/models/porcelain.rb', line 9843

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



9845
9846
9847
# File 'lib/models/porcelain.rb', line 9845

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



9847
9848
9849
# File 'lib/models/porcelain.rb', line 9847

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9861
9862
9863
9864
9865
9866
9867
# File 'lib/models/porcelain.rb', line 9861

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end