Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



9771
9772
9773
9774
9775
9776
9777
9778
9779
9780
9781
# File 'lib/models/porcelain.rb', line 9771

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



9763
9764
9765
# File 'lib/models/porcelain.rb', line 9763

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



9765
9766
9767
# File 'lib/models/porcelain.rb', line 9765

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



9767
9768
9769
# File 'lib/models/porcelain.rb', line 9767

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



9769
9770
9771
# File 'lib/models/porcelain.rb', line 9769

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9783
9784
9785
9786
9787
9788
9789
# File 'lib/models/porcelain.rb', line 9783

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end