Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



9695
9696
9697
9698
9699
9700
9701
9702
9703
9704
9705
# File 'lib/models/porcelain.rb', line 9695

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



9687
9688
9689
# File 'lib/models/porcelain.rb', line 9687

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



9689
9690
9691
# File 'lib/models/porcelain.rb', line 9689

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



9691
9692
9693
# File 'lib/models/porcelain.rb', line 9691

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



9693
9694
9695
# File 'lib/models/porcelain.rb', line 9693

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9707
9708
9709
9710
9711
9712
9713
# File 'lib/models/porcelain.rb', line 9707

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end