Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



9624
9625
9626
9627
9628
9629
9630
9631
9632
9633
9634
# File 'lib/models/porcelain.rb', line 9624

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



9616
9617
9618
# File 'lib/models/porcelain.rb', line 9616

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



9618
9619
9620
# File 'lib/models/porcelain.rb', line 9618

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



9620
9621
9622
# File 'lib/models/porcelain.rb', line 9620

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



9622
9623
9624
# File 'lib/models/porcelain.rb', line 9622

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9636
9637
9638
9639
9640
9641
9642
# File 'lib/models/porcelain.rb', line 9636

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end