Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



9263
9264
9265
9266
9267
9268
9269
9270
9271
9272
9273
# File 'lib/models/porcelain.rb', line 9263

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



9255
9256
9257
# File 'lib/models/porcelain.rb', line 9255

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



9257
9258
9259
# File 'lib/models/porcelain.rb', line 9257

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



9259
9260
9261
# File 'lib/models/porcelain.rb', line 9259

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



9261
9262
9263
# File 'lib/models/porcelain.rb', line 9261

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9275
9276
9277
9278
9279
9280
9281
# File 'lib/models/porcelain.rb', line 9275

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end