Class: SDM::ProxyClusterKey

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey

Returns a new instance of ProxyClusterKey.



9014
9015
9016
9017
9018
9019
9020
9021
9022
9023
9024
# File 'lib/models/porcelain.rb', line 9014

def initialize(
  created_at: nil,
  id: nil,
  last_used_at: nil,
  proxy_cluster_id: nil
)
  @created_at = created_at == nil ? nil : created_at
  @id = id == nil ? "" : id
  @last_used_at = last_used_at == nil ? nil : last_used_at
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
end

Instance Attribute Details

#created_atObject

The timestamp when this key was created.



9006
9007
9008
# File 'lib/models/porcelain.rb', line 9006

def created_at
  @created_at
end

#idObject

Unique identifier of the Relay.



9008
9009
9010
# File 'lib/models/porcelain.rb', line 9008

def id
  @id
end

#last_used_atObject

The timestamp when this key was last used, if at all.



9010
9011
9012
# File 'lib/models/porcelain.rb', line 9010

def last_used_at
  @last_used_at
end

#proxy_cluster_idObject

The ID of the proxy cluster which this key authenticates to.



9012
9013
9014
# File 'lib/models/porcelain.rb', line 9012

def proxy_cluster_id
  @proxy_cluster_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9026
9027
9028
9029
9030
9031
9032
# File 'lib/models/porcelain.rb', line 9026

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end