Class: SDM::ProxyClusterKey
- Inherits:
-
Object
- Object
- SDM::ProxyClusterKey
- Defined in:
- lib/models/porcelain.rb
Overview
Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
The timestamp when this key was created.
-
#id ⇒ Object
Unique identifier of the Relay.
-
#last_used_at ⇒ Object
The timestamp when this key was last used, if at all.
-
#proxy_cluster_id ⇒ Object
The ID of the proxy cluster which this key authenticates to.
Instance Method Summary collapse
-
#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey
constructor
A new instance of ProxyClusterKey.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil) ⇒ ProxyClusterKey
Returns a new instance of ProxyClusterKey.
8943 8944 8945 8946 8947 8948 8949 8950 8951 8952 8953 |
# File 'lib/models/porcelain.rb', line 8943 def initialize( created_at: nil, id: nil, last_used_at: nil, proxy_cluster_id: nil ) @created_at = created_at == nil ? nil : created_at @id = id == nil ? "" : id @last_used_at = last_used_at == nil ? nil : last_used_at @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id end |
Instance Attribute Details
#created_at ⇒ Object
The timestamp when this key was created.
8935 8936 8937 |
# File 'lib/models/porcelain.rb', line 8935 def created_at @created_at end |
#id ⇒ Object
Unique identifier of the Relay.
8937 8938 8939 |
# File 'lib/models/porcelain.rb', line 8937 def id @id end |
#last_used_at ⇒ Object
The timestamp when this key was last used, if at all.
8939 8940 8941 |
# File 'lib/models/porcelain.rb', line 8939 def last_used_at @last_used_at end |
#proxy_cluster_id ⇒ Object
The ID of the proxy cluster which this key authenticates to.
8941 8942 8943 |
# File 'lib/models/porcelain.rb', line 8941 def proxy_cluster_id @proxy_cluster_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8955 8956 8957 8958 8959 8960 8961 |
# File 'lib/models/porcelain.rb', line 8955 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |