Class: SDM::ProxyClusterKeys
- Inherits:
-
Object
- Object
- SDM::ProxyClusterKeys
- Extended by:
- Gem::Deprecate
- Defined in:
- lib/svc.rb
Overview
Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.
See ProxyClusterKey.
Instance Method Summary collapse
-
#create(proxy_cluster_key, deadline: nil) ⇒ Object
Create registers a new ProxyClusterKey.
-
#delete(id, deadline: nil) ⇒ Object
Delete removes a ProxyClusterKey by ID.
-
#get(id, deadline: nil) ⇒ Object
Get reads one ProxyClusterKey by ID.
-
#initialize(channel, parent) ⇒ ProxyClusterKeys
constructor
A new instance of ProxyClusterKeys.
-
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of ProxyClusterKeys matching a given set of criteria.
Constructor Details
#initialize(channel, parent) ⇒ ProxyClusterKeys
Returns a new instance of ProxyClusterKeys.
6313 6314 6315 6316 6317 6318 6319 6320 |
# File 'lib/svc.rb', line 6313 def initialize(channel, parent) begin @stub = V1::ProxyClusterKeys::Stub.new(nil, nil, channel_override: channel) rescue => exception raise Plumbing::convert_error_to_porcelain(exception) end @parent = parent end |
Instance Method Details
#create(proxy_cluster_key, deadline: nil) ⇒ Object
Create registers a new ProxyClusterKey.
6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 |
# File 'lib/svc.rb', line 6323 def create( proxy_cluster_key, deadline: nil ) req = V1::ProxyClusterKeyCreateRequest.new() req.proxy_cluster_key = Plumbing::convert_proxy_cluster_key_to_plumbing(proxy_cluster_key) # Execute before interceptor hooks req = @parent.interceptor.execute_before("ProxyClusterKeys.Create", self, req) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.create(req, metadata: @parent.("ProxyClusterKeys.Create", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end # Execute after interceptor hooks plumbing_response = @parent.interceptor.execute_after("ProxyClusterKeys.Create", self, req, plumbing_response) resp = ProxyClusterKeyCreateResponse.new() resp. = Plumbing::(plumbing_response.) resp.proxy_cluster_key = Plumbing::convert_proxy_cluster_key_to_porcelain(plumbing_response.proxy_cluster_key) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp.secret_key = (plumbing_response.secret_key) resp end |
#delete(id, deadline: nil) ⇒ Object
Delete removes a ProxyClusterKey by ID.
6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 |
# File 'lib/svc.rb', line 6398 def delete( id, deadline: nil ) req = V1::ProxyClusterKeyDeleteRequest.new() req.id = (id) # Execute before interceptor hooks req = @parent.interceptor.execute_before("ProxyClusterKeys.Delete", self, req) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.delete(req, metadata: @parent.("ProxyClusterKeys.Delete", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end # Execute after interceptor hooks plumbing_response = @parent.interceptor.execute_after("ProxyClusterKeys.Delete", self, req, plumbing_response) resp = ProxyClusterKeyDeleteResponse.new() resp. = Plumbing::(plumbing_response.) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp end |
#get(id, deadline: nil) ⇒ Object
Get reads one ProxyClusterKey by ID.
6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 |
# File 'lib/svc.rb', line 6359 def get( id, deadline: nil ) req = V1::ProxyClusterKeyGetRequest.new() if not @parent.snapshot_time.nil? req. = V1::GetRequestMetadata.new() req..snapshot_at = @parent.snapshot_time end req.id = (id) # Execute before interceptor hooks req = @parent.interceptor.execute_before("ProxyClusterKeys.Get", self, req) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.get(req, metadata: @parent.("ProxyClusterKeys.Get", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end # Execute after interceptor hooks plumbing_response = @parent.interceptor.execute_after("ProxyClusterKeys.Get", self, req, plumbing_response) resp = ProxyClusterKeyGetResponse.new() resp. = Plumbing::(plumbing_response.) resp.proxy_cluster_key = Plumbing::convert_proxy_cluster_key_to_porcelain(plumbing_response.proxy_cluster_key) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp end |
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of ProxyClusterKeys matching a given set of criteria.
6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 6445 6446 6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 6458 6459 6460 6461 6462 6463 6464 6465 6466 6467 6468 |
# File 'lib/svc.rb', line 6432 def list( filter, *args, deadline: nil ) req = V1::ProxyClusterKeyListRequest.new() req. = V1::ListRequestMetadata.new() if not @parent.page_limit.nil? req..limit = @parent.page_limit end if not @parent.snapshot_time.nil? req..snapshot_at = @parent.snapshot_time end req.filter = Plumbing::quote_filter_args(filter, *args) resp = Enumerator::Generator.new { |g| tries = 0 loop do begin plumbing_response = @stub.list(req, metadata: @parent.("ProxyClusterKeys.List", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end tries = 0 plumbing_response.proxy_cluster_keys.each do |plumbing_item| g.yield Plumbing::convert_proxy_cluster_key_to_porcelain(plumbing_item) end break if plumbing_response..next_cursor == "" req..cursor = plumbing_response..next_cursor end } resp end |