Class: SDM::ProxyClusterKeys
- Inherits:
-
Object
- Object
- SDM::ProxyClusterKeys
- Extended by:
- Gem::Deprecate
- Defined in:
- lib/svc.rb
Overview
Proxy Cluster Keys are authentication keys for all proxies within a cluster. The proxies within a cluster share the same key. One cluster can have multiple keys in order to facilitate key rotation.
See ProxyClusterKey.
Instance Method Summary collapse
-
#create(proxy_cluster_key, deadline: nil) ⇒ Object
Create registers a new ProxyClusterKey.
-
#delete(id, deadline: nil) ⇒ Object
Delete removes a ProxyClusterKey by ID.
-
#get(id, deadline: nil) ⇒ Object
Get reads one ProxyClusterKey by ID.
-
#initialize(channel, parent) ⇒ ProxyClusterKeys
constructor
A new instance of ProxyClusterKeys.
-
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of ProxyClusterKeys matching a given set of criteria.
Constructor Details
#initialize(channel, parent) ⇒ ProxyClusterKeys
Returns a new instance of ProxyClusterKeys.
4461 4462 4463 4464 4465 4466 4467 4468 |
# File 'lib/svc.rb', line 4461 def initialize(channel, parent) begin @stub = V1::ProxyClusterKeys::Stub.new(nil, nil, channel_override: channel) rescue => exception raise Plumbing::convert_error_to_porcelain(exception) end @parent = parent end |
Instance Method Details
#create(proxy_cluster_key, deadline: nil) ⇒ Object
Create registers a new ProxyClusterKey.
4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 |
# File 'lib/svc.rb', line 4471 def create( proxy_cluster_key, deadline: nil ) req = V1::ProxyClusterKeyCreateRequest.new() req.proxy_cluster_key = Plumbing::convert_proxy_cluster_key_to_plumbing(proxy_cluster_key) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.create(req, metadata: @parent.("ProxyClusterKeys.Create", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end resp = ProxyClusterKeyCreateResponse.new() resp. = Plumbing::(plumbing_response.) resp.proxy_cluster_key = Plumbing::convert_proxy_cluster_key_to_porcelain(plumbing_response.proxy_cluster_key) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp.secret_key = (plumbing_response.secret_key) resp end |
#delete(id, deadline: nil) ⇒ Object
Delete removes a ProxyClusterKey by ID.
4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 |
# File 'lib/svc.rb', line 4536 def delete( id, deadline: nil ) req = V1::ProxyClusterKeyDeleteRequest.new() req.id = (id) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.delete(req, metadata: @parent.("ProxyClusterKeys.Delete", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end resp = ProxyClusterKeyDeleteResponse.new() resp. = Plumbing::(plumbing_response.) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp end |
#get(id, deadline: nil) ⇒ Object
Get reads one ProxyClusterKey by ID.
4502 4503 4504 4505 4506 4507 4508 4509 4510 4511 4512 4513 4514 4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 4532 4533 |
# File 'lib/svc.rb', line 4502 def get( id, deadline: nil ) req = V1::ProxyClusterKeyGetRequest.new() if not @parent.snapshot_time.nil? req. = V1::GetRequestMetadata.new() req..snapshot_at = @parent.snapshot_time end req.id = (id) tries = 0 plumbing_response = nil loop do begin plumbing_response = @stub.get(req, metadata: @parent.("ProxyClusterKeys.Get", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end break end resp = ProxyClusterKeyGetResponse.new() resp. = Plumbing::(plumbing_response.) resp.proxy_cluster_key = Plumbing::convert_proxy_cluster_key_to_porcelain(plumbing_response.proxy_cluster_key) resp.rate_limit = Plumbing::(plumbing_response.rate_limit) resp end |
#list(filter, *args, deadline: nil) ⇒ Object
List gets a list of ProxyClusterKeys matching a given set of criteria.
4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 |
# File 'lib/svc.rb', line 4565 def list( filter, *args, deadline: nil ) req = V1::ProxyClusterKeyListRequest.new() req. = V1::ListRequestMetadata.new() if not @parent.page_limit.nil? req..limit = @parent.page_limit end if not @parent.snapshot_time.nil? req..snapshot_at = @parent.snapshot_time end req.filter = Plumbing::quote_filter_args(filter, *args) resp = Enumerator::Generator.new { |g| tries = 0 loop do begin plumbing_response = @stub.list(req, metadata: @parent.("ProxyClusterKeys.List", req), deadline: deadline) rescue => exception if (@parent.shouldRetry(tries, exception, deadline)) tries + +sleep(@parent.exponentialBackoff(tries, deadline)) next end raise Plumbing::convert_error_to_porcelain(exception) end tries = 0 plumbing_response.proxy_cluster_keys.each do |plumbing_item| g.yield Plumbing::convert_proxy_cluster_key_to_porcelain(plumbing_item) end break if plumbing_response..next_cursor == "" req..cursor = plumbing_response..next_cursor end } resp end |