Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, metadata_json: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



13807
13808
13809
13810
13811
13812
13813
13814
13815
13816
13817
13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
13829
13830
13831
13832
13833
13834
13835
13836
13837
13838
13839
13840
13841
13842
13843
13844
13845
13846
13847
13848
13849
13850
13851
13852
13853
13854
13855
13856
13857
13858
13859
13860
13861
13862
13863
13864
13865
13866
13867
# File 'lib/models/porcelain.rb', line 13807

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  metadata_json: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @metadata_json =  == nil ? "" : 
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



13738
13739
13740
# File 'lib/models/porcelain.rb', line 13738

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



13741
13742
13743
# File 'lib/models/porcelain.rb', line 13741

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



13743
13744
13745
# File 'lib/models/porcelain.rb', line 13743

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



13746
13747
13748
# File 'lib/models/porcelain.rb', line 13746

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



13749
13750
13751
# File 'lib/models/porcelain.rb', line 13749

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



13751
13752
13753
# File 'lib/models/porcelain.rb', line 13751

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



13754
13755
13756
# File 'lib/models/porcelain.rb', line 13754

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



13756
13757
13758
# File 'lib/models/porcelain.rb', line 13756

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



13759
13760
13761
# File 'lib/models/porcelain.rb', line 13759

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



13761
13762
13763
# File 'lib/models/porcelain.rb', line 13761

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



13763
13764
13765
# File 'lib/models/porcelain.rb', line 13763

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



13765
13766
13767
# File 'lib/models/porcelain.rb', line 13765

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



13767
13768
13769
# File 'lib/models/porcelain.rb', line 13767

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



13769
13770
13771
# File 'lib/models/porcelain.rb', line 13769

def identity_alias_username
  @identity_alias_username
end

#metadata_jsonObject

Driver specific metadata associated with this query.



13771
13772
13773
# File 'lib/models/porcelain.rb', line 13771

def 
  @metadata_json
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



13774
13775
13776
# File 'lib/models/porcelain.rb', line 13774

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



13776
13777
13778
# File 'lib/models/porcelain.rb', line 13776

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



13778
13779
13780
# File 'lib/models/porcelain.rb', line 13778

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



13783
13784
13785
# File 'lib/models/porcelain.rb', line 13783

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



13785
13786
13787
# File 'lib/models/porcelain.rb', line 13785

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



13787
13788
13789
# File 'lib/models/porcelain.rb', line 13787

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



13789
13790
13791
# File 'lib/models/porcelain.rb', line 13789

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



13791
13792
13793
# File 'lib/models/porcelain.rb', line 13791

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



13794
13795
13796
# File 'lib/models/porcelain.rb', line 13794

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



13797
13798
13799
# File 'lib/models/porcelain.rb', line 13797

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



13799
13800
13801
# File 'lib/models/porcelain.rb', line 13799

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



13801
13802
13803
# File 'lib/models/porcelain.rb', line 13801

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



13803
13804
13805
# File 'lib/models/porcelain.rb', line 13803

def target
  @target
end

#timestampObject

The time at which the Query was started.



13805
13806
13807
# File 'lib/models/porcelain.rb', line 13805

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13869
13870
13871
13872
13873
13874
13875
# File 'lib/models/porcelain.rb', line 13869

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end