Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, metadata_json: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



13733
13734
13735
13736
13737
13738
13739
13740
13741
13742
13743
13744
13745
13746
13747
13748
13749
13750
13751
13752
13753
13754
13755
13756
13757
13758
13759
13760
13761
13762
13763
13764
13765
13766
13767
13768
13769
13770
13771
13772
13773
13774
13775
13776
13777
13778
13779
13780
13781
13782
13783
13784
13785
13786
13787
13788
13789
13790
13791
13792
13793
# File 'lib/models/porcelain.rb', line 13733

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  metadata_json: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @metadata_json =  == nil ? "" : 
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



13664
13665
13666
# File 'lib/models/porcelain.rb', line 13664

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



13667
13668
13669
# File 'lib/models/porcelain.rb', line 13667

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



13669
13670
13671
# File 'lib/models/porcelain.rb', line 13669

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



13672
13673
13674
# File 'lib/models/porcelain.rb', line 13672

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



13675
13676
13677
# File 'lib/models/porcelain.rb', line 13675

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



13677
13678
13679
# File 'lib/models/porcelain.rb', line 13677

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



13680
13681
13682
# File 'lib/models/porcelain.rb', line 13680

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



13682
13683
13684
# File 'lib/models/porcelain.rb', line 13682

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



13685
13686
13687
# File 'lib/models/porcelain.rb', line 13685

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



13687
13688
13689
# File 'lib/models/porcelain.rb', line 13687

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



13689
13690
13691
# File 'lib/models/porcelain.rb', line 13689

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



13691
13692
13693
# File 'lib/models/porcelain.rb', line 13691

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



13693
13694
13695
# File 'lib/models/porcelain.rb', line 13693

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



13695
13696
13697
# File 'lib/models/porcelain.rb', line 13695

def identity_alias_username
  @identity_alias_username
end

#metadata_jsonObject

Driver specific metadata associated with this query.



13697
13698
13699
# File 'lib/models/porcelain.rb', line 13697

def 
  @metadata_json
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



13700
13701
13702
# File 'lib/models/porcelain.rb', line 13700

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



13702
13703
13704
# File 'lib/models/porcelain.rb', line 13702

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



13704
13705
13706
# File 'lib/models/porcelain.rb', line 13704

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



13709
13710
13711
# File 'lib/models/porcelain.rb', line 13709

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



13711
13712
13713
# File 'lib/models/porcelain.rb', line 13711

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



13713
13714
13715
# File 'lib/models/porcelain.rb', line 13713

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



13715
13716
13717
# File 'lib/models/porcelain.rb', line 13715

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



13717
13718
13719
# File 'lib/models/porcelain.rb', line 13717

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



13720
13721
13722
# File 'lib/models/porcelain.rb', line 13720

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



13723
13724
13725
# File 'lib/models/porcelain.rb', line 13723

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



13725
13726
13727
# File 'lib/models/porcelain.rb', line 13725

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



13727
13728
13729
# File 'lib/models/porcelain.rb', line 13727

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



13729
13730
13731
# File 'lib/models/porcelain.rb', line 13729

def target
  @target
end

#timestampObject

The time at which the Query was started.



13731
13732
13733
# File 'lib/models/porcelain.rb', line 13731

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13795
13796
13797
13798
13799
13800
13801
# File 'lib/models/porcelain.rb', line 13795

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end