Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, metadata_json: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



13431
13432
13433
13434
13435
13436
13437
13438
13439
13440
13441
13442
13443
13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
13458
13459
13460
13461
13462
13463
13464
13465
13466
13467
13468
13469
13470
13471
13472
13473
13474
13475
13476
13477
13478
13479
13480
13481
13482
13483
13484
13485
13486
13487
13488
13489
13490
13491
# File 'lib/models/porcelain.rb', line 13431

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  metadata_json: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @metadata_json =  == nil ? "" : 
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



13362
13363
13364
# File 'lib/models/porcelain.rb', line 13362

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



13365
13366
13367
# File 'lib/models/porcelain.rb', line 13365

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



13367
13368
13369
# File 'lib/models/porcelain.rb', line 13367

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



13370
13371
13372
# File 'lib/models/porcelain.rb', line 13370

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



13373
13374
13375
# File 'lib/models/porcelain.rb', line 13373

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



13375
13376
13377
# File 'lib/models/porcelain.rb', line 13375

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



13378
13379
13380
# File 'lib/models/porcelain.rb', line 13378

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



13380
13381
13382
# File 'lib/models/porcelain.rb', line 13380

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



13383
13384
13385
# File 'lib/models/porcelain.rb', line 13383

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



13385
13386
13387
# File 'lib/models/porcelain.rb', line 13385

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



13387
13388
13389
# File 'lib/models/porcelain.rb', line 13387

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



13389
13390
13391
# File 'lib/models/porcelain.rb', line 13389

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



13391
13392
13393
# File 'lib/models/porcelain.rb', line 13391

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



13393
13394
13395
# File 'lib/models/porcelain.rb', line 13393

def identity_alias_username
  @identity_alias_username
end

#metadata_jsonObject

Driver specific metadata associated with this query.



13395
13396
13397
# File 'lib/models/porcelain.rb', line 13395

def 
  @metadata_json
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



13398
13399
13400
# File 'lib/models/porcelain.rb', line 13398

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



13400
13401
13402
# File 'lib/models/porcelain.rb', line 13400

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



13402
13403
13404
# File 'lib/models/porcelain.rb', line 13402

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



13407
13408
13409
# File 'lib/models/porcelain.rb', line 13407

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



13409
13410
13411
# File 'lib/models/porcelain.rb', line 13409

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



13411
13412
13413
# File 'lib/models/porcelain.rb', line 13411

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



13413
13414
13415
# File 'lib/models/porcelain.rb', line 13413

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



13415
13416
13417
# File 'lib/models/porcelain.rb', line 13415

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



13418
13419
13420
# File 'lib/models/porcelain.rb', line 13418

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



13421
13422
13423
# File 'lib/models/porcelain.rb', line 13421

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



13423
13424
13425
# File 'lib/models/porcelain.rb', line 13423

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



13425
13426
13427
# File 'lib/models/porcelain.rb', line 13425

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



13427
13428
13429
# File 'lib/models/porcelain.rb', line 13427

def target
  @target
end

#timestampObject

The time at which the Query was started.



13429
13430
13431
# File 'lib/models/porcelain.rb', line 13429

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13493
13494
13495
13496
13497
13498
13499
# File 'lib/models/porcelain.rb', line 13493

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end