Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, metadata_json: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



13367
13368
13369
13370
13371
13372
13373
13374
13375
13376
13377
13378
13379
13380
13381
13382
13383
13384
13385
13386
13387
13388
13389
13390
13391
13392
13393
13394
13395
13396
13397
13398
13399
13400
13401
13402
13403
13404
13405
13406
13407
13408
13409
13410
13411
13412
13413
13414
13415
13416
13417
13418
13419
13420
13421
13422
13423
13424
13425
13426
13427
# File 'lib/models/porcelain.rb', line 13367

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  metadata_json: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @metadata_json =  == nil ? "" : 
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



13298
13299
13300
# File 'lib/models/porcelain.rb', line 13298

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



13301
13302
13303
# File 'lib/models/porcelain.rb', line 13301

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



13303
13304
13305
# File 'lib/models/porcelain.rb', line 13303

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



13306
13307
13308
# File 'lib/models/porcelain.rb', line 13306

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



13309
13310
13311
# File 'lib/models/porcelain.rb', line 13309

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



13311
13312
13313
# File 'lib/models/porcelain.rb', line 13311

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



13314
13315
13316
# File 'lib/models/porcelain.rb', line 13314

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



13316
13317
13318
# File 'lib/models/porcelain.rb', line 13316

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



13319
13320
13321
# File 'lib/models/porcelain.rb', line 13319

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



13321
13322
13323
# File 'lib/models/porcelain.rb', line 13321

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



13323
13324
13325
# File 'lib/models/porcelain.rb', line 13323

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



13325
13326
13327
# File 'lib/models/porcelain.rb', line 13325

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



13327
13328
13329
# File 'lib/models/porcelain.rb', line 13327

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



13329
13330
13331
# File 'lib/models/porcelain.rb', line 13329

def identity_alias_username
  @identity_alias_username
end

#metadata_jsonObject

Driver specific metadata associated with this query.



13331
13332
13333
# File 'lib/models/porcelain.rb', line 13331

def 
  @metadata_json
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



13334
13335
13336
# File 'lib/models/porcelain.rb', line 13334

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



13336
13337
13338
# File 'lib/models/porcelain.rb', line 13336

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



13338
13339
13340
# File 'lib/models/porcelain.rb', line 13338

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



13343
13344
13345
# File 'lib/models/porcelain.rb', line 13343

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



13345
13346
13347
# File 'lib/models/porcelain.rb', line 13345

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



13347
13348
13349
# File 'lib/models/porcelain.rb', line 13347

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



13349
13350
13351
# File 'lib/models/porcelain.rb', line 13349

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



13351
13352
13353
# File 'lib/models/porcelain.rb', line 13351

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



13354
13355
13356
# File 'lib/models/porcelain.rb', line 13354

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



13357
13358
13359
# File 'lib/models/porcelain.rb', line 13357

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



13359
13360
13361
# File 'lib/models/porcelain.rb', line 13359

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



13361
13362
13363
# File 'lib/models/porcelain.rb', line 13361

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



13363
13364
13365
# File 'lib/models/porcelain.rb', line 13363

def target
  @target
end

#timestampObject

The time at which the Query was started.



13365
13366
13367
# File 'lib/models/porcelain.rb', line 13365

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13429
13430
13431
13432
13433
13434
13435
# File 'lib/models/porcelain.rb', line 13429

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end