Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, metadata_json: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
11539
11540
11541
11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
11552
11553
11554
11555
11556
11557
11558
11559
11560
11561
11562
11563
11564
11565
11566
11567
11568
11569
11570
11571
11572
11573
11574
11575
11576
11577
11578
11579
11580
11581
11582
11583
11584
11585
11586
11587
11588
# File 'lib/models/porcelain.rb', line 11528

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  metadata_json: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @metadata_json =  == nil ? "" : 
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



11459
11460
11461
# File 'lib/models/porcelain.rb', line 11459

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



11462
11463
11464
# File 'lib/models/porcelain.rb', line 11462

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



11464
11465
11466
# File 'lib/models/porcelain.rb', line 11464

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



11467
11468
11469
# File 'lib/models/porcelain.rb', line 11467

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



11470
11471
11472
# File 'lib/models/porcelain.rb', line 11470

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



11472
11473
11474
# File 'lib/models/porcelain.rb', line 11472

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



11475
11476
11477
# File 'lib/models/porcelain.rb', line 11475

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



11477
11478
11479
# File 'lib/models/porcelain.rb', line 11477

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



11480
11481
11482
# File 'lib/models/porcelain.rb', line 11480

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



11482
11483
11484
# File 'lib/models/porcelain.rb', line 11482

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



11484
11485
11486
# File 'lib/models/porcelain.rb', line 11484

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



11486
11487
11488
# File 'lib/models/porcelain.rb', line 11486

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



11488
11489
11490
# File 'lib/models/porcelain.rb', line 11488

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



11490
11491
11492
# File 'lib/models/porcelain.rb', line 11490

def identity_alias_username
  @identity_alias_username
end

#metadata_jsonObject

Driver specific metadata associated with this query.



11492
11493
11494
# File 'lib/models/porcelain.rb', line 11492

def 
  @metadata_json
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



11495
11496
11497
# File 'lib/models/porcelain.rb', line 11495

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



11497
11498
11499
# File 'lib/models/porcelain.rb', line 11497

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



11499
11500
11501
# File 'lib/models/porcelain.rb', line 11499

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



11504
11505
11506
# File 'lib/models/porcelain.rb', line 11504

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



11506
11507
11508
# File 'lib/models/porcelain.rb', line 11506

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



11508
11509
11510
# File 'lib/models/porcelain.rb', line 11508

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



11510
11511
11512
# File 'lib/models/porcelain.rb', line 11510

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



11512
11513
11514
# File 'lib/models/porcelain.rb', line 11512

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



11515
11516
11517
# File 'lib/models/porcelain.rb', line 11515

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



11518
11519
11520
# File 'lib/models/porcelain.rb', line 11518

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



11520
11521
11522
# File 'lib/models/porcelain.rb', line 11520

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



11522
11523
11524
# File 'lib/models/porcelain.rb', line 11522

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



11524
11525
11526
# File 'lib/models/porcelain.rb', line 11524

def target
  @target
end

#timestampObject

The time at which the Query was started.



11526
11527
11528
# File 'lib/models/porcelain.rb', line 11526

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11590
11591
11592
11593
11594
11595
11596
# File 'lib/models/porcelain.rb', line 11590

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end