Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, metadata_json: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



11270
11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
11305
11306
11307
11308
11309
11310
11311
11312
11313
11314
11315
11316
11317
11318
11319
11320
11321
11322
11323
11324
11325
11326
11327
11328
11329
11330
# File 'lib/models/porcelain.rb', line 11270

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  metadata_json: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @metadata_json =  == nil ? "" : 
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



11201
11202
11203
# File 'lib/models/porcelain.rb', line 11201

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



11204
11205
11206
# File 'lib/models/porcelain.rb', line 11204

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



11206
11207
11208
# File 'lib/models/porcelain.rb', line 11206

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



11209
11210
11211
# File 'lib/models/porcelain.rb', line 11209

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



11212
11213
11214
# File 'lib/models/porcelain.rb', line 11212

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



11214
11215
11216
# File 'lib/models/porcelain.rb', line 11214

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



11217
11218
11219
# File 'lib/models/porcelain.rb', line 11217

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



11219
11220
11221
# File 'lib/models/porcelain.rb', line 11219

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



11222
11223
11224
# File 'lib/models/porcelain.rb', line 11222

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



11224
11225
11226
# File 'lib/models/porcelain.rb', line 11224

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



11226
11227
11228
# File 'lib/models/porcelain.rb', line 11226

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



11228
11229
11230
# File 'lib/models/porcelain.rb', line 11228

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



11230
11231
11232
# File 'lib/models/porcelain.rb', line 11230

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



11232
11233
11234
# File 'lib/models/porcelain.rb', line 11232

def identity_alias_username
  @identity_alias_username
end

#metadata_jsonObject

Driver specific metadata associated with this query.



11234
11235
11236
# File 'lib/models/porcelain.rb', line 11234

def 
  @metadata_json
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



11237
11238
11239
# File 'lib/models/porcelain.rb', line 11237

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



11239
11240
11241
# File 'lib/models/porcelain.rb', line 11239

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



11241
11242
11243
# File 'lib/models/porcelain.rb', line 11241

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



11246
11247
11248
# File 'lib/models/porcelain.rb', line 11246

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



11248
11249
11250
# File 'lib/models/porcelain.rb', line 11248

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



11250
11251
11252
# File 'lib/models/porcelain.rb', line 11250

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



11252
11253
11254
# File 'lib/models/porcelain.rb', line 11252

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



11254
11255
11256
# File 'lib/models/porcelain.rb', line 11254

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



11257
11258
11259
# File 'lib/models/porcelain.rb', line 11257

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



11260
11261
11262
# File 'lib/models/porcelain.rb', line 11260

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



11262
11263
11264
# File 'lib/models/porcelain.rb', line 11262

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



11264
11265
11266
# File 'lib/models/porcelain.rb', line 11264

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



11266
11267
11268
# File 'lib/models/porcelain.rb', line 11266

def target
  @target
end

#timestampObject

The time at which the Query was started.



11268
11269
11270
# File 'lib/models/porcelain.rb', line 11268

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11332
11333
11334
11335
11336
11337
11338
# File 'lib/models/porcelain.rb', line 11332

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end