Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
11036
11037
11038
11039
11040
11041
11042
11043
11044
11045
11046
11047
11048
11049
11050
11051
11052
11053
11054
11055
11056
11057
11058
11059
11060
11061
11062
11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
11079
11080
11081
11082
11083
# File 'lib/models/porcelain.rb', line 11025

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



10958
10959
10960
# File 'lib/models/porcelain.rb', line 10958

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



10961
10962
10963
# File 'lib/models/porcelain.rb', line 10961

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



10963
10964
10965
# File 'lib/models/porcelain.rb', line 10963

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



10966
10967
10968
# File 'lib/models/porcelain.rb', line 10966

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



10969
10970
10971
# File 'lib/models/porcelain.rb', line 10969

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



10971
10972
10973
# File 'lib/models/porcelain.rb', line 10971

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



10974
10975
10976
# File 'lib/models/porcelain.rb', line 10974

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



10976
10977
10978
# File 'lib/models/porcelain.rb', line 10976

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



10979
10980
10981
# File 'lib/models/porcelain.rb', line 10979

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



10981
10982
10983
# File 'lib/models/porcelain.rb', line 10981

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



10983
10984
10985
# File 'lib/models/porcelain.rb', line 10983

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



10985
10986
10987
# File 'lib/models/porcelain.rb', line 10985

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



10987
10988
10989
# File 'lib/models/porcelain.rb', line 10987

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



10989
10990
10991
# File 'lib/models/porcelain.rb', line 10989

def identity_alias_username
  @identity_alias_username
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



10992
10993
10994
# File 'lib/models/porcelain.rb', line 10992

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



10994
10995
10996
# File 'lib/models/porcelain.rb', line 10994

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



10996
10997
10998
# File 'lib/models/porcelain.rb', line 10996

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



11001
11002
11003
# File 'lib/models/porcelain.rb', line 11001

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



11003
11004
11005
# File 'lib/models/porcelain.rb', line 11003

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



11005
11006
11007
# File 'lib/models/porcelain.rb', line 11005

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



11007
11008
11009
# File 'lib/models/porcelain.rb', line 11007

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



11009
11010
11011
# File 'lib/models/porcelain.rb', line 11009

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



11012
11013
11014
# File 'lib/models/porcelain.rb', line 11012

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



11015
11016
11017
# File 'lib/models/porcelain.rb', line 11015

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



11017
11018
11019
# File 'lib/models/porcelain.rb', line 11017

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



11019
11020
11021
# File 'lib/models/porcelain.rb', line 11019

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



11021
11022
11023
# File 'lib/models/porcelain.rb', line 11021

def target
  @target
end

#timestampObject

The time at which the Query was started.



11023
11024
11025
# File 'lib/models/porcelain.rb', line 11023

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11085
11086
11087
11088
11089
11090
11091
# File 'lib/models/porcelain.rb', line 11085

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end