Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



10030
10031
10032
10033
10034
10035
10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
10058
10059
10060
10061
10062
10063
10064
10065
10066
10067
10068
10069
10070
10071
10072
10073
10074
10075
10076
10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
# File 'lib/models/porcelain.rb', line 10030

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



9963
9964
9965
# File 'lib/models/porcelain.rb', line 9963

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



9966
9967
9968
# File 'lib/models/porcelain.rb', line 9966

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



9968
9969
9970
# File 'lib/models/porcelain.rb', line 9968

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



9971
9972
9973
# File 'lib/models/porcelain.rb', line 9971

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



9974
9975
9976
# File 'lib/models/porcelain.rb', line 9974

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



9976
9977
9978
# File 'lib/models/porcelain.rb', line 9976

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



9979
9980
9981
# File 'lib/models/porcelain.rb', line 9979

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



9981
9982
9983
# File 'lib/models/porcelain.rb', line 9981

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



9984
9985
9986
# File 'lib/models/porcelain.rb', line 9984

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



9986
9987
9988
# File 'lib/models/porcelain.rb', line 9986

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



9988
9989
9990
# File 'lib/models/porcelain.rb', line 9988

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



9990
9991
9992
# File 'lib/models/porcelain.rb', line 9990

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



9992
9993
9994
# File 'lib/models/porcelain.rb', line 9992

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



9994
9995
9996
# File 'lib/models/porcelain.rb', line 9994

def identity_alias_username
  @identity_alias_username
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



9997
9998
9999
# File 'lib/models/porcelain.rb', line 9997

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



9999
10000
10001
# File 'lib/models/porcelain.rb', line 9999

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



10001
10002
10003
# File 'lib/models/porcelain.rb', line 10001

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



10006
10007
10008
# File 'lib/models/porcelain.rb', line 10006

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



10008
10009
10010
# File 'lib/models/porcelain.rb', line 10008

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



10010
10011
10012
# File 'lib/models/porcelain.rb', line 10010

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



10012
10013
10014
# File 'lib/models/porcelain.rb', line 10012

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



10014
10015
10016
# File 'lib/models/porcelain.rb', line 10014

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



10017
10018
10019
# File 'lib/models/porcelain.rb', line 10017

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



10020
10021
10022
# File 'lib/models/porcelain.rb', line 10020

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



10022
10023
10024
# File 'lib/models/porcelain.rb', line 10022

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



10024
10025
10026
# File 'lib/models/porcelain.rb', line 10024

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



10026
10027
10028
# File 'lib/models/porcelain.rb', line 10026

def target
  @target
end

#timestampObject

The time at which the Query was started.



10028
10029
10030
# File 'lib/models/porcelain.rb', line 10028

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10090
10091
10092
10093
10094
10095
10096
# File 'lib/models/porcelain.rb', line 10090

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end