Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
9981
9982
9983
9984
9985
9986
9987
9988
9989
9990
9991
9992
9993
9994
9995
9996
9997
9998
9999
10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/models/porcelain.rb', line 9956

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



9889
9890
9891
# File 'lib/models/porcelain.rb', line 9889

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



9892
9893
9894
# File 'lib/models/porcelain.rb', line 9892

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



9894
9895
9896
# File 'lib/models/porcelain.rb', line 9894

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



9897
9898
9899
# File 'lib/models/porcelain.rb', line 9897

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



9900
9901
9902
# File 'lib/models/porcelain.rb', line 9900

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



9902
9903
9904
# File 'lib/models/porcelain.rb', line 9902

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



9905
9906
9907
# File 'lib/models/porcelain.rb', line 9905

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



9907
9908
9909
# File 'lib/models/porcelain.rb', line 9907

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



9910
9911
9912
# File 'lib/models/porcelain.rb', line 9910

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



9912
9913
9914
# File 'lib/models/porcelain.rb', line 9912

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



9914
9915
9916
# File 'lib/models/porcelain.rb', line 9914

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



9916
9917
9918
# File 'lib/models/porcelain.rb', line 9916

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



9918
9919
9920
# File 'lib/models/porcelain.rb', line 9918

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



9920
9921
9922
# File 'lib/models/porcelain.rb', line 9920

def identity_alias_username
  @identity_alias_username
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



9923
9924
9925
# File 'lib/models/porcelain.rb', line 9923

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



9925
9926
9927
# File 'lib/models/porcelain.rb', line 9925

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



9927
9928
9929
# File 'lib/models/porcelain.rb', line 9927

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



9932
9933
9934
# File 'lib/models/porcelain.rb', line 9932

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



9934
9935
9936
# File 'lib/models/porcelain.rb', line 9934

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



9936
9937
9938
# File 'lib/models/porcelain.rb', line 9936

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



9938
9939
9940
# File 'lib/models/porcelain.rb', line 9938

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



9940
9941
9942
# File 'lib/models/porcelain.rb', line 9940

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



9943
9944
9945
# File 'lib/models/porcelain.rb', line 9943

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



9946
9947
9948
# File 'lib/models/porcelain.rb', line 9946

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



9948
9949
9950
# File 'lib/models/porcelain.rb', line 9948

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



9950
9951
9952
# File 'lib/models/porcelain.rb', line 9950

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



9952
9953
9954
# File 'lib/models/porcelain.rb', line 9952

def target
  @target
end

#timestampObject

The time at which the Query was started.



9954
9955
9956
# File 'lib/models/porcelain.rb', line 9954

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10016
10017
10018
10019
10020
10021
10022
# File 'lib/models/porcelain.rb', line 10016

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end