Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



9806
9807
9808
9809
9810
9811
9812
9813
9814
9815
9816
9817
9818
9819
9820
9821
9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
9840
9841
9842
9843
9844
9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
9861
9862
9863
9864
# File 'lib/models/porcelain.rb', line 9806

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



9739
9740
9741
# File 'lib/models/porcelain.rb', line 9739

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



9742
9743
9744
# File 'lib/models/porcelain.rb', line 9742

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



9744
9745
9746
# File 'lib/models/porcelain.rb', line 9744

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



9747
9748
9749
# File 'lib/models/porcelain.rb', line 9747

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



9750
9751
9752
# File 'lib/models/porcelain.rb', line 9750

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



9752
9753
9754
# File 'lib/models/porcelain.rb', line 9752

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



9755
9756
9757
# File 'lib/models/porcelain.rb', line 9755

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



9757
9758
9759
# File 'lib/models/porcelain.rb', line 9757

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



9760
9761
9762
# File 'lib/models/porcelain.rb', line 9760

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



9762
9763
9764
# File 'lib/models/porcelain.rb', line 9762

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



9764
9765
9766
# File 'lib/models/porcelain.rb', line 9764

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



9766
9767
9768
# File 'lib/models/porcelain.rb', line 9766

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



9768
9769
9770
# File 'lib/models/porcelain.rb', line 9768

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



9770
9771
9772
# File 'lib/models/porcelain.rb', line 9770

def identity_alias_username
  @identity_alias_username
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



9773
9774
9775
# File 'lib/models/porcelain.rb', line 9773

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



9775
9776
9777
# File 'lib/models/porcelain.rb', line 9775

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



9777
9778
9779
# File 'lib/models/porcelain.rb', line 9777

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



9782
9783
9784
# File 'lib/models/porcelain.rb', line 9782

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



9784
9785
9786
# File 'lib/models/porcelain.rb', line 9784

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



9786
9787
9788
# File 'lib/models/porcelain.rb', line 9786

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



9788
9789
9790
# File 'lib/models/porcelain.rb', line 9788

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



9790
9791
9792
# File 'lib/models/porcelain.rb', line 9790

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



9793
9794
9795
# File 'lib/models/porcelain.rb', line 9793

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



9796
9797
9798
# File 'lib/models/porcelain.rb', line 9796

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



9798
9799
9800
# File 'lib/models/porcelain.rb', line 9798

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



9800
9801
9802
# File 'lib/models/porcelain.rb', line 9800

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



9802
9803
9804
# File 'lib/models/porcelain.rb', line 9802

def target
  @target
end

#timestampObject

The time at which the Query was started.



9804
9805
9806
# File 'lib/models/porcelain.rb', line 9804

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9866
9867
9868
9869
9870
9871
9872
# File 'lib/models/porcelain.rb', line 9866

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end