Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
9459
9460
9461
9462
9463
9464
9465
9466
9467
9468
9469
9470
9471
9472
9473
9474
9475
9476
9477
9478
9479
9480
9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
# File 'lib/models/porcelain.rb', line 9444

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



9377
9378
9379
# File 'lib/models/porcelain.rb', line 9377

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



9380
9381
9382
# File 'lib/models/porcelain.rb', line 9380

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



9382
9383
9384
# File 'lib/models/porcelain.rb', line 9382

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



9385
9386
9387
# File 'lib/models/porcelain.rb', line 9385

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



9388
9389
9390
# File 'lib/models/porcelain.rb', line 9388

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



9390
9391
9392
# File 'lib/models/porcelain.rb', line 9390

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



9393
9394
9395
# File 'lib/models/porcelain.rb', line 9393

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



9395
9396
9397
# File 'lib/models/porcelain.rb', line 9395

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



9398
9399
9400
# File 'lib/models/porcelain.rb', line 9398

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



9400
9401
9402
# File 'lib/models/porcelain.rb', line 9400

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



9402
9403
9404
# File 'lib/models/porcelain.rb', line 9402

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



9404
9405
9406
# File 'lib/models/porcelain.rb', line 9404

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



9406
9407
9408
# File 'lib/models/porcelain.rb', line 9406

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



9408
9409
9410
# File 'lib/models/porcelain.rb', line 9408

def identity_alias_username
  @identity_alias_username
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



9411
9412
9413
# File 'lib/models/porcelain.rb', line 9411

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



9413
9414
9415
# File 'lib/models/porcelain.rb', line 9413

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



9415
9416
9417
# File 'lib/models/porcelain.rb', line 9415

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



9420
9421
9422
# File 'lib/models/porcelain.rb', line 9420

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



9422
9423
9424
# File 'lib/models/porcelain.rb', line 9422

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



9424
9425
9426
# File 'lib/models/porcelain.rb', line 9424

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



9426
9427
9428
# File 'lib/models/porcelain.rb', line 9426

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



9428
9429
9430
# File 'lib/models/porcelain.rb', line 9428

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



9431
9432
9433
# File 'lib/models/porcelain.rb', line 9431

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



9434
9435
9436
# File 'lib/models/porcelain.rb', line 9434

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



9436
9437
9438
# File 'lib/models/porcelain.rb', line 9436

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



9438
9439
9440
# File 'lib/models/porcelain.rb', line 9438

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



9440
9441
9442
# File 'lib/models/porcelain.rb', line 9440

def target
  @target
end

#timestampObject

The time at which the Query was started.



9442
9443
9444
# File 'lib/models/porcelain.rb', line 9442

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9504
9505
9506
9507
9508
9509
9510
# File 'lib/models/porcelain.rb', line 9504

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end