Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



8622
8623
8624
8625
8626
8627
8628
8629
8630
8631
8632
8633
8634
8635
8636
8637
8638
8639
8640
8641
8642
8643
8644
8645
8646
8647
8648
8649
8650
8651
8652
8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
# File 'lib/models/porcelain.rb', line 8622

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



8555
8556
8557
# File 'lib/models/porcelain.rb', line 8555

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



8558
8559
8560
# File 'lib/models/porcelain.rb', line 8558

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



8560
8561
8562
# File 'lib/models/porcelain.rb', line 8560

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



8563
8564
8565
# File 'lib/models/porcelain.rb', line 8563

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



8566
8567
8568
# File 'lib/models/porcelain.rb', line 8566

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



8568
8569
8570
# File 'lib/models/porcelain.rb', line 8568

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



8571
8572
8573
# File 'lib/models/porcelain.rb', line 8571

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



8573
8574
8575
# File 'lib/models/porcelain.rb', line 8573

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



8576
8577
8578
# File 'lib/models/porcelain.rb', line 8576

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



8578
8579
8580
# File 'lib/models/porcelain.rb', line 8578

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



8580
8581
8582
# File 'lib/models/porcelain.rb', line 8580

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



8582
8583
8584
# File 'lib/models/porcelain.rb', line 8582

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



8584
8585
8586
# File 'lib/models/porcelain.rb', line 8584

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



8586
8587
8588
# File 'lib/models/porcelain.rb', line 8586

def identity_alias_username
  @identity_alias_username
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



8589
8590
8591
# File 'lib/models/porcelain.rb', line 8589

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



8591
8592
8593
# File 'lib/models/porcelain.rb', line 8591

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



8593
8594
8595
# File 'lib/models/porcelain.rb', line 8593

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



8598
8599
8600
# File 'lib/models/porcelain.rb', line 8598

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



8600
8601
8602
# File 'lib/models/porcelain.rb', line 8600

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



8602
8603
8604
# File 'lib/models/porcelain.rb', line 8602

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



8604
8605
8606
# File 'lib/models/porcelain.rb', line 8604

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



8606
8607
8608
# File 'lib/models/porcelain.rb', line 8606

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



8609
8610
8611
# File 'lib/models/porcelain.rb', line 8609

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



8612
8613
8614
# File 'lib/models/porcelain.rb', line 8612

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



8614
8615
8616
# File 'lib/models/porcelain.rb', line 8614

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



8616
8617
8618
# File 'lib/models/porcelain.rb', line 8616

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



8618
8619
8620
# File 'lib/models/porcelain.rb', line 8618

def target
  @target
end

#timestampObject

The time at which the Query was started.



8620
8621
8622
# File 'lib/models/porcelain.rb', line 8620

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8682
8683
8684
8685
8686
8687
8688
# File 'lib/models/porcelain.rb', line 8682

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end