Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, capture: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
7150
7151
7152
7153
7154
7155
7156
7157
7158
7159
7160
7161
7162
7163
7164
7165
7166
7167
7168
7169
7170
7171
7172
7173
7174
7175
7176
7177
7178
7179
# File 'lib/models/porcelain.rb', line 7129

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  capture: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @capture = capture == nil ? nil : capture
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



7070
7071
7072
# File 'lib/models/porcelain.rb', line 7070

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



7073
7074
7075
# File 'lib/models/porcelain.rb', line 7073

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



7075
7076
7077
# File 'lib/models/porcelain.rb', line 7075

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



7078
7079
7080
# File 'lib/models/porcelain.rb', line 7078

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



7081
7082
7083
# File 'lib/models/porcelain.rb', line 7081

def 
  @account_tags
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



7084
7085
7086
# File 'lib/models/porcelain.rb', line 7084

def capture
  @capture
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



7087
7088
7089
# File 'lib/models/porcelain.rb', line 7087

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



7089
7090
7091
# File 'lib/models/porcelain.rb', line 7089

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



7091
7092
7093
# File 'lib/models/porcelain.rb', line 7091

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



7093
7094
7095
# File 'lib/models/porcelain.rb', line 7093

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



7095
7096
7097
# File 'lib/models/porcelain.rb', line 7095

def id
  @id
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



7098
7099
7100
# File 'lib/models/porcelain.rb', line 7098

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



7100
7101
7102
# File 'lib/models/porcelain.rb', line 7100

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



7102
7103
7104
# File 'lib/models/porcelain.rb', line 7102

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



7107
7108
7109
# File 'lib/models/porcelain.rb', line 7107

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



7109
7110
7111
# File 'lib/models/porcelain.rb', line 7109

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



7111
7112
7113
# File 'lib/models/porcelain.rb', line 7111

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



7113
7114
7115
# File 'lib/models/porcelain.rb', line 7113

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



7115
7116
7117
# File 'lib/models/porcelain.rb', line 7115

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



7118
7119
7120
# File 'lib/models/porcelain.rb', line 7118

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



7121
7122
7123
# File 'lib/models/porcelain.rb', line 7121

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



7123
7124
7125
# File 'lib/models/porcelain.rb', line 7123

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



7125
7126
7127
# File 'lib/models/porcelain.rb', line 7125

def source_ip
  @source_ip
end

#timestampObject

The time at which the Query was started.



7127
7128
7129
# File 'lib/models/porcelain.rb', line 7127

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7181
7182
7183
7184
7185
7186
7187
# File 'lib/models/porcelain.rb', line 7181

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end