Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, capture: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
# File 'lib/models/porcelain.rb', line 7008

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  capture: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @capture = capture == nil ? nil : capture
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



6949
6950
6951
# File 'lib/models/porcelain.rb', line 6949

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



6952
6953
6954
# File 'lib/models/porcelain.rb', line 6952

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



6954
6955
6956
# File 'lib/models/porcelain.rb', line 6954

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



6957
6958
6959
# File 'lib/models/porcelain.rb', line 6957

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



6960
6961
6962
# File 'lib/models/porcelain.rb', line 6960

def 
  @account_tags
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



6963
6964
6965
# File 'lib/models/porcelain.rb', line 6963

def capture
  @capture
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



6966
6967
6968
# File 'lib/models/porcelain.rb', line 6966

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



6968
6969
6970
# File 'lib/models/porcelain.rb', line 6968

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



6970
6971
6972
# File 'lib/models/porcelain.rb', line 6970

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



6972
6973
6974
# File 'lib/models/porcelain.rb', line 6972

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



6974
6975
6976
# File 'lib/models/porcelain.rb', line 6974

def id
  @id
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



6977
6978
6979
# File 'lib/models/porcelain.rb', line 6977

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



6979
6980
6981
# File 'lib/models/porcelain.rb', line 6979

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



6981
6982
6983
# File 'lib/models/porcelain.rb', line 6981

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



6986
6987
6988
# File 'lib/models/porcelain.rb', line 6986

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



6988
6989
6990
# File 'lib/models/porcelain.rb', line 6988

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



6990
6991
6992
# File 'lib/models/porcelain.rb', line 6990

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



6992
6993
6994
# File 'lib/models/porcelain.rb', line 6992

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



6994
6995
6996
# File 'lib/models/porcelain.rb', line 6994

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



6997
6998
6999
# File 'lib/models/porcelain.rb', line 6997

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



7000
7001
7002
# File 'lib/models/porcelain.rb', line 7000

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



7002
7003
7004
# File 'lib/models/porcelain.rb', line 7002

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



7004
7005
7006
# File 'lib/models/porcelain.rb', line 7004

def source_ip
  @source_ip
end

#timestampObject

The time at which the Query was started.



7006
7007
7008
# File 'lib/models/porcelain.rb', line 7006

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7060
7061
7062
7063
7064
7065
7066
# File 'lib/models/porcelain.rb', line 7060

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end