Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, capture: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



6685
6686
6687
6688
6689
6690
6691
6692
6693
6694
6695
6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
6720
6721
6722
6723
6724
6725
6726
6727
6728
6729
6730
6731
6732
6733
6734
6735
# File 'lib/models/porcelain.rb', line 6685

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  capture: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @capture = capture == nil ? nil : capture
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



6626
6627
6628
# File 'lib/models/porcelain.rb', line 6626

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



6629
6630
6631
# File 'lib/models/porcelain.rb', line 6629

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



6631
6632
6633
# File 'lib/models/porcelain.rb', line 6631

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



6634
6635
6636
# File 'lib/models/porcelain.rb', line 6634

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



6637
6638
6639
# File 'lib/models/porcelain.rb', line 6637

def 
  @account_tags
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



6640
6641
6642
# File 'lib/models/porcelain.rb', line 6640

def capture
  @capture
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



6643
6644
6645
# File 'lib/models/porcelain.rb', line 6643

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



6645
6646
6647
# File 'lib/models/porcelain.rb', line 6645

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



6647
6648
6649
# File 'lib/models/porcelain.rb', line 6647

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



6649
6650
6651
# File 'lib/models/porcelain.rb', line 6649

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



6651
6652
6653
# File 'lib/models/porcelain.rb', line 6651

def id
  @id
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



6654
6655
6656
# File 'lib/models/porcelain.rb', line 6654

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



6656
6657
6658
# File 'lib/models/porcelain.rb', line 6656

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



6658
6659
6660
# File 'lib/models/porcelain.rb', line 6658

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



6663
6664
6665
# File 'lib/models/porcelain.rb', line 6663

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



6665
6666
6667
# File 'lib/models/porcelain.rb', line 6665

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



6667
6668
6669
# File 'lib/models/porcelain.rb', line 6667

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



6669
6670
6671
# File 'lib/models/porcelain.rb', line 6669

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



6671
6672
6673
# File 'lib/models/porcelain.rb', line 6671

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



6674
6675
6676
# File 'lib/models/porcelain.rb', line 6674

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



6677
6678
6679
# File 'lib/models/porcelain.rb', line 6677

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



6679
6680
6681
# File 'lib/models/porcelain.rb', line 6679

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



6681
6682
6683
# File 'lib/models/porcelain.rb', line 6681

def source_ip
  @source_ip
end

#timestampObject

The time at which the Query was started.



6683
6684
6685
# File 'lib/models/porcelain.rb', line 6683

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6737
6738
6739
6740
6741
6742
6743
# File 'lib/models/porcelain.rb', line 6737

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end