Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, capture: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
# File 'lib/models/porcelain.rb', line 6261

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  capture: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @capture = capture == nil ? nil : capture
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



6202
6203
6204
# File 'lib/models/porcelain.rb', line 6202

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



6205
6206
6207
# File 'lib/models/porcelain.rb', line 6205

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



6207
6208
6209
# File 'lib/models/porcelain.rb', line 6207

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



6210
6211
6212
# File 'lib/models/porcelain.rb', line 6210

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



6213
6214
6215
# File 'lib/models/porcelain.rb', line 6213

def 
  @account_tags
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



6216
6217
6218
# File 'lib/models/porcelain.rb', line 6216

def capture
  @capture
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



6219
6220
6221
# File 'lib/models/porcelain.rb', line 6219

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



6221
6222
6223
# File 'lib/models/porcelain.rb', line 6221

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



6223
6224
6225
# File 'lib/models/porcelain.rb', line 6223

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



6225
6226
6227
# File 'lib/models/porcelain.rb', line 6225

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



6227
6228
6229
# File 'lib/models/porcelain.rb', line 6227

def id
  @id
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



6230
6231
6232
# File 'lib/models/porcelain.rb', line 6230

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



6232
6233
6234
# File 'lib/models/porcelain.rb', line 6232

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



6234
6235
6236
# File 'lib/models/porcelain.rb', line 6234

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



6239
6240
6241
# File 'lib/models/porcelain.rb', line 6239

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



6241
6242
6243
# File 'lib/models/porcelain.rb', line 6241

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



6243
6244
6245
# File 'lib/models/porcelain.rb', line 6243

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



6245
6246
6247
# File 'lib/models/porcelain.rb', line 6245

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



6247
6248
6249
# File 'lib/models/porcelain.rb', line 6247

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



6250
6251
6252
# File 'lib/models/porcelain.rb', line 6250

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



6253
6254
6255
# File 'lib/models/porcelain.rb', line 6253

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



6255
6256
6257
# File 'lib/models/porcelain.rb', line 6255

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



6257
6258
6259
# File 'lib/models/porcelain.rb', line 6257

def source_ip
  @source_ip
end

#timestampObject

The time at which the Query was started.



6259
6260
6261
# File 'lib/models/porcelain.rb', line 6259

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6313
6314
6315
6316
6317
6318
6319
# File 'lib/models/porcelain.rb', line 6313

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end