Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, capture: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



6101
6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
6112
6113
6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
6124
6125
6126
6127
6128
6129
6130
6131
6132
6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/models/porcelain.rb', line 6101

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  capture: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @capture = capture == nil ? nil : capture
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



6044
6045
6046
# File 'lib/models/porcelain.rb', line 6044

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



6047
6048
6049
# File 'lib/models/porcelain.rb', line 6047

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



6049
6050
6051
# File 'lib/models/porcelain.rb', line 6049

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



6052
6053
6054
# File 'lib/models/porcelain.rb', line 6052

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



6055
6056
6057
# File 'lib/models/porcelain.rb', line 6055

def 
  @account_tags
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



6058
6059
6060
# File 'lib/models/porcelain.rb', line 6058

def capture
  @capture
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



6061
6062
6063
# File 'lib/models/porcelain.rb', line 6061

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



6063
6064
6065
# File 'lib/models/porcelain.rb', line 6063

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



6065
6066
6067
# File 'lib/models/porcelain.rb', line 6065

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



6067
6068
6069
# File 'lib/models/porcelain.rb', line 6067

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



6069
6070
6071
# File 'lib/models/porcelain.rb', line 6069

def id
  @id
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



6072
6073
6074
# File 'lib/models/porcelain.rb', line 6072

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



6074
6075
6076
# File 'lib/models/porcelain.rb', line 6074

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



6076
6077
6078
# File 'lib/models/porcelain.rb', line 6076

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



6081
6082
6083
# File 'lib/models/porcelain.rb', line 6081

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



6083
6084
6085
# File 'lib/models/porcelain.rb', line 6083

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



6085
6086
6087
# File 'lib/models/porcelain.rb', line 6085

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



6087
6088
6089
# File 'lib/models/porcelain.rb', line 6087

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



6089
6090
6091
# File 'lib/models/porcelain.rb', line 6089

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



6092
6093
6094
# File 'lib/models/porcelain.rb', line 6092

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



6095
6096
6097
# File 'lib/models/porcelain.rb', line 6095

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



6097
6098
6099
# File 'lib/models/porcelain.rb', line 6097

def resource_type
  @resource_type
end

#timestampObject

The time at which the Query was started.



6099
6100
6101
# File 'lib/models/porcelain.rb', line 6099

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6151
6152
6153
6154
6155
6156
6157
# File 'lib/models/porcelain.rb', line 6151

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end