Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, capture: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
6027
6028
6029
6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
# File 'lib/models/porcelain.rb', line 5992

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  capture: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @capture = capture == nil ? nil : capture
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



5935
5936
5937
# File 'lib/models/porcelain.rb', line 5935

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



5938
5939
5940
# File 'lib/models/porcelain.rb', line 5938

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



5940
5941
5942
# File 'lib/models/porcelain.rb', line 5940

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



5943
5944
5945
# File 'lib/models/porcelain.rb', line 5943

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



5946
5947
5948
# File 'lib/models/porcelain.rb', line 5946

def 
  @account_tags
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



5949
5950
5951
# File 'lib/models/porcelain.rb', line 5949

def capture
  @capture
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



5952
5953
5954
# File 'lib/models/porcelain.rb', line 5952

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



5954
5955
5956
# File 'lib/models/porcelain.rb', line 5954

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



5956
5957
5958
# File 'lib/models/porcelain.rb', line 5956

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



5958
5959
5960
# File 'lib/models/porcelain.rb', line 5958

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



5960
5961
5962
# File 'lib/models/porcelain.rb', line 5960

def id
  @id
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



5963
5964
5965
# File 'lib/models/porcelain.rb', line 5963

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



5965
5966
5967
# File 'lib/models/porcelain.rb', line 5965

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



5967
5968
5969
# File 'lib/models/porcelain.rb', line 5967

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



5972
5973
5974
# File 'lib/models/porcelain.rb', line 5972

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



5974
5975
5976
# File 'lib/models/porcelain.rb', line 5974

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



5976
5977
5978
# File 'lib/models/porcelain.rb', line 5976

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



5978
5979
5980
# File 'lib/models/porcelain.rb', line 5978

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



5980
5981
5982
# File 'lib/models/porcelain.rb', line 5980

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



5983
5984
5985
# File 'lib/models/porcelain.rb', line 5983

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



5986
5987
5988
# File 'lib/models/porcelain.rb', line 5986

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



5988
5989
5990
# File 'lib/models/porcelain.rb', line 5988

def resource_type
  @resource_type
end

#timestampObject

The time at which the Query was started.



5990
5991
5992
# File 'lib/models/porcelain.rb', line 5990

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6042
6043
6044
6045
6046
6047
6048
# File 'lib/models/porcelain.rb', line 6042

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end