Class: SDM::Query

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Query is a record of a single client request to a resource, such as a SQL query. Longer-running queries including long-running SSH commands and SSH, RDP, or Kubernetes interactive sessions will return two Query records with the same identifier, one record at the start of the query and a second record upon the completion of the query with additional detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_email: nil, account_first_name: nil, account_id: nil, account_last_name: nil, account_tags: nil, authzjson: nil, capture: nil, client_ip: nil, completed_at: nil, duration: nil, egress_node_id: nil, encrypted: nil, id: nil, identity_alias_username: nil, query_body: nil, query_category: nil, query_hash: nil, query_key: nil, record_count: nil, remote_identity_username: nil, replayable: nil, resource_id: nil, resource_name: nil, resource_tags: nil, resource_type: nil, source_ip: nil, target: nil, timestamp: nil) ⇒ Query

Returns a new instance of Query.



11093
11094
11095
11096
11097
11098
11099
11100
11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
11113
11114
11115
11116
11117
11118
11119
11120
11121
11122
11123
11124
11125
11126
11127
11128
11129
11130
11131
11132
11133
11134
11135
11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
# File 'lib/models/porcelain.rb', line 11093

def initialize(
  account_email: nil,
  account_first_name: nil,
  account_id: nil,
  account_last_name: nil,
  account_tags: nil,
  authzjson: nil,
  capture: nil,
  client_ip: nil,
  completed_at: nil,
  duration: nil,
  egress_node_id: nil,
  encrypted: nil,
  id: nil,
  identity_alias_username: nil,
  query_body: nil,
  query_category: nil,
  query_hash: nil,
  query_key: nil,
  record_count: nil,
  remote_identity_username: nil,
  replayable: nil,
  resource_id: nil,
  resource_name: nil,
  resource_tags: nil,
  resource_type: nil,
  source_ip: nil,
  target: nil,
  timestamp: nil
)
  @account_email =  == nil ? "" : 
  @account_first_name =  == nil ? "" : 
  @account_id =  == nil ? "" : 
  @account_last_name =  == nil ? "" : 
  @account_tags =  == nil ? SDM::_porcelain_zero_value_tags() : 
  @authzjson = authzjson == nil ? "" : authzjson
  @capture = capture == nil ? nil : capture
  @client_ip = client_ip == nil ? "" : client_ip
  @completed_at = completed_at == nil ? nil : completed_at
  @duration = duration == nil ? nil : duration
  @egress_node_id = egress_node_id == nil ? "" : egress_node_id
  @encrypted = encrypted == nil ? false : encrypted
  @id = id == nil ? "" : id
  @identity_alias_username = identity_alias_username == nil ? "" : identity_alias_username
  @query_body = query_body == nil ? "" : query_body
  @query_category = query_category == nil ? "" : query_category
  @query_hash = query_hash == nil ? "" : query_hash
  @query_key = query_key == nil ? "" : query_key
  @record_count = record_count == nil ? 0 : record_count
  @remote_identity_username = remote_identity_username == nil ? "" : remote_identity_username
  @replayable = replayable == nil ? false : replayable
  @resource_id = resource_id == nil ? "" : resource_id
  @resource_name = resource_name == nil ? "" : resource_name
  @resource_tags = resource_tags == nil ? SDM::_porcelain_zero_value_tags() : resource_tags
  @resource_type = resource_type == nil ? "" : resource_type
  @source_ip = source_ip == nil ? "" : source_ip
  @target = target == nil ? "" : target
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#account_emailObject

The email of the account performing this query, at the time the query was executed. If the account email is later changed, that change will not be reflected via this field.



11026
11027
11028
# File 'lib/models/porcelain.rb', line 11026

def 
  @account_email
end

#account_first_nameObject

The given name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



11029
11030
11031
# File 'lib/models/porcelain.rb', line 11029

def 
  @account_first_name
end

#account_idObject

Unique identifier of the Account that performed the Query.



11031
11032
11033
# File 'lib/models/porcelain.rb', line 11031

def 
  @account_id
end

#account_last_nameObject

The family name of the account performing this query, at the time the query was executed. If the account is later renamed, that change will not be reflected via this field.



11034
11035
11036
# File 'lib/models/porcelain.rb', line 11034

def 
  @account_last_name
end

#account_tagsObject

The tags of the account accessed, at the time the query was executed. If the account tags are later changed, that change will not be reflected via this field.



11037
11038
11039
# File 'lib/models/porcelain.rb', line 11037

def 
  @account_tags
end

#authzjsonObject

Authorization metadata associated with this query.



11039
11040
11041
# File 'lib/models/porcelain.rb', line 11039

def authzjson
  @authzjson
end

#captureObject

For queries against SSH, Kubernetes, and RDP resources, this contains additional information about the captured query.



11042
11043
11044
# File 'lib/models/porcelain.rb', line 11042

def capture
  @capture
end

#client_ipObject

The IP address the Query was performed from, as detected at the StrongDM control plane.



11044
11045
11046
# File 'lib/models/porcelain.rb', line 11044

def client_ip
  @client_ip
end

#completed_atObject

The time at which the Query was completed. Empty if this record indicates the start of a long-running query.



11047
11048
11049
# File 'lib/models/porcelain.rb', line 11047

def completed_at
  @completed_at
end

#durationObject

The duration of the Query.



11049
11050
11051
# File 'lib/models/porcelain.rb', line 11049

def duration
  @duration
end

#egress_node_idObject

The unique ID of the node through which the Resource was accessed.



11051
11052
11053
# File 'lib/models/porcelain.rb', line 11051

def egress_node_id
  @egress_node_id
end

#encryptedObject

Indicates that the body of the Query is encrypted.



11053
11054
11055
# File 'lib/models/porcelain.rb', line 11053

def encrypted
  @encrypted
end

#idObject

Unique identifier of the Query.



11055
11056
11057
# File 'lib/models/porcelain.rb', line 11055

def id
  @id
end

#identity_alias_usernameObject

The username of the IdentityAlias used to access the Resource.



11057
11058
11059
# File 'lib/models/porcelain.rb', line 11057

def identity_alias_username
  @identity_alias_username
end

#query_bodyObject

The captured content of the Query. For queries against SSH, Kubernetes, and RDP resources, this contains a JSON representation of the QueryCapture.



11060
11061
11062
# File 'lib/models/porcelain.rb', line 11060

def query_body
  @query_body
end

#query_categoryObject

The general category of Resource against which Query was performed, e.g. "web" or "cloud".



11062
11063
11064
# File 'lib/models/porcelain.rb', line 11062

def query_category
  @query_category
end

#query_hashObject

The hash of the body of the Query.



11064
11065
11066
# File 'lib/models/porcelain.rb', line 11064

def query_hash
  @query_hash
end

#query_keyObject

The symmetric key used to encrypt the body of this Query and its replay if replayable. If the Query is encrypted, this field contains an encrypted symmetric key in base64 encoding. This key must be decrypted with the organization's private key to obtain the symmetric key needed to decrypt the body. If the Query is not encrypted, this field is empty.



11069
11070
11071
# File 'lib/models/porcelain.rb', line 11069

def query_key
  @query_key
end

#record_countObject

The number of records returned by the Query, for a database Resource.



11071
11072
11073
# File 'lib/models/porcelain.rb', line 11071

def record_count
  @record_count
end

#remote_identity_usernameObject

The username of the RemoteIdentity used to access the Resource.



11073
11074
11075
# File 'lib/models/porcelain.rb', line 11073

def remote_identity_username
  @remote_identity_username
end

#replayableObject

Indicates that the Query is replayable, e.g. for some SSH or K8s sessions.



11075
11076
11077
# File 'lib/models/porcelain.rb', line 11075

def replayable
  @replayable
end

#resource_idObject

Unique identifier of the Resource against which the Query was performed.



11077
11078
11079
# File 'lib/models/porcelain.rb', line 11077

def resource_id
  @resource_id
end

#resource_nameObject

The name of the resource accessed, at the time the query was executed. If the resource is later renamed, that change will not be reflected via this field.



11080
11081
11082
# File 'lib/models/porcelain.rb', line 11080

def resource_name
  @resource_name
end

#resource_tagsObject

The tags of the resource accessed, at the time the query was executed. If the resource tags are later changed, that change will not be reflected via this field.



11083
11084
11085
# File 'lib/models/porcelain.rb', line 11083

def resource_tags
  @resource_tags
end

#resource_typeObject

The specific type of Resource against which the Query was performed, e.g. "ssh" or "postgres".



11085
11086
11087
# File 'lib/models/porcelain.rb', line 11085

def resource_type
  @resource_type
end

#source_ipObject

The IP address the Query was performed from, as detected at the ingress gateway.



11087
11088
11089
# File 'lib/models/porcelain.rb', line 11087

def source_ip
  @source_ip
end

#targetObject

The target destination of the query, in host:port format.



11089
11090
11091
# File 'lib/models/porcelain.rb', line 11089

def target
  @target
end

#timestampObject

The time at which the Query was started.



11091
11092
11093
# File 'lib/models/porcelain.rb', line 11091

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11153
11154
11155
11156
11157
11158
11159
# File 'lib/models/porcelain.rb', line 11153

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end