Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



13839
13840
13841
13842
13843
13844
13845
13846
13847
13848
13849
13850
13851
13852
13853
13854
13855
13856
13857
13858
13859
13860
13861
13862
13863
13864
13865
13866
13867
13868
13869
13870
13871
13872
13873
# File 'lib/models/porcelain.rb', line 13839

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  impersonation_groups: nil,
  impersonation_user: nil,
  pod: nil,
  privilege_groups: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @impersonation_groups = impersonation_groups == nil ? [] : impersonation_groups
  @impersonation_user = impersonation_user == nil ? "" : impersonation_user
  @pod = pod == nil ? "" : pod
  @privilege_groups = privilege_groups == nil ? [] : privilege_groups
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



13807
13808
13809
# File 'lib/models/porcelain.rb', line 13807

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



13809
13810
13811
# File 'lib/models/porcelain.rb', line 13809

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



13811
13812
13813
# File 'lib/models/porcelain.rb', line 13811

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



13813
13814
13815
# File 'lib/models/porcelain.rb', line 13813

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



13815
13816
13817
# File 'lib/models/porcelain.rb', line 13815

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



13817
13818
13819
# File 'lib/models/porcelain.rb', line 13817

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



13819
13820
13821
# File 'lib/models/porcelain.rb', line 13819

def height
  @height
end

#impersonation_groupsObject

The impersonation groups of a Kubernetes operation.



13821
13822
13823
# File 'lib/models/porcelain.rb', line 13821

def impersonation_groups
  @impersonation_groups
end

#impersonation_userObject

The impersonation user of a Kubernetes operation.



13823
13824
13825
# File 'lib/models/porcelain.rb', line 13823

def impersonation_user
  @impersonation_user
end

#podObject

The target pod of a Kubernetes operation.



13825
13826
13827
# File 'lib/models/porcelain.rb', line 13825

def pod
  @pod
end

#privilege_groupsObject

The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.



13827
13828
13829
# File 'lib/models/porcelain.rb', line 13827

def privilege_groups
  @privilege_groups
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



13829
13830
13831
# File 'lib/models/porcelain.rb', line 13829

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



13831
13832
13833
# File 'lib/models/porcelain.rb', line 13831

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



13833
13834
13835
# File 'lib/models/porcelain.rb', line 13833

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture, one of the CaptureType constants.



13835
13836
13837
# File 'lib/models/porcelain.rb', line 13835

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



13837
13838
13839
# File 'lib/models/porcelain.rb', line 13837

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13875
13876
13877
13878
13879
13880
13881
# File 'lib/models/porcelain.rb', line 13875

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end