Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
12674
12675
12676
12677
12678
12679
12680
12681
12682
12683
12684
12685
12686
12687
12688
12689
12690
12691
12692
12693
12694
12695
12696
12697
# File 'lib/models/porcelain.rb', line 12663

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  impersonation_groups: nil,
  impersonation_user: nil,
  pod: nil,
  privilege_groups: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @impersonation_groups = impersonation_groups == nil ? [] : impersonation_groups
  @impersonation_user = impersonation_user == nil ? "" : impersonation_user
  @pod = pod == nil ? "" : pod
  @privilege_groups = privilege_groups == nil ? [] : privilege_groups
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



12631
12632
12633
# File 'lib/models/porcelain.rb', line 12631

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



12633
12634
12635
# File 'lib/models/porcelain.rb', line 12633

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



12635
12636
12637
# File 'lib/models/porcelain.rb', line 12635

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



12637
12638
12639
# File 'lib/models/porcelain.rb', line 12637

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



12639
12640
12641
# File 'lib/models/porcelain.rb', line 12639

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



12641
12642
12643
# File 'lib/models/porcelain.rb', line 12641

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



12643
12644
12645
# File 'lib/models/porcelain.rb', line 12643

def height
  @height
end

#impersonation_groupsObject

The impersonation groups of a Kubernetes operation.



12645
12646
12647
# File 'lib/models/porcelain.rb', line 12645

def impersonation_groups
  @impersonation_groups
end

#impersonation_userObject

The impersonation user of a Kubernetes operation.



12647
12648
12649
# File 'lib/models/porcelain.rb', line 12647

def impersonation_user
  @impersonation_user
end

#podObject

The target pod of a Kubernetes operation.



12649
12650
12651
# File 'lib/models/porcelain.rb', line 12649

def pod
  @pod
end

#privilege_groupsObject

The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.



12651
12652
12653
# File 'lib/models/porcelain.rb', line 12651

def privilege_groups
  @privilege_groups
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



12653
12654
12655
# File 'lib/models/porcelain.rb', line 12653

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



12655
12656
12657
# File 'lib/models/porcelain.rb', line 12655

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



12657
12658
12659
# File 'lib/models/porcelain.rb', line 12657

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture, one of the CaptureType constants.



12659
12660
12661
# File 'lib/models/porcelain.rb', line 12659

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



12661
12662
12663
# File 'lib/models/porcelain.rb', line 12661

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12699
12700
12701
12702
12703
12704
12705
# File 'lib/models/porcelain.rb', line 12699

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end