Class: SDM::QueryCapture
- Inherits:
-
Object
- Object
- SDM::QueryCapture
- Defined in:
- lib/models/porcelain.rb
Overview
A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.
Instance Attribute Summary collapse
-
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
-
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
-
#container ⇒ Object
The target container of a Kubernetes operation.
-
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
-
#file_name ⇒ Object
The remote file name of an SCP operation.
-
#file_size ⇒ Object
The file size transferred for an SCP operation.
-
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
-
#impersonation_groups ⇒ Object
The impersonation groups of a Kubernetes operation.
-
#impersonation_user ⇒ Object
The impersonation user of a Kubernetes operation.
-
#pod ⇒ Object
The target pod of a Kubernetes operation.
-
#privilege_groups ⇒ Object
The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.
-
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
-
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
-
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
-
#type ⇒ Object
The CaptureType of this query capture, one of the CaptureType constants.
-
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
Instance Method Summary collapse
-
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
constructor
A new instance of QueryCapture.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
Returns a new instance of QueryCapture.
11391 11392 11393 11394 11395 11396 11397 11398 11399 11400 11401 11402 11403 11404 11405 11406 11407 11408 11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 |
# File 'lib/models/porcelain.rb', line 11391 def initialize( client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil ) @client_command = client_command == nil ? "" : client_command @command = command == nil ? "" : command @container = container == nil ? "" : container @env = env == nil ? {} : env @file_name = file_name == nil ? "" : file_name @file_size = file_size == nil ? 0 : file_size @height = height == nil ? 0 : height @impersonation_groups = impersonation_groups == nil ? [] : impersonation_groups @impersonation_user = impersonation_user == nil ? "" : impersonation_user @pod = pod == nil ? "" : pod @privilege_groups = privilege_groups == nil ? [] : privilege_groups @request_body = request_body == nil ? "" : request_body @request_method = request_method == nil ? "" : request_method @request_uri = request_uri == nil ? "" : request_uri @type = type == nil ? "" : type @width = width == nil ? 0 : width end |
Instance Attribute Details
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
11359 11360 11361 |
# File 'lib/models/porcelain.rb', line 11359 def client_command @client_command end |
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
11361 11362 11363 |
# File 'lib/models/porcelain.rb', line 11361 def command @command end |
#container ⇒ Object
The target container of a Kubernetes operation.
11363 11364 11365 |
# File 'lib/models/porcelain.rb', line 11363 def container @container end |
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
11365 11366 11367 |
# File 'lib/models/porcelain.rb', line 11365 def env @env end |
#file_name ⇒ Object
The remote file name of an SCP operation.
11367 11368 11369 |
# File 'lib/models/porcelain.rb', line 11367 def file_name @file_name end |
#file_size ⇒ Object
The file size transferred for an SCP operation.
11369 11370 11371 |
# File 'lib/models/porcelain.rb', line 11369 def file_size @file_size end |
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
11371 11372 11373 |
# File 'lib/models/porcelain.rb', line 11371 def height @height end |
#impersonation_groups ⇒ Object
The impersonation groups of a Kubernetes operation.
11373 11374 11375 |
# File 'lib/models/porcelain.rb', line 11373 def impersonation_groups @impersonation_groups end |
#impersonation_user ⇒ Object
The impersonation user of a Kubernetes operation.
11375 11376 11377 |
# File 'lib/models/porcelain.rb', line 11375 def impersonation_user @impersonation_user end |
#pod ⇒ Object
The target pod of a Kubernetes operation.
11377 11378 11379 |
# File 'lib/models/porcelain.rb', line 11377 def pod @pod end |
#privilege_groups ⇒ Object
The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.
11379 11380 11381 |
# File 'lib/models/porcelain.rb', line 11379 def privilege_groups @privilege_groups end |
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
11381 11382 11383 |
# File 'lib/models/porcelain.rb', line 11381 def request_body @request_body end |
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
11383 11384 11385 |
# File 'lib/models/porcelain.rb', line 11383 def request_method @request_method end |
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
11385 11386 11387 |
# File 'lib/models/porcelain.rb', line 11385 def request_uri @request_uri end |
#type ⇒ Object
The CaptureType of this query capture, one of the CaptureType constants.
11387 11388 11389 |
# File 'lib/models/porcelain.rb', line 11387 def type @type end |
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
11389 11390 11391 |
# File 'lib/models/porcelain.rb', line 11389 def width @width end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11427 11428 11429 11430 11431 11432 11433 |
# File 'lib/models/porcelain.rb', line 11427 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |