Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
# File 'lib/models/porcelain.rb', line 11376

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  impersonation_groups: nil,
  impersonation_user: nil,
  pod: nil,
  privilege_groups: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @impersonation_groups = impersonation_groups == nil ? [] : impersonation_groups
  @impersonation_user = impersonation_user == nil ? "" : impersonation_user
  @pod = pod == nil ? "" : pod
  @privilege_groups = privilege_groups == nil ? [] : privilege_groups
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



11344
11345
11346
# File 'lib/models/porcelain.rb', line 11344

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



11346
11347
11348
# File 'lib/models/porcelain.rb', line 11346

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



11348
11349
11350
# File 'lib/models/porcelain.rb', line 11348

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



11350
11351
11352
# File 'lib/models/porcelain.rb', line 11350

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



11352
11353
11354
# File 'lib/models/porcelain.rb', line 11352

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



11354
11355
11356
# File 'lib/models/porcelain.rb', line 11354

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



11356
11357
11358
# File 'lib/models/porcelain.rb', line 11356

def height
  @height
end

#impersonation_groupsObject

The impersonation groups of a Kubernetes operation.



11358
11359
11360
# File 'lib/models/porcelain.rb', line 11358

def impersonation_groups
  @impersonation_groups
end

#impersonation_userObject

The impersonation user of a Kubernetes operation.



11360
11361
11362
# File 'lib/models/porcelain.rb', line 11360

def impersonation_user
  @impersonation_user
end

#podObject

The target pod of a Kubernetes operation.



11362
11363
11364
# File 'lib/models/porcelain.rb', line 11362

def pod
  @pod
end

#privilege_groupsObject

The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.



11364
11365
11366
# File 'lib/models/porcelain.rb', line 11364

def privilege_groups
  @privilege_groups
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



11366
11367
11368
# File 'lib/models/porcelain.rb', line 11366

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



11368
11369
11370
# File 'lib/models/porcelain.rb', line 11368

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



11370
11371
11372
# File 'lib/models/porcelain.rb', line 11370

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture, one of the CaptureType constants.



11372
11373
11374
# File 'lib/models/porcelain.rb', line 11372

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



11374
11375
11376
# File 'lib/models/porcelain.rb', line 11374

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11412
11413
11414
11415
11416
11417
11418
# File 'lib/models/porcelain.rb', line 11412

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end