Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



10985
10986
10987
10988
10989
10990
10991
10992
10993
10994
10995
10996
10997
10998
10999
11000
11001
11002
11003
11004
11005
11006
11007
11008
11009
11010
11011
11012
11013
11014
11015
11016
11017
11018
11019
# File 'lib/models/porcelain.rb', line 10985

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  impersonation_groups: nil,
  impersonation_user: nil,
  pod: nil,
  privilege_groups: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @impersonation_groups = impersonation_groups == nil ? [] : impersonation_groups
  @impersonation_user = impersonation_user == nil ? "" : impersonation_user
  @pod = pod == nil ? "" : pod
  @privilege_groups = privilege_groups == nil ? [] : privilege_groups
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



10953
10954
10955
# File 'lib/models/porcelain.rb', line 10953

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



10955
10956
10957
# File 'lib/models/porcelain.rb', line 10955

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



10957
10958
10959
# File 'lib/models/porcelain.rb', line 10957

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



10959
10960
10961
# File 'lib/models/porcelain.rb', line 10959

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



10961
10962
10963
# File 'lib/models/porcelain.rb', line 10961

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



10963
10964
10965
# File 'lib/models/porcelain.rb', line 10963

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



10965
10966
10967
# File 'lib/models/porcelain.rb', line 10965

def height
  @height
end

#impersonation_groupsObject

The impersonation groups of a Kubernetes operation.



10967
10968
10969
# File 'lib/models/porcelain.rb', line 10967

def impersonation_groups
  @impersonation_groups
end

#impersonation_userObject

The impersonation user of a Kubernetes operation.



10969
10970
10971
# File 'lib/models/porcelain.rb', line 10969

def impersonation_user
  @impersonation_user
end

#podObject

The target pod of a Kubernetes operation.



10971
10972
10973
# File 'lib/models/porcelain.rb', line 10971

def pod
  @pod
end

#privilege_groupsObject

The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.



10973
10974
10975
# File 'lib/models/porcelain.rb', line 10973

def privilege_groups
  @privilege_groups
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



10975
10976
10977
# File 'lib/models/porcelain.rb', line 10975

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



10977
10978
10979
# File 'lib/models/porcelain.rb', line 10977

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



10979
10980
10981
# File 'lib/models/porcelain.rb', line 10979

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture, one of the CaptureType constants.



10981
10982
10983
# File 'lib/models/porcelain.rb', line 10981

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



10983
10984
10985
# File 'lib/models/porcelain.rb', line 10983

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11021
11022
11023
11024
11025
11026
11027
# File 'lib/models/porcelain.rb', line 11021

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end