Class: SDM::QueryCapture
- Inherits:
-
Object
- Object
- SDM::QueryCapture
- Defined in:
- lib/models/porcelain.rb
Overview
A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.
Instance Attribute Summary collapse
-
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
-
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
-
#container ⇒ Object
The target container of a Kubernetes operation.
-
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
-
#file_name ⇒ Object
The remote file name of an SCP operation.
-
#file_size ⇒ Object
The file size transferred for an SCP operation.
-
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
-
#impersonation_groups ⇒ Object
The impersonation groups of a Kubernetes operation.
-
#impersonation_user ⇒ Object
The impersonation user of a Kubernetes operation.
-
#pod ⇒ Object
The target pod of a Kubernetes operation.
-
#privilege_groups ⇒ Object
The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.
-
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
-
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
-
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
-
#type ⇒ Object
The CaptureType of this query capture, one of the CaptureType constants.
-
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
Instance Method Summary collapse
-
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
constructor
A new instance of QueryCapture.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
Returns a new instance of QueryCapture.
10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 10090 10091 10092 10093 |
# File 'lib/models/porcelain.rb', line 10059 def initialize( client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil ) @client_command = client_command == nil ? "" : client_command @command = command == nil ? "" : command @container = container == nil ? "" : container @env = env == nil ? {} : env @file_name = file_name == nil ? "" : file_name @file_size = file_size == nil ? 0 : file_size @height = height == nil ? 0 : height @impersonation_groups = impersonation_groups == nil ? [] : impersonation_groups @impersonation_user = impersonation_user == nil ? "" : impersonation_user @pod = pod == nil ? "" : pod @privilege_groups = privilege_groups == nil ? [] : privilege_groups @request_body = request_body == nil ? "" : request_body @request_method = request_method == nil ? "" : request_method @request_uri = request_uri == nil ? "" : request_uri @type = type == nil ? "" : type @width = width == nil ? 0 : width end |
Instance Attribute Details
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
10027 10028 10029 |
# File 'lib/models/porcelain.rb', line 10027 def client_command @client_command end |
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
10029 10030 10031 |
# File 'lib/models/porcelain.rb', line 10029 def command @command end |
#container ⇒ Object
The target container of a Kubernetes operation.
10031 10032 10033 |
# File 'lib/models/porcelain.rb', line 10031 def container @container end |
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
10033 10034 10035 |
# File 'lib/models/porcelain.rb', line 10033 def env @env end |
#file_name ⇒ Object
The remote file name of an SCP operation.
10035 10036 10037 |
# File 'lib/models/porcelain.rb', line 10035 def file_name @file_name end |
#file_size ⇒ Object
The file size transferred for an SCP operation.
10037 10038 10039 |
# File 'lib/models/porcelain.rb', line 10037 def file_size @file_size end |
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
10039 10040 10041 |
# File 'lib/models/porcelain.rb', line 10039 def height @height end |
#impersonation_groups ⇒ Object
The impersonation groups of a Kubernetes operation.
10041 10042 10043 |
# File 'lib/models/porcelain.rb', line 10041 def impersonation_groups @impersonation_groups end |
#impersonation_user ⇒ Object
The impersonation user of a Kubernetes operation.
10043 10044 10045 |
# File 'lib/models/porcelain.rb', line 10043 def impersonation_user @impersonation_user end |
#pod ⇒ Object
The target pod of a Kubernetes operation.
10045 10046 10047 |
# File 'lib/models/porcelain.rb', line 10045 def pod @pod end |
#privilege_groups ⇒ Object
The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.
10047 10048 10049 |
# File 'lib/models/porcelain.rb', line 10047 def privilege_groups @privilege_groups end |
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
10049 10050 10051 |
# File 'lib/models/porcelain.rb', line 10049 def request_body @request_body end |
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
10051 10052 10053 |
# File 'lib/models/porcelain.rb', line 10051 def request_method @request_method end |
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
10053 10054 10055 |
# File 'lib/models/porcelain.rb', line 10053 def request_uri @request_uri end |
#type ⇒ Object
The CaptureType of this query capture, one of the CaptureType constants.
10055 10056 10057 |
# File 'lib/models/porcelain.rb', line 10055 def type @type end |
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
10057 10058 10059 |
# File 'lib/models/porcelain.rb', line 10057 def width @width end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10095 10096 10097 10098 10099 10100 10101 |
# File 'lib/models/porcelain.rb', line 10095 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |