Class: SDM::QueryCapture
- Inherits:
-
Object
- Object
- SDM::QueryCapture
- Defined in:
- lib/models/porcelain.rb
Overview
A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.
Instance Attribute Summary collapse
-
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
-
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
-
#container ⇒ Object
The target container of a Kubernetes operation.
-
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
-
#file_name ⇒ Object
The remote file name of an SCP operation.
-
#file_size ⇒ Object
The file size transferred for an SCP operation.
-
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
-
#pod ⇒ Object
The target pod of a Kubernetes operation.
-
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
-
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
-
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
-
#type ⇒ Object
The CaptureType of this query capture, one of the CaptureType constants.
-
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
Instance Method Summary collapse
-
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
constructor
A new instance of QueryCapture.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
Returns a new instance of QueryCapture.
8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 8905 8906 8907 8908 8909 8910 8911 8912 8913 8914 8915 8916 8917 |
# File 'lib/models/porcelain.rb', line 8889 def initialize( client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil ) @client_command = client_command == nil ? "" : client_command @command = command == nil ? "" : command @container = container == nil ? "" : container @env = env == nil ? {} : env @file_name = file_name == nil ? "" : file_name @file_size = file_size == nil ? 0 : file_size @height = height == nil ? 0 : height @pod = pod == nil ? "" : pod @request_body = request_body == nil ? "" : request_body @request_method = request_method == nil ? "" : request_method @request_uri = request_uri == nil ? "" : request_uri @type = type == nil ? "" : type @width = width == nil ? 0 : width end |
Instance Attribute Details
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
8863 8864 8865 |
# File 'lib/models/porcelain.rb', line 8863 def client_command @client_command end |
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
8865 8866 8867 |
# File 'lib/models/porcelain.rb', line 8865 def command @command end |
#container ⇒ Object
The target container of a Kubernetes operation.
8867 8868 8869 |
# File 'lib/models/porcelain.rb', line 8867 def container @container end |
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
8869 8870 8871 |
# File 'lib/models/porcelain.rb', line 8869 def env @env end |
#file_name ⇒ Object
The remote file name of an SCP operation.
8871 8872 8873 |
# File 'lib/models/porcelain.rb', line 8871 def file_name @file_name end |
#file_size ⇒ Object
The file size transferred for an SCP operation.
8873 8874 8875 |
# File 'lib/models/porcelain.rb', line 8873 def file_size @file_size end |
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
8875 8876 8877 |
# File 'lib/models/porcelain.rb', line 8875 def height @height end |
#pod ⇒ Object
The target pod of a Kubernetes operation.
8877 8878 8879 |
# File 'lib/models/porcelain.rb', line 8877 def pod @pod end |
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
8879 8880 8881 |
# File 'lib/models/porcelain.rb', line 8879 def request_body @request_body end |
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
8881 8882 8883 |
# File 'lib/models/porcelain.rb', line 8881 def request_method @request_method end |
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
8883 8884 8885 |
# File 'lib/models/porcelain.rb', line 8883 def request_uri @request_uri end |
#type ⇒ Object
The CaptureType of this query capture, one of the CaptureType constants.
8885 8886 8887 |
# File 'lib/models/porcelain.rb', line 8885 def type @type end |
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
8887 8888 8889 |
# File 'lib/models/porcelain.rb', line 8887 def width @width end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8919 8920 8921 8922 8923 8924 8925 |
# File 'lib/models/porcelain.rb', line 8919 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |