Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



8716
8717
8718
8719
8720
8721
8722
8723
8724
8725
8726
8727
8728
8729
8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
# File 'lib/models/porcelain.rb', line 8716

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  pod: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @pod = pod == nil ? "" : pod
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



8690
8691
8692
# File 'lib/models/porcelain.rb', line 8690

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



8692
8693
8694
# File 'lib/models/porcelain.rb', line 8692

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



8694
8695
8696
# File 'lib/models/porcelain.rb', line 8694

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



8696
8697
8698
# File 'lib/models/porcelain.rb', line 8696

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



8698
8699
8700
# File 'lib/models/porcelain.rb', line 8698

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



8700
8701
8702
# File 'lib/models/porcelain.rb', line 8700

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



8702
8703
8704
# File 'lib/models/porcelain.rb', line 8702

def height
  @height
end

#podObject

The target pod of a Kubernetes operation.



8704
8705
8706
# File 'lib/models/porcelain.rb', line 8704

def pod
  @pod
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



8706
8707
8708
# File 'lib/models/porcelain.rb', line 8706

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



8708
8709
8710
# File 'lib/models/porcelain.rb', line 8708

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



8710
8711
8712
# File 'lib/models/porcelain.rb', line 8710

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture, one of the CaptureType constants.



8712
8713
8714
# File 'lib/models/porcelain.rb', line 8712

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



8714
8715
8716
# File 'lib/models/porcelain.rb', line 8714

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8746
8747
8748
8749
8750
8751
8752
# File 'lib/models/porcelain.rb', line 8746

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end