Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



7219
7220
7221
7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
7245
7246
7247
# File 'lib/models/porcelain.rb', line 7219

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  pod: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @pod = pod == nil ? "" : pod
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



7193
7194
7195
# File 'lib/models/porcelain.rb', line 7193

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



7195
7196
7197
# File 'lib/models/porcelain.rb', line 7195

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



7197
7198
7199
# File 'lib/models/porcelain.rb', line 7197

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



7199
7200
7201
# File 'lib/models/porcelain.rb', line 7199

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



7201
7202
7203
# File 'lib/models/porcelain.rb', line 7201

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



7203
7204
7205
# File 'lib/models/porcelain.rb', line 7203

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



7205
7206
7207
# File 'lib/models/porcelain.rb', line 7205

def height
  @height
end

#podObject

The target pod of a Kubernetes operation.



7207
7208
7209
# File 'lib/models/porcelain.rb', line 7207

def pod
  @pod
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



7209
7210
7211
# File 'lib/models/porcelain.rb', line 7209

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



7211
7212
7213
# File 'lib/models/porcelain.rb', line 7211

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



7213
7214
7215
# File 'lib/models/porcelain.rb', line 7213

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture.



7215
7216
7217
# File 'lib/models/porcelain.rb', line 7215

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



7217
7218
7219
# File 'lib/models/porcelain.rb', line 7217

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7249
7250
7251
7252
7253
7254
7255
# File 'lib/models/porcelain.rb', line 7249

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end