Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



6986
6987
6988
6989
6990
6991
6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
# File 'lib/models/porcelain.rb', line 6986

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  pod: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @pod = pod == nil ? "" : pod
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



6960
6961
6962
# File 'lib/models/porcelain.rb', line 6960

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



6962
6963
6964
# File 'lib/models/porcelain.rb', line 6962

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



6964
6965
6966
# File 'lib/models/porcelain.rb', line 6964

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



6966
6967
6968
# File 'lib/models/porcelain.rb', line 6966

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



6968
6969
6970
# File 'lib/models/porcelain.rb', line 6968

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



6970
6971
6972
# File 'lib/models/porcelain.rb', line 6970

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



6972
6973
6974
# File 'lib/models/porcelain.rb', line 6972

def height
  @height
end

#podObject

The target pod of a Kubernetes operation.



6974
6975
6976
# File 'lib/models/porcelain.rb', line 6974

def pod
  @pod
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



6976
6977
6978
# File 'lib/models/porcelain.rb', line 6976

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



6978
6979
6980
# File 'lib/models/porcelain.rb', line 6978

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



6980
6981
6982
# File 'lib/models/porcelain.rb', line 6980

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture.



6982
6983
6984
# File 'lib/models/porcelain.rb', line 6982

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



6984
6985
6986
# File 'lib/models/porcelain.rb', line 6984

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7016
7017
7018
7019
7020
7021
7022
# File 'lib/models/porcelain.rb', line 7016

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end