Class: SDM::QueryCapture
- Inherits:
-
Object
- Object
- SDM::QueryCapture
- Defined in:
- lib/models/porcelain.rb
Overview
A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.
Instance Attribute Summary collapse
-
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
-
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
-
#container ⇒ Object
The target container of a Kubernetes operation.
-
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
-
#file_name ⇒ Object
The remote file name of an SCP operation.
-
#file_size ⇒ Object
The file size transferred for an SCP operation.
-
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
-
#pod ⇒ Object
The target pod of a Kubernetes operation.
-
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
-
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
-
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
-
#type ⇒ Object
The CaptureType of this query capture.
-
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
Instance Method Summary collapse
-
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
constructor
A new instance of QueryCapture.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
Returns a new instance of QueryCapture.
6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 6973 6974 6975 |
# File 'lib/models/porcelain.rb', line 6947 def initialize( client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil ) @client_command = client_command == nil ? "" : client_command @command = command == nil ? "" : command @container = container == nil ? "" : container @env = env == nil ? {} : env @file_name = file_name == nil ? "" : file_name @file_size = file_size == nil ? 0 : file_size @height = height == nil ? 0 : height @pod = pod == nil ? "" : pod @request_body = request_body == nil ? "" : request_body @request_method = request_method == nil ? "" : request_method @request_uri = request_uri == nil ? "" : request_uri @type = type == nil ? "" : type @width = width == nil ? 0 : width end |
Instance Attribute Details
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
6921 6922 6923 |
# File 'lib/models/porcelain.rb', line 6921 def client_command @client_command end |
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
6923 6924 6925 |
# File 'lib/models/porcelain.rb', line 6923 def command @command end |
#container ⇒ Object
The target container of a Kubernetes operation.
6925 6926 6927 |
# File 'lib/models/porcelain.rb', line 6925 def container @container end |
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
6927 6928 6929 |
# File 'lib/models/porcelain.rb', line 6927 def env @env end |
#file_name ⇒ Object
The remote file name of an SCP operation.
6929 6930 6931 |
# File 'lib/models/porcelain.rb', line 6929 def file_name @file_name end |
#file_size ⇒ Object
The file size transferred for an SCP operation.
6931 6932 6933 |
# File 'lib/models/porcelain.rb', line 6931 def file_size @file_size end |
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
6933 6934 6935 |
# File 'lib/models/porcelain.rb', line 6933 def height @height end |
#pod ⇒ Object
The target pod of a Kubernetes operation.
6935 6936 6937 |
# File 'lib/models/porcelain.rb', line 6935 def pod @pod end |
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
6937 6938 6939 |
# File 'lib/models/porcelain.rb', line 6937 def request_body @request_body end |
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
6939 6940 6941 |
# File 'lib/models/porcelain.rb', line 6939 def request_method @request_method end |
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
6941 6942 6943 |
# File 'lib/models/porcelain.rb', line 6941 def request_uri @request_uri end |
#type ⇒ Object
The CaptureType of this query capture.
6943 6944 6945 |
# File 'lib/models/porcelain.rb', line 6943 def type @type end |
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
6945 6946 6947 |
# File 'lib/models/porcelain.rb', line 6945 def width @width end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6977 6978 6979 6980 6981 6982 6983 |
# File 'lib/models/porcelain.rb', line 6977 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |