Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



6783
6784
6785
6786
6787
6788
6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
6808
6809
6810
6811
# File 'lib/models/porcelain.rb', line 6783

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  pod: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @pod = pod == nil ? "" : pod
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



6757
6758
6759
# File 'lib/models/porcelain.rb', line 6757

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



6759
6760
6761
# File 'lib/models/porcelain.rb', line 6759

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



6761
6762
6763
# File 'lib/models/porcelain.rb', line 6761

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



6763
6764
6765
# File 'lib/models/porcelain.rb', line 6763

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



6765
6766
6767
# File 'lib/models/porcelain.rb', line 6765

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



6767
6768
6769
# File 'lib/models/porcelain.rb', line 6767

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



6769
6770
6771
# File 'lib/models/porcelain.rb', line 6769

def height
  @height
end

#podObject

The target pod of a Kubernetes operation.



6771
6772
6773
# File 'lib/models/porcelain.rb', line 6771

def pod
  @pod
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



6773
6774
6775
# File 'lib/models/porcelain.rb', line 6773

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



6775
6776
6777
# File 'lib/models/porcelain.rb', line 6775

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



6777
6778
6779
# File 'lib/models/porcelain.rb', line 6777

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture.



6779
6780
6781
# File 'lib/models/porcelain.rb', line 6779

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



6781
6782
6783
# File 'lib/models/porcelain.rb', line 6781

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6813
6814
6815
6816
6817
6818
6819
# File 'lib/models/porcelain.rb', line 6813

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end