Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, pod: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



6080
6081
6082
6083
6084
6085
6086
6087
6088
6089
6090
6091
6092
6093
6094
6095
6096
6097
6098
6099
6100
6101
6102
6103
6104
6105
6106
6107
6108
# File 'lib/models/porcelain.rb', line 6080

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  pod: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @pod = pod == nil ? "" : pod
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



6054
6055
6056
# File 'lib/models/porcelain.rb', line 6054

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



6056
6057
6058
# File 'lib/models/porcelain.rb', line 6056

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



6058
6059
6060
# File 'lib/models/porcelain.rb', line 6058

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



6060
6061
6062
# File 'lib/models/porcelain.rb', line 6060

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



6062
6063
6064
# File 'lib/models/porcelain.rb', line 6062

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



6064
6065
6066
# File 'lib/models/porcelain.rb', line 6064

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



6066
6067
6068
# File 'lib/models/porcelain.rb', line 6066

def height
  @height
end

#podObject

The target pod of a Kubernetes operation.



6068
6069
6070
# File 'lib/models/porcelain.rb', line 6068

def pod
  @pod
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



6070
6071
6072
# File 'lib/models/porcelain.rb', line 6070

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



6072
6073
6074
# File 'lib/models/porcelain.rb', line 6072

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



6074
6075
6076
# File 'lib/models/porcelain.rb', line 6074

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture.



6076
6077
6078
# File 'lib/models/porcelain.rb', line 6076

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



6078
6079
6080
# File 'lib/models/porcelain.rb', line 6078

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6110
6111
6112
6113
6114
6115
6116
# File 'lib/models/porcelain.rb', line 6110

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end