Class: SDM::QueryCapture
- Inherits:
-
Object
- Object
- SDM::QueryCapture
- Defined in:
- lib/models/porcelain.rb
Overview
A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.
Instance Attribute Summary collapse
-
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
-
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
-
#container ⇒ Object
The target container of a Kubernetes operation.
-
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
-
#file_name ⇒ Object
The remote file name of an SCP operation.
-
#file_size ⇒ Object
The file size transferred for an SCP operation.
-
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
-
#impersonation_groups ⇒ Object
The impersonation groups of a Kubernetes operation.
-
#impersonation_user ⇒ Object
The impersonation user of a Kubernetes operation.
-
#pod ⇒ Object
The target pod of a Kubernetes operation.
-
#privilege_groups ⇒ Object
The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.
-
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
-
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
-
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
-
#type ⇒ Object
The CaptureType of this query capture, one of the CaptureType constants.
-
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
Instance Method Summary collapse
-
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
constructor
A new instance of QueryCapture.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture
Returns a new instance of QueryCapture.
14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 14230 14231 14232 14233 14234 14235 14236 14237 14238 14239 14240 14241 14242 14243 14244 14245 14246 |
# File 'lib/models/porcelain.rb', line 14212 def initialize( client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil ) @client_command = client_command == nil ? "" : client_command @command = command == nil ? "" : command @container = container == nil ? "" : container @env = env == nil ? {} : env @file_name = file_name == nil ? "" : file_name @file_size = file_size == nil ? 0 : file_size @height = height == nil ? 0 : height @impersonation_groups = impersonation_groups == nil ? [] : impersonation_groups @impersonation_user = impersonation_user == nil ? "" : impersonation_user @pod = pod == nil ? "" : pod @privilege_groups = privilege_groups == nil ? [] : privilege_groups @request_body = request_body == nil ? "" : request_body @request_method = request_method == nil ? "" : request_method @request_uri = request_uri == nil ? "" : request_uri @type = type == nil ? "" : type @width = width == nil ? 0 : width end |
Instance Attribute Details
#client_command ⇒ Object
The command executed on the client for a Kubernetes session.
14180 14181 14182 |
# File 'lib/models/porcelain.rb', line 14180 def client_command @client_command end |
#command ⇒ Object
The command executed over an SSH or Kubernetes session.
14182 14183 14184 |
# File 'lib/models/porcelain.rb', line 14182 def command @command end |
#container ⇒ Object
The target container of a Kubernetes operation.
14184 14185 14186 |
# File 'lib/models/porcelain.rb', line 14184 def container @container end |
#env ⇒ Object
The environment variables for an SSH or Kubernetes session.
14186 14187 14188 |
# File 'lib/models/porcelain.rb', line 14186 def env @env end |
#file_name ⇒ Object
The remote file name of an SCP operation.
14188 14189 14190 |
# File 'lib/models/porcelain.rb', line 14188 def file_name @file_name end |
#file_size ⇒ Object
The file size transferred for an SCP operation.
14190 14191 14192 |
# File 'lib/models/porcelain.rb', line 14190 def file_size @file_size end |
#height ⇒ Object
The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
14192 14193 14194 |
# File 'lib/models/porcelain.rb', line 14192 def height @height end |
#impersonation_groups ⇒ Object
The impersonation groups of a Kubernetes operation.
14194 14195 14196 |
# File 'lib/models/porcelain.rb', line 14194 def impersonation_groups @impersonation_groups end |
#impersonation_user ⇒ Object
The impersonation user of a Kubernetes operation.
14196 14197 14198 |
# File 'lib/models/porcelain.rb', line 14196 def impersonation_user @impersonation_user end |
#pod ⇒ Object
The target pod of a Kubernetes operation.
14198 14199 14200 |
# File 'lib/models/porcelain.rb', line 14198 def pod @pod end |
#privilege_groups ⇒ Object
The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.
14200 14201 14202 |
# File 'lib/models/porcelain.rb', line 14200 def privilege_groups @privilege_groups end |
#request_body ⇒ Object
The HTTP request body of a Kubernetes operation.
14202 14203 14204 |
# File 'lib/models/porcelain.rb', line 14202 def request_body @request_body end |
#request_method ⇒ Object
The HTTP request method of a Kubernetes operation.
14204 14205 14206 |
# File 'lib/models/porcelain.rb', line 14204 def request_method @request_method end |
#request_uri ⇒ Object
The HTTP request URI of a Kubernetes operation.
14206 14207 14208 |
# File 'lib/models/porcelain.rb', line 14206 def request_uri @request_uri end |
#type ⇒ Object
The CaptureType of this query capture, one of the CaptureType constants.
14208 14209 14210 |
# File 'lib/models/porcelain.rb', line 14208 def type @type end |
#width ⇒ Object
The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.
14210 14211 14212 |
# File 'lib/models/porcelain.rb', line 14210 def width @width end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14248 14249 14250 14251 14252 14253 14254 |
# File 'lib/models/porcelain.rb', line 14248 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |