Class: SDM::QueryCapture

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A QueryCapture contains additional information about queries against SSH, Kubernetes, and RDP resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client_command: nil, command: nil, container: nil, env: nil, file_name: nil, file_size: nil, height: nil, impersonation_groups: nil, impersonation_user: nil, pod: nil, privilege_groups: nil, request_body: nil, request_method: nil, request_uri: nil, type: nil, width: nil) ⇒ QueryCapture

Returns a new instance of QueryCapture.



14064
14065
14066
14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
14079
14080
14081
14082
14083
14084
14085
14086
14087
14088
14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
# File 'lib/models/porcelain.rb', line 14064

def initialize(
  client_command: nil,
  command: nil,
  container: nil,
  env: nil,
  file_name: nil,
  file_size: nil,
  height: nil,
  impersonation_groups: nil,
  impersonation_user: nil,
  pod: nil,
  privilege_groups: nil,
  request_body: nil,
  request_method: nil,
  request_uri: nil,
  type: nil,
  width: nil
)
  @client_command = client_command == nil ? "" : client_command
  @command = command == nil ? "" : command
  @container = container == nil ? "" : container
  @env = env == nil ? {} : env
  @file_name = file_name == nil ? "" : file_name
  @file_size = file_size == nil ? 0 : file_size
  @height = height == nil ? 0 : height
  @impersonation_groups = impersonation_groups == nil ? [] : impersonation_groups
  @impersonation_user = impersonation_user == nil ? "" : impersonation_user
  @pod = pod == nil ? "" : pod
  @privilege_groups = privilege_groups == nil ? [] : privilege_groups
  @request_body = request_body == nil ? "" : request_body
  @request_method = request_method == nil ? "" : request_method
  @request_uri = request_uri == nil ? "" : request_uri
  @type = type == nil ? "" : type
  @width = width == nil ? 0 : width
end

Instance Attribute Details

#client_commandObject

The command executed on the client for a Kubernetes session.



14032
14033
14034
# File 'lib/models/porcelain.rb', line 14032

def client_command
  @client_command
end

#commandObject

The command executed over an SSH or Kubernetes session.



14034
14035
14036
# File 'lib/models/porcelain.rb', line 14034

def command
  @command
end

#containerObject

The target container of a Kubernetes operation.



14036
14037
14038
# File 'lib/models/porcelain.rb', line 14036

def container
  @container
end

#envObject

The environment variables for an SSH or Kubernetes session.



14038
14039
14040
# File 'lib/models/porcelain.rb', line 14038

def env
  @env
end

#file_nameObject

The remote file name of an SCP operation.



14040
14041
14042
# File 'lib/models/porcelain.rb', line 14040

def file_name
  @file_name
end

#file_sizeObject

The file size transferred for an SCP operation.



14042
14043
14044
# File 'lib/models/porcelain.rb', line 14042

def file_size
  @file_size
end

#heightObject

The height of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



14044
14045
14046
# File 'lib/models/porcelain.rb', line 14044

def height
  @height
end

#impersonation_groupsObject

The impersonation groups of a Kubernetes operation.



14046
14047
14048
# File 'lib/models/porcelain.rb', line 14046

def impersonation_groups
  @impersonation_groups
end

#impersonation_userObject

The impersonation user of a Kubernetes operation.



14048
14049
14050
# File 'lib/models/porcelain.rb', line 14048

def impersonation_user
  @impersonation_user
end

#podObject

The target pod of a Kubernetes operation.



14050
14051
14052
# File 'lib/models/porcelain.rb', line 14050

def pod
  @pod
end

#privilege_groupsObject

The additional impersonation groups, as granted by privilege levels, of a Kubernetes operation.



14052
14053
14054
# File 'lib/models/porcelain.rb', line 14052

def privilege_groups
  @privilege_groups
end

#request_bodyObject

The HTTP request body of a Kubernetes operation.



14054
14055
14056
# File 'lib/models/porcelain.rb', line 14054

def request_body
  @request_body
end

#request_methodObject

The HTTP request method of a Kubernetes operation.



14056
14057
14058
# File 'lib/models/porcelain.rb', line 14056

def request_method
  @request_method
end

#request_uriObject

The HTTP request URI of a Kubernetes operation.



14058
14059
14060
# File 'lib/models/porcelain.rb', line 14058

def request_uri
  @request_uri
end

#typeObject

The CaptureType of this query capture, one of the CaptureType constants.



14060
14061
14062
# File 'lib/models/porcelain.rb', line 14060

def type
  @type
end

#widthObject

The width of the terminal or window for SSH, Kubernetes, and RDP interactive sessions.



14062
14063
14064
# File 'lib/models/porcelain.rb', line 14062

def width
  @width
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14100
14101
14102
14103
14104
14105
14106
# File 'lib/models/porcelain.rb', line 14100

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end