Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



14669
14670
14671
14672
14673
14674
14675
14676
14677
14678
14679
14680
14681
14682
14683
14684
14685
14686
14687
14688
14689
14690
14691
14692
14693
14694
14695
14696
14697
14698
14699
14700
14701
14702
14703
14704
14705
14706
14707
# File 'lib/models/porcelain.rb', line 14669

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14633
14634
14635
# File 'lib/models/porcelain.rb', line 14633

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



14635
14636
14637
# File 'lib/models/porcelain.rb', line 14635

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14637
14638
14639
# File 'lib/models/porcelain.rb', line 14637

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14639
14640
14641
# File 'lib/models/porcelain.rb', line 14639

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14641
14642
14643
# File 'lib/models/porcelain.rb', line 14641

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14643
14644
14645
# File 'lib/models/porcelain.rb', line 14643

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



14645
14646
14647
# File 'lib/models/porcelain.rb', line 14645

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

if provided use identity_set to map username to secret store path



14647
14648
14649
# File 'lib/models/porcelain.rb', line 14647

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



14649
14650
14651
# File 'lib/models/porcelain.rb', line 14649

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



14651
14652
14653
# File 'lib/models/porcelain.rb', line 14651

def name
  @name
end

#passwordObject

The password to authenticate with.



14653
14654
14655
# File 'lib/models/porcelain.rb', line 14653

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14655
14656
14657
# File 'lib/models/porcelain.rb', line 14655

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14657
14658
14659
# File 'lib/models/porcelain.rb', line 14657

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14659
14660
14661
# File 'lib/models/porcelain.rb', line 14659

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14661
14662
14663
# File 'lib/models/porcelain.rb', line 14661

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14663
14664
14665
# File 'lib/models/porcelain.rb', line 14663

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14665
14666
14667
# File 'lib/models/porcelain.rb', line 14665

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14667
14668
14669
# File 'lib/models/porcelain.rb', line 14667

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14709
14710
14711
14712
14713
14714
14715
# File 'lib/models/porcelain.rb', line 14709

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end