Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



14315
14316
14317
14318
14319
14320
14321
14322
14323
14324
14325
14326
14327
14328
14329
14330
14331
14332
14333
14334
14335
14336
14337
14338
14339
14340
14341
14342
14343
14344
14345
14346
14347
14348
14349
14350
14351
14352
14353
# File 'lib/models/porcelain.rb', line 14315

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14279
14280
14281
# File 'lib/models/porcelain.rb', line 14279

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



14281
14282
14283
# File 'lib/models/porcelain.rb', line 14281

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14283
14284
14285
# File 'lib/models/porcelain.rb', line 14283

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14285
14286
14287
# File 'lib/models/porcelain.rb', line 14285

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14287
14288
14289
# File 'lib/models/porcelain.rb', line 14287

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14289
14290
14291
# File 'lib/models/porcelain.rb', line 14289

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



14291
14292
14293
# File 'lib/models/porcelain.rb', line 14291

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

if provided use identity_set to map username to secret store path



14293
14294
14295
# File 'lib/models/porcelain.rb', line 14293

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



14295
14296
14297
# File 'lib/models/porcelain.rb', line 14295

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



14297
14298
14299
# File 'lib/models/porcelain.rb', line 14297

def name
  @name
end

#passwordObject

The password to authenticate with.



14299
14300
14301
# File 'lib/models/porcelain.rb', line 14299

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14301
14302
14303
# File 'lib/models/porcelain.rb', line 14301

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14303
14304
14305
# File 'lib/models/porcelain.rb', line 14303

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14305
14306
14307
# File 'lib/models/porcelain.rb', line 14305

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14307
14308
14309
# File 'lib/models/porcelain.rb', line 14307

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14309
14310
14311
# File 'lib/models/porcelain.rb', line 14309

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14311
14312
14313
# File 'lib/models/porcelain.rb', line 14311

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14313
14314
14315
# File 'lib/models/porcelain.rb', line 14313

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14355
14356
14357
14358
14359
14360
14361
# File 'lib/models/porcelain.rb', line 14355

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end