Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



13922
13923
13924
13925
13926
13927
13928
13929
13930
13931
13932
13933
13934
13935
13936
13937
13938
13939
13940
13941
13942
13943
13944
13945
13946
13947
13948
13949
13950
13951
13952
13953
13954
13955
13956
13957
13958
13959
13960
# File 'lib/models/porcelain.rb', line 13922

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13886
13887
13888
# File 'lib/models/porcelain.rb', line 13886

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



13888
13889
13890
# File 'lib/models/porcelain.rb', line 13888

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13890
13891
13892
# File 'lib/models/porcelain.rb', line 13890

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13892
13893
13894
# File 'lib/models/porcelain.rb', line 13892

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13894
13895
13896
# File 'lib/models/porcelain.rb', line 13894

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13896
13897
13898
# File 'lib/models/porcelain.rb', line 13896

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13898
13899
13900
# File 'lib/models/porcelain.rb', line 13898

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

if provided use identity_set to map username to secret store path



13900
13901
13902
# File 'lib/models/porcelain.rb', line 13900

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



13902
13903
13904
# File 'lib/models/porcelain.rb', line 13902

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



13904
13905
13906
# File 'lib/models/porcelain.rb', line 13904

def name
  @name
end

#passwordObject

The password to authenticate with.



13906
13907
13908
# File 'lib/models/porcelain.rb', line 13906

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13908
13909
13910
# File 'lib/models/porcelain.rb', line 13908

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13910
13911
13912
# File 'lib/models/porcelain.rb', line 13910

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13912
13913
13914
# File 'lib/models/porcelain.rb', line 13912

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13914
13915
13916
# File 'lib/models/porcelain.rb', line 13914

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13916
13917
13918
# File 'lib/models/porcelain.rb', line 13916

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13918
13919
13920
# File 'lib/models/porcelain.rb', line 13918

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13920
13921
13922
# File 'lib/models/porcelain.rb', line 13920

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13962
13963
13964
13965
13966
13967
13968
# File 'lib/models/porcelain.rb', line 13962

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end