Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



13556
13557
13558
13559
13560
13561
13562
13563
13564
13565
13566
13567
13568
13569
13570
13571
13572
13573
13574
13575
13576
13577
13578
13579
13580
13581
13582
13583
13584
13585
13586
13587
13588
13589
13590
13591
13592
13593
13594
# File 'lib/models/porcelain.rb', line 13556

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13520
13521
13522
# File 'lib/models/porcelain.rb', line 13520

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



13522
13523
13524
# File 'lib/models/porcelain.rb', line 13522

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13524
13525
13526
# File 'lib/models/porcelain.rb', line 13524

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13526
13527
13528
# File 'lib/models/porcelain.rb', line 13526

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13528
13529
13530
# File 'lib/models/porcelain.rb', line 13528

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13530
13531
13532
# File 'lib/models/porcelain.rb', line 13530

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13532
13533
13534
# File 'lib/models/porcelain.rb', line 13532

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

if provided use identity_set to map username to secret store path



13534
13535
13536
# File 'lib/models/porcelain.rb', line 13534

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



13536
13537
13538
# File 'lib/models/porcelain.rb', line 13536

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



13538
13539
13540
# File 'lib/models/porcelain.rb', line 13538

def name
  @name
end

#passwordObject

The password to authenticate with.



13540
13541
13542
# File 'lib/models/porcelain.rb', line 13540

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13542
13543
13544
# File 'lib/models/porcelain.rb', line 13542

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13544
13545
13546
# File 'lib/models/porcelain.rb', line 13544

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13546
13547
13548
# File 'lib/models/porcelain.rb', line 13546

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13548
13549
13550
# File 'lib/models/porcelain.rb', line 13548

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13550
13551
13552
# File 'lib/models/porcelain.rb', line 13550

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13552
13553
13554
# File 'lib/models/porcelain.rb', line 13552

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13554
13555
13556
# File 'lib/models/porcelain.rb', line 13554

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13596
13597
13598
13599
13600
13601
13602
# File 'lib/models/porcelain.rb', line 13596

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end