Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



11725
11726
11727
11728
11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
11752
11753
11754
11755
11756
11757
11758
11759
# File 'lib/models/porcelain.rb', line 11725

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11693
11694
11695
# File 'lib/models/porcelain.rb', line 11693

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



11695
11696
11697
# File 'lib/models/porcelain.rb', line 11695

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11697
11698
11699
# File 'lib/models/porcelain.rb', line 11697

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11699
11700
11701
# File 'lib/models/porcelain.rb', line 11699

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11701
11702
11703
# File 'lib/models/porcelain.rb', line 11701

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11703
11704
11705
# File 'lib/models/porcelain.rb', line 11703

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



11705
11706
11707
# File 'lib/models/porcelain.rb', line 11705

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



11707
11708
11709
# File 'lib/models/porcelain.rb', line 11707

def name
  @name
end

#passwordObject

The password to authenticate with.



11709
11710
11711
# File 'lib/models/porcelain.rb', line 11709

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11711
11712
11713
# File 'lib/models/porcelain.rb', line 11711

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11713
11714
11715
# File 'lib/models/porcelain.rb', line 11713

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11715
11716
11717
# File 'lib/models/porcelain.rb', line 11715

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11717
11718
11719
# File 'lib/models/porcelain.rb', line 11717

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11719
11720
11721
# File 'lib/models/porcelain.rb', line 11719

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11721
11722
11723
# File 'lib/models/porcelain.rb', line 11721

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11723
11724
11725
# File 'lib/models/porcelain.rb', line 11723

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11761
11762
11763
11764
11765
11766
11767
# File 'lib/models/porcelain.rb', line 11761

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end