Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



11455
11456
11457
11458
11459
11460
11461
11462
11463
11464
11465
11466
11467
11468
11469
11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
# File 'lib/models/porcelain.rb', line 11455

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11423
11424
11425
# File 'lib/models/porcelain.rb', line 11423

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



11425
11426
11427
# File 'lib/models/porcelain.rb', line 11425

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11427
11428
11429
# File 'lib/models/porcelain.rb', line 11427

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11429
11430
11431
# File 'lib/models/porcelain.rb', line 11429

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11431
11432
11433
# File 'lib/models/porcelain.rb', line 11431

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11433
11434
11435
# File 'lib/models/porcelain.rb', line 11433

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



11435
11436
11437
# File 'lib/models/porcelain.rb', line 11435

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



11437
11438
11439
# File 'lib/models/porcelain.rb', line 11437

def name
  @name
end

#passwordObject

The password to authenticate with.



11439
11440
11441
# File 'lib/models/porcelain.rb', line 11439

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11441
11442
11443
# File 'lib/models/porcelain.rb', line 11441

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11443
11444
11445
# File 'lib/models/porcelain.rb', line 11443

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11445
11446
11447
# File 'lib/models/porcelain.rb', line 11445

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11447
11448
11449
# File 'lib/models/porcelain.rb', line 11447

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11449
11450
11451
# File 'lib/models/porcelain.rb', line 11449

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11451
11452
11453
# File 'lib/models/porcelain.rb', line 11451

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11453
11454
11455
# File 'lib/models/porcelain.rb', line 11453

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11491
11492
11493
11494
11495
11496
11497
# File 'lib/models/porcelain.rb', line 11491

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end