Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



11208
11209
11210
11211
11212
11213
11214
11215
11216
11217
11218
11219
11220
11221
11222
11223
11224
11225
11226
11227
11228
11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
11241
11242
# File 'lib/models/porcelain.rb', line 11208

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11176
11177
11178
# File 'lib/models/porcelain.rb', line 11176

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



11178
11179
11180
# File 'lib/models/porcelain.rb', line 11178

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11180
11181
11182
# File 'lib/models/porcelain.rb', line 11180

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11182
11183
11184
# File 'lib/models/porcelain.rb', line 11182

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11184
11185
11186
# File 'lib/models/porcelain.rb', line 11184

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11186
11187
11188
# File 'lib/models/porcelain.rb', line 11186

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



11188
11189
11190
# File 'lib/models/porcelain.rb', line 11188

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



11190
11191
11192
# File 'lib/models/porcelain.rb', line 11190

def name
  @name
end

#passwordObject

The password to authenticate with.



11192
11193
11194
# File 'lib/models/porcelain.rb', line 11192

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11194
11195
11196
# File 'lib/models/porcelain.rb', line 11194

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11196
11197
11198
# File 'lib/models/porcelain.rb', line 11196

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11198
11199
11200
# File 'lib/models/porcelain.rb', line 11198

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11200
11201
11202
# File 'lib/models/porcelain.rb', line 11200

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11202
11203
11204
# File 'lib/models/porcelain.rb', line 11202

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11204
11205
11206
# File 'lib/models/porcelain.rb', line 11204

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11206
11207
11208
# File 'lib/models/porcelain.rb', line 11206

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11244
11245
11246
11247
11248
11249
11250
# File 'lib/models/porcelain.rb', line 11244

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end