Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



10214
10215
10216
10217
10218
10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
10241
10242
10243
10244
10245
10246
10247
10248
# File 'lib/models/porcelain.rb', line 10214

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10182
10183
10184
# File 'lib/models/porcelain.rb', line 10182

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



10184
10185
10186
# File 'lib/models/porcelain.rb', line 10184

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10186
10187
10188
# File 'lib/models/porcelain.rb', line 10186

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10188
10189
10190
# File 'lib/models/porcelain.rb', line 10188

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10190
10191
10192
# File 'lib/models/porcelain.rb', line 10190

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10192
10193
10194
# File 'lib/models/porcelain.rb', line 10192

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



10194
10195
10196
# File 'lib/models/porcelain.rb', line 10194

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



10196
10197
10198
# File 'lib/models/porcelain.rb', line 10196

def name
  @name
end

#passwordObject

The password to authenticate with.



10198
10199
10200
# File 'lib/models/porcelain.rb', line 10198

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10200
10201
10202
# File 'lib/models/porcelain.rb', line 10200

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10202
10203
10204
# File 'lib/models/porcelain.rb', line 10202

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10204
10205
10206
# File 'lib/models/porcelain.rb', line 10204

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10206
10207
10208
# File 'lib/models/porcelain.rb', line 10206

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10208
10209
10210
# File 'lib/models/porcelain.rb', line 10208

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10210
10211
10212
# File 'lib/models/porcelain.rb', line 10210

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10212
10213
10214
# File 'lib/models/porcelain.rb', line 10212

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10250
10251
10252
10253
10254
10255
10256
# File 'lib/models/porcelain.rb', line 10250

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end