Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



9918
9919
9920
9921
9922
9923
9924
9925
9926
9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
9944
9945
9946
9947
9948
9949
9950
9951
9952
# File 'lib/models/porcelain.rb', line 9918

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9886
9887
9888
# File 'lib/models/porcelain.rb', line 9886

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



9888
9889
9890
# File 'lib/models/porcelain.rb', line 9888

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9890
9891
9892
# File 'lib/models/porcelain.rb', line 9890

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9892
9893
9894
# File 'lib/models/porcelain.rb', line 9892

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9894
9895
9896
# File 'lib/models/porcelain.rb', line 9894

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9896
9897
9898
# File 'lib/models/porcelain.rb', line 9896

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



9898
9899
9900
# File 'lib/models/porcelain.rb', line 9898

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



9900
9901
9902
# File 'lib/models/porcelain.rb', line 9900

def name
  @name
end

#passwordObject

The password to authenticate with.



9902
9903
9904
# File 'lib/models/porcelain.rb', line 9902

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9904
9905
9906
# File 'lib/models/porcelain.rb', line 9904

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9906
9907
9908
# File 'lib/models/porcelain.rb', line 9906

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9908
9909
9910
# File 'lib/models/porcelain.rb', line 9908

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9910
9911
9912
# File 'lib/models/porcelain.rb', line 9910

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9912
9913
9914
# File 'lib/models/porcelain.rb', line 9912

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9914
9915
9916
# File 'lib/models/porcelain.rb', line 9914

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9916
9917
9918
# File 'lib/models/porcelain.rb', line 9916

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9954
9955
9956
9957
9958
9959
9960
# File 'lib/models/porcelain.rb', line 9954

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end