Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



9623
9624
9625
9626
9627
9628
9629
9630
9631
9632
9633
9634
9635
9636
9637
9638
9639
9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
# File 'lib/models/porcelain.rb', line 9623

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9591
9592
9593
# File 'lib/models/porcelain.rb', line 9591

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



9593
9594
9595
# File 'lib/models/porcelain.rb', line 9593

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9595
9596
9597
# File 'lib/models/porcelain.rb', line 9595

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9597
9598
9599
# File 'lib/models/porcelain.rb', line 9597

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9599
9600
9601
# File 'lib/models/porcelain.rb', line 9599

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9601
9602
9603
# File 'lib/models/porcelain.rb', line 9601

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



9603
9604
9605
# File 'lib/models/porcelain.rb', line 9603

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



9605
9606
9607
# File 'lib/models/porcelain.rb', line 9605

def name
  @name
end

#passwordObject

The password to authenticate with.



9607
9608
9609
# File 'lib/models/porcelain.rb', line 9607

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9609
9610
9611
# File 'lib/models/porcelain.rb', line 9609

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9611
9612
9613
# File 'lib/models/porcelain.rb', line 9611

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9613
9614
9615
# File 'lib/models/porcelain.rb', line 9613

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9615
9616
9617
# File 'lib/models/porcelain.rb', line 9615

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9617
9618
9619
# File 'lib/models/porcelain.rb', line 9617

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9619
9620
9621
# File 'lib/models/porcelain.rb', line 9619

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9621
9622
9623
# File 'lib/models/porcelain.rb', line 9621

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9659
9660
9661
9662
9663
9664
9665
# File 'lib/models/porcelain.rb', line 9659

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end