Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
9374 9375 9376 9377 9378 9379 9380 9381 9382 9383 9384 9385 9386 9387 9388 9389 9390 9391 9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 |
# File 'lib/models/porcelain.rb', line 9374 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @lock_required = lock_required == nil ? false : lock_required @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9342 9343 9344 |
# File 'lib/models/porcelain.rb', line 9342 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.
9344 9345 9346 |
# File 'lib/models/porcelain.rb', line 9344 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9346 9347 9348 |
# File 'lib/models/porcelain.rb', line 9346 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9348 9349 9350 |
# File 'lib/models/porcelain.rb', line 9348 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9350 9351 9352 |
# File 'lib/models/porcelain.rb', line 9350 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9352 9353 9354 |
# File 'lib/models/porcelain.rb', line 9352 def id @id end |
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
9354 9355 9356 |
# File 'lib/models/porcelain.rb', line 9354 def lock_required @lock_required end |
#name ⇒ Object
Unique human-readable name of the Resource.
9356 9357 9358 |
# File 'lib/models/porcelain.rb', line 9356 def name @name end |
#password ⇒ Object
The password to authenticate with.
9358 9359 9360 |
# File 'lib/models/porcelain.rb', line 9358 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9360 9361 9362 |
# File 'lib/models/porcelain.rb', line 9360 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9362 9363 9364 |
# File 'lib/models/porcelain.rb', line 9362 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9364 9365 9366 |
# File 'lib/models/porcelain.rb', line 9364 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9366 9367 9368 |
# File 'lib/models/porcelain.rb', line 9366 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9368 9369 9370 |
# File 'lib/models/porcelain.rb', line 9368 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9370 9371 9372 |
# File 'lib/models/porcelain.rb', line 9370 def @tags end |
#username ⇒ Object
The username to authenticate with.
9372 9373 9374 |
# File 'lib/models/porcelain.rb', line 9372 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9410 9411 9412 9413 9414 9415 9416 |
# File 'lib/models/porcelain.rb', line 9410 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |