Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
8960 8961 8962 8963 8964 8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 |
# File 'lib/models/porcelain.rb', line 8960 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @lock_required = lock_required == nil ? false : lock_required @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8930 8931 8932 |
# File 'lib/models/porcelain.rb', line 8930 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.
8932 8933 8934 |
# File 'lib/models/porcelain.rb', line 8932 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8934 8935 8936 |
# File 'lib/models/porcelain.rb', line 8934 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8936 8937 8938 |
# File 'lib/models/porcelain.rb', line 8936 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8938 8939 8940 |
# File 'lib/models/porcelain.rb', line 8938 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8940 8941 8942 |
# File 'lib/models/porcelain.rb', line 8940 def id @id end |
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
8942 8943 8944 |
# File 'lib/models/porcelain.rb', line 8942 def lock_required @lock_required end |
#name ⇒ Object
Unique human-readable name of the Resource.
8944 8945 8946 |
# File 'lib/models/porcelain.rb', line 8944 def name @name end |
#password ⇒ Object
The password to authenticate with.
8946 8947 8948 |
# File 'lib/models/porcelain.rb', line 8946 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8948 8949 8950 |
# File 'lib/models/porcelain.rb', line 8948 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8950 8951 8952 |
# File 'lib/models/porcelain.rb', line 8950 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8952 8953 8954 |
# File 'lib/models/porcelain.rb', line 8952 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8954 8955 8956 |
# File 'lib/models/porcelain.rb', line 8954 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8956 8957 8958 |
# File 'lib/models/porcelain.rb', line 8956 def @tags end |
#username ⇒ Object
The username to authenticate with.
8958 8959 8960 |
# File 'lib/models/porcelain.rb', line 8958 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8994 8995 8996 8997 8998 8999 9000 |
# File 'lib/models/porcelain.rb', line 8994 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |