Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 8816 8817 8818 8819 |
# File 'lib/models/porcelain.rb', line 8787 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @lock_required = lock_required == nil ? false : lock_required @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8757 8758 8759 |
# File 'lib/models/porcelain.rb', line 8757 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.
8759 8760 8761 |
# File 'lib/models/porcelain.rb', line 8759 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8761 8762 8763 |
# File 'lib/models/porcelain.rb', line 8761 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8763 8764 8765 |
# File 'lib/models/porcelain.rb', line 8763 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8765 8766 8767 |
# File 'lib/models/porcelain.rb', line 8765 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8767 8768 8769 |
# File 'lib/models/porcelain.rb', line 8767 def id @id end |
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
8769 8770 8771 |
# File 'lib/models/porcelain.rb', line 8769 def lock_required @lock_required end |
#name ⇒ Object
Unique human-readable name of the Resource.
8771 8772 8773 |
# File 'lib/models/porcelain.rb', line 8771 def name @name end |
#password ⇒ Object
The password to authenticate with.
8773 8774 8775 |
# File 'lib/models/porcelain.rb', line 8773 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8775 8776 8777 |
# File 'lib/models/porcelain.rb', line 8775 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8777 8778 8779 |
# File 'lib/models/porcelain.rb', line 8777 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8779 8780 8781 |
# File 'lib/models/porcelain.rb', line 8779 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8781 8782 8783 |
# File 'lib/models/porcelain.rb', line 8781 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8783 8784 8785 |
# File 'lib/models/porcelain.rb', line 8783 def @tags end |
#username ⇒ Object
The username to authenticate with.
8785 8786 8787 |
# File 'lib/models/porcelain.rb', line 8785 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8821 8822 8823 8824 8825 8826 8827 |
# File 'lib/models/porcelain.rb', line 8821 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |