Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
# File 'lib/models/porcelain.rb', line 7850

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7820
7821
7822
# File 'lib/models/porcelain.rb', line 7820

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



7822
7823
7824
# File 'lib/models/porcelain.rb', line 7822

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7824
7825
7826
# File 'lib/models/porcelain.rb', line 7824

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7826
7827
7828
# File 'lib/models/porcelain.rb', line 7826

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7828
7829
7830
# File 'lib/models/porcelain.rb', line 7828

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7830
7831
7832
# File 'lib/models/porcelain.rb', line 7830

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



7832
7833
7834
# File 'lib/models/porcelain.rb', line 7832

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



7834
7835
7836
# File 'lib/models/porcelain.rb', line 7834

def name
  @name
end

#passwordObject

The password to authenticate with.



7836
7837
7838
# File 'lib/models/porcelain.rb', line 7836

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7838
7839
7840
# File 'lib/models/porcelain.rb', line 7838

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7840
7841
7842
# File 'lib/models/porcelain.rb', line 7840

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7842
7843
7844
# File 'lib/models/porcelain.rb', line 7842

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7844
7845
7846
# File 'lib/models/porcelain.rb', line 7844

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7846
7847
7848
# File 'lib/models/porcelain.rb', line 7846

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7848
7849
7850
# File 'lib/models/porcelain.rb', line 7848

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7884
7885
7886
7887
7888
7889
7890
# File 'lib/models/porcelain.rb', line 7884

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end