Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



7290
7291
7292
7293
7294
7295
7296
7297
7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
7314
7315
7316
7317
7318
7319
7320
7321
7322
# File 'lib/models/porcelain.rb', line 7290

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7260
7261
7262
# File 'lib/models/porcelain.rb', line 7260

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



7262
7263
7264
# File 'lib/models/porcelain.rb', line 7262

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7264
7265
7266
# File 'lib/models/porcelain.rb', line 7264

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7266
7267
7268
# File 'lib/models/porcelain.rb', line 7266

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7268
7269
7270
# File 'lib/models/porcelain.rb', line 7268

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7270
7271
7272
# File 'lib/models/porcelain.rb', line 7270

def id
  @id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



7272
7273
7274
# File 'lib/models/porcelain.rb', line 7272

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



7274
7275
7276
# File 'lib/models/porcelain.rb', line 7274

def name
  @name
end

#passwordObject

The password to authenticate with.



7276
7277
7278
# File 'lib/models/porcelain.rb', line 7276

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7278
7279
7280
# File 'lib/models/porcelain.rb', line 7278

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7280
7281
7282
# File 'lib/models/porcelain.rb', line 7280

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7282
7283
7284
# File 'lib/models/porcelain.rb', line 7282

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7284
7285
7286
# File 'lib/models/porcelain.rb', line 7284

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7286
7287
7288
# File 'lib/models/porcelain.rb', line 7286

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7288
7289
7290
# File 'lib/models/porcelain.rb', line 7288

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7324
7325
7326
7327
7328
7329
7330
# File 'lib/models/porcelain.rb', line 7324

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end