Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
7042
7043
7044
7045
7046
# File 'lib/models/porcelain.rb', line 7016

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6988
6989
6990
# File 'lib/models/porcelain.rb', line 6988

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



6990
6991
6992
# File 'lib/models/porcelain.rb', line 6990

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6992
6993
6994
# File 'lib/models/porcelain.rb', line 6992

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6994
6995
6996
# File 'lib/models/porcelain.rb', line 6994

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6996
6997
6998
# File 'lib/models/porcelain.rb', line 6996

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6998
6999
7000
# File 'lib/models/porcelain.rb', line 6998

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7000
7001
7002
# File 'lib/models/porcelain.rb', line 7000

def name
  @name
end

#passwordObject

The password to authenticate with.



7002
7003
7004
# File 'lib/models/porcelain.rb', line 7002

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7004
7005
7006
# File 'lib/models/porcelain.rb', line 7004

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7006
7007
7008
# File 'lib/models/porcelain.rb', line 7006

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7008
7009
7010
# File 'lib/models/porcelain.rb', line 7008

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7010
7011
7012
# File 'lib/models/porcelain.rb', line 7010

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7012
7013
7014
# File 'lib/models/porcelain.rb', line 7012

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7014
7015
7016
# File 'lib/models/porcelain.rb', line 7014

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7048
7049
7050
7051
7052
7053
7054
# File 'lib/models/porcelain.rb', line 7048

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end