Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
6878
6879
6880
6881
6882
# File 'lib/models/porcelain.rb', line 6852

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6824
6825
6826
# File 'lib/models/porcelain.rb', line 6824

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



6826
6827
6828
# File 'lib/models/porcelain.rb', line 6826

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6828
6829
6830
# File 'lib/models/porcelain.rb', line 6828

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6830
6831
6832
# File 'lib/models/porcelain.rb', line 6830

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6832
6833
6834
# File 'lib/models/porcelain.rb', line 6832

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6834
6835
6836
# File 'lib/models/porcelain.rb', line 6834

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6836
6837
6838
# File 'lib/models/porcelain.rb', line 6836

def name
  @name
end

#passwordObject

The password to authenticate with.



6838
6839
6840
# File 'lib/models/porcelain.rb', line 6838

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6840
6841
6842
# File 'lib/models/porcelain.rb', line 6840

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6842
6843
6844
# File 'lib/models/porcelain.rb', line 6842

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6844
6845
6846
# File 'lib/models/porcelain.rb', line 6844

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6846
6847
6848
# File 'lib/models/porcelain.rb', line 6846

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6848
6849
6850
# File 'lib/models/porcelain.rb', line 6848

def tags
  @tags
end

#usernameObject

The username to authenticate with.



6850
6851
6852
# File 'lib/models/porcelain.rb', line 6850

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6884
6885
6886
6887
6888
6889
6890
# File 'lib/models/porcelain.rb', line 6884

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end