Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 |
# File 'lib/models/porcelain.rb', line 6844 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6816 6817 6818 |
# File 'lib/models/porcelain.rb', line 6816 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.
6818 6819 6820 |
# File 'lib/models/porcelain.rb', line 6818 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6820 6821 6822 |
# File 'lib/models/porcelain.rb', line 6820 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6822 6823 6824 |
# File 'lib/models/porcelain.rb', line 6822 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6824 6825 6826 |
# File 'lib/models/porcelain.rb', line 6824 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6826 6827 6828 |
# File 'lib/models/porcelain.rb', line 6826 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6828 6829 6830 |
# File 'lib/models/porcelain.rb', line 6828 def name @name end |
#password ⇒ Object
The password to authenticate with.
6830 6831 6832 |
# File 'lib/models/porcelain.rb', line 6830 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6832 6833 6834 |
# File 'lib/models/porcelain.rb', line 6832 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6834 6835 6836 |
# File 'lib/models/porcelain.rb', line 6834 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6836 6837 6838 |
# File 'lib/models/porcelain.rb', line 6836 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6838 6839 6840 |
# File 'lib/models/porcelain.rb', line 6838 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6840 6841 6842 |
# File 'lib/models/porcelain.rb', line 6840 def @tags end |
#username ⇒ Object
The username to authenticate with.
6842 6843 6844 |
# File 'lib/models/porcelain.rb', line 6842 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6876 6877 6878 6879 6880 6881 6882 |
# File 'lib/models/porcelain.rb', line 6876 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |