Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 6445 6446 |
# File 'lib/models/porcelain.rb', line 6416 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6388 6389 6390 |
# File 'lib/models/porcelain.rb', line 6388 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.
6390 6391 6392 |
# File 'lib/models/porcelain.rb', line 6390 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6392 6393 6394 |
# File 'lib/models/porcelain.rb', line 6392 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6394 6395 6396 |
# File 'lib/models/porcelain.rb', line 6394 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6396 6397 6398 |
# File 'lib/models/porcelain.rb', line 6396 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6398 6399 6400 |
# File 'lib/models/porcelain.rb', line 6398 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6400 6401 6402 |
# File 'lib/models/porcelain.rb', line 6400 def name @name end |
#password ⇒ Object
The password to authenticate with.
6402 6403 6404 |
# File 'lib/models/porcelain.rb', line 6402 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6404 6405 6406 |
# File 'lib/models/porcelain.rb', line 6404 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6406 6407 6408 |
# File 'lib/models/porcelain.rb', line 6406 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6408 6409 6410 |
# File 'lib/models/porcelain.rb', line 6408 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6410 6411 6412 |
# File 'lib/models/porcelain.rb', line 6410 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6412 6413 6414 |
# File 'lib/models/porcelain.rb', line 6412 def @tags end |
#username ⇒ Object
The username to authenticate with.
6414 6415 6416 |
# File 'lib/models/porcelain.rb', line 6414 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6448 6449 6450 6451 6452 6453 6454 |
# File 'lib/models/porcelain.rb', line 6448 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |