Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#downgrade_nla_connections ⇒ Object
Returns the value of attribute downgrade_nla_connections.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
5949 5950 5951 5952 5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 |
# File 'lib/models/porcelain.rb', line 5949 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5921 5922 5923 |
# File 'lib/models/porcelain.rb', line 5921 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
Returns the value of attribute downgrade_nla_connections.
5923 5924 5925 |
# File 'lib/models/porcelain.rb', line 5923 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5925 5926 5927 |
# File 'lib/models/porcelain.rb', line 5925 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5927 5928 5929 |
# File 'lib/models/porcelain.rb', line 5927 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5929 5930 5931 |
# File 'lib/models/porcelain.rb', line 5929 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5931 5932 5933 |
# File 'lib/models/porcelain.rb', line 5931 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5933 5934 5935 |
# File 'lib/models/porcelain.rb', line 5933 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5935 5936 5937 |
# File 'lib/models/porcelain.rb', line 5935 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5937 5938 5939 |
# File 'lib/models/porcelain.rb', line 5937 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5939 5940 5941 |
# File 'lib/models/porcelain.rb', line 5939 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5941 5942 5943 |
# File 'lib/models/porcelain.rb', line 5941 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
5943 5944 5945 |
# File 'lib/models/porcelain.rb', line 5943 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5945 5946 5947 |
# File 'lib/models/porcelain.rb', line 5945 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5947 5948 5949 |
# File 'lib/models/porcelain.rb', line 5947 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5981 5982 5983 5984 5985 5986 5987 |
# File 'lib/models/porcelain.rb', line 5981 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |