Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#downgrade_nla_connections ⇒ Object
Returns the value of attribute downgrade_nla_connections.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
5739 5740 5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 |
# File 'lib/models/porcelain.rb', line 5739 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5713 5714 5715 |
# File 'lib/models/porcelain.rb', line 5713 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
Returns the value of attribute downgrade_nla_connections.
5715 5716 5717 |
# File 'lib/models/porcelain.rb', line 5715 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5717 5718 5719 |
# File 'lib/models/porcelain.rb', line 5717 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5719 5720 5721 |
# File 'lib/models/porcelain.rb', line 5719 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5721 5722 5723 |
# File 'lib/models/porcelain.rb', line 5721 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5723 5724 5725 |
# File 'lib/models/porcelain.rb', line 5723 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5725 5726 5727 |
# File 'lib/models/porcelain.rb', line 5725 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5727 5728 5729 |
# File 'lib/models/porcelain.rb', line 5727 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5729 5730 5731 |
# File 'lib/models/porcelain.rb', line 5729 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5731 5732 5733 |
# File 'lib/models/porcelain.rb', line 5731 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5733 5734 5735 |
# File 'lib/models/porcelain.rb', line 5733 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5735 5736 5737 |
# File 'lib/models/porcelain.rb', line 5735 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5737 5738 5739 |
# File 'lib/models/porcelain.rb', line 5737 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5769 5770 5771 5772 5773 5774 5775 |
# File 'lib/models/porcelain.rb', line 5769 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |