Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



5117
5118
5119
5120
5121
5122
5123
5124
5125
5126
5127
5128
5129
5130
5131
5132
5133
5134
5135
5136
5137
5138
5139
5140
5141
5142
5143
5144
5145
# File 'lib/models/porcelain.rb', line 5117

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5091
5092
5093
# File 'lib/models/porcelain.rb', line 5091

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

Returns the value of attribute downgrade_nla_connections.



5093
5094
5095
# File 'lib/models/porcelain.rb', line 5093

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5095
5096
5097
# File 'lib/models/porcelain.rb', line 5095

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5097
5098
5099
# File 'lib/models/porcelain.rb', line 5097

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5099
5100
5101
# File 'lib/models/porcelain.rb', line 5099

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5101
5102
5103
# File 'lib/models/porcelain.rb', line 5101

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5103
5104
5105
# File 'lib/models/porcelain.rb', line 5103

def name
  @name
end

#passwordObject

Returns the value of attribute password.



5105
5106
5107
# File 'lib/models/porcelain.rb', line 5105

def password
  @password
end

#portObject

Returns the value of attribute port.



5107
5108
5109
# File 'lib/models/porcelain.rb', line 5107

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5109
5110
5111
# File 'lib/models/porcelain.rb', line 5109

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5111
5112
5113
# File 'lib/models/porcelain.rb', line 5111

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5113
5114
5115
# File 'lib/models/porcelain.rb', line 5113

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5115
5116
5117
# File 'lib/models/porcelain.rb', line 5115

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5147
5148
5149
5150
5151
5152
5153
# File 'lib/models/porcelain.rb', line 5147

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end