Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#downgrade_nla_connections ⇒ Object
Returns the value of attribute downgrade_nla_connections.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 5037 |
# File 'lib/models/porcelain.rb', line 5009 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4983 4984 4985 |
# File 'lib/models/porcelain.rb', line 4983 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
Returns the value of attribute downgrade_nla_connections.
4985 4986 4987 |
# File 'lib/models/porcelain.rb', line 4985 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4987 4988 4989 |
# File 'lib/models/porcelain.rb', line 4987 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4989 4990 4991 |
# File 'lib/models/porcelain.rb', line 4989 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4991 4992 4993 |
# File 'lib/models/porcelain.rb', line 4991 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4993 4994 4995 |
# File 'lib/models/porcelain.rb', line 4993 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4995 4996 4997 |
# File 'lib/models/porcelain.rb', line 4995 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4997 4998 4999 |
# File 'lib/models/porcelain.rb', line 4997 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4999 5000 5001 |
# File 'lib/models/porcelain.rb', line 4999 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5001 5002 5003 |
# File 'lib/models/porcelain.rb', line 5001 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5003 5004 5005 |
# File 'lib/models/porcelain.rb', line 5003 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5005 5006 5007 |
# File 'lib/models/porcelain.rb', line 5005 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5007 5008 5009 |
# File 'lib/models/porcelain.rb', line 5007 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5039 5040 5041 5042 5043 5044 5045 |
# File 'lib/models/porcelain.rb', line 5039 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |