Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#downgrade_nla_connections ⇒ Object
Returns the value of attribute downgrade_nla_connections.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 |
# File 'lib/models/porcelain.rb', line 4990 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
4964 4965 4966 |
# File 'lib/models/porcelain.rb', line 4964 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
Returns the value of attribute downgrade_nla_connections.
4966 4967 4968 |
# File 'lib/models/porcelain.rb', line 4966 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4968 4969 4970 |
# File 'lib/models/porcelain.rb', line 4968 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4970 4971 4972 |
# File 'lib/models/porcelain.rb', line 4970 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4972 4973 4974 |
# File 'lib/models/porcelain.rb', line 4972 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4974 4975 4976 |
# File 'lib/models/porcelain.rb', line 4974 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4976 4977 4978 |
# File 'lib/models/porcelain.rb', line 4976 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4978 4979 4980 |
# File 'lib/models/porcelain.rb', line 4978 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4980 4981 4982 |
# File 'lib/models/porcelain.rb', line 4980 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4982 4983 4984 |
# File 'lib/models/porcelain.rb', line 4982 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4984 4985 4986 |
# File 'lib/models/porcelain.rb', line 4984 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4986 4987 4988 |
# File 'lib/models/porcelain.rb', line 4986 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
4988 4989 4990 |
# File 'lib/models/porcelain.rb', line 4988 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5020 5021 5022 5023 5024 5025 5026 |
# File 'lib/models/porcelain.rb', line 5020 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |