Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



5561
5562
5563
5564
5565
5566
5567
5568
5569
5570
5571
5572
5573
5574
5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
5596
5597
5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
# File 'lib/models/porcelain.rb', line 5561

def initialize(
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  if downgrade_nla_connections != nil
    @downgrade_nla_connections = downgrade_nla_connections
  end
  if egress_filter != nil
    @egress_filter = egress_filter
  end
  if healthy != nil
    @healthy = healthy
  end
  if hostname != nil
    @hostname = hostname
  end
  if id != nil
    @id = id
  end
  if name != nil
    @name = name
  end
  if password != nil
    @password = password
  end
  if port != nil
    @port = port
  end
  if port_override != nil
    @port_override = port_override
  end
  if secret_store_id != nil
    @secret_store_id = secret_store_id
  end
  if tags != nil
    @tags = tags
  end
  if username != nil
    @username = username
  end
end

Instance Attribute Details

#downgrade_nla_connectionsObject

Returns the value of attribute downgrade_nla_connections.



5537
5538
5539
# File 'lib/models/porcelain.rb', line 5537

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5539
5540
5541
# File 'lib/models/porcelain.rb', line 5539

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5541
5542
5543
# File 'lib/models/porcelain.rb', line 5541

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5543
5544
5545
# File 'lib/models/porcelain.rb', line 5543

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5545
5546
5547
# File 'lib/models/porcelain.rb', line 5545

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5547
5548
5549
# File 'lib/models/porcelain.rb', line 5547

def name
  @name
end

#passwordObject

Returns the value of attribute password.



5549
5550
5551
# File 'lib/models/porcelain.rb', line 5549

def password
  @password
end

#portObject

Returns the value of attribute port.



5551
5552
5553
# File 'lib/models/porcelain.rb', line 5551

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5553
5554
5555
# File 'lib/models/porcelain.rb', line 5553

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5555
5556
5557
# File 'lib/models/porcelain.rb', line 5555

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5557
5558
5559
# File 'lib/models/porcelain.rb', line 5557

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5559
5560
5561
# File 'lib/models/porcelain.rb', line 5559

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5613
5614
5615
5616
5617
5618
5619
# File 'lib/models/porcelain.rb', line 5613

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end