Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



13995
13996
13997
13998
13999
14000
14001
14002
14003
14004
14005
14006
14007
14008
14009
14010
14011
14012
14013
14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
14030
14031
14032
14033
# File 'lib/models/porcelain.rb', line 13995

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13959
13960
13961
# File 'lib/models/porcelain.rb', line 13959

def bind_interface
  @bind_interface
end

#downgrade_nla_connectionsObject

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



13961
13962
13963
# File 'lib/models/porcelain.rb', line 13961

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13963
13964
13965
# File 'lib/models/porcelain.rb', line 13963

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13965
13966
13967
# File 'lib/models/porcelain.rb', line 13965

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13967
13968
13969
# File 'lib/models/porcelain.rb', line 13967

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13969
13970
13971
# File 'lib/models/porcelain.rb', line 13969

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13971
13972
13973
# File 'lib/models/porcelain.rb', line 13971

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

if provided use identity_set to map username to secret store path



13973
13974
13975
# File 'lib/models/porcelain.rb', line 13973

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



13975
13976
13977
# File 'lib/models/porcelain.rb', line 13975

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



13977
13978
13979
# File 'lib/models/porcelain.rb', line 13977

def name
  @name
end

#passwordObject

The password to authenticate with.



13979
13980
13981
# File 'lib/models/porcelain.rb', line 13979

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13981
13982
13983
# File 'lib/models/porcelain.rb', line 13981

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13983
13984
13985
# File 'lib/models/porcelain.rb', line 13983

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13985
13986
13987
# File 'lib/models/porcelain.rb', line 13985

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13987
13988
13989
# File 'lib/models/porcelain.rb', line 13987

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13989
13990
13991
# File 'lib/models/porcelain.rb', line 13989

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13991
13992
13993
# File 'lib/models/porcelain.rb', line 13991

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13993
13994
13995
# File 'lib/models/porcelain.rb', line 13993

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14035
14036
14037
14038
14039
14040
14041
# File 'lib/models/porcelain.rb', line 14035

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end