Class: SDM::RDP
- Inherits:
-
Object
- Object
- SDM::RDP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
if provided use identity_set to map username to secret store path.
-
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
constructor
A new instance of RDP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP
Returns a new instance of RDP.
14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 14757 14758 14759 14760 14761 14762 14763 14764 14765 14766 |
# File 'lib/models/porcelain.rb', line 14728 def initialize( bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @lock_required = lock_required == nil ? false : lock_required @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
14692 14693 14694 |
# File 'lib/models/porcelain.rb', line 14692 def bind_interface @bind_interface end |
#downgrade_nla_connections ⇒ Object
When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.
14694 14695 14696 |
# File 'lib/models/porcelain.rb', line 14694 def downgrade_nla_connections @downgrade_nla_connections end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14696 14697 14698 |
# File 'lib/models/porcelain.rb', line 14696 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14698 14699 14700 |
# File 'lib/models/porcelain.rb', line 14698 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14700 14701 14702 |
# File 'lib/models/porcelain.rb', line 14700 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14702 14703 14704 |
# File 'lib/models/porcelain.rb', line 14702 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
14704 14705 14706 |
# File 'lib/models/porcelain.rb', line 14704 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
if provided use identity_set to map username to secret store path
14706 14707 14708 |
# File 'lib/models/porcelain.rb', line 14706 def identity_set_id @identity_set_id end |
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
14708 14709 14710 |
# File 'lib/models/porcelain.rb', line 14708 def lock_required @lock_required end |
#name ⇒ Object
Unique human-readable name of the Resource.
14710 14711 14712 |
# File 'lib/models/porcelain.rb', line 14710 def name @name end |
#password ⇒ Object
The password to authenticate with.
14712 14713 14714 |
# File 'lib/models/porcelain.rb', line 14712 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14714 14715 14716 |
# File 'lib/models/porcelain.rb', line 14714 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
14716 14717 14718 |
# File 'lib/models/porcelain.rb', line 14716 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14718 14719 14720 |
# File 'lib/models/porcelain.rb', line 14718 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14720 14721 14722 |
# File 'lib/models/porcelain.rb', line 14720 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
14722 14723 14724 |
# File 'lib/models/porcelain.rb', line 14722 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14724 14725 14726 |
# File 'lib/models/porcelain.rb', line 14724 def end |
#username ⇒ Object
The username to authenticate with.
14726 14727 14728 |
# File 'lib/models/porcelain.rb', line 14726 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14768 14769 14770 14771 14772 14773 14774 |
# File 'lib/models/porcelain.rb', line 14768 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |