Class: SDM::RDP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, downgrade_nla_connections: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDP

Returns a new instance of RDP.



14729
14730
14731
14732
14733
14734
14735
14736
14737
14738
14739
14740
14741
14742
14743
14744
14745
14746
14747
14748
14749
14750
14751
14752
14753
14754
14755
14756
14757
14758
14759
14760
14761
14762
14763
14764
14765
14766
14767
# File 'lib/models/porcelain.rb', line 14729

def initialize(
  bind_interface: nil,
  downgrade_nla_connections: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @downgrade_nla_connections = downgrade_nla_connections == nil ? false : downgrade_nla_connections
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14693
14694
14695
# File 'lib/models/porcelain.rb', line 14693

def bind_interface
  @bind_interface
end

#downgrade_nla_connections ⇒ Object

When set, network level authentication will not be used. May resolve unexpected authentication errors to older servers. When set, healthchecks cannot detect if a provided username / password pair is correct.



14695
14696
14697
# File 'lib/models/porcelain.rb', line 14695

def downgrade_nla_connections
  @downgrade_nla_connections
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



14697
14698
14699
# File 'lib/models/porcelain.rb', line 14697

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



14699
14700
14701
# File 'lib/models/porcelain.rb', line 14699

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



14701
14702
14703
# File 'lib/models/porcelain.rb', line 14701

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



14703
14704
14705
# File 'lib/models/porcelain.rb', line 14703

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



14705
14706
14707
# File 'lib/models/porcelain.rb', line 14705

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

if provided use identity_set to map username to secret store path



14707
14708
14709
# File 'lib/models/porcelain.rb', line 14707

def identity_set_id
  @identity_set_id
end

#lock_required ⇒ Object

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



14709
14710
14711
# File 'lib/models/porcelain.rb', line 14709

def lock_required
  @lock_required
end

#name ⇒ Object

Unique human-readable name of the Resource.



14711
14712
14713
# File 'lib/models/porcelain.rb', line 14711

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



14713
14714
14715
# File 'lib/models/porcelain.rb', line 14713

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



14715
14716
14717
# File 'lib/models/porcelain.rb', line 14715

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14717
14718
14719
# File 'lib/models/porcelain.rb', line 14717

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



14719
14720
14721
# File 'lib/models/porcelain.rb', line 14719

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



14721
14722
14723
# File 'lib/models/porcelain.rb', line 14721

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14723
14724
14725
# File 'lib/models/porcelain.rb', line 14723

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



14725
14726
14727
# File 'lib/models/porcelain.rb', line 14725

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



14727
14728
14729
# File 'lib/models/porcelain.rb', line 14727

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14769
14770
14771
14772
14773
14774
14775
# File 'lib/models/porcelain.rb', line 14769

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end