Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



14710
14711
14712
14713
14714
14715
14716
14717
14718
14719
14720
14721
14722
14723
14724
14725
14726
14727
14728
14729
14730
14731
14732
14733
14734
14735
14736
14737
14738
14739
14740
14741
14742
14743
14744
14745
14746
14747
14748
14749
14750
# File 'lib/models/porcelain.rb', line 14710

def initialize(
  bind_interface: nil,
  dc_hostnames: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_fqdn: nil,
  sid: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @dc_hostnames = dc_hostnames == nil ? "" : dc_hostnames
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_fqdn = server_fqdn == nil ? "" : server_fqdn
  @sid = sid == nil ? "" : sid
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14672
14673
14674
# File 'lib/models/porcelain.rb', line 14672

def bind_interface
  @bind_interface
end

#dc_hostnamesObject

Comma-separated list of Active Directory Domain Controller hostnames. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), and for LDAPS SID resolution for strong certificate mapping in full enforcement mode when the identity alias does not specify a SID. Unused for Entra ID.



14674
14675
14676
# File 'lib/models/porcelain.rb', line 14674

def dc_hostnames
  @dc_hostnames
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14676
14677
14678
# File 'lib/models/porcelain.rb', line 14676

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14678
14679
14680
# File 'lib/models/porcelain.rb', line 14678

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14680
14681
14682
# File 'lib/models/porcelain.rb', line 14680

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14682
14683
14684
# File 'lib/models/porcelain.rb', line 14682

def id
  @id
end

#identity_alias_healthcheck_usernameObject

Username of the AD service account for health checks, and LDAPS SID resolution if necessary. Required for on-premises AD environments, unused for Entra ID.



14684
14685
14686
# File 'lib/models/porcelain.rb', line 14684

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



14686
14687
14688
# File 'lib/models/porcelain.rb', line 14686

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



14688
14689
14690
# File 'lib/models/porcelain.rb', line 14688

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



14690
14691
14692
# File 'lib/models/porcelain.rb', line 14690

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14692
14693
14694
# File 'lib/models/porcelain.rb', line 14692

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14694
14695
14696
# File 'lib/models/porcelain.rb', line 14694

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14696
14697
14698
# File 'lib/models/porcelain.rb', line 14696

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14698
14699
14700
# File 'lib/models/porcelain.rb', line 14698

def secret_store_id
  @secret_store_id
end

#server_fqdnObject

Fully-qualified DNS name of the target Windows server, including the AD domain. Must match the Service Principal Name (SPN) of the server in AD. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), unused for Entra ID.



14700
14701
14702
# File 'lib/models/porcelain.rb', line 14700

def server_fqdn
  @server_fqdn
end

#sidObject

Windows Security Identifier (SID) of the configured Username, or AD service account if using LDAPS SID resolution. Required in on-premises AD environments for strong certificate mapping in full enforcement mode, unused for Entra ID.



14702
14703
14704
# File 'lib/models/porcelain.rb', line 14702

def sid
  @sid
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14704
14705
14706
# File 'lib/models/porcelain.rb', line 14704

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14706
14707
14708
# File 'lib/models/porcelain.rb', line 14706

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14708
14709
14710
# File 'lib/models/porcelain.rb', line 14708

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14752
14753
14754
14755
14756
14757
14758
# File 'lib/models/porcelain.rb', line 14752

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end