Class: SDM::RDPCert
- Inherits:
-
Object
- Object
- SDM::RDPCert
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#dc_hostnames ⇒ Object
Comma-separated list of Active Directory Domain Controller hostnames.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
Username of the AD service account for health checks, and LDAPS SID resolution if necessary.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_fqdn ⇒ Object
Fully-qualified DNS name of the target Windows server, including the AD domain.
-
#sid ⇒ Object
Windows Security Identifier (SID) of the configured Username, or AD service account if using LDAPS SID resolution.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert
constructor
A new instance of RDPCert.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert
Returns a new instance of RDPCert.
14404 14405 14406 14407 14408 14409 14410 14411 14412 14413 14414 14415 14416 14417 14418 14419 14420 14421 14422 14423 14424 14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 |
# File 'lib/models/porcelain.rb', line 14404 def initialize( bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @dc_hostnames = dc_hostnames == nil ? "" : dc_hostnames @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @lock_required = lock_required == nil ? false : lock_required @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_fqdn = server_fqdn == nil ? "" : server_fqdn @sid = sid == nil ? "" : sid @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
14366 14367 14368 |
# File 'lib/models/porcelain.rb', line 14366 def bind_interface @bind_interface end |
#dc_hostnames ⇒ Object
Comma-separated list of Active Directory Domain Controller hostnames. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), and for LDAPS SID resolution for strong certificate mapping in full enforcement mode when the identity alias does not specify a SID. Unused for Entra ID.
14368 14369 14370 |
# File 'lib/models/porcelain.rb', line 14368 def dc_hostnames @dc_hostnames end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14370 14371 14372 |
# File 'lib/models/porcelain.rb', line 14370 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14372 14373 14374 |
# File 'lib/models/porcelain.rb', line 14372 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14374 14375 14376 |
# File 'lib/models/porcelain.rb', line 14374 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14376 14377 14378 |
# File 'lib/models/porcelain.rb', line 14376 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
Username of the AD service account for health checks, and LDAPS SID resolution if necessary. Required for on-premises AD environments, unused for Entra ID.
14378 14379 14380 |
# File 'lib/models/porcelain.rb', line 14378 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
14380 14381 14382 |
# File 'lib/models/porcelain.rb', line 14380 def identity_set_id @identity_set_id end |
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
14382 14383 14384 |
# File 'lib/models/porcelain.rb', line 14382 def lock_required @lock_required end |
#name ⇒ Object
Unique human-readable name of the Resource.
14384 14385 14386 |
# File 'lib/models/porcelain.rb', line 14384 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14386 14387 14388 |
# File 'lib/models/porcelain.rb', line 14386 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
14388 14389 14390 |
# File 'lib/models/porcelain.rb', line 14388 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14390 14391 14392 |
# File 'lib/models/porcelain.rb', line 14390 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14392 14393 14394 |
# File 'lib/models/porcelain.rb', line 14392 def secret_store_id @secret_store_id end |
#server_fqdn ⇒ Object
Fully-qualified DNS name of the target Windows server, including the AD domain. Must match the Service Principal Name (SPN) of the server in AD. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), unused for Entra ID.
14394 14395 14396 |
# File 'lib/models/porcelain.rb', line 14394 def server_fqdn @server_fqdn end |
#sid ⇒ Object
Windows Security Identifier (SID) of the configured Username, or AD service account if using LDAPS SID resolution. Required in on-premises AD environments for strong certificate mapping in full enforcement mode, unused for Entra ID.
14396 14397 14398 |
# File 'lib/models/porcelain.rb', line 14396 def sid @sid end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
14398 14399 14400 |
# File 'lib/models/porcelain.rb', line 14398 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14400 14401 14402 |
# File 'lib/models/porcelain.rb', line 14400 def @tags end |
#username ⇒ Object
The username to authenticate with.
14402 14403 14404 |
# File 'lib/models/porcelain.rb', line 14402 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14446 14447 14448 14449 14450 14451 14452 |
# File 'lib/models/porcelain.rb', line 14446 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |