Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



14085
14086
14087
14088
14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
# File 'lib/models/porcelain.rb', line 14085

def initialize(
  bind_interface: nil,
  dc_hostnames: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_fqdn: nil,
  sid: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @dc_hostnames = dc_hostnames == nil ? "" : dc_hostnames
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_fqdn = server_fqdn == nil ? "" : server_fqdn
  @sid = sid == nil ? "" : sid
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14047
14048
14049
# File 'lib/models/porcelain.rb', line 14047

def bind_interface
  @bind_interface
end

#dc_hostnamesObject

Comma-separated list of Active Directory Domain Controller hostnames. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), and for LDAPS SID resolution for strong certificate mapping in full enforcement mode when the identity alias does not specify a SID. Unused for Entra ID.



14049
14050
14051
# File 'lib/models/porcelain.rb', line 14049

def dc_hostnames
  @dc_hostnames
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14051
14052
14053
# File 'lib/models/porcelain.rb', line 14051

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14053
14054
14055
# File 'lib/models/porcelain.rb', line 14053

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14055
14056
14057
# File 'lib/models/porcelain.rb', line 14055

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14057
14058
14059
# File 'lib/models/porcelain.rb', line 14057

def id
  @id
end

#identity_alias_healthcheck_usernameObject

Username of the AD service account for health checks, and LDAPS SID resolution if necessary. Required for on-premises AD environments, unused for Entra ID.



14059
14060
14061
# File 'lib/models/porcelain.rb', line 14059

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



14061
14062
14063
# File 'lib/models/porcelain.rb', line 14061

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



14063
14064
14065
# File 'lib/models/porcelain.rb', line 14063

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



14065
14066
14067
# File 'lib/models/porcelain.rb', line 14065

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14067
14068
14069
# File 'lib/models/porcelain.rb', line 14067

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14069
14070
14071
# File 'lib/models/porcelain.rb', line 14069

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14071
14072
14073
# File 'lib/models/porcelain.rb', line 14071

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14073
14074
14075
# File 'lib/models/porcelain.rb', line 14073

def secret_store_id
  @secret_store_id
end

#server_fqdnObject

Fully-qualified DNS name of the target Windows server, including the AD domain. Must match the Service Principal Name (SPN) of the server in AD. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), unused for Entra ID.



14075
14076
14077
# File 'lib/models/porcelain.rb', line 14075

def server_fqdn
  @server_fqdn
end

#sidObject

Windows Security Identifier (SID) of the configured Username, or AD service account if using LDAPS SID resolution. Required in on-premises AD environments for strong certificate mapping in full enforcement mode, unused for Entra ID.



14077
14078
14079
# File 'lib/models/porcelain.rb', line 14077

def sid
  @sid
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14079
14080
14081
# File 'lib/models/porcelain.rb', line 14079

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14081
14082
14083
# File 'lib/models/porcelain.rb', line 14081

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14083
14084
14085
# File 'lib/models/porcelain.rb', line 14083

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14127
14128
14129
14130
14131
14132
14133
# File 'lib/models/porcelain.rb', line 14127

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end