Class: SDM::RDPCert
- Inherits:
-
Object
- Object
- SDM::RDPCert
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#dc_hostnames ⇒ Object
Comma-separated list of Active Directory Domain Controller hostnames.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
Username of the AD service account for health checks, and LDAPS SID resolution if necessary.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_fqdn ⇒ Object
Fully-qualified DNS name of the target Windows server, including the AD domain.
-
#sid ⇒ Object
Windows Security Identifier (SID) of the configured Username, or AD service account if using LDAPS SID resolution.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert
constructor
A new instance of RDPCert.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert
Returns a new instance of RDPCert.
14011 14012 14013 14014 14015 14016 14017 14018 14019 14020 14021 14022 14023 14024 14025 14026 14027 14028 14029 14030 14031 14032 14033 14034 14035 14036 14037 14038 14039 14040 14041 14042 14043 14044 14045 14046 14047 14048 14049 14050 14051 |
# File 'lib/models/porcelain.rb', line 14011 def initialize( bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @dc_hostnames = dc_hostnames == nil ? "" : dc_hostnames @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @lock_required = lock_required == nil ? false : lock_required @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_fqdn = server_fqdn == nil ? "" : server_fqdn @sid = sid == nil ? "" : sid @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
13973 13974 13975 |
# File 'lib/models/porcelain.rb', line 13973 def bind_interface @bind_interface end |
#dc_hostnames ⇒ Object
Comma-separated list of Active Directory Domain Controller hostnames. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), and for LDAPS SID resolution for strong certificate mapping in full enforcement mode when the identity alias does not specify a SID. Unused for Entra ID.
13975 13976 13977 |
# File 'lib/models/porcelain.rb', line 13975 def dc_hostnames @dc_hostnames end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
13977 13978 13979 |
# File 'lib/models/porcelain.rb', line 13977 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
13979 13980 13981 |
# File 'lib/models/porcelain.rb', line 13979 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
13981 13982 13983 |
# File 'lib/models/porcelain.rb', line 13981 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
13983 13984 13985 |
# File 'lib/models/porcelain.rb', line 13983 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
Username of the AD service account for health checks, and LDAPS SID resolution if necessary. Required for on-premises AD environments, unused for Entra ID.
13985 13986 13987 |
# File 'lib/models/porcelain.rb', line 13985 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
13987 13988 13989 |
# File 'lib/models/porcelain.rb', line 13987 def identity_set_id @identity_set_id end |
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
13989 13990 13991 |
# File 'lib/models/porcelain.rb', line 13989 def lock_required @lock_required end |
#name ⇒ Object
Unique human-readable name of the Resource.
13991 13992 13993 |
# File 'lib/models/porcelain.rb', line 13991 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
13993 13994 13995 |
# File 'lib/models/porcelain.rb', line 13993 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
13995 13996 13997 |
# File 'lib/models/porcelain.rb', line 13995 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
13997 13998 13999 |
# File 'lib/models/porcelain.rb', line 13997 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
13999 14000 14001 |
# File 'lib/models/porcelain.rb', line 13999 def secret_store_id @secret_store_id end |
#server_fqdn ⇒ Object
Fully-qualified DNS name of the target Windows server, including the AD domain. Must match the Service Principal Name (SPN) of the server in AD. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), unused for Entra ID.
14001 14002 14003 |
# File 'lib/models/porcelain.rb', line 14001 def server_fqdn @server_fqdn end |
#sid ⇒ Object
Windows Security Identifier (SID) of the configured Username, or AD service account if using LDAPS SID resolution. Required in on-premises AD environments for strong certificate mapping in full enforcement mode, unused for Entra ID.
14003 14004 14005 |
# File 'lib/models/porcelain.rb', line 14003 def sid @sid end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
14005 14006 14007 |
# File 'lib/models/porcelain.rb', line 14005 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14007 14008 14009 |
# File 'lib/models/porcelain.rb', line 14007 def @tags end |
#username ⇒ Object
The username to authenticate with.
14009 14010 14011 |
# File 'lib/models/porcelain.rb', line 14009 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14053 14054 14055 14056 14057 14058 14059 |
# File 'lib/models/porcelain.rb', line 14053 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |