Class: SDM::RDPCert
- Inherits:
-
Object
- Object
- SDM::RDPCert
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#dc_hostnames ⇒ Object
Comma-separated list of Active Directory Domain Controller hostnames for LDAPS SID resolution.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
-
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
-
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#sid ⇒ Object
Windows Security Identifier (SID) of the configured Username, required for strong certificate mapping in full enforcement mode.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert
constructor
A new instance of RDPCert.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert
Returns a new instance of RDPCert.
12825 12826 12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 12841 12842 12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 |
# File 'lib/models/porcelain.rb', line 12825 def initialize( bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, sid: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @dc_hostnames = dc_hostnames == nil ? "" : dc_hostnames @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username @identity_set_id = identity_set_id == nil ? "" : identity_set_id @lock_required = lock_required == nil ? false : lock_required @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @sid = sid == nil ? "" : sid @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
12789 12790 12791 |
# File 'lib/models/porcelain.rb', line 12789 def bind_interface @bind_interface end |
#dc_hostnames ⇒ Object
Comma-separated list of Active Directory Domain Controller hostnames for LDAPS SID resolution. Utilized for strong certificate mapping in full enforcement mode when the identity alias does not specify a SID.
12791 12792 12793 |
# File 'lib/models/porcelain.rb', line 12791 def dc_hostnames @dc_hostnames end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12793 12794 12795 |
# File 'lib/models/porcelain.rb', line 12793 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12795 12796 12797 |
# File 'lib/models/porcelain.rb', line 12795 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12797 12798 12799 |
# File 'lib/models/porcelain.rb', line 12797 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12799 12800 12801 |
# File 'lib/models/porcelain.rb', line 12799 def id @id end |
#identity_alias_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own identity alias username.
12801 12802 12803 |
# File 'lib/models/porcelain.rb', line 12801 def identity_alias_healthcheck_username @identity_alias_healthcheck_username end |
#identity_set_id ⇒ Object
The ID of the identity set to use for identity connections.
12803 12804 12805 |
# File 'lib/models/porcelain.rb', line 12803 def identity_set_id @identity_set_id end |
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
12805 12806 12807 |
# File 'lib/models/porcelain.rb', line 12805 def lock_required @lock_required end |
#name ⇒ Object
Unique human-readable name of the Resource.
12807 12808 12809 |
# File 'lib/models/porcelain.rb', line 12807 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
12809 12810 12811 |
# File 'lib/models/porcelain.rb', line 12809 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
12811 12812 12813 |
# File 'lib/models/porcelain.rb', line 12811 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
12813 12814 12815 |
# File 'lib/models/porcelain.rb', line 12813 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
12815 12816 12817 |
# File 'lib/models/porcelain.rb', line 12815 def secret_store_id @secret_store_id end |
#sid ⇒ Object
Windows Security Identifier (SID) of the configured Username, required for strong certificate mapping in full enforcement mode.
12817 12818 12819 |
# File 'lib/models/porcelain.rb', line 12817 def sid @sid end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
12819 12820 12821 |
# File 'lib/models/porcelain.rb', line 12819 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12821 12822 12823 |
# File 'lib/models/porcelain.rb', line 12821 def @tags end |
#username ⇒ Object
The username to authenticate with.
12823 12824 12825 |
# File 'lib/models/porcelain.rb', line 12823 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12865 12866 12867 12868 12869 12870 12871 |
# File 'lib/models/porcelain.rb', line 12865 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |