Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



11534
11535
11536
11537
11538
11539
11540
11541
11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
11552
11553
11554
11555
11556
11557
11558
11559
11560
11561
11562
11563
11564
11565
11566
11567
11568
# File 'lib/models/porcelain.rb', line 11534

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11502
11503
11504
# File 'lib/models/porcelain.rb', line 11502

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11504
11505
11506
# File 'lib/models/porcelain.rb', line 11504

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11506
11507
11508
# File 'lib/models/porcelain.rb', line 11506

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11508
11509
11510
# File 'lib/models/porcelain.rb', line 11508

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11510
11511
11512
# File 'lib/models/porcelain.rb', line 11510

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



11512
11513
11514
# File 'lib/models/porcelain.rb', line 11512

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



11514
11515
11516
# File 'lib/models/porcelain.rb', line 11514

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



11516
11517
11518
# File 'lib/models/porcelain.rb', line 11516

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



11518
11519
11520
# File 'lib/models/porcelain.rb', line 11518

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11520
11521
11522
# File 'lib/models/porcelain.rb', line 11520

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11522
11523
11524
# File 'lib/models/porcelain.rb', line 11522

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11524
11525
11526
# File 'lib/models/porcelain.rb', line 11524

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11526
11527
11528
# File 'lib/models/porcelain.rb', line 11526

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11528
11529
11530
# File 'lib/models/porcelain.rb', line 11528

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11530
11531
11532
# File 'lib/models/porcelain.rb', line 11530

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11532
11533
11534
# File 'lib/models/porcelain.rb', line 11532

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11570
11571
11572
11573
11574
11575
11576
# File 'lib/models/porcelain.rb', line 11570

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end