Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



11355
11356
11357
11358
11359
11360
11361
11362
11363
11364
11365
11366
11367
11368
11369
11370
11371
11372
11373
11374
11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
# File 'lib/models/porcelain.rb', line 11355

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11323
11324
11325
# File 'lib/models/porcelain.rb', line 11323

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11325
11326
11327
# File 'lib/models/porcelain.rb', line 11325

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11327
11328
11329
# File 'lib/models/porcelain.rb', line 11327

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11329
11330
11331
# File 'lib/models/porcelain.rb', line 11329

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11331
11332
11333
# File 'lib/models/porcelain.rb', line 11331

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



11333
11334
11335
# File 'lib/models/porcelain.rb', line 11333

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



11335
11336
11337
# File 'lib/models/porcelain.rb', line 11335

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



11337
11338
11339
# File 'lib/models/porcelain.rb', line 11337

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



11339
11340
11341
# File 'lib/models/porcelain.rb', line 11339

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11341
11342
11343
# File 'lib/models/porcelain.rb', line 11341

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11343
11344
11345
# File 'lib/models/porcelain.rb', line 11343

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11345
11346
11347
# File 'lib/models/porcelain.rb', line 11345

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11347
11348
11349
# File 'lib/models/porcelain.rb', line 11347

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11349
11350
11351
# File 'lib/models/porcelain.rb', line 11349

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11351
11352
11353
# File 'lib/models/porcelain.rb', line 11351

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11353
11354
11355
# File 'lib/models/porcelain.rb', line 11353

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11391
11392
11393
11394
11395
11396
11397
# File 'lib/models/porcelain.rb', line 11391

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end