Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
11161
11162
11163
11164
11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
11176
11177
# File 'lib/models/porcelain.rb', line 11143

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11111
11112
11113
# File 'lib/models/porcelain.rb', line 11111

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11113
11114
11115
# File 'lib/models/porcelain.rb', line 11113

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11115
11116
11117
# File 'lib/models/porcelain.rb', line 11115

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11117
11118
11119
# File 'lib/models/porcelain.rb', line 11117

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11119
11120
11121
# File 'lib/models/porcelain.rb', line 11119

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



11121
11122
11123
# File 'lib/models/porcelain.rb', line 11121

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



11123
11124
11125
# File 'lib/models/porcelain.rb', line 11123

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



11125
11126
11127
# File 'lib/models/porcelain.rb', line 11125

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



11127
11128
11129
# File 'lib/models/porcelain.rb', line 11127

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11129
11130
11131
# File 'lib/models/porcelain.rb', line 11129

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11131
11132
11133
# File 'lib/models/porcelain.rb', line 11131

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11133
11134
11135
# File 'lib/models/porcelain.rb', line 11133

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11135
11136
11137
# File 'lib/models/porcelain.rb', line 11135

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11137
11138
11139
# File 'lib/models/porcelain.rb', line 11137

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11139
11140
11141
# File 'lib/models/porcelain.rb', line 11139

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11141
11142
11143
# File 'lib/models/porcelain.rb', line 11141

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11179
11180
11181
11182
11183
11184
11185
# File 'lib/models/porcelain.rb', line 11179

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end