Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
# File 'lib/models/porcelain.rb', line 10293

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10261
10262
10263
# File 'lib/models/porcelain.rb', line 10261

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10263
10264
10265
# File 'lib/models/porcelain.rb', line 10263

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10265
10266
10267
# File 'lib/models/porcelain.rb', line 10265

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10267
10268
10269
# File 'lib/models/porcelain.rb', line 10267

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10269
10270
10271
# File 'lib/models/porcelain.rb', line 10269

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



10271
10272
10273
# File 'lib/models/porcelain.rb', line 10271

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



10273
10274
10275
# File 'lib/models/porcelain.rb', line 10273

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



10275
10276
10277
# File 'lib/models/porcelain.rb', line 10275

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



10277
10278
10279
# File 'lib/models/porcelain.rb', line 10277

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10279
10280
10281
# File 'lib/models/porcelain.rb', line 10279

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10281
10282
10283
# File 'lib/models/porcelain.rb', line 10281

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10283
10284
10285
# File 'lib/models/porcelain.rb', line 10283

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10285
10286
10287
# File 'lib/models/porcelain.rb', line 10285

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10287
10288
10289
# File 'lib/models/porcelain.rb', line 10287

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10289
10290
10291
# File 'lib/models/porcelain.rb', line 10289

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10291
10292
10293
# File 'lib/models/porcelain.rb', line 10291

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10329
10330
10331
10332
10333
10334
10335
# File 'lib/models/porcelain.rb', line 10329

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end