Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



10217
10218
10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
10241
10242
10243
10244
10245
10246
10247
10248
10249
10250
10251
# File 'lib/models/porcelain.rb', line 10217

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10185
10186
10187
# File 'lib/models/porcelain.rb', line 10185

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10187
10188
10189
# File 'lib/models/porcelain.rb', line 10187

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10189
10190
10191
# File 'lib/models/porcelain.rb', line 10189

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10191
10192
10193
# File 'lib/models/porcelain.rb', line 10191

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10193
10194
10195
# File 'lib/models/porcelain.rb', line 10193

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



10195
10196
10197
# File 'lib/models/porcelain.rb', line 10195

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



10197
10198
10199
# File 'lib/models/porcelain.rb', line 10197

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



10199
10200
10201
# File 'lib/models/porcelain.rb', line 10199

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



10201
10202
10203
# File 'lib/models/porcelain.rb', line 10201

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10203
10204
10205
# File 'lib/models/porcelain.rb', line 10203

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10205
10206
10207
# File 'lib/models/porcelain.rb', line 10205

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10207
10208
10209
# File 'lib/models/porcelain.rb', line 10207

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10209
10210
10211
# File 'lib/models/porcelain.rb', line 10209

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10211
10212
10213
# File 'lib/models/porcelain.rb', line 10211

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10213
10214
10215
# File 'lib/models/porcelain.rb', line 10213

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10215
10216
10217
# File 'lib/models/porcelain.rb', line 10215

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10253
10254
10255
10256
10257
10258
10259
# File 'lib/models/porcelain.rb', line 10253

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end