Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
10148
10149
10150
10151
10152
10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
# File 'lib/models/porcelain.rb', line 10138

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10106
10107
10108
# File 'lib/models/porcelain.rb', line 10106

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10108
10109
10110
# File 'lib/models/porcelain.rb', line 10108

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10110
10111
10112
# File 'lib/models/porcelain.rb', line 10110

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10112
10113
10114
# File 'lib/models/porcelain.rb', line 10112

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10114
10115
10116
# File 'lib/models/porcelain.rb', line 10114

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



10116
10117
10118
# File 'lib/models/porcelain.rb', line 10116

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



10118
10119
10120
# File 'lib/models/porcelain.rb', line 10118

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



10120
10121
10122
# File 'lib/models/porcelain.rb', line 10120

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



10122
10123
10124
# File 'lib/models/porcelain.rb', line 10122

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10124
10125
10126
# File 'lib/models/porcelain.rb', line 10124

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10126
10127
10128
# File 'lib/models/porcelain.rb', line 10126

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10128
10129
10130
# File 'lib/models/porcelain.rb', line 10128

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10130
10131
10132
# File 'lib/models/porcelain.rb', line 10130

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10132
10133
10134
# File 'lib/models/porcelain.rb', line 10132

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10134
10135
10136
# File 'lib/models/porcelain.rb', line 10134

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10136
10137
10138
# File 'lib/models/porcelain.rb', line 10136

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10174
10175
10176
10177
10178
10179
10180
# File 'lib/models/porcelain.rb', line 10174

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end