Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



10063
10064
10065
10066
10067
10068
10069
10070
10071
10072
10073
10074
10075
10076
10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
10090
10091
10092
10093
10094
10095
10096
10097
# File 'lib/models/porcelain.rb', line 10063

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10031
10032
10033
# File 'lib/models/porcelain.rb', line 10031

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10033
10034
10035
# File 'lib/models/porcelain.rb', line 10033

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10035
10036
10037
# File 'lib/models/porcelain.rb', line 10035

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10037
10038
10039
# File 'lib/models/porcelain.rb', line 10037

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10039
10040
10041
# File 'lib/models/porcelain.rb', line 10039

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



10041
10042
10043
# File 'lib/models/porcelain.rb', line 10041

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



10043
10044
10045
# File 'lib/models/porcelain.rb', line 10043

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



10045
10046
10047
# File 'lib/models/porcelain.rb', line 10045

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



10047
10048
10049
# File 'lib/models/porcelain.rb', line 10047

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10049
10050
10051
# File 'lib/models/porcelain.rb', line 10049

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10051
10052
10053
# File 'lib/models/porcelain.rb', line 10051

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10053
10054
10055
# File 'lib/models/porcelain.rb', line 10053

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10055
10056
10057
# File 'lib/models/porcelain.rb', line 10055

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10057
10058
10059
# File 'lib/models/porcelain.rb', line 10057

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10059
10060
10061
# File 'lib/models/porcelain.rb', line 10059

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10061
10062
10063
# File 'lib/models/porcelain.rb', line 10061

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10099
10100
10101
10102
10103
10104
10105
# File 'lib/models/porcelain.rb', line 10099

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end