Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



9700
9701
9702
9703
9704
9705
9706
9707
9708
9709
9710
9711
9712
9713
9714
9715
9716
9717
9718
9719
9720
9721
9722
9723
9724
9725
9726
9727
9728
9729
9730
9731
9732
9733
9734
# File 'lib/models/porcelain.rb', line 9700

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9668
9669
9670
# File 'lib/models/porcelain.rb', line 9668

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9670
9671
9672
# File 'lib/models/porcelain.rb', line 9670

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9672
9673
9674
# File 'lib/models/porcelain.rb', line 9672

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9674
9675
9676
# File 'lib/models/porcelain.rb', line 9674

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9676
9677
9678
# File 'lib/models/porcelain.rb', line 9676

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



9678
9679
9680
# File 'lib/models/porcelain.rb', line 9678

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



9680
9681
9682
# File 'lib/models/porcelain.rb', line 9680

def identity_set_id
  @identity_set_id
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



9682
9683
9684
# File 'lib/models/porcelain.rb', line 9682

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



9684
9685
9686
# File 'lib/models/porcelain.rb', line 9684

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9686
9687
9688
# File 'lib/models/porcelain.rb', line 9686

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9688
9689
9690
# File 'lib/models/porcelain.rb', line 9688

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9690
9691
9692
# File 'lib/models/porcelain.rb', line 9690

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9692
9693
9694
# File 'lib/models/porcelain.rb', line 9692

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9694
9695
9696
# File 'lib/models/porcelain.rb', line 9694

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9696
9697
9698
# File 'lib/models/porcelain.rb', line 9696

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9698
9699
9700
# File 'lib/models/porcelain.rb', line 9698

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9736
9737
9738
9739
9740
9741
9742
# File 'lib/models/porcelain.rb', line 9736

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end