Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



9451
9452
9453
9454
9455
9456
9457
9458
9459
9460
9461
9462
9463
9464
9465
9466
9467
9468
9469
9470
9471
9472
9473
9474
9475
9476
9477
9478
9479
9480
9481
9482
9483
# File 'lib/models/porcelain.rb', line 9451

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9421
9422
9423
# File 'lib/models/porcelain.rb', line 9421

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9423
9424
9425
# File 'lib/models/porcelain.rb', line 9423

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9425
9426
9427
# File 'lib/models/porcelain.rb', line 9425

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9427
9428
9429
# File 'lib/models/porcelain.rb', line 9427

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9429
9430
9431
# File 'lib/models/porcelain.rb', line 9429

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



9431
9432
9433
# File 'lib/models/porcelain.rb', line 9431

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



9433
9434
9435
# File 'lib/models/porcelain.rb', line 9433

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



9435
9436
9437
# File 'lib/models/porcelain.rb', line 9435

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9437
9438
9439
# File 'lib/models/porcelain.rb', line 9437

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9439
9440
9441
# File 'lib/models/porcelain.rb', line 9439

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9441
9442
9443
# File 'lib/models/porcelain.rb', line 9441

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9443
9444
9445
# File 'lib/models/porcelain.rb', line 9443

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9445
9446
9447
# File 'lib/models/porcelain.rb', line 9445

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9447
9448
9449
# File 'lib/models/porcelain.rb', line 9447

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9449
9450
9451
# File 'lib/models/porcelain.rb', line 9449

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9485
9486
9487
9488
9489
9490
9491
# File 'lib/models/porcelain.rb', line 9485

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end