Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



9380
9381
9382
9383
9384
9385
9386
9387
9388
9389
9390
9391
9392
9393
9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
# File 'lib/models/porcelain.rb', line 9380

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9350
9351
9352
# File 'lib/models/porcelain.rb', line 9350

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9352
9353
9354
# File 'lib/models/porcelain.rb', line 9352

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9354
9355
9356
# File 'lib/models/porcelain.rb', line 9354

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9356
9357
9358
# File 'lib/models/porcelain.rb', line 9356

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9358
9359
9360
# File 'lib/models/porcelain.rb', line 9358

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



9360
9361
9362
# File 'lib/models/porcelain.rb', line 9360

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



9362
9363
9364
# File 'lib/models/porcelain.rb', line 9362

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



9364
9365
9366
# File 'lib/models/porcelain.rb', line 9364

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9366
9367
9368
# File 'lib/models/porcelain.rb', line 9366

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9368
9369
9370
# File 'lib/models/porcelain.rb', line 9368

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9370
9371
9372
# File 'lib/models/porcelain.rb', line 9370

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9372
9373
9374
# File 'lib/models/porcelain.rb', line 9372

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9374
9375
9376
# File 'lib/models/porcelain.rb', line 9374

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9376
9377
9378
# File 'lib/models/porcelain.rb', line 9376

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9378
9379
9380
# File 'lib/models/porcelain.rb', line 9378

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9414
9415
9416
9417
9418
9419
9420
# File 'lib/models/porcelain.rb', line 9414

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end