Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
9325
9326
9327
9328
9329
9330
9331
9332
9333
9334
9335
# File 'lib/models/porcelain.rb', line 9303

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9273
9274
9275
# File 'lib/models/porcelain.rb', line 9273

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9275
9276
9277
# File 'lib/models/porcelain.rb', line 9275

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9277
9278
9279
# File 'lib/models/porcelain.rb', line 9277

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9279
9280
9281
# File 'lib/models/porcelain.rb', line 9279

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9281
9282
9283
# File 'lib/models/porcelain.rb', line 9281

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



9283
9284
9285
# File 'lib/models/porcelain.rb', line 9283

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



9285
9286
9287
# File 'lib/models/porcelain.rb', line 9285

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



9287
9288
9289
# File 'lib/models/porcelain.rb', line 9287

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9289
9290
9291
# File 'lib/models/porcelain.rb', line 9289

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9291
9292
9293
# File 'lib/models/porcelain.rb', line 9291

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9293
9294
9295
# File 'lib/models/porcelain.rb', line 9293

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9295
9296
9297
# File 'lib/models/porcelain.rb', line 9295

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9297
9298
9299
# File 'lib/models/porcelain.rb', line 9297

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9299
9300
9301
# File 'lib/models/porcelain.rb', line 9299

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9301
9302
9303
# File 'lib/models/porcelain.rb', line 9301

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9337
9338
9339
9340
9341
9342
9343
# File 'lib/models/porcelain.rb', line 9337

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end