Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
# File 'lib/models/porcelain.rb', line 9033

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9005
9006
9007
# File 'lib/models/porcelain.rb', line 9005

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9007
9008
9009
# File 'lib/models/porcelain.rb', line 9007

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9009
9010
9011
# File 'lib/models/porcelain.rb', line 9009

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9011
9012
9013
# File 'lib/models/porcelain.rb', line 9011

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9013
9014
9015
# File 'lib/models/porcelain.rb', line 9013

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



9015
9016
9017
# File 'lib/models/porcelain.rb', line 9015

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



9017
9018
9019
# File 'lib/models/porcelain.rb', line 9017

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



9019
9020
9021
# File 'lib/models/porcelain.rb', line 9019

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9021
9022
9023
# File 'lib/models/porcelain.rb', line 9021

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9023
9024
9025
# File 'lib/models/porcelain.rb', line 9023

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9025
9026
9027
# File 'lib/models/porcelain.rb', line 9025

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9027
9028
9029
# File 'lib/models/porcelain.rb', line 9027

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9029
9030
9031
# File 'lib/models/porcelain.rb', line 9029

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9031
9032
9033
# File 'lib/models/porcelain.rb', line 9031

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9065
9066
9067
9068
9069
9070
9071
# File 'lib/models/porcelain.rb', line 9065

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end