Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



8860
8861
8862
8863
8864
8865
8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
8890
# File 'lib/models/porcelain.rb', line 8860

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8832
8833
8834
# File 'lib/models/porcelain.rb', line 8832

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8834
8835
8836
# File 'lib/models/porcelain.rb', line 8834

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8836
8837
8838
# File 'lib/models/porcelain.rb', line 8836

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8838
8839
8840
# File 'lib/models/porcelain.rb', line 8838

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8840
8841
8842
# File 'lib/models/porcelain.rb', line 8840

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



8842
8843
8844
# File 'lib/models/porcelain.rb', line 8842

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



8844
8845
8846
# File 'lib/models/porcelain.rb', line 8844

def identity_set_id
  @identity_set_id
end

#nameObject

Unique human-readable name of the Resource.



8846
8847
8848
# File 'lib/models/porcelain.rb', line 8846

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8848
8849
8850
# File 'lib/models/porcelain.rb', line 8848

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8850
8851
8852
# File 'lib/models/porcelain.rb', line 8850

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8852
8853
8854
# File 'lib/models/porcelain.rb', line 8852

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8854
8855
8856
# File 'lib/models/porcelain.rb', line 8854

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8856
8857
8858
# File 'lib/models/porcelain.rb', line 8856

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8858
8859
8860
# File 'lib/models/porcelain.rb', line 8858

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8892
8893
8894
8895
8896
8897
8898
# File 'lib/models/porcelain.rb', line 8892

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end