Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
# File 'lib/models/porcelain.rb', line 7923

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7895
7896
7897
# File 'lib/models/porcelain.rb', line 7895

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7897
7898
7899
# File 'lib/models/porcelain.rb', line 7897

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7899
7900
7901
# File 'lib/models/porcelain.rb', line 7899

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7901
7902
7903
# File 'lib/models/porcelain.rb', line 7901

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7903
7904
7905
# File 'lib/models/porcelain.rb', line 7903

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7905
7906
7907
# File 'lib/models/porcelain.rb', line 7905

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7907
7908
7909
# File 'lib/models/porcelain.rb', line 7907

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7909
7910
7911
# File 'lib/models/porcelain.rb', line 7909

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



7911
7912
7913
# File 'lib/models/porcelain.rb', line 7911

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



7913
7914
7915
# File 'lib/models/porcelain.rb', line 7913

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7915
7916
7917
# File 'lib/models/porcelain.rb', line 7915

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7917
7918
7919
# File 'lib/models/porcelain.rb', line 7917

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7919
7920
7921
# File 'lib/models/porcelain.rb', line 7919

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7921
7922
7923
# File 'lib/models/porcelain.rb', line 7921

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7955
7956
7957
7958
7959
7960
7961
# File 'lib/models/porcelain.rb', line 7955

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end