Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
7298
7299
7300
7301
# File 'lib/models/porcelain.rb', line 7271

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7243
7244
7245
# File 'lib/models/porcelain.rb', line 7243

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7245
7246
7247
# File 'lib/models/porcelain.rb', line 7245

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7247
7248
7249
# File 'lib/models/porcelain.rb', line 7247

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7249
7250
7251
# File 'lib/models/porcelain.rb', line 7249

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7251
7252
7253
# File 'lib/models/porcelain.rb', line 7251

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7253
7254
7255
# File 'lib/models/porcelain.rb', line 7253

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7255
7256
7257
# File 'lib/models/porcelain.rb', line 7255

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7257
7258
7259
# File 'lib/models/porcelain.rb', line 7257

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



7259
7260
7261
# File 'lib/models/porcelain.rb', line 7259

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



7261
7262
7263
# File 'lib/models/porcelain.rb', line 7261

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7263
7264
7265
# File 'lib/models/porcelain.rb', line 7263

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7265
7266
7267
# File 'lib/models/porcelain.rb', line 7265

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7267
7268
7269
# File 'lib/models/porcelain.rb', line 7267

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7269
7270
7271
# File 'lib/models/porcelain.rb', line 7269

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7303
7304
7305
7306
7307
7308
7309
# File 'lib/models/porcelain.rb', line 7303

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end