Class: SDM::RDPCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, dc_hostnames: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, lock_required: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, server_fqdn: nil, sid: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDPCert

Returns a new instance of RDPCert.



14818
14819
14820
14821
14822
14823
14824
14825
14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
14853
14854
14855
14856
14857
14858
# File 'lib/models/porcelain.rb', line 14818

def initialize(
  bind_interface: nil,
  dc_hostnames: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  server_fqdn: nil,
  sid: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @dc_hostnames = dc_hostnames == nil ? "" : dc_hostnames
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_fqdn = server_fqdn == nil ? "" : server_fqdn
  @sid = sid == nil ? "" : sid
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14780
14781
14782
# File 'lib/models/porcelain.rb', line 14780

def bind_interface
  @bind_interface
end

#dc_hostnames ⇒ Object

Comma-separated list of Active Directory Domain Controller hostnames. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), and for LDAPS SID resolution for strong certificate mapping in full enforcement mode when the identity alias does not specify a SID. Unused for Entra ID.



14782
14783
14784
# File 'lib/models/porcelain.rb', line 14782

def dc_hostnames
  @dc_hostnames
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



14784
14785
14786
# File 'lib/models/porcelain.rb', line 14784

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



14786
14787
14788
# File 'lib/models/porcelain.rb', line 14786

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



14788
14789
14790
# File 'lib/models/porcelain.rb', line 14788

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



14790
14791
14792
# File 'lib/models/porcelain.rb', line 14790

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

Username of the AD service account for health checks, and LDAPS SID resolution if necessary. Required for on-premises AD environments, unused for Entra ID.



14792
14793
14794
# File 'lib/models/porcelain.rb', line 14792

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



14794
14795
14796
# File 'lib/models/porcelain.rb', line 14794

def identity_set_id
  @identity_set_id
end

#lock_required ⇒ Object

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



14796
14797
14798
# File 'lib/models/porcelain.rb', line 14796

def lock_required
  @lock_required
end

#name ⇒ Object

Unique human-readable name of the Resource.



14798
14799
14800
# File 'lib/models/porcelain.rb', line 14798

def name
  @name
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



14800
14801
14802
# File 'lib/models/porcelain.rb', line 14800

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14802
14803
14804
# File 'lib/models/porcelain.rb', line 14802

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



14804
14805
14806
# File 'lib/models/porcelain.rb', line 14804

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



14806
14807
14808
# File 'lib/models/porcelain.rb', line 14806

def secret_store_id
  @secret_store_id
end

#server_fqdn ⇒ Object

Fully-qualified DNS name of the target Windows server, including the AD domain. Must match the Service Principal Name (SPN) of the server in AD. Required in on-premises AD environments for Kerberos Network Level Authentication (NLA), unused for Entra ID.



14808
14809
14810
# File 'lib/models/porcelain.rb', line 14808

def server_fqdn
  @server_fqdn
end

#sid ⇒ Object

Windows Security Identifier (SID) of the configured Username, or AD service account if using LDAPS SID resolution. Required in on-premises AD environments for strong certificate mapping in full enforcement mode, unused for Entra ID.



14810
14811
14812
# File 'lib/models/porcelain.rb', line 14810

def sid
  @sid
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14812
14813
14814
# File 'lib/models/porcelain.rb', line 14812

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



14814
14815
14816
# File 'lib/models/porcelain.rb', line 14814

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



14816
14817
14818
# File 'lib/models/porcelain.rb', line 14816

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14860
14861
14862
14863
14864
14865
14866
# File 'lib/models/porcelain.rb', line 14860

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end