Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



14845
14846
14847
14848
14849
14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
14862
14863
14864
14865
14866
14867
14868
14869
14870
14871
14872
14873
14874
14875
14876
14877
14878
14879
14880
14881
# File 'lib/models/porcelain.rb', line 14845

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14811
14812
14813
# File 'lib/models/porcelain.rb', line 14811

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14813
14814
14815
# File 'lib/models/porcelain.rb', line 14813

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14815
14816
14817
# File 'lib/models/porcelain.rb', line 14815

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14817
14818
14819
# File 'lib/models/porcelain.rb', line 14817

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14819
14820
14821
# File 'lib/models/porcelain.rb', line 14819

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14821
14822
14823
# File 'lib/models/porcelain.rb', line 14821

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14823
14824
14825
# File 'lib/models/porcelain.rb', line 14823

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14825
14826
14827
# File 'lib/models/porcelain.rb', line 14825

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14827
14828
14829
# File 'lib/models/porcelain.rb', line 14827

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14829
14830
14831
# File 'lib/models/porcelain.rb', line 14829

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14831
14832
14833
# File 'lib/models/porcelain.rb', line 14831

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14833
14834
14835
# File 'lib/models/porcelain.rb', line 14833

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14835
14836
14837
# File 'lib/models/porcelain.rb', line 14835

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14837
14838
14839
# File 'lib/models/porcelain.rb', line 14837

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14839
14840
14841
# File 'lib/models/porcelain.rb', line 14839

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14841
14842
14843
# File 'lib/models/porcelain.rb', line 14841

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14843
14844
14845
# File 'lib/models/porcelain.rb', line 14843

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14883
14884
14885
14886
14887
14888
14889
# File 'lib/models/porcelain.rb', line 14883

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end