Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



14797
14798
14799
14800
14801
14802
14803
14804
14805
14806
14807
14808
14809
14810
14811
14812
14813
14814
14815
14816
14817
14818
14819
14820
14821
14822
14823
14824
14825
14826
14827
14828
14829
14830
14831
14832
14833
# File 'lib/models/porcelain.rb', line 14797

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14763
14764
14765
# File 'lib/models/porcelain.rb', line 14763

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14765
14766
14767
# File 'lib/models/porcelain.rb', line 14765

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14767
14768
14769
# File 'lib/models/porcelain.rb', line 14767

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14769
14770
14771
# File 'lib/models/porcelain.rb', line 14769

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14771
14772
14773
# File 'lib/models/porcelain.rb', line 14771

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14773
14774
14775
# File 'lib/models/porcelain.rb', line 14773

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14775
14776
14777
# File 'lib/models/porcelain.rb', line 14775

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14777
14778
14779
# File 'lib/models/porcelain.rb', line 14777

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14779
14780
14781
# File 'lib/models/porcelain.rb', line 14779

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14781
14782
14783
# File 'lib/models/porcelain.rb', line 14781

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14783
14784
14785
# File 'lib/models/porcelain.rb', line 14783

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14785
14786
14787
# File 'lib/models/porcelain.rb', line 14785

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14787
14788
14789
# File 'lib/models/porcelain.rb', line 14787

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14789
14790
14791
# File 'lib/models/porcelain.rb', line 14789

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14791
14792
14793
# File 'lib/models/porcelain.rb', line 14791

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14793
14794
14795
# File 'lib/models/porcelain.rb', line 14793

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14795
14796
14797
# File 'lib/models/porcelain.rb', line 14795

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14835
14836
14837
14838
14839
14840
14841
# File 'lib/models/porcelain.rb', line 14835

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end