Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



14717
14718
14719
14720
14721
14722
14723
14724
14725
14726
14727
14728
14729
14730
14731
14732
14733
14734
14735
14736
14737
14738
14739
14740
14741
14742
14743
14744
14745
14746
14747
14748
14749
14750
14751
14752
14753
# File 'lib/models/porcelain.rb', line 14717

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14683
14684
14685
# File 'lib/models/porcelain.rb', line 14683

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14685
14686
14687
# File 'lib/models/porcelain.rb', line 14685

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14687
14688
14689
# File 'lib/models/porcelain.rb', line 14687

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14689
14690
14691
# File 'lib/models/porcelain.rb', line 14689

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14691
14692
14693
# File 'lib/models/porcelain.rb', line 14691

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14693
14694
14695
# File 'lib/models/porcelain.rb', line 14693

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14695
14696
14697
# File 'lib/models/porcelain.rb', line 14695

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14697
14698
14699
# File 'lib/models/porcelain.rb', line 14697

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14699
14700
14701
# File 'lib/models/porcelain.rb', line 14699

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14701
14702
14703
# File 'lib/models/porcelain.rb', line 14701

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14703
14704
14705
# File 'lib/models/porcelain.rb', line 14703

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14705
14706
14707
# File 'lib/models/porcelain.rb', line 14705

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14707
14708
14709
# File 'lib/models/porcelain.rb', line 14707

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14709
14710
14711
# File 'lib/models/porcelain.rb', line 14709

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14711
14712
14713
# File 'lib/models/porcelain.rb', line 14711

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14713
14714
14715
# File 'lib/models/porcelain.rb', line 14713

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14715
14716
14717
# File 'lib/models/porcelain.rb', line 14715

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14755
14756
14757
14758
14759
14760
14761
# File 'lib/models/porcelain.rb', line 14755

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end