Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
14503
14504
14505
14506
14507
14508
14509
14510
14511
14512
14513
14514
14515
14516
14517
14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
# File 'lib/models/porcelain.rb', line 14491

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14457
14458
14459
# File 'lib/models/porcelain.rb', line 14457

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14459
14460
14461
# File 'lib/models/porcelain.rb', line 14459

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14461
14462
14463
# File 'lib/models/porcelain.rb', line 14461

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14463
14464
14465
# File 'lib/models/porcelain.rb', line 14463

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14465
14466
14467
# File 'lib/models/porcelain.rb', line 14465

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14467
14468
14469
# File 'lib/models/porcelain.rb', line 14467

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14469
14470
14471
# File 'lib/models/porcelain.rb', line 14469

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14471
14472
14473
# File 'lib/models/porcelain.rb', line 14471

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14473
14474
14475
# File 'lib/models/porcelain.rb', line 14473

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14475
14476
14477
# File 'lib/models/porcelain.rb', line 14475

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14477
14478
14479
# File 'lib/models/porcelain.rb', line 14477

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14479
14480
14481
# File 'lib/models/porcelain.rb', line 14479

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14481
14482
14483
# File 'lib/models/porcelain.rb', line 14481

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14483
14484
14485
# File 'lib/models/porcelain.rb', line 14483

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14485
14486
14487
# File 'lib/models/porcelain.rb', line 14485

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14487
14488
14489
# File 'lib/models/porcelain.rb', line 14487

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14489
14490
14491
# File 'lib/models/porcelain.rb', line 14489

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14529
14530
14531
14532
14533
14534
14535
# File 'lib/models/porcelain.rb', line 14529

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end