Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



14098
14099
14100
14101
14102
14103
14104
14105
14106
14107
14108
14109
14110
14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
# File 'lib/models/porcelain.rb', line 14098

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14064
14065
14066
# File 'lib/models/porcelain.rb', line 14064

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14066
14067
14068
# File 'lib/models/porcelain.rb', line 14066

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14068
14069
14070
# File 'lib/models/porcelain.rb', line 14068

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14070
14071
14072
# File 'lib/models/porcelain.rb', line 14070

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14072
14073
14074
# File 'lib/models/porcelain.rb', line 14072

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14074
14075
14076
# File 'lib/models/porcelain.rb', line 14074

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14076
14077
14078
# File 'lib/models/porcelain.rb', line 14076

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14078
14079
14080
# File 'lib/models/porcelain.rb', line 14078

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14080
14081
14082
# File 'lib/models/porcelain.rb', line 14080

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14082
14083
14084
# File 'lib/models/porcelain.rb', line 14082

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14084
14085
14086
# File 'lib/models/porcelain.rb', line 14084

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14086
14087
14088
# File 'lib/models/porcelain.rb', line 14086

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14088
14089
14090
# File 'lib/models/porcelain.rb', line 14088

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14090
14091
14092
# File 'lib/models/porcelain.rb', line 14090

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14092
14093
14094
# File 'lib/models/porcelain.rb', line 14092

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14094
14095
14096
# File 'lib/models/porcelain.rb', line 14094

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14096
14097
14098
# File 'lib/models/porcelain.rb', line 14096

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14136
14137
14138
14139
14140
14141
14142
# File 'lib/models/porcelain.rb', line 14136

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end