Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



13796
13797
13798
13799
13800
13801
13802
13803
13804
13805
13806
13807
13808
13809
13810
13811
13812
13813
13814
13815
13816
13817
13818
13819
13820
13821
13822
13823
13824
13825
13826
13827
13828
13829
13830
13831
13832
# File 'lib/models/porcelain.rb', line 13796

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13762
13763
13764
# File 'lib/models/porcelain.rb', line 13762

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13764
13765
13766
# File 'lib/models/porcelain.rb', line 13764

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13766
13767
13768
# File 'lib/models/porcelain.rb', line 13766

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13768
13769
13770
# File 'lib/models/porcelain.rb', line 13768

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13770
13771
13772
# File 'lib/models/porcelain.rb', line 13770

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13772
13773
13774
# File 'lib/models/porcelain.rb', line 13772

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13774
13775
13776
# File 'lib/models/porcelain.rb', line 13774

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13776
13777
13778
# File 'lib/models/porcelain.rb', line 13776

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13778
13779
13780
# File 'lib/models/porcelain.rb', line 13778

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13780
13781
13782
# File 'lib/models/porcelain.rb', line 13780

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13782
13783
13784
# File 'lib/models/porcelain.rb', line 13782

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



13784
13785
13786
# File 'lib/models/porcelain.rb', line 13784

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



13786
13787
13788
# File 'lib/models/porcelain.rb', line 13786

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13788
13789
13790
# File 'lib/models/porcelain.rb', line 13788

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13790
13791
13792
# File 'lib/models/porcelain.rb', line 13790

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13792
13793
13794
# File 'lib/models/porcelain.rb', line 13792

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13794
13795
13796
# File 'lib/models/porcelain.rb', line 13794

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13834
13835
13836
13837
13838
13839
13840
# File 'lib/models/porcelain.rb', line 13834

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end