Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



13732
13733
13734
13735
13736
13737
13738
13739
13740
13741
13742
13743
13744
13745
13746
13747
13748
13749
13750
13751
13752
13753
13754
13755
13756
13757
13758
13759
13760
13761
13762
13763
13764
13765
13766
13767
13768
# File 'lib/models/porcelain.rb', line 13732

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13698
13699
13700
# File 'lib/models/porcelain.rb', line 13698

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



13700
13701
13702
# File 'lib/models/porcelain.rb', line 13700

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13702
13703
13704
# File 'lib/models/porcelain.rb', line 13702

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13704
13705
13706
# File 'lib/models/porcelain.rb', line 13704

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13706
13707
13708
# File 'lib/models/porcelain.rb', line 13706

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13708
13709
13710
# File 'lib/models/porcelain.rb', line 13708

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13710
13711
13712
# File 'lib/models/porcelain.rb', line 13710

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13712
13713
13714
# File 'lib/models/porcelain.rb', line 13712

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13714
13715
13716
# File 'lib/models/porcelain.rb', line 13714

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13716
13717
13718
# File 'lib/models/porcelain.rb', line 13716

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13718
13719
13720
# File 'lib/models/porcelain.rb', line 13718

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



13720
13721
13722
# File 'lib/models/porcelain.rb', line 13720

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



13722
13723
13724
# File 'lib/models/porcelain.rb', line 13722

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13724
13725
13726
# File 'lib/models/porcelain.rb', line 13724

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13726
13727
13728
# File 'lib/models/porcelain.rb', line 13726

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13728
13729
13730
# File 'lib/models/porcelain.rb', line 13728

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13730
13731
13732
# File 'lib/models/porcelain.rb', line 13730

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13770
13771
13772
13773
13774
13775
13776
# File 'lib/models/porcelain.rb', line 13770

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end