Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
11626
11627
11628
11629
11630
11631
11632
11633
11634
11635
11636
11637
11638
11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
# File 'lib/models/porcelain.rb', line 11615

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11581
11582
11583
# File 'lib/models/porcelain.rb', line 11581

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11583
11584
11585
# File 'lib/models/porcelain.rb', line 11583

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11585
11586
11587
# File 'lib/models/porcelain.rb', line 11585

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11587
11588
11589
# File 'lib/models/porcelain.rb', line 11587

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11589
11590
11591
# File 'lib/models/porcelain.rb', line 11589

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11591
11592
11593
# File 'lib/models/porcelain.rb', line 11591

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11593
11594
11595
# File 'lib/models/porcelain.rb', line 11593

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11595
11596
11597
# File 'lib/models/porcelain.rb', line 11595

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11597
11598
11599
# File 'lib/models/porcelain.rb', line 11597

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11599
11600
11601
# File 'lib/models/porcelain.rb', line 11599

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11601
11602
11603
# File 'lib/models/porcelain.rb', line 11601

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



11603
11604
11605
# File 'lib/models/porcelain.rb', line 11603

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



11605
11606
11607
# File 'lib/models/porcelain.rb', line 11605

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11607
11608
11609
# File 'lib/models/porcelain.rb', line 11607

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11609
11610
11611
# File 'lib/models/porcelain.rb', line 11609

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11611
11612
11613
# File 'lib/models/porcelain.rb', line 11611

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11613
11614
11615
# File 'lib/models/porcelain.rb', line 11613

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11653
11654
11655
11656
11657
11658
11659
# File 'lib/models/porcelain.rb', line 11653

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end