Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



11436
11437
11438
11439
11440
11441
11442
11443
11444
11445
11446
11447
11448
11449
11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
11461
11462
11463
11464
11465
11466
11467
11468
11469
11470
11471
11472
# File 'lib/models/porcelain.rb', line 11436

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11402
11403
11404
# File 'lib/models/porcelain.rb', line 11402

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11404
11405
11406
# File 'lib/models/porcelain.rb', line 11404

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11406
11407
11408
# File 'lib/models/porcelain.rb', line 11406

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11408
11409
11410
# File 'lib/models/porcelain.rb', line 11408

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11410
11411
11412
# File 'lib/models/porcelain.rb', line 11410

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11412
11413
11414
# File 'lib/models/porcelain.rb', line 11412

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11414
11415
11416
# File 'lib/models/porcelain.rb', line 11414

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11416
11417
11418
# File 'lib/models/porcelain.rb', line 11416

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11418
11419
11420
# File 'lib/models/porcelain.rb', line 11418

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11420
11421
11422
# File 'lib/models/porcelain.rb', line 11420

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11422
11423
11424
# File 'lib/models/porcelain.rb', line 11422

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



11424
11425
11426
# File 'lib/models/porcelain.rb', line 11424

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



11426
11427
11428
# File 'lib/models/porcelain.rb', line 11426

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11428
11429
11430
# File 'lib/models/porcelain.rb', line 11428

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11430
11431
11432
# File 'lib/models/porcelain.rb', line 11430

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11432
11433
11434
# File 'lib/models/porcelain.rb', line 11432

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11434
11435
11436
# File 'lib/models/porcelain.rb', line 11434

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11474
11475
11476
11477
11478
11479
11480
# File 'lib/models/porcelain.rb', line 11474

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end