Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



11368
11369
11370
11371
11372
11373
11374
11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
# File 'lib/models/porcelain.rb', line 11368

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11334
11335
11336
# File 'lib/models/porcelain.rb', line 11334

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11336
11337
11338
# File 'lib/models/porcelain.rb', line 11336

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11338
11339
11340
# File 'lib/models/porcelain.rb', line 11338

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11340
11341
11342
# File 'lib/models/porcelain.rb', line 11340

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11342
11343
11344
# File 'lib/models/porcelain.rb', line 11342

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11344
11345
11346
# File 'lib/models/porcelain.rb', line 11344

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11346
11347
11348
# File 'lib/models/porcelain.rb', line 11346

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11348
11349
11350
# File 'lib/models/porcelain.rb', line 11348

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11350
11351
11352
# File 'lib/models/porcelain.rb', line 11350

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11352
11353
11354
# File 'lib/models/porcelain.rb', line 11352

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11354
11355
11356
# File 'lib/models/porcelain.rb', line 11354

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



11356
11357
11358
# File 'lib/models/porcelain.rb', line 11356

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



11358
11359
11360
# File 'lib/models/porcelain.rb', line 11358

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11360
11361
11362
# File 'lib/models/porcelain.rb', line 11360

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11362
11363
11364
# File 'lib/models/porcelain.rb', line 11362

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11364
11365
11366
# File 'lib/models/porcelain.rb', line 11364

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11366
11367
11368
# File 'lib/models/porcelain.rb', line 11366

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11406
11407
11408
11409
11410
11411
11412
# File 'lib/models/porcelain.rb', line 11406

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end