Class: SDM::RDSPostgresIAM
- Inherits:
-
Object
- Object
- SDM::RDSPostgresIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM
constructor
A new instance of RDSPostgresIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM
Returns a new instance of RDSPostgresIAM.
11224 11225 11226 11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 11260 |
# File 'lib/models/porcelain.rb', line 11224 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11190 11191 11192 |
# File 'lib/models/porcelain.rb', line 11190 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11192 11193 11194 |
# File 'lib/models/porcelain.rb', line 11192 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11194 11195 11196 |
# File 'lib/models/porcelain.rb', line 11194 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11196 11197 11198 |
# File 'lib/models/porcelain.rb', line 11196 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11198 11199 11200 |
# File 'lib/models/porcelain.rb', line 11198 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11200 11201 11202 |
# File 'lib/models/porcelain.rb', line 11200 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11202 11203 11204 |
# File 'lib/models/porcelain.rb', line 11202 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
11204 11205 11206 |
# File 'lib/models/porcelain.rb', line 11204 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11206 11207 11208 |
# File 'lib/models/porcelain.rb', line 11206 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11208 11209 11210 |
# File 'lib/models/porcelain.rb', line 11208 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11210 11211 11212 |
# File 'lib/models/porcelain.rb', line 11210 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
11212 11213 11214 |
# File 'lib/models/porcelain.rb', line 11212 def region @region end |
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
11214 11215 11216 |
# File 'lib/models/porcelain.rb', line 11214 def role_assumption_arn @role_assumption_arn end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11216 11217 11218 |
# File 'lib/models/porcelain.rb', line 11216 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11218 11219 11220 |
# File 'lib/models/porcelain.rb', line 11218 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11220 11221 11222 |
# File 'lib/models/porcelain.rb', line 11220 def @tags end |
#username ⇒ Object
The username to authenticate with.
11222 11223 11224 |
# File 'lib/models/porcelain.rb', line 11222 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11262 11263 11264 11265 11266 11267 11268 |
# File 'lib/models/porcelain.rb', line 11262 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |