Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
10399
10400
10401
10402
10403
10404
10405
10406
10407
10408
10409
# File 'lib/models/porcelain.rb', line 10373

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10339
10340
10341
# File 'lib/models/porcelain.rb', line 10339

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10341
10342
10343
# File 'lib/models/porcelain.rb', line 10341

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10343
10344
10345
# File 'lib/models/porcelain.rb', line 10343

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10345
10346
10347
# File 'lib/models/porcelain.rb', line 10345

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10347
10348
10349
# File 'lib/models/porcelain.rb', line 10347

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10349
10350
10351
# File 'lib/models/porcelain.rb', line 10349

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10351
10352
10353
# File 'lib/models/porcelain.rb', line 10351

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10353
10354
10355
# File 'lib/models/porcelain.rb', line 10353

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10355
10356
10357
# File 'lib/models/porcelain.rb', line 10355

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10357
10358
10359
# File 'lib/models/porcelain.rb', line 10357

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10359
10360
10361
# File 'lib/models/porcelain.rb', line 10359

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10361
10362
10363
# File 'lib/models/porcelain.rb', line 10361

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10363
10364
10365
# File 'lib/models/porcelain.rb', line 10363

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10365
10366
10367
# File 'lib/models/porcelain.rb', line 10365

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10367
10368
10369
# File 'lib/models/porcelain.rb', line 10367

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10369
10370
10371
# File 'lib/models/porcelain.rb', line 10369

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10371
10372
10373
# File 'lib/models/porcelain.rb', line 10371

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10411
10412
10413
10414
10415
10416
10417
# File 'lib/models/porcelain.rb', line 10411

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end