Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
10331
10332
10333
10334
# File 'lib/models/porcelain.rb', line 10298

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10264
10265
10266
# File 'lib/models/porcelain.rb', line 10264

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10266
10267
10268
# File 'lib/models/porcelain.rb', line 10266

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10268
10269
10270
# File 'lib/models/porcelain.rb', line 10268

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10270
10271
10272
# File 'lib/models/porcelain.rb', line 10270

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10272
10273
10274
# File 'lib/models/porcelain.rb', line 10272

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10274
10275
10276
# File 'lib/models/porcelain.rb', line 10274

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10276
10277
10278
# File 'lib/models/porcelain.rb', line 10276

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10278
10279
10280
# File 'lib/models/porcelain.rb', line 10278

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10280
10281
10282
# File 'lib/models/porcelain.rb', line 10280

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10282
10283
10284
# File 'lib/models/porcelain.rb', line 10282

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10284
10285
10286
# File 'lib/models/porcelain.rb', line 10284

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10286
10287
10288
# File 'lib/models/porcelain.rb', line 10286

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10288
10289
10290
# File 'lib/models/porcelain.rb', line 10288

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10290
10291
10292
# File 'lib/models/porcelain.rb', line 10290

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10292
10293
10294
# File 'lib/models/porcelain.rb', line 10292

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10294
10295
10296
# File 'lib/models/porcelain.rb', line 10294

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10296
10297
10298
# File 'lib/models/porcelain.rb', line 10296

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10336
10337
10338
10339
10340
10341
10342
# File 'lib/models/porcelain.rb', line 10336

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end