Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



10215
10216
10217
10218
10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
10241
10242
10243
10244
10245
10246
10247
10248
10249
10250
10251
# File 'lib/models/porcelain.rb', line 10215

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10181
10182
10183
# File 'lib/models/porcelain.rb', line 10181

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10183
10184
10185
# File 'lib/models/porcelain.rb', line 10183

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10185
10186
10187
# File 'lib/models/porcelain.rb', line 10185

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10187
10188
10189
# File 'lib/models/porcelain.rb', line 10187

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10189
10190
10191
# File 'lib/models/porcelain.rb', line 10189

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10191
10192
10193
# File 'lib/models/porcelain.rb', line 10191

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10193
10194
10195
# File 'lib/models/porcelain.rb', line 10193

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10195
10196
10197
# File 'lib/models/porcelain.rb', line 10195

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10197
10198
10199
# File 'lib/models/porcelain.rb', line 10197

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10199
10200
10201
# File 'lib/models/porcelain.rb', line 10199

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10201
10202
10203
# File 'lib/models/porcelain.rb', line 10201

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10203
10204
10205
# File 'lib/models/porcelain.rb', line 10203

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10205
10206
10207
# File 'lib/models/porcelain.rb', line 10205

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10207
10208
10209
# File 'lib/models/porcelain.rb', line 10207

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10209
10210
10211
# File 'lib/models/porcelain.rb', line 10209

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10211
10212
10213
# File 'lib/models/porcelain.rb', line 10211

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10213
10214
10215
# File 'lib/models/porcelain.rb', line 10213

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10253
10254
10255
10256
10257
10258
10259
# File 'lib/models/porcelain.rb', line 10253

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end