Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



10145
10146
10147
10148
10149
10150
10151
10152
10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
10171
10172
10173
10174
10175
10176
10177
10178
10179
10180
10181
# File 'lib/models/porcelain.rb', line 10145

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10111
10112
10113
# File 'lib/models/porcelain.rb', line 10111

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10113
10114
10115
# File 'lib/models/porcelain.rb', line 10113

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10115
10116
10117
# File 'lib/models/porcelain.rb', line 10115

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10117
10118
10119
# File 'lib/models/porcelain.rb', line 10117

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10119
10120
10121
# File 'lib/models/porcelain.rb', line 10119

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10121
10122
10123
# File 'lib/models/porcelain.rb', line 10121

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10123
10124
10125
# File 'lib/models/porcelain.rb', line 10123

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10125
10126
10127
# File 'lib/models/porcelain.rb', line 10125

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10127
10128
10129
# File 'lib/models/porcelain.rb', line 10127

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10129
10130
10131
# File 'lib/models/porcelain.rb', line 10129

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10131
10132
10133
# File 'lib/models/porcelain.rb', line 10131

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10133
10134
10135
# File 'lib/models/porcelain.rb', line 10133

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10135
10136
10137
# File 'lib/models/porcelain.rb', line 10135

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10137
10138
10139
# File 'lib/models/porcelain.rb', line 10137

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10139
10140
10141
# File 'lib/models/porcelain.rb', line 10139

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10141
10142
10143
# File 'lib/models/porcelain.rb', line 10141

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10143
10144
10145
# File 'lib/models/porcelain.rb', line 10143

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10183
10184
10185
10186
10187
10188
10189
# File 'lib/models/porcelain.rb', line 10183

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end