Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
10090
10091
10092
10093
10094
10095
10096
10097
10098
10099
10100
10101
10102
10103
10104
10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
# File 'lib/models/porcelain.rb', line 10078

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10044
10045
10046
# File 'lib/models/porcelain.rb', line 10044

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10046
10047
10048
# File 'lib/models/porcelain.rb', line 10046

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10048
10049
10050
# File 'lib/models/porcelain.rb', line 10048

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10050
10051
10052
# File 'lib/models/porcelain.rb', line 10050

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10052
10053
10054
# File 'lib/models/porcelain.rb', line 10052

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10054
10055
10056
# File 'lib/models/porcelain.rb', line 10054

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10056
10057
10058
# File 'lib/models/porcelain.rb', line 10056

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10058
10059
10060
# File 'lib/models/porcelain.rb', line 10058

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10060
10061
10062
# File 'lib/models/porcelain.rb', line 10060

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10062
10063
10064
# File 'lib/models/porcelain.rb', line 10062

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10064
10065
10066
# File 'lib/models/porcelain.rb', line 10064

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10066
10067
10068
# File 'lib/models/porcelain.rb', line 10066

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10068
10069
10070
# File 'lib/models/porcelain.rb', line 10068

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10070
10071
10072
# File 'lib/models/porcelain.rb', line 10070

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10072
10073
10074
# File 'lib/models/porcelain.rb', line 10072

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10074
10075
10076
# File 'lib/models/porcelain.rb', line 10074

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10076
10077
10078
# File 'lib/models/porcelain.rb', line 10076

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10116
10117
10118
10119
10120
10121
10122
# File 'lib/models/porcelain.rb', line 10116

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end