Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
9815
9816
9817
# File 'lib/models/porcelain.rb', line 9781

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9747
9748
9749
# File 'lib/models/porcelain.rb', line 9747

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9749
9750
9751
# File 'lib/models/porcelain.rb', line 9749

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9751
9752
9753
# File 'lib/models/porcelain.rb', line 9751

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9753
9754
9755
# File 'lib/models/porcelain.rb', line 9753

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9755
9756
9757
# File 'lib/models/porcelain.rb', line 9755

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9757
9758
9759
# File 'lib/models/porcelain.rb', line 9757

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9759
9760
9761
# File 'lib/models/porcelain.rb', line 9759

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



9761
9762
9763
# File 'lib/models/porcelain.rb', line 9761

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9763
9764
9765
# File 'lib/models/porcelain.rb', line 9763

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9765
9766
9767
# File 'lib/models/porcelain.rb', line 9765

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9767
9768
9769
# File 'lib/models/porcelain.rb', line 9767

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



9769
9770
9771
# File 'lib/models/porcelain.rb', line 9769

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



9771
9772
9773
# File 'lib/models/porcelain.rb', line 9771

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9773
9774
9775
# File 'lib/models/porcelain.rb', line 9773

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9775
9776
9777
# File 'lib/models/porcelain.rb', line 9775

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9777
9778
9779
# File 'lib/models/porcelain.rb', line 9777

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9779
9780
9781
# File 'lib/models/porcelain.rb', line 9779

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9819
9820
9821
9822
9823
9824
9825
# File 'lib/models/porcelain.rb', line 9819

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end