Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
9545
9546
9547
9548
9549
9550
9551
9552
9553
9554
9555
9556
9557
9558
9559
9560
9561
9562
9563
9564
9565
9566
# File 'lib/models/porcelain.rb', line 9530

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9496
9497
9498
# File 'lib/models/porcelain.rb', line 9496

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9498
9499
9500
# File 'lib/models/porcelain.rb', line 9498

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9500
9501
9502
# File 'lib/models/porcelain.rb', line 9500

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9502
9503
9504
# File 'lib/models/porcelain.rb', line 9502

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9504
9505
9506
# File 'lib/models/porcelain.rb', line 9504

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9506
9507
9508
# File 'lib/models/porcelain.rb', line 9506

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9508
9509
9510
# File 'lib/models/porcelain.rb', line 9508

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



9510
9511
9512
# File 'lib/models/porcelain.rb', line 9510

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9512
9513
9514
# File 'lib/models/porcelain.rb', line 9512

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9514
9515
9516
# File 'lib/models/porcelain.rb', line 9514

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9516
9517
9518
# File 'lib/models/porcelain.rb', line 9516

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



9518
9519
9520
# File 'lib/models/porcelain.rb', line 9518

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



9520
9521
9522
# File 'lib/models/porcelain.rb', line 9520

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9522
9523
9524
# File 'lib/models/porcelain.rb', line 9522

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9524
9525
9526
# File 'lib/models/porcelain.rb', line 9524

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9526
9527
9528
# File 'lib/models/porcelain.rb', line 9526

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9528
9529
9530
# File 'lib/models/porcelain.rb', line 9528

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9568
9569
9570
9571
9572
9573
9574
# File 'lib/models/porcelain.rb', line 9568

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end