Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



8935
8936
8937
8938
8939
8940
8941
8942
8943
8944
8945
8946
8947
8948
8949
8950
8951
8952
8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
8967
8968
8969
# File 'lib/models/porcelain.rb', line 8935

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8903
8904
8905
# File 'lib/models/porcelain.rb', line 8903

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8905
8906
8907
# File 'lib/models/porcelain.rb', line 8905

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8907
8908
8909
# File 'lib/models/porcelain.rb', line 8907

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8909
8910
8911
# File 'lib/models/porcelain.rb', line 8909

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8911
8912
8913
# File 'lib/models/porcelain.rb', line 8911

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8913
8914
8915
# File 'lib/models/porcelain.rb', line 8913

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8915
8916
8917
# File 'lib/models/porcelain.rb', line 8915

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8917
8918
8919
# File 'lib/models/porcelain.rb', line 8917

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8919
8920
8921
# File 'lib/models/porcelain.rb', line 8919

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8921
8922
8923
# File 'lib/models/porcelain.rb', line 8921

def port_override
  @port_override
end

#regionObject

The AWS region to connect to.



8923
8924
8925
# File 'lib/models/porcelain.rb', line 8923

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



8925
8926
8927
# File 'lib/models/porcelain.rb', line 8925

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8927
8928
8929
# File 'lib/models/porcelain.rb', line 8927

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8929
8930
8931
# File 'lib/models/porcelain.rb', line 8929

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8931
8932
8933
# File 'lib/models/porcelain.rb', line 8931

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8933
8934
8935
# File 'lib/models/porcelain.rb', line 8933

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8971
8972
8973
8974
8975
8976
8977
# File 'lib/models/porcelain.rb', line 8971

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end