Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
# File 'lib/models/porcelain.rb', line 7346

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7314
7315
7316
# File 'lib/models/porcelain.rb', line 7314

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7316
7317
7318
# File 'lib/models/porcelain.rb', line 7316

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7318
7319
7320
# File 'lib/models/porcelain.rb', line 7318

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7320
7321
7322
# File 'lib/models/porcelain.rb', line 7320

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7322
7323
7324
# File 'lib/models/porcelain.rb', line 7322

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7324
7325
7326
# File 'lib/models/porcelain.rb', line 7324

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7326
7327
7328
# File 'lib/models/porcelain.rb', line 7326

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



7328
7329
7330
# File 'lib/models/porcelain.rb', line 7328

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7330
7331
7332
# File 'lib/models/porcelain.rb', line 7330

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7332
7333
7334
# File 'lib/models/porcelain.rb', line 7332

def port_override
  @port_override
end

#regionObject

The AWS region to connect to.



7334
7335
7336
# File 'lib/models/porcelain.rb', line 7334

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



7336
7337
7338
# File 'lib/models/porcelain.rb', line 7336

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7338
7339
7340
# File 'lib/models/porcelain.rb', line 7338

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7340
7341
7342
# File 'lib/models/porcelain.rb', line 7340

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7342
7343
7344
# File 'lib/models/porcelain.rb', line 7342

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7344
7345
7346
# File 'lib/models/porcelain.rb', line 7344

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7382
7383
7384
7385
7386
7387
7388
# File 'lib/models/porcelain.rb', line 7382

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end