Class: SDM::RDSPostgresIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ RDSPostgresIAM

Returns a new instance of RDSPostgresIAM.



14905
14906
14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
14940
14941
# File 'lib/models/porcelain.rb', line 14905

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14871
14872
14873
# File 'lib/models/porcelain.rb', line 14871

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14873
14874
14875
# File 'lib/models/porcelain.rb', line 14873

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



14875
14876
14877
# File 'lib/models/porcelain.rb', line 14875

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



14877
14878
14879
# File 'lib/models/porcelain.rb', line 14877

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



14879
14880
14881
# File 'lib/models/porcelain.rb', line 14879

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



14881
14882
14883
# File 'lib/models/porcelain.rb', line 14881

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



14883
14884
14885
# File 'lib/models/porcelain.rb', line 14883

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14885
14886
14887
# File 'lib/models/porcelain.rb', line 14885

def override_database
  @override_database
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



14887
14888
14889
# File 'lib/models/porcelain.rb', line 14887

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14889
14890
14891
# File 'lib/models/porcelain.rb', line 14889

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



14891
14892
14893
# File 'lib/models/porcelain.rb', line 14891

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to connect to.



14893
14894
14895
# File 'lib/models/porcelain.rb', line 14893

def region
  @region
end

#role_assumption_arn ⇒ Object

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14895
14896
14897
# File 'lib/models/porcelain.rb', line 14895

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



14897
14898
14899
# File 'lib/models/porcelain.rb', line 14897

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14899
14900
14901
# File 'lib/models/porcelain.rb', line 14899

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



14901
14902
14903
# File 'lib/models/porcelain.rb', line 14901

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



14903
14904
14905
# File 'lib/models/porcelain.rb', line 14903

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14943
14944
14945
14946
14947
14948
14949
# File 'lib/models/porcelain.rb', line 14943

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end