Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
14940
14941
14942
14943
14944
14945
14946
14947
14948
14949
14950
14951
14952
14953
14954
14955
14956
# File 'lib/models/porcelain.rb', line 14924

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14894
14895
14896
# File 'lib/models/porcelain.rb', line 14894

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14896
14897
14898
# File 'lib/models/porcelain.rb', line 14896

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14898
14899
14900
# File 'lib/models/porcelain.rb', line 14898

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14900
14901
14902
# File 'lib/models/porcelain.rb', line 14900

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14902
14903
14904
# File 'lib/models/porcelain.rb', line 14902

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14904
14905
14906
# File 'lib/models/porcelain.rb', line 14904

def name
  @name
end

#passwordObject

The password to authenticate with.



14906
14907
14908
# File 'lib/models/porcelain.rb', line 14906

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14908
14909
14910
# File 'lib/models/porcelain.rb', line 14908

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14910
14911
14912
# File 'lib/models/porcelain.rb', line 14910

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14912
14913
14914
# File 'lib/models/porcelain.rb', line 14912

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14914
14915
14916
# File 'lib/models/porcelain.rb', line 14914

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14916
14917
14918
# File 'lib/models/porcelain.rb', line 14916

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14918
14919
14920
# File 'lib/models/porcelain.rb', line 14918

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14920
14921
14922
# File 'lib/models/porcelain.rb', line 14920

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14922
14923
14924
# File 'lib/models/porcelain.rb', line 14922

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14958
14959
14960
14961
14962
14963
14964
# File 'lib/models/porcelain.rb', line 14958

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end