Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



14570
14571
14572
14573
14574
14575
14576
14577
14578
14579
14580
14581
14582
14583
14584
14585
14586
14587
14588
14589
14590
14591
14592
14593
14594
14595
14596
14597
14598
14599
14600
14601
14602
# File 'lib/models/porcelain.rb', line 14570

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14540
14541
14542
# File 'lib/models/porcelain.rb', line 14540

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14542
14543
14544
# File 'lib/models/porcelain.rb', line 14542

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14544
14545
14546
# File 'lib/models/porcelain.rb', line 14544

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14546
14547
14548
# File 'lib/models/porcelain.rb', line 14546

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14548
14549
14550
# File 'lib/models/porcelain.rb', line 14548

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14550
14551
14552
# File 'lib/models/porcelain.rb', line 14550

def name
  @name
end

#passwordObject

The password to authenticate with.



14552
14553
14554
# File 'lib/models/porcelain.rb', line 14552

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14554
14555
14556
# File 'lib/models/porcelain.rb', line 14554

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14556
14557
14558
# File 'lib/models/porcelain.rb', line 14556

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14558
14559
14560
# File 'lib/models/porcelain.rb', line 14558

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14560
14561
14562
# File 'lib/models/porcelain.rb', line 14560

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14562
14563
14564
# File 'lib/models/porcelain.rb', line 14562

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14564
14565
14566
# File 'lib/models/porcelain.rb', line 14564

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14566
14567
14568
# File 'lib/models/porcelain.rb', line 14566

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14568
14569
14570
# File 'lib/models/porcelain.rb', line 14568

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14604
14605
14606
14607
14608
14609
14610
# File 'lib/models/porcelain.rb', line 14604

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end