Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



14250
14251
14252
14253
14254
14255
14256
14257
14258
14259
14260
14261
14262
14263
14264
14265
14266
14267
14268
14269
14270
14271
14272
14273
14274
14275
14276
14277
14278
14279
14280
14281
14282
# File 'lib/models/porcelain.rb', line 14250

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14220
14221
14222
# File 'lib/models/porcelain.rb', line 14220

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14222
14223
14224
# File 'lib/models/porcelain.rb', line 14222

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14224
14225
14226
# File 'lib/models/porcelain.rb', line 14224

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14226
14227
14228
# File 'lib/models/porcelain.rb', line 14226

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14228
14229
14230
# File 'lib/models/porcelain.rb', line 14228

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14230
14231
14232
# File 'lib/models/porcelain.rb', line 14230

def name
  @name
end

#passwordObject

The password to authenticate with.



14232
14233
14234
# File 'lib/models/porcelain.rb', line 14232

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14234
14235
14236
# File 'lib/models/porcelain.rb', line 14234

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14236
14237
14238
# File 'lib/models/porcelain.rb', line 14236

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14238
14239
14240
# File 'lib/models/porcelain.rb', line 14238

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14240
14241
14242
# File 'lib/models/porcelain.rb', line 14240

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14242
14243
14244
# File 'lib/models/porcelain.rb', line 14242

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14244
14245
14246
# File 'lib/models/porcelain.rb', line 14244

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14246
14247
14248
# File 'lib/models/porcelain.rb', line 14246

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14248
14249
14250
# File 'lib/models/porcelain.rb', line 14248

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14284
14285
14286
14287
14288
14289
14290
# File 'lib/models/porcelain.rb', line 14284

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end