Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



14161
14162
14163
14164
14165
14166
14167
14168
14169
14170
14171
14172
14173
14174
14175
14176
14177
14178
14179
14180
14181
14182
14183
14184
14185
14186
14187
14188
14189
14190
14191
14192
14193
# File 'lib/models/porcelain.rb', line 14161

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14131
14132
14133
# File 'lib/models/porcelain.rb', line 14131

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14133
14134
14135
# File 'lib/models/porcelain.rb', line 14133

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14135
14136
14137
# File 'lib/models/porcelain.rb', line 14135

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14137
14138
14139
# File 'lib/models/porcelain.rb', line 14137

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14139
14140
14141
# File 'lib/models/porcelain.rb', line 14139

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14141
14142
14143
# File 'lib/models/porcelain.rb', line 14141

def name
  @name
end

#passwordObject

The password to authenticate with.



14143
14144
14145
# File 'lib/models/porcelain.rb', line 14143

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14145
14146
14147
# File 'lib/models/porcelain.rb', line 14145

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14147
14148
14149
# File 'lib/models/porcelain.rb', line 14147

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14149
14150
14151
# File 'lib/models/porcelain.rb', line 14149

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14151
14152
14153
# File 'lib/models/porcelain.rb', line 14151

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14153
14154
14155
# File 'lib/models/porcelain.rb', line 14153

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14155
14156
14157
# File 'lib/models/porcelain.rb', line 14155

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14157
14158
14159
# File 'lib/models/porcelain.rb', line 14157

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14159
14160
14161
# File 'lib/models/porcelain.rb', line 14159

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14195
14196
14197
14198
14199
14200
14201
# File 'lib/models/porcelain.rb', line 14195

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end