Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



13875
13876
13877
13878
13879
13880
13881
13882
13883
13884
13885
13886
13887
13888
13889
13890
13891
13892
13893
13894
13895
13896
13897
13898
13899
13900
13901
13902
13903
13904
13905
13906
13907
# File 'lib/models/porcelain.rb', line 13875

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13845
13846
13847
# File 'lib/models/porcelain.rb', line 13845

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13847
13848
13849
# File 'lib/models/porcelain.rb', line 13847

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13849
13850
13851
# File 'lib/models/porcelain.rb', line 13849

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13851
13852
13853
# File 'lib/models/porcelain.rb', line 13851

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13853
13854
13855
# File 'lib/models/porcelain.rb', line 13853

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13855
13856
13857
# File 'lib/models/porcelain.rb', line 13855

def name
  @name
end

#passwordObject

The password to authenticate with.



13857
13858
13859
# File 'lib/models/porcelain.rb', line 13857

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13859
13860
13861
# File 'lib/models/porcelain.rb', line 13859

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13861
13862
13863
# File 'lib/models/porcelain.rb', line 13861

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13863
13864
13865
# File 'lib/models/porcelain.rb', line 13863

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13865
13866
13867
# File 'lib/models/porcelain.rb', line 13865

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13867
13868
13869
# File 'lib/models/porcelain.rb', line 13867

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13869
13870
13871
# File 'lib/models/porcelain.rb', line 13869

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



13871
13872
13873
# File 'lib/models/porcelain.rb', line 13871

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



13873
13874
13875
# File 'lib/models/porcelain.rb', line 13873

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13909
13910
13911
13912
13913
13914
13915
# File 'lib/models/porcelain.rb', line 13909

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end