Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



12989
12990
12991
12992
12993
12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
13012
13013
13014
13015
13016
13017
13018
13019
13020
13021
# File 'lib/models/porcelain.rb', line 12989

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



12959
12960
12961
# File 'lib/models/porcelain.rb', line 12959

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12961
12962
12963
# File 'lib/models/porcelain.rb', line 12961

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12963
12964
12965
# File 'lib/models/porcelain.rb', line 12963

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12965
12966
12967
# File 'lib/models/porcelain.rb', line 12965

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12967
12968
12969
# File 'lib/models/porcelain.rb', line 12967

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12969
12970
12971
# File 'lib/models/porcelain.rb', line 12969

def name
  @name
end

#passwordObject

The password to authenticate with.



12971
12972
12973
# File 'lib/models/porcelain.rb', line 12971

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12973
12974
12975
# File 'lib/models/porcelain.rb', line 12973

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



12975
12976
12977
# File 'lib/models/porcelain.rb', line 12975

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12977
12978
12979
# File 'lib/models/porcelain.rb', line 12977

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12979
12980
12981
# File 'lib/models/porcelain.rb', line 12979

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



12981
12982
12983
# File 'lib/models/porcelain.rb', line 12981

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12983
12984
12985
# File 'lib/models/porcelain.rb', line 12983

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



12985
12986
12987
# File 'lib/models/porcelain.rb', line 12985

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



12987
12988
12989
# File 'lib/models/porcelain.rb', line 12987

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13023
13024
13025
13026
13027
13028
13029
# File 'lib/models/porcelain.rb', line 13023

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end