Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
11526 11527 11528 11529 11530 11531 11532 11533 11534 11535 11536 11537 11538 11539 11540 11541 11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 11552 11553 11554 11555 11556 11557 11558 |
# File 'lib/models/porcelain.rb', line 11526 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11496 11497 11498 |
# File 'lib/models/porcelain.rb', line 11496 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11498 11499 11500 |
# File 'lib/models/porcelain.rb', line 11498 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11500 11501 11502 |
# File 'lib/models/porcelain.rb', line 11500 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11502 11503 11504 |
# File 'lib/models/porcelain.rb', line 11502 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11504 11505 11506 |
# File 'lib/models/porcelain.rb', line 11504 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11506 11507 11508 |
# File 'lib/models/porcelain.rb', line 11506 def name @name end |
#password ⇒ Object
The password to authenticate with.
11508 11509 11510 |
# File 'lib/models/porcelain.rb', line 11508 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11510 11511 11512 |
# File 'lib/models/porcelain.rb', line 11510 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11512 11513 11514 |
# File 'lib/models/porcelain.rb', line 11512 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11514 11515 11516 |
# File 'lib/models/porcelain.rb', line 11514 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11516 11517 11518 |
# File 'lib/models/porcelain.rb', line 11516 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11518 11519 11520 |
# File 'lib/models/porcelain.rb', line 11518 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11520 11521 11522 |
# File 'lib/models/porcelain.rb', line 11520 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
11522 11523 11524 |
# File 'lib/models/porcelain.rb', line 11522 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
11524 11525 11526 |
# File 'lib/models/porcelain.rb', line 11524 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11560 11561 11562 11563 11564 11565 11566 |
# File 'lib/models/porcelain.rb', line 11560 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |