Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 |
# File 'lib/models/porcelain.rb', line 11447 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11417 11418 11419 |
# File 'lib/models/porcelain.rb', line 11417 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11419 11420 11421 |
# File 'lib/models/porcelain.rb', line 11419 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11421 11422 11423 |
# File 'lib/models/porcelain.rb', line 11421 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11423 11424 11425 |
# File 'lib/models/porcelain.rb', line 11423 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11425 11426 11427 |
# File 'lib/models/porcelain.rb', line 11425 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11427 11428 11429 |
# File 'lib/models/porcelain.rb', line 11427 def name @name end |
#password ⇒ Object
The password to authenticate with.
11429 11430 11431 |
# File 'lib/models/porcelain.rb', line 11429 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11431 11432 11433 |
# File 'lib/models/porcelain.rb', line 11431 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11433 11434 11435 |
# File 'lib/models/porcelain.rb', line 11433 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11435 11436 11437 |
# File 'lib/models/porcelain.rb', line 11435 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11437 11438 11439 |
# File 'lib/models/porcelain.rb', line 11437 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11439 11440 11441 |
# File 'lib/models/porcelain.rb', line 11439 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11441 11442 11443 |
# File 'lib/models/porcelain.rb', line 11441 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
11443 11444 11445 |
# File 'lib/models/porcelain.rb', line 11443 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
11445 11446 11447 |
# File 'lib/models/porcelain.rb', line 11445 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11481 11482 11483 11484 11485 11486 11487 |
# File 'lib/models/porcelain.rb', line 11481 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |