Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



11303
11304
11305
11306
11307
11308
11309
11310
11311
11312
11313
11314
11315
11316
11317
11318
11319
11320
11321
11322
11323
11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
# File 'lib/models/porcelain.rb', line 11303

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11273
11274
11275
# File 'lib/models/porcelain.rb', line 11273

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11275
11276
11277
# File 'lib/models/porcelain.rb', line 11275

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11277
11278
11279
# File 'lib/models/porcelain.rb', line 11277

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11279
11280
11281
# File 'lib/models/porcelain.rb', line 11279

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11281
11282
11283
# File 'lib/models/porcelain.rb', line 11281

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11283
11284
11285
# File 'lib/models/porcelain.rb', line 11283

def name
  @name
end

#passwordObject

The password to authenticate with.



11285
11286
11287
# File 'lib/models/porcelain.rb', line 11285

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11287
11288
11289
# File 'lib/models/porcelain.rb', line 11287

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11289
11290
11291
# File 'lib/models/porcelain.rb', line 11289

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11291
11292
11293
# File 'lib/models/porcelain.rb', line 11291

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11293
11294
11295
# File 'lib/models/porcelain.rb', line 11293

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11295
11296
11297
# File 'lib/models/porcelain.rb', line 11295

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11297
11298
11299
# File 'lib/models/porcelain.rb', line 11297

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11299
11300
11301
# File 'lib/models/porcelain.rb', line 11299

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11301
11302
11303
# File 'lib/models/porcelain.rb', line 11301

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11337
11338
11339
11340
11341
11342
11343
# File 'lib/models/porcelain.rb', line 11337

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end