Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
10452 10453 10454 10455 10456 10457 10458 10459 10460 10461 10462 10463 10464 10465 10466 10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 |
# File 'lib/models/porcelain.rb', line 10452 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10422 10423 10424 |
# File 'lib/models/porcelain.rb', line 10422 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10424 10425 10426 |
# File 'lib/models/porcelain.rb', line 10424 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10426 10427 10428 |
# File 'lib/models/porcelain.rb', line 10426 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10428 10429 10430 |
# File 'lib/models/porcelain.rb', line 10428 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10430 10431 10432 |
# File 'lib/models/porcelain.rb', line 10430 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10432 10433 10434 |
# File 'lib/models/porcelain.rb', line 10432 def name @name end |
#password ⇒ Object
The password to authenticate with.
10434 10435 10436 |
# File 'lib/models/porcelain.rb', line 10434 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10436 10437 10438 |
# File 'lib/models/porcelain.rb', line 10436 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10438 10439 10440 |
# File 'lib/models/porcelain.rb', line 10438 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10440 10441 10442 |
# File 'lib/models/porcelain.rb', line 10440 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10442 10443 10444 |
# File 'lib/models/porcelain.rb', line 10442 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10444 10445 10446 |
# File 'lib/models/porcelain.rb', line 10444 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10446 10447 10448 |
# File 'lib/models/porcelain.rb', line 10446 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
10448 10449 10450 |
# File 'lib/models/porcelain.rb', line 10448 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
10450 10451 10452 |
# File 'lib/models/porcelain.rb', line 10450 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10486 10487 10488 10489 10490 10491 10492 |
# File 'lib/models/porcelain.rb', line 10486 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |