Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
9860 9861 9862 9863 9864 9865 9866 9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 9888 9889 9890 9891 9892 |
# File 'lib/models/porcelain.rb', line 9860 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9830 9831 9832 |
# File 'lib/models/porcelain.rb', line 9830 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9832 9833 9834 |
# File 'lib/models/porcelain.rb', line 9832 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9834 9835 9836 |
# File 'lib/models/porcelain.rb', line 9834 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9836 9837 9838 |
# File 'lib/models/porcelain.rb', line 9836 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9838 9839 9840 |
# File 'lib/models/porcelain.rb', line 9838 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9840 9841 9842 |
# File 'lib/models/porcelain.rb', line 9840 def name @name end |
#password ⇒ Object
The password to authenticate with.
9842 9843 9844 |
# File 'lib/models/porcelain.rb', line 9842 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9844 9845 9846 |
# File 'lib/models/porcelain.rb', line 9844 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9846 9847 9848 |
# File 'lib/models/porcelain.rb', line 9846 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9848 9849 9850 |
# File 'lib/models/porcelain.rb', line 9848 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9850 9851 9852 |
# File 'lib/models/porcelain.rb', line 9850 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9852 9853 9854 |
# File 'lib/models/porcelain.rb', line 9852 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9854 9855 9856 |
# File 'lib/models/porcelain.rb', line 9854 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9856 9857 9858 |
# File 'lib/models/porcelain.rb', line 9856 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9858 9859 9860 |
# File 'lib/models/porcelain.rb', line 9858 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9894 9895 9896 9897 9898 9899 9900 |
# File 'lib/models/porcelain.rb', line 9894 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |