Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
# File 'lib/models/porcelain.rb', line 9778

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9748
9749
9750
# File 'lib/models/porcelain.rb', line 9748

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9750
9751
9752
# File 'lib/models/porcelain.rb', line 9750

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9752
9753
9754
# File 'lib/models/porcelain.rb', line 9752

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9754
9755
9756
# File 'lib/models/porcelain.rb', line 9754

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9756
9757
9758
# File 'lib/models/porcelain.rb', line 9756

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9758
9759
9760
# File 'lib/models/porcelain.rb', line 9758

def name
  @name
end

#passwordObject

The password to authenticate with.



9760
9761
9762
# File 'lib/models/porcelain.rb', line 9760

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9762
9763
9764
# File 'lib/models/porcelain.rb', line 9762

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9764
9765
9766
# File 'lib/models/porcelain.rb', line 9764

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9766
9767
9768
# File 'lib/models/porcelain.rb', line 9766

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9768
9769
9770
# File 'lib/models/porcelain.rb', line 9768

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9770
9771
9772
# File 'lib/models/porcelain.rb', line 9770

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9772
9773
9774
# File 'lib/models/porcelain.rb', line 9772

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9774
9775
9776
# File 'lib/models/porcelain.rb', line 9774

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9776
9777
9778
# File 'lib/models/porcelain.rb', line 9776

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9812
9813
9814
9815
9816
9817
9818
# File 'lib/models/porcelain.rb', line 9812

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end