Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
9538 9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 |
# File 'lib/models/porcelain.rb', line 9538 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9508 9509 9510 |
# File 'lib/models/porcelain.rb', line 9508 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9510 9511 9512 |
# File 'lib/models/porcelain.rb', line 9510 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9512 9513 9514 |
# File 'lib/models/porcelain.rb', line 9512 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9514 9515 9516 |
# File 'lib/models/porcelain.rb', line 9514 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9516 9517 9518 |
# File 'lib/models/porcelain.rb', line 9516 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9518 9519 9520 |
# File 'lib/models/porcelain.rb', line 9518 def name @name end |
#password ⇒ Object
The password to authenticate with.
9520 9521 9522 |
# File 'lib/models/porcelain.rb', line 9520 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9522 9523 9524 |
# File 'lib/models/porcelain.rb', line 9522 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9524 9525 9526 |
# File 'lib/models/porcelain.rb', line 9524 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9526 9527 9528 |
# File 'lib/models/porcelain.rb', line 9526 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9528 9529 9530 |
# File 'lib/models/porcelain.rb', line 9528 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9530 9531 9532 |
# File 'lib/models/porcelain.rb', line 9530 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9532 9533 9534 |
# File 'lib/models/porcelain.rb', line 9532 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9534 9535 9536 |
# File 'lib/models/porcelain.rb', line 9534 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9536 9537 9538 |
# File 'lib/models/porcelain.rb', line 9536 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9572 9573 9574 9575 9576 9577 9578 |
# File 'lib/models/porcelain.rb', line 9572 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |