Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 |
# File 'lib/models/porcelain.rb', line 9183 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9155 9156 9157 |
# File 'lib/models/porcelain.rb', line 9155 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9157 9158 9159 |
# File 'lib/models/porcelain.rb', line 9157 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9159 9160 9161 |
# File 'lib/models/porcelain.rb', line 9159 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9161 9162 9163 |
# File 'lib/models/porcelain.rb', line 9161 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9163 9164 9165 |
# File 'lib/models/porcelain.rb', line 9163 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9165 9166 9167 |
# File 'lib/models/porcelain.rb', line 9165 def name @name end |
#password ⇒ Object
The password to authenticate with.
9167 9168 9169 |
# File 'lib/models/porcelain.rb', line 9167 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9169 9170 9171 |
# File 'lib/models/porcelain.rb', line 9169 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9171 9172 9173 |
# File 'lib/models/porcelain.rb', line 9171 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9173 9174 9175 |
# File 'lib/models/porcelain.rb', line 9173 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9175 9176 9177 |
# File 'lib/models/porcelain.rb', line 9175 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9177 9178 9179 |
# File 'lib/models/porcelain.rb', line 9177 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9179 9180 9181 |
# File 'lib/models/porcelain.rb', line 9179 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9181 9182 9183 |
# File 'lib/models/porcelain.rb', line 9181 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9215 9216 9217 9218 9219 9220 9221 |
# File 'lib/models/porcelain.rb', line 9215 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |