Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



9014
9015
9016
9017
9018
9019
9020
9021
9022
9023
9024
9025
9026
9027
9028
9029
9030
9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
# File 'lib/models/porcelain.rb', line 9014

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8986
8987
8988
# File 'lib/models/porcelain.rb', line 8986

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8988
8989
8990
# File 'lib/models/porcelain.rb', line 8988

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8990
8991
8992
# File 'lib/models/porcelain.rb', line 8990

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8992
8993
8994
# File 'lib/models/porcelain.rb', line 8992

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8994
8995
8996
# File 'lib/models/porcelain.rb', line 8994

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8996
8997
8998
# File 'lib/models/porcelain.rb', line 8996

def name
  @name
end

#passwordObject

The password to authenticate with.



8998
8999
9000
# File 'lib/models/porcelain.rb', line 8998

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9000
9001
9002
# File 'lib/models/porcelain.rb', line 9000

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9002
9003
9004
# File 'lib/models/porcelain.rb', line 9002

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9004
9005
9006
# File 'lib/models/porcelain.rb', line 9004

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9006
9007
9008
# File 'lib/models/porcelain.rb', line 9006

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9008
9009
9010
# File 'lib/models/porcelain.rb', line 9008

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9010
9011
9012
# File 'lib/models/porcelain.rb', line 9010

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9012
9013
9014
# File 'lib/models/porcelain.rb', line 9012

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9046
9047
9048
9049
9050
9051
9052
# File 'lib/models/porcelain.rb', line 9046

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end