Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 |
# File 'lib/models/porcelain.rb', line 8845 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8817 8818 8819 |
# File 'lib/models/porcelain.rb', line 8817 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8819 8820 8821 |
# File 'lib/models/porcelain.rb', line 8819 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8821 8822 8823 |
# File 'lib/models/porcelain.rb', line 8821 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8823 8824 8825 |
# File 'lib/models/porcelain.rb', line 8823 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8825 8826 8827 |
# File 'lib/models/porcelain.rb', line 8825 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8827 8828 8829 |
# File 'lib/models/porcelain.rb', line 8827 def name @name end |
#password ⇒ Object
The password to authenticate with.
8829 8830 8831 |
# File 'lib/models/porcelain.rb', line 8829 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8831 8832 8833 |
# File 'lib/models/porcelain.rb', line 8831 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8833 8834 8835 |
# File 'lib/models/porcelain.rb', line 8833 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8835 8836 8837 |
# File 'lib/models/porcelain.rb', line 8835 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8837 8838 8839 |
# File 'lib/models/porcelain.rb', line 8837 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8839 8840 8841 |
# File 'lib/models/porcelain.rb', line 8839 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8841 8842 8843 |
# File 'lib/models/porcelain.rb', line 8841 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8843 8844 8845 |
# File 'lib/models/porcelain.rb', line 8843 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8877 8878 8879 8880 8881 8882 8883 |
# File 'lib/models/porcelain.rb', line 8877 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |