Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
8467 8468 8469 8470 8471 8472 8473 8474 8475 8476 8477 8478 8479 8480 8481 8482 8483 8484 8485 8486 8487 8488 8489 8490 8491 8492 8493 8494 8495 8496 8497 |
# File 'lib/models/porcelain.rb', line 8467 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8439 8440 8441 |
# File 'lib/models/porcelain.rb', line 8439 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8441 8442 8443 |
# File 'lib/models/porcelain.rb', line 8441 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8443 8444 8445 |
# File 'lib/models/porcelain.rb', line 8443 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8445 8446 8447 |
# File 'lib/models/porcelain.rb', line 8445 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8447 8448 8449 |
# File 'lib/models/porcelain.rb', line 8447 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8449 8450 8451 |
# File 'lib/models/porcelain.rb', line 8449 def name @name end |
#password ⇒ Object
The password to authenticate with.
8451 8452 8453 |
# File 'lib/models/porcelain.rb', line 8451 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8453 8454 8455 |
# File 'lib/models/porcelain.rb', line 8453 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8455 8456 8457 |
# File 'lib/models/porcelain.rb', line 8455 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8457 8458 8459 |
# File 'lib/models/porcelain.rb', line 8457 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8459 8460 8461 |
# File 'lib/models/porcelain.rb', line 8459 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8461 8462 8463 |
# File 'lib/models/porcelain.rb', line 8461 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8463 8464 8465 |
# File 'lib/models/porcelain.rb', line 8463 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8465 8466 8467 |
# File 'lib/models/porcelain.rb', line 8465 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8499 8500 8501 8502 8503 8504 8505 |
# File 'lib/models/porcelain.rb', line 8499 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |