Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



7465
7466
7467
7468
7469
7470
7471
7472
7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
7483
7484
7485
7486
7487
7488
7489
7490
7491
7492
7493
7494
7495
# File 'lib/models/porcelain.rb', line 7465

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7437
7438
7439
# File 'lib/models/porcelain.rb', line 7437

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7439
7440
7441
# File 'lib/models/porcelain.rb', line 7439

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7441
7442
7443
# File 'lib/models/porcelain.rb', line 7441

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7443
7444
7445
# File 'lib/models/porcelain.rb', line 7443

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7445
7446
7447
# File 'lib/models/porcelain.rb', line 7445

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7447
7448
7449
# File 'lib/models/porcelain.rb', line 7447

def name
  @name
end

#passwordObject

The password to authenticate with.



7449
7450
7451
# File 'lib/models/porcelain.rb', line 7449

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7451
7452
7453
# File 'lib/models/porcelain.rb', line 7451

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7453
7454
7455
# File 'lib/models/porcelain.rb', line 7453

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7455
7456
7457
# File 'lib/models/porcelain.rb', line 7455

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7457
7458
7459
# File 'lib/models/porcelain.rb', line 7457

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7459
7460
7461
# File 'lib/models/porcelain.rb', line 7459

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7461
7462
7463
# File 'lib/models/porcelain.rb', line 7461

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7463
7464
7465
# File 'lib/models/porcelain.rb', line 7463

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7497
7498
7499
7500
7501
7502
7503
# File 'lib/models/porcelain.rb', line 7497

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end