Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
7421 7422 7423 7424 7425 7426 7427 7428 7429 7430 7431 7432 7433 7434 7435 7436 7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 7451 |
# File 'lib/models/porcelain.rb', line 7421 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7393 7394 7395 |
# File 'lib/models/porcelain.rb', line 7393 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7395 7396 7397 |
# File 'lib/models/porcelain.rb', line 7395 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7397 7398 7399 |
# File 'lib/models/porcelain.rb', line 7397 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7399 7400 7401 |
# File 'lib/models/porcelain.rb', line 7399 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7401 7402 7403 |
# File 'lib/models/porcelain.rb', line 7401 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7403 7404 7405 |
# File 'lib/models/porcelain.rb', line 7403 def name @name end |
#password ⇒ Object
The password to authenticate with.
7405 7406 7407 |
# File 'lib/models/porcelain.rb', line 7405 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7407 7408 7409 |
# File 'lib/models/porcelain.rb', line 7407 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7409 7410 7411 |
# File 'lib/models/porcelain.rb', line 7409 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7411 7412 7413 |
# File 'lib/models/porcelain.rb', line 7411 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7413 7414 7415 |
# File 'lib/models/porcelain.rb', line 7413 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7415 7416 7417 |
# File 'lib/models/porcelain.rb', line 7415 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7417 7418 7419 |
# File 'lib/models/porcelain.rb', line 7417 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7419 7420 7421 |
# File 'lib/models/porcelain.rb', line 7419 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7453 7454 7455 7456 7457 7458 7459 |
# File 'lib/models/porcelain.rb', line 7453 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |