Class: SDM::RabbitMQAMQP091

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091

Returns a new instance of RabbitMQAMQP091.



7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
# File 'lib/models/porcelain.rb', line 7087

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7059
7060
7061
# File 'lib/models/porcelain.rb', line 7059

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7061
7062
7063
# File 'lib/models/porcelain.rb', line 7061

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7063
7064
7065
# File 'lib/models/porcelain.rb', line 7063

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7065
7066
7067
# File 'lib/models/porcelain.rb', line 7065

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7067
7068
7069
# File 'lib/models/porcelain.rb', line 7067

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7069
7070
7071
# File 'lib/models/porcelain.rb', line 7069

def name
  @name
end

#passwordObject

The password to authenticate with.



7071
7072
7073
# File 'lib/models/porcelain.rb', line 7071

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7073
7074
7075
# File 'lib/models/porcelain.rb', line 7073

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7075
7076
7077
# File 'lib/models/porcelain.rb', line 7075

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7077
7078
7079
# File 'lib/models/porcelain.rb', line 7077

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7079
7080
7081
# File 'lib/models/porcelain.rb', line 7079

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7081
7082
7083
# File 'lib/models/porcelain.rb', line 7081

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



7083
7084
7085
# File 'lib/models/porcelain.rb', line 7083

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



7085
7086
7087
# File 'lib/models/porcelain.rb', line 7085

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7119
7120
7121
7122
7123
7124
7125
# File 'lib/models/porcelain.rb', line 7119

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end