Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 |
# File 'lib/models/porcelain.rb', line 6329 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6301 6302 6303 |
# File 'lib/models/porcelain.rb', line 6301 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6303 6304 6305 |
# File 'lib/models/porcelain.rb', line 6303 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6305 6306 6307 |
# File 'lib/models/porcelain.rb', line 6305 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6307 6308 6309 |
# File 'lib/models/porcelain.rb', line 6307 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6309 6310 6311 |
# File 'lib/models/porcelain.rb', line 6309 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6311 6312 6313 |
# File 'lib/models/porcelain.rb', line 6311 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6313 6314 6315 |
# File 'lib/models/porcelain.rb', line 6313 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6315 6316 6317 |
# File 'lib/models/porcelain.rb', line 6315 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6317 6318 6319 |
# File 'lib/models/porcelain.rb', line 6317 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6319 6320 6321 |
# File 'lib/models/porcelain.rb', line 6319 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6321 6322 6323 |
# File 'lib/models/porcelain.rb', line 6321 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6323 6324 6325 |
# File 'lib/models/porcelain.rb', line 6323 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
6325 6326 6327 |
# File 'lib/models/porcelain.rb', line 6325 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
6327 6328 6329 |
# File 'lib/models/porcelain.rb', line 6327 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/models/porcelain.rb', line 6361 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |