Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
6020 6021 6022 6023 6024 6025 6026 6027 6028 6029 6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 6045 6046 6047 6048 6049 6050 |
# File 'lib/models/porcelain.rb', line 6020 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5992 5993 5994 |
# File 'lib/models/porcelain.rb', line 5992 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5994 5995 5996 |
# File 'lib/models/porcelain.rb', line 5994 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5996 5997 5998 |
# File 'lib/models/porcelain.rb', line 5996 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5998 5999 6000 |
# File 'lib/models/porcelain.rb', line 5998 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6000 6001 6002 |
# File 'lib/models/porcelain.rb', line 6000 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6002 6003 6004 |
# File 'lib/models/porcelain.rb', line 6002 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6004 6005 6006 |
# File 'lib/models/porcelain.rb', line 6004 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6006 6007 6008 |
# File 'lib/models/porcelain.rb', line 6006 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6008 6009 6010 |
# File 'lib/models/porcelain.rb', line 6008 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6010 6011 6012 |
# File 'lib/models/porcelain.rb', line 6010 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6012 6013 6014 |
# File 'lib/models/porcelain.rb', line 6012 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6014 6015 6016 |
# File 'lib/models/porcelain.rb', line 6014 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
6016 6017 6018 |
# File 'lib/models/porcelain.rb', line 6016 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
6018 6019 6020 |
# File 'lib/models/porcelain.rb', line 6018 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/models/porcelain.rb', line 6052 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |