Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
5806 5807 5808 5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 |
# File 'lib/models/porcelain.rb', line 5806 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5780 5781 5782 |
# File 'lib/models/porcelain.rb', line 5780 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5782 5783 5784 |
# File 'lib/models/porcelain.rb', line 5782 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5784 5785 5786 |
# File 'lib/models/porcelain.rb', line 5784 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5786 5787 5788 |
# File 'lib/models/porcelain.rb', line 5786 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5788 5789 5790 |
# File 'lib/models/porcelain.rb', line 5788 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5790 5791 5792 |
# File 'lib/models/porcelain.rb', line 5790 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5792 5793 5794 |
# File 'lib/models/porcelain.rb', line 5792 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5794 5795 5796 |
# File 'lib/models/porcelain.rb', line 5794 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5796 5797 5798 |
# File 'lib/models/porcelain.rb', line 5796 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5798 5799 5800 |
# File 'lib/models/porcelain.rb', line 5798 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5800 5801 5802 |
# File 'lib/models/porcelain.rb', line 5800 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5802 5803 5804 |
# File 'lib/models/porcelain.rb', line 5802 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5804 5805 5806 |
# File 'lib/models/porcelain.rb', line 5804 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5836 5837 5838 5839 5840 5841 5842 |
# File 'lib/models/porcelain.rb', line 5836 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |