Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 5208 5209 5210 5211 |
# File 'lib/models/porcelain.rb', line 5183 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5157 5158 5159 |
# File 'lib/models/porcelain.rb', line 5157 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5159 5160 5161 |
# File 'lib/models/porcelain.rb', line 5159 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5161 5162 5163 |
# File 'lib/models/porcelain.rb', line 5161 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5163 5164 5165 |
# File 'lib/models/porcelain.rb', line 5163 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5165 5166 5167 |
# File 'lib/models/porcelain.rb', line 5165 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5167 5168 5169 |
# File 'lib/models/porcelain.rb', line 5167 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5169 5170 5171 |
# File 'lib/models/porcelain.rb', line 5169 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5171 5172 5173 |
# File 'lib/models/porcelain.rb', line 5171 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5173 5174 5175 |
# File 'lib/models/porcelain.rb', line 5173 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5175 5176 5177 |
# File 'lib/models/porcelain.rb', line 5175 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5177 5178 5179 |
# File 'lib/models/porcelain.rb', line 5177 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5179 5180 5181 |
# File 'lib/models/porcelain.rb', line 5179 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5181 5182 5183 |
# File 'lib/models/porcelain.rb', line 5181 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5213 5214 5215 5216 5217 5218 5219 |
# File 'lib/models/porcelain.rb', line 5213 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |