Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/models/porcelain.rb', line 5072 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5046 5047 5048 |
# File 'lib/models/porcelain.rb', line 5046 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5048 5049 5050 |
# File 'lib/models/porcelain.rb', line 5048 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5050 5051 5052 |
# File 'lib/models/porcelain.rb', line 5050 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5052 5053 5054 |
# File 'lib/models/porcelain.rb', line 5052 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5054 5055 5056 |
# File 'lib/models/porcelain.rb', line 5054 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5056 5057 5058 |
# File 'lib/models/porcelain.rb', line 5056 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5058 5059 5060 |
# File 'lib/models/porcelain.rb', line 5058 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5060 5061 5062 |
# File 'lib/models/porcelain.rb', line 5060 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5062 5063 5064 |
# File 'lib/models/porcelain.rb', line 5062 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5064 5065 5066 |
# File 'lib/models/porcelain.rb', line 5064 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5066 5067 5068 |
# File 'lib/models/porcelain.rb', line 5066 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5068 5069 5070 |
# File 'lib/models/porcelain.rb', line 5068 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5070 5071 5072 |
# File 'lib/models/porcelain.rb', line 5070 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5102 5103 5104 5105 5106 5107 5108 |
# File 'lib/models/porcelain.rb', line 5102 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |