Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
4289 4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 |
# File 'lib/models/porcelain.rb', line 4289 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
4265 4266 4267 |
# File 'lib/models/porcelain.rb', line 4265 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
4267 4268 4269 |
# File 'lib/models/porcelain.rb', line 4267 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
4269 4270 4271 |
# File 'lib/models/porcelain.rb', line 4269 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
4271 4272 4273 |
# File 'lib/models/porcelain.rb', line 4271 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
4273 4274 4275 |
# File 'lib/models/porcelain.rb', line 4273 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
4275 4276 4277 |
# File 'lib/models/porcelain.rb', line 4275 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
4277 4278 4279 |
# File 'lib/models/porcelain.rb', line 4277 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
4279 4280 4281 |
# File 'lib/models/porcelain.rb', line 4279 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
4281 4282 4283 |
# File 'lib/models/porcelain.rb', line 4281 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
4283 4284 4285 |
# File 'lib/models/porcelain.rb', line 4283 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
4285 4286 4287 |
# File 'lib/models/porcelain.rb', line 4285 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
4287 4288 4289 |
# File 'lib/models/porcelain.rb', line 4287 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
4317 4318 4319 4320 4321 4322 4323 |
# File 'lib/models/porcelain.rb', line 4317 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |