Class: SDM::RabbitMQAMQP091
- Inherits:
-
Object
- Object
- SDM::RabbitMQAMQP091
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
constructor
A new instance of RabbitMQAMQP091.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ RabbitMQAMQP091
Returns a new instance of RabbitMQAMQP091.
5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 5658 5659 5660 5661 5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 |
# File 'lib/models/porcelain.rb', line 5648 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if tls_required != nil @tls_required = tls_required end if username != nil @username = username end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5624 5625 5626 |
# File 'lib/models/porcelain.rb', line 5624 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5626 5627 5628 |
# File 'lib/models/porcelain.rb', line 5626 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5628 5629 5630 |
# File 'lib/models/porcelain.rb', line 5628 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5630 5631 5632 |
# File 'lib/models/porcelain.rb', line 5630 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5632 5633 5634 |
# File 'lib/models/porcelain.rb', line 5632 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5634 5635 5636 |
# File 'lib/models/porcelain.rb', line 5634 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5636 5637 5638 |
# File 'lib/models/porcelain.rb', line 5636 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5638 5639 5640 |
# File 'lib/models/porcelain.rb', line 5638 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5640 5641 5642 |
# File 'lib/models/porcelain.rb', line 5640 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5642 5643 5644 |
# File 'lib/models/porcelain.rb', line 5642 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5644 5645 5646 |
# File 'lib/models/porcelain.rb', line 5644 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5646 5647 5648 |
# File 'lib/models/porcelain.rb', line 5646 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/models/porcelain.rb', line 5700 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |