Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
14981 14982 14983 14984 14985 14986 14987 14988 14989 14990 14991 |
# File 'lib/models/porcelain.rb', line 14981 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
14972 14973 14974 |
# File 'lib/models/porcelain.rb', line 14972 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
14975 14976 14977 |
# File 'lib/models/porcelain.rb', line 14975 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
14977 14978 14979 |
# File 'lib/models/porcelain.rb', line 14977 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
14979 14980 14981 |
# File 'lib/models/porcelain.rb', line 14979 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14993 14994 14995 14996 14997 14998 14999 |
# File 'lib/models/porcelain.rb', line 14993 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |