Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
14627 14628 14629 14630 14631 14632 14633 14634 14635 14636 14637 |
# File 'lib/models/porcelain.rb', line 14627 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
14618 14619 14620 |
# File 'lib/models/porcelain.rb', line 14618 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
14621 14622 14623 |
# File 'lib/models/porcelain.rb', line 14621 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
14623 14624 14625 |
# File 'lib/models/porcelain.rb', line 14623 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
14625 14626 14627 |
# File 'lib/models/porcelain.rb', line 14625 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14639 14640 14641 14642 14643 14644 14645 |
# File 'lib/models/porcelain.rb', line 14639 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |