Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
10431 10432 10433 10434 10435 10436 10437 10438 10439 10440 10441 |
# File 'lib/models/porcelain.rb', line 10431 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
10422 10423 10424 |
# File 'lib/models/porcelain.rb', line 10422 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
10425 10426 10427 |
# File 'lib/models/porcelain.rb', line 10425 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
10427 10428 10429 |
# File 'lib/models/porcelain.rb', line 10427 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
10429 10430 10431 |
# File 'lib/models/porcelain.rb', line 10429 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10443 10444 10445 10446 10447 10448 10449 |
# File 'lib/models/porcelain.rb', line 10443 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |