Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 |
# File 'lib/models/porcelain.rb', line 10214 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
10205 10206 10207 |
# File 'lib/models/porcelain.rb', line 10205 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
10208 10209 10210 |
# File 'lib/models/porcelain.rb', line 10208 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
10210 10211 10212 |
# File 'lib/models/porcelain.rb', line 10210 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
10212 10213 10214 |
# File 'lib/models/porcelain.rb', line 10212 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10226 10227 10228 10229 10230 10231 10232 |
# File 'lib/models/porcelain.rb', line 10226 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |