Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/models/porcelain.rb', line 8201 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
8192 8193 8194 |
# File 'lib/models/porcelain.rb', line 8192 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
8195 8196 8197 |
# File 'lib/models/porcelain.rb', line 8195 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
8197 8198 8199 |
# File 'lib/models/porcelain.rb', line 8197 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
8199 8200 8201 |
# File 'lib/models/porcelain.rb', line 8199 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8213 8214 8215 8216 8217 8218 8219 |
# File 'lib/models/porcelain.rb', line 8213 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |