Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
7568 7569 7570 7571 7572 7573 7574 7575 7576 7577 7578 |
# File 'lib/models/porcelain.rb', line 7568 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
7559 7560 7561 |
# File 'lib/models/porcelain.rb', line 7559 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
7562 7563 7564 |
# File 'lib/models/porcelain.rb', line 7562 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
7564 7565 7566 |
# File 'lib/models/porcelain.rb', line 7564 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
7566 7567 7568 |
# File 'lib/models/porcelain.rb', line 7566 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7580 7581 7582 7583 7584 7585 7586 |
# File 'lib/models/porcelain.rb', line 7580 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |