Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 |
# File 'lib/models/porcelain.rb', line 7476 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
7467 7468 7469 |
# File 'lib/models/porcelain.rb', line 7467 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
7470 7471 7472 |
# File 'lib/models/porcelain.rb', line 7470 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
7472 7473 7474 |
# File 'lib/models/porcelain.rb', line 7472 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
7474 7475 7476 |
# File 'lib/models/porcelain.rb', line 7474 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7488 7489 7490 7491 7492 7493 7494 |
# File 'lib/models/porcelain.rb', line 7488 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |