Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
6978 6979 6980 6981 6982 6983 6984 6985 6986 6987 6988 |
# File 'lib/models/porcelain.rb', line 6978 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
6969 6970 6971 |
# File 'lib/models/porcelain.rb', line 6969 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
6972 6973 6974 |
# File 'lib/models/porcelain.rb', line 6972 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
6974 6975 6976 |
# File 'lib/models/porcelain.rb', line 6974 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
6976 6977 6978 |
# File 'lib/models/porcelain.rb', line 6976 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/models/porcelain.rb', line 6990 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |