Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 |
# File 'lib/models/porcelain.rb', line 6542 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
6533 6534 6535 |
# File 'lib/models/porcelain.rb', line 6533 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
6536 6537 6538 |
# File 'lib/models/porcelain.rb', line 6536 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
6538 6539 6540 |
# File 'lib/models/porcelain.rb', line 6538 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
6540 6541 6542 |
# File 'lib/models/porcelain.rb', line 6540 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6554 6555 6556 6557 6558 6559 6560 |
# File 'lib/models/porcelain.rb', line 6554 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |