Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/models/porcelain.rb', line 6328 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
6319 6320 6321 |
# File 'lib/models/porcelain.rb', line 6319 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
6322 6323 6324 |
# File 'lib/models/porcelain.rb', line 6322 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
6324 6325 6326 |
# File 'lib/models/porcelain.rb', line 6324 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
6326 6327 6328 |
# File 'lib/models/porcelain.rb', line 6326 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6340 6341 6342 6343 6344 6345 6346 |
# File 'lib/models/porcelain.rb', line 6340 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |