Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
5859 5860 5861 5862 5863 5864 5865 5866 5867 5868 5869 |
# File 'lib/models/porcelain.rb', line 5859 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
5850 5851 5852 |
# File 'lib/models/porcelain.rb', line 5850 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
5853 5854 5855 |
# File 'lib/models/porcelain.rb', line 5853 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
5855 5856 5857 |
# File 'lib/models/porcelain.rb', line 5855 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
5857 5858 5859 |
# File 'lib/models/porcelain.rb', line 5857 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5871 5872 5873 5874 5875 5876 5877 |
# File 'lib/models/porcelain.rb', line 5871 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |