Class: SDM::RateLimitMetadata
- Inherits:
-
Object
- Object
- SDM::RateLimitMetadata
- Defined in:
- lib/models/porcelain.rb
Overview
RateLimitMetadata contains information about remaining requests avaialable to the user over some timeframe.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
-
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
-
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
-
#reset_at ⇒ Object
The time when remaining will be reset to limit.
Instance Method Summary collapse
-
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
constructor
A new instance of RateLimitMetadata.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bucket: nil, limit: nil, remaining: nil, reset_at: nil) ⇒ RateLimitMetadata
Returns a new instance of RateLimitMetadata.
5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 |
# File 'lib/models/porcelain.rb', line 5110 def initialize( bucket: nil, limit: nil, remaining: nil, reset_at: nil ) @bucket = bucket == nil ? "" : bucket @limit = limit == nil ? 0 : limit @remaining = remaining == nil ? 0 : remaining @reset_at = reset_at == nil ? nil : reset_at end |
Instance Attribute Details
#bucket ⇒ Object
The bucket this user/token is associated with, which may be shared between multiple users/tokens.
5101 5102 5103 |
# File 'lib/models/porcelain.rb', line 5101 def bucket @bucket end |
#limit ⇒ Object
How many total requests the user/token is authorized to make before being rate limited.
5104 5105 5106 |
# File 'lib/models/porcelain.rb', line 5104 def limit @limit end |
#remaining ⇒ Object
How many remaining requests out of the limit are still avaialable.
5106 5107 5108 |
# File 'lib/models/porcelain.rb', line 5106 def remaining @remaining end |
#reset_at ⇒ Object
The time when remaining will be reset to limit.
5108 5109 5110 |
# File 'lib/models/porcelain.rb', line 5108 def reset_at @reset_at end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/models/porcelain.rb', line 5122 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |