Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



14673
14674
14675
14676
14677
14678
14679
14680
14681
14682
14683
14684
14685
14686
14687
14688
14689
14690
14691
14692
14693
14694
14695
14696
14697
14698
14699
# File 'lib/models/porcelain.rb', line 14673

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14649
14650
14651
# File 'lib/models/porcelain.rb', line 14649

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14651
14652
14653
# File 'lib/models/porcelain.rb', line 14651

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14653
14654
14655
# File 'lib/models/porcelain.rb', line 14653

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14655
14656
14657
# File 'lib/models/porcelain.rb', line 14655

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14657
14658
14659
# File 'lib/models/porcelain.rb', line 14657

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14659
14660
14661
# File 'lib/models/porcelain.rb', line 14659

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14661
14662
14663
# File 'lib/models/porcelain.rb', line 14661

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14663
14664
14665
# File 'lib/models/porcelain.rb', line 14663

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14665
14666
14667
# File 'lib/models/porcelain.rb', line 14665

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14667
14668
14669
# File 'lib/models/porcelain.rb', line 14667

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14669
14670
14671
# File 'lib/models/porcelain.rb', line 14669

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14671
14672
14673
# File 'lib/models/porcelain.rb', line 14671

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14701
14702
14703
14704
14705
14706
14707
# File 'lib/models/porcelain.rb', line 14701

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end