Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



14355
14356
14357
14358
14359
14360
14361
14362
14363
14364
14365
14366
14367
14368
14369
14370
14371
14372
14373
14374
14375
14376
14377
14378
14379
14380
14381
# File 'lib/models/porcelain.rb', line 14355

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14331
14332
14333
# File 'lib/models/porcelain.rb', line 14331

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14333
14334
14335
# File 'lib/models/porcelain.rb', line 14333

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14335
14336
14337
# File 'lib/models/porcelain.rb', line 14335

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14337
14338
14339
# File 'lib/models/porcelain.rb', line 14337

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14339
14340
14341
# File 'lib/models/porcelain.rb', line 14339

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14341
14342
14343
# File 'lib/models/porcelain.rb', line 14341

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14343
14344
14345
# File 'lib/models/porcelain.rb', line 14343

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14345
14346
14347
# File 'lib/models/porcelain.rb', line 14345

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14347
14348
14349
# File 'lib/models/porcelain.rb', line 14347

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14349
14350
14351
# File 'lib/models/porcelain.rb', line 14349

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14351
14352
14353
# File 'lib/models/porcelain.rb', line 14351

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14353
14354
14355
# File 'lib/models/porcelain.rb', line 14353

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14383
14384
14385
14386
14387
14388
14389
# File 'lib/models/porcelain.rb', line 14383

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end