Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



13979
13980
13981
13982
13983
13984
13985
13986
13987
13988
13989
13990
13991
13992
13993
13994
13995
13996
13997
13998
13999
14000
14001
14002
14003
14004
14005
# File 'lib/models/porcelain.rb', line 13979

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13955
13956
13957
# File 'lib/models/porcelain.rb', line 13955

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13957
13958
13959
# File 'lib/models/porcelain.rb', line 13957

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13959
13960
13961
# File 'lib/models/porcelain.rb', line 13959

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13961
13962
13963
# File 'lib/models/porcelain.rb', line 13961

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13963
13964
13965
# File 'lib/models/porcelain.rb', line 13963

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13965
13966
13967
# File 'lib/models/porcelain.rb', line 13965

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13967
13968
13969
# File 'lib/models/porcelain.rb', line 13967

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13969
13970
13971
# File 'lib/models/porcelain.rb', line 13969

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13971
13972
13973
# File 'lib/models/porcelain.rb', line 13971

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13973
13974
13975
# File 'lib/models/porcelain.rb', line 13973

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13975
13976
13977
# File 'lib/models/porcelain.rb', line 13975

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13977
13978
13979
# File 'lib/models/porcelain.rb', line 13977

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14007
14008
14009
14010
14011
14012
14013
# File 'lib/models/porcelain.rb', line 14007

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end