Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



13915
13916
13917
13918
13919
13920
13921
13922
13923
13924
13925
13926
13927
13928
13929
13930
13931
13932
13933
13934
13935
13936
13937
13938
13939
13940
13941
# File 'lib/models/porcelain.rb', line 13915

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13891
13892
13893
# File 'lib/models/porcelain.rb', line 13891

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13893
13894
13895
# File 'lib/models/porcelain.rb', line 13893

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13895
13896
13897
# File 'lib/models/porcelain.rb', line 13895

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13897
13898
13899
# File 'lib/models/porcelain.rb', line 13897

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13899
13900
13901
# File 'lib/models/porcelain.rb', line 13899

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13901
13902
13903
# File 'lib/models/porcelain.rb', line 13901

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13903
13904
13905
# File 'lib/models/porcelain.rb', line 13903

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13905
13906
13907
# File 'lib/models/porcelain.rb', line 13905

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13907
13908
13909
# File 'lib/models/porcelain.rb', line 13907

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13909
13910
13911
# File 'lib/models/porcelain.rb', line 13909

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13911
13912
13913
# File 'lib/models/porcelain.rb', line 13911

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13913
13914
13915
# File 'lib/models/porcelain.rb', line 13913

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13943
13944
13945
13946
13947
13948
13949
# File 'lib/models/porcelain.rb', line 13943

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end