Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



13093
13094
13095
13096
13097
13098
13099
13100
13101
13102
13103
13104
13105
13106
13107
13108
13109
13110
13111
13112
13113
13114
13115
13116
13117
13118
13119
# File 'lib/models/porcelain.rb', line 13093

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13069
13070
13071
# File 'lib/models/porcelain.rb', line 13069

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13071
13072
13073
# File 'lib/models/porcelain.rb', line 13071

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13073
13074
13075
# File 'lib/models/porcelain.rb', line 13073

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13075
13076
13077
# File 'lib/models/porcelain.rb', line 13075

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13077
13078
13079
# File 'lib/models/porcelain.rb', line 13077

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13079
13080
13081
# File 'lib/models/porcelain.rb', line 13079

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13081
13082
13083
# File 'lib/models/porcelain.rb', line 13081

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13083
13084
13085
# File 'lib/models/porcelain.rb', line 13083

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13085
13086
13087
# File 'lib/models/porcelain.rb', line 13085

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13087
13088
13089
# File 'lib/models/porcelain.rb', line 13087

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13089
13090
13091
# File 'lib/models/porcelain.rb', line 13089

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13091
13092
13093
# File 'lib/models/porcelain.rb', line 13091

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13121
13122
13123
13124
13125
13126
13127
# File 'lib/models/porcelain.rb', line 13121

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end