Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



11813
11814
11815
11816
11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
11829
11830
11831
11832
11833
11834
11835
11836
11837
11838
11839
# File 'lib/models/porcelain.rb', line 11813

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11789
11790
11791
# File 'lib/models/porcelain.rb', line 11789

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11791
11792
11793
# File 'lib/models/porcelain.rb', line 11791

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11793
11794
11795
# File 'lib/models/porcelain.rb', line 11793

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11795
11796
11797
# File 'lib/models/porcelain.rb', line 11795

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11797
11798
11799
# File 'lib/models/porcelain.rb', line 11797

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11799
11800
11801
# File 'lib/models/porcelain.rb', line 11799

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11801
11802
11803
# File 'lib/models/porcelain.rb', line 11801

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11803
11804
11805
# File 'lib/models/porcelain.rb', line 11803

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11805
11806
11807
# File 'lib/models/porcelain.rb', line 11805

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11807
11808
11809
# File 'lib/models/porcelain.rb', line 11807

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11809
11810
11811
# File 'lib/models/porcelain.rb', line 11809

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11811
11812
11813
# File 'lib/models/porcelain.rb', line 11811

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11841
11842
11843
11844
11845
11846
11847
# File 'lib/models/porcelain.rb', line 11841

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end