Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



11630
11631
11632
11633
11634
11635
11636
11637
11638
11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
# File 'lib/models/porcelain.rb', line 11630

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11606
11607
11608
# File 'lib/models/porcelain.rb', line 11606

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11608
11609
11610
# File 'lib/models/porcelain.rb', line 11608

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11610
11611
11612
# File 'lib/models/porcelain.rb', line 11610

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11612
11613
11614
# File 'lib/models/porcelain.rb', line 11612

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11614
11615
11616
# File 'lib/models/porcelain.rb', line 11614

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11616
11617
11618
# File 'lib/models/porcelain.rb', line 11616

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11618
11619
11620
# File 'lib/models/porcelain.rb', line 11618

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11620
11621
11622
# File 'lib/models/porcelain.rb', line 11620

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11622
11623
11624
# File 'lib/models/porcelain.rb', line 11622

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11624
11625
11626
# File 'lib/models/porcelain.rb', line 11624

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11626
11627
11628
# File 'lib/models/porcelain.rb', line 11626

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11628
11629
11630
# File 'lib/models/porcelain.rb', line 11628

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11658
11659
11660
11661
11662
11663
11664
# File 'lib/models/porcelain.rb', line 11658

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end