Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



10398
10399
10400
10401
10402
10403
10404
10405
10406
10407
10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
# File 'lib/models/porcelain.rb', line 10398

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10374
10375
10376
# File 'lib/models/porcelain.rb', line 10374

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10376
10377
10378
# File 'lib/models/porcelain.rb', line 10376

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10378
10379
10380
# File 'lib/models/porcelain.rb', line 10378

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10380
10381
10382
# File 'lib/models/porcelain.rb', line 10380

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10382
10383
10384
# File 'lib/models/porcelain.rb', line 10382

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10384
10385
10386
# File 'lib/models/porcelain.rb', line 10384

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10386
10387
10388
# File 'lib/models/porcelain.rb', line 10386

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10388
10389
10390
# File 'lib/models/porcelain.rb', line 10388

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10390
10391
10392
# File 'lib/models/porcelain.rb', line 10390

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10392
10393
10394
# File 'lib/models/porcelain.rb', line 10392

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10394
10395
10396
# File 'lib/models/porcelain.rb', line 10394

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10396
10397
10398
# File 'lib/models/porcelain.rb', line 10396

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10426
10427
10428
10429
10430
10431
10432
# File 'lib/models/porcelain.rb', line 10426

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end