Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



10327
10328
10329
10330
10331
10332
10333
10334
10335
10336
10337
10338
10339
10340
10341
10342
10343
10344
10345
10346
10347
10348
10349
10350
10351
10352
10353
# File 'lib/models/porcelain.rb', line 10327

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10303
10304
10305
# File 'lib/models/porcelain.rb', line 10303

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10305
10306
10307
# File 'lib/models/porcelain.rb', line 10305

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10307
10308
10309
# File 'lib/models/porcelain.rb', line 10307

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10309
10310
10311
# File 'lib/models/porcelain.rb', line 10309

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10311
10312
10313
# File 'lib/models/porcelain.rb', line 10311

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10313
10314
10315
# File 'lib/models/porcelain.rb', line 10313

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10315
10316
10317
# File 'lib/models/porcelain.rb', line 10315

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10317
10318
10319
# File 'lib/models/porcelain.rb', line 10317

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10319
10320
10321
# File 'lib/models/porcelain.rb', line 10319

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10321
10322
10323
# File 'lib/models/porcelain.rb', line 10321

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10323
10324
10325
# File 'lib/models/porcelain.rb', line 10323

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10325
10326
10327
# File 'lib/models/porcelain.rb', line 10325

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10355
10356
10357
10358
10359
10360
10361
# File 'lib/models/porcelain.rb', line 10355

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end