Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
10281
10282
10283
10284
10285
10286
10287
# File 'lib/models/porcelain.rb', line 10261

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10237
10238
10239
# File 'lib/models/porcelain.rb', line 10237

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10239
10240
10241
# File 'lib/models/porcelain.rb', line 10239

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10241
10242
10243
# File 'lib/models/porcelain.rb', line 10241

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10243
10244
10245
# File 'lib/models/porcelain.rb', line 10243

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10245
10246
10247
# File 'lib/models/porcelain.rb', line 10245

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10247
10248
10249
# File 'lib/models/porcelain.rb', line 10247

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10249
10250
10251
# File 'lib/models/porcelain.rb', line 10249

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10251
10252
10253
# File 'lib/models/porcelain.rb', line 10251

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10253
10254
10255
# File 'lib/models/porcelain.rb', line 10253

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10255
10256
10257
# File 'lib/models/porcelain.rb', line 10255

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10257
10258
10259
# File 'lib/models/porcelain.rb', line 10257

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10259
10260
10261
# File 'lib/models/porcelain.rb', line 10259

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10289
10290
10291
10292
10293
10294
10295
# File 'lib/models/porcelain.rb', line 10289

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end