Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
9981
9982
9983
9984
9985
9986
9987
9988
9989
9990
9991
9992
# File 'lib/models/porcelain.rb', line 9966

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9942
9943
9944
# File 'lib/models/porcelain.rb', line 9942

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9944
9945
9946
# File 'lib/models/porcelain.rb', line 9944

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9946
9947
9948
# File 'lib/models/porcelain.rb', line 9946

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9948
9949
9950
# File 'lib/models/porcelain.rb', line 9948

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9950
9951
9952
# File 'lib/models/porcelain.rb', line 9950

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9952
9953
9954
# File 'lib/models/porcelain.rb', line 9952

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9954
9955
9956
# File 'lib/models/porcelain.rb', line 9954

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9956
9957
9958
# File 'lib/models/porcelain.rb', line 9956

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9958
9959
9960
# File 'lib/models/porcelain.rb', line 9958

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9960
9961
9962
# File 'lib/models/porcelain.rb', line 9960

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9962
9963
9964
# File 'lib/models/porcelain.rb', line 9962

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9964
9965
9966
# File 'lib/models/porcelain.rb', line 9964

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9994
9995
9996
9997
9998
9999
10000
# File 'lib/models/porcelain.rb', line 9994

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end