Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



9283
9284
9285
9286
9287
9288
9289
9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
# File 'lib/models/porcelain.rb', line 9283

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9261
9262
9263
# File 'lib/models/porcelain.rb', line 9261

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9263
9264
9265
# File 'lib/models/porcelain.rb', line 9263

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9265
9266
9267
# File 'lib/models/porcelain.rb', line 9265

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9267
9268
9269
# File 'lib/models/porcelain.rb', line 9267

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9269
9270
9271
# File 'lib/models/porcelain.rb', line 9269

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9271
9272
9273
# File 'lib/models/porcelain.rb', line 9271

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9273
9274
9275
# File 'lib/models/porcelain.rb', line 9273

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9275
9276
9277
# File 'lib/models/porcelain.rb', line 9275

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9277
9278
9279
# File 'lib/models/porcelain.rb', line 9277

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9279
9280
9281
# File 'lib/models/porcelain.rb', line 9279

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9281
9282
9283
# File 'lib/models/porcelain.rb', line 9281

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9309
9310
9311
9312
9313
9314
9315
# File 'lib/models/porcelain.rb', line 9309

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end