Class: SDM::RawTCP

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RawTCP

Returns a new instance of RawTCP.



7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
7210
7211
# File 'lib/models/porcelain.rb', line 7187

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7165
7166
7167
# File 'lib/models/porcelain.rb', line 7165

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7167
7168
7169
# File 'lib/models/porcelain.rb', line 7167

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7169
7170
7171
# File 'lib/models/porcelain.rb', line 7169

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7171
7172
7173
# File 'lib/models/porcelain.rb', line 7171

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7173
7174
7175
# File 'lib/models/porcelain.rb', line 7173

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7175
7176
7177
# File 'lib/models/porcelain.rb', line 7175

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7177
7178
7179
# File 'lib/models/porcelain.rb', line 7177

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7179
7180
7181
# File 'lib/models/porcelain.rb', line 7179

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7181
7182
7183
# File 'lib/models/porcelain.rb', line 7181

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7183
7184
7185
# File 'lib/models/porcelain.rb', line 7183

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7185
7186
7187
# File 'lib/models/porcelain.rb', line 7185

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7213
7214
7215
7216
7217
7218
7219
# File 'lib/models/porcelain.rb', line 7213

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end