Class: SDM::RawTCP
- Inherits:
-
Object
- Object
- SDM::RawTCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ RawTCP
constructor
A new instance of RawTCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ RawTCP
Returns a new instance of RawTCP.
5902 5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 5922 5923 5924 |
# File 'lib/models/porcelain.rb', line 5902 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5882 5883 5884 |
# File 'lib/models/porcelain.rb', line 5882 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5884 5885 5886 |
# File 'lib/models/porcelain.rb', line 5884 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5886 5887 5888 |
# File 'lib/models/porcelain.rb', line 5886 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5888 5889 5890 |
# File 'lib/models/porcelain.rb', line 5888 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5890 5891 5892 |
# File 'lib/models/porcelain.rb', line 5890 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5892 5893 5894 |
# File 'lib/models/porcelain.rb', line 5892 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5894 5895 5896 |
# File 'lib/models/porcelain.rb', line 5894 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5896 5897 5898 |
# File 'lib/models/porcelain.rb', line 5896 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5898 5899 5900 |
# File 'lib/models/porcelain.rb', line 5898 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5900 5901 5902 |
# File 'lib/models/porcelain.rb', line 5900 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5926 5927 5928 5929 5930 5931 5932 |
# File 'lib/models/porcelain.rb', line 5926 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |