Class: SDM::RawTCP
- Inherits:
-
Object
- Object
- SDM::RawTCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ RawTCP
constructor
A new instance of RawTCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ RawTCP
Returns a new instance of RawTCP.
5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 |
# File 'lib/models/porcelain.rb', line 5172 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5152 5153 5154 |
# File 'lib/models/porcelain.rb', line 5152 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5154 5155 5156 |
# File 'lib/models/porcelain.rb', line 5154 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5156 5157 5158 |
# File 'lib/models/porcelain.rb', line 5156 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5158 5159 5160 |
# File 'lib/models/porcelain.rb', line 5158 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5160 5161 5162 |
# File 'lib/models/porcelain.rb', line 5160 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5162 5163 5164 |
# File 'lib/models/porcelain.rb', line 5162 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5164 5165 5166 |
# File 'lib/models/porcelain.rb', line 5164 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5166 5167 5168 |
# File 'lib/models/porcelain.rb', line 5166 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5168 5169 5170 |
# File 'lib/models/porcelain.rb', line 5168 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5170 5171 5172 |
# File 'lib/models/porcelain.rb', line 5170 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5196 5197 5198 5199 5200 5201 5202 |
# File 'lib/models/porcelain.rb', line 5196 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |