Class: SDM::RawTCP
- Inherits:
-
Object
- Object
- SDM::RawTCP
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ RawTCP
constructor
A new instance of RawTCP.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ RawTCP
Returns a new instance of RawTCP.
5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 5786 5787 5788 5789 5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 5806 5807 5808 5809 5810 |
# File 'lib/models/porcelain.rb', line 5772 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5754 5755 5756 |
# File 'lib/models/porcelain.rb', line 5754 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5756 5757 5758 |
# File 'lib/models/porcelain.rb', line 5756 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5758 5759 5760 |
# File 'lib/models/porcelain.rb', line 5758 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5760 5761 5762 |
# File 'lib/models/porcelain.rb', line 5760 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5762 5763 5764 |
# File 'lib/models/porcelain.rb', line 5762 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5764 5765 5766 |
# File 'lib/models/porcelain.rb', line 5764 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5766 5767 5768 |
# File 'lib/models/porcelain.rb', line 5766 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5768 5769 5770 |
# File 'lib/models/porcelain.rb', line 5768 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5770 5771 5772 |
# File 'lib/models/porcelain.rb', line 5770 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5812 5813 5814 5815 5816 5817 5818 |
# File 'lib/models/porcelain.rb', line 5812 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |