Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



14742
14743
14744
14745
14746
14747
14748
14749
14750
14751
14752
14753
14754
14755
14756
14757
14758
14759
14760
14761
14762
14763
14764
14765
14766
14767
14768
14769
14770
14771
14772
14773
14774
# File 'lib/models/porcelain.rb', line 14742

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14712
14713
14714
# File 'lib/models/porcelain.rb', line 14712

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14714
14715
14716
# File 'lib/models/porcelain.rb', line 14714

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14716
14717
14718
# File 'lib/models/porcelain.rb', line 14716

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14718
14719
14720
# File 'lib/models/porcelain.rb', line 14718

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14720
14721
14722
# File 'lib/models/porcelain.rb', line 14720

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14722
14723
14724
# File 'lib/models/porcelain.rb', line 14722

def name
  @name
end

#passwordObject

The password to authenticate with.



14724
14725
14726
# File 'lib/models/porcelain.rb', line 14724

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14726
14727
14728
# File 'lib/models/porcelain.rb', line 14726

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14728
14729
14730
# File 'lib/models/porcelain.rb', line 14728

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14730
14731
14732
# File 'lib/models/porcelain.rb', line 14730

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14732
14733
14734
# File 'lib/models/porcelain.rb', line 14732

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14734
14735
14736
# File 'lib/models/porcelain.rb', line 14734

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14736
14737
14738
# File 'lib/models/porcelain.rb', line 14736

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14738
14739
14740
# File 'lib/models/porcelain.rb', line 14738

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14740
14741
14742
# File 'lib/models/porcelain.rb', line 14740

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14776
14777
14778
14779
14780
14781
14782
# File 'lib/models/porcelain.rb', line 14776

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end