Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



14424
14425
14426
14427
14428
14429
14430
14431
14432
14433
14434
14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
14447
14448
14449
14450
14451
14452
14453
14454
14455
14456
# File 'lib/models/porcelain.rb', line 14424

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14394
14395
14396
# File 'lib/models/porcelain.rb', line 14394

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14396
14397
14398
# File 'lib/models/porcelain.rb', line 14396

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14398
14399
14400
# File 'lib/models/porcelain.rb', line 14398

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14400
14401
14402
# File 'lib/models/porcelain.rb', line 14400

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14402
14403
14404
# File 'lib/models/porcelain.rb', line 14402

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14404
14405
14406
# File 'lib/models/porcelain.rb', line 14404

def name
  @name
end

#passwordObject

The password to authenticate with.



14406
14407
14408
# File 'lib/models/porcelain.rb', line 14406

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14408
14409
14410
# File 'lib/models/porcelain.rb', line 14408

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14410
14411
14412
# File 'lib/models/porcelain.rb', line 14410

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14412
14413
14414
# File 'lib/models/porcelain.rb', line 14412

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14414
14415
14416
# File 'lib/models/porcelain.rb', line 14414

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14416
14417
14418
# File 'lib/models/porcelain.rb', line 14416

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14418
14419
14420
# File 'lib/models/porcelain.rb', line 14418

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14420
14421
14422
# File 'lib/models/porcelain.rb', line 14420

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14422
14423
14424
# File 'lib/models/porcelain.rb', line 14422

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14458
14459
14460
14461
14462
14463
14464
# File 'lib/models/porcelain.rb', line 14458

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end