Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



14048
14049
14050
14051
14052
14053
14054
14055
14056
14057
14058
14059
14060
14061
14062
14063
14064
14065
14066
14067
14068
14069
14070
14071
14072
14073
14074
14075
14076
14077
14078
14079
14080
# File 'lib/models/porcelain.rb', line 14048

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14018
14019
14020
# File 'lib/models/porcelain.rb', line 14018

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14020
14021
14022
# File 'lib/models/porcelain.rb', line 14020

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14022
14023
14024
# File 'lib/models/porcelain.rb', line 14022

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14024
14025
14026
# File 'lib/models/porcelain.rb', line 14024

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14026
14027
14028
# File 'lib/models/porcelain.rb', line 14026

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14028
14029
14030
# File 'lib/models/porcelain.rb', line 14028

def name
  @name
end

#passwordObject

The password to authenticate with.



14030
14031
14032
# File 'lib/models/porcelain.rb', line 14030

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14032
14033
14034
# File 'lib/models/porcelain.rb', line 14032

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14034
14035
14036
# File 'lib/models/porcelain.rb', line 14034

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14036
14037
14038
# File 'lib/models/porcelain.rb', line 14036

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14038
14039
14040
# File 'lib/models/porcelain.rb', line 14038

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14040
14041
14042
# File 'lib/models/porcelain.rb', line 14040

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14042
14043
14044
# File 'lib/models/porcelain.rb', line 14042

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14044
14045
14046
# File 'lib/models/porcelain.rb', line 14044

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14046
14047
14048
# File 'lib/models/porcelain.rb', line 14046

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14082
14083
14084
14085
14086
14087
14088
# File 'lib/models/porcelain.rb', line 14082

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end