Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



13984
13985
13986
13987
13988
13989
13990
13991
13992
13993
13994
13995
13996
13997
13998
13999
14000
14001
14002
14003
14004
14005
14006
14007
14008
14009
14010
14011
14012
14013
14014
14015
14016
# File 'lib/models/porcelain.rb', line 13984

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13954
13955
13956
# File 'lib/models/porcelain.rb', line 13954

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13956
13957
13958
# File 'lib/models/porcelain.rb', line 13956

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13958
13959
13960
# File 'lib/models/porcelain.rb', line 13958

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13960
13961
13962
# File 'lib/models/porcelain.rb', line 13960

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13962
13963
13964
# File 'lib/models/porcelain.rb', line 13962

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13964
13965
13966
# File 'lib/models/porcelain.rb', line 13964

def name
  @name
end

#passwordObject

The password to authenticate with.



13966
13967
13968
# File 'lib/models/porcelain.rb', line 13966

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13968
13969
13970
# File 'lib/models/porcelain.rb', line 13968

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13970
13971
13972
# File 'lib/models/porcelain.rb', line 13970

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13972
13973
13974
# File 'lib/models/porcelain.rb', line 13972

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13974
13975
13976
# File 'lib/models/porcelain.rb', line 13974

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13976
13977
13978
# File 'lib/models/porcelain.rb', line 13976

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13978
13979
13980
# File 'lib/models/porcelain.rb', line 13978

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



13980
13981
13982
# File 'lib/models/porcelain.rb', line 13980

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



13982
13983
13984
# File 'lib/models/porcelain.rb', line 13982

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14018
14019
14020
14021
14022
14023
14024
# File 'lib/models/porcelain.rb', line 14018

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end