Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 11727 11728 11729 11730 11731 |
# File 'lib/models/porcelain.rb', line 11699 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11669 11670 11671 |
# File 'lib/models/porcelain.rb', line 11669 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11671 11672 11673 |
# File 'lib/models/porcelain.rb', line 11671 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11673 11674 11675 |
# File 'lib/models/porcelain.rb', line 11673 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11675 11676 11677 |
# File 'lib/models/porcelain.rb', line 11675 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11677 11678 11679 |
# File 'lib/models/porcelain.rb', line 11677 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11679 11680 11681 |
# File 'lib/models/porcelain.rb', line 11679 def name @name end |
#password ⇒ Object
The password to authenticate with.
11681 11682 11683 |
# File 'lib/models/porcelain.rb', line 11681 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11683 11684 11685 |
# File 'lib/models/porcelain.rb', line 11683 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11685 11686 11687 |
# File 'lib/models/porcelain.rb', line 11685 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11687 11688 11689 |
# File 'lib/models/porcelain.rb', line 11687 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11689 11690 11691 |
# File 'lib/models/porcelain.rb', line 11689 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11691 11692 11693 |
# File 'lib/models/porcelain.rb', line 11691 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11693 11694 11695 |
# File 'lib/models/porcelain.rb', line 11693 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
11695 11696 11697 |
# File 'lib/models/porcelain.rb', line 11695 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
11697 11698 11699 |
# File 'lib/models/porcelain.rb', line 11697 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11733 11734 11735 11736 11737 11738 11739 |
# File 'lib/models/porcelain.rb', line 11733 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |