Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
11494
11495
11496
11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
# File 'lib/models/porcelain.rb', line 11476

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11446
11447
11448
# File 'lib/models/porcelain.rb', line 11446

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11448
11449
11450
# File 'lib/models/porcelain.rb', line 11448

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11450
11451
11452
# File 'lib/models/porcelain.rb', line 11450

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11452
11453
11454
# File 'lib/models/porcelain.rb', line 11452

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11454
11455
11456
# File 'lib/models/porcelain.rb', line 11454

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11456
11457
11458
# File 'lib/models/porcelain.rb', line 11456

def name
  @name
end

#passwordObject

The password to authenticate with.



11458
11459
11460
# File 'lib/models/porcelain.rb', line 11458

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11460
11461
11462
# File 'lib/models/porcelain.rb', line 11460

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11462
11463
11464
# File 'lib/models/porcelain.rb', line 11462

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11464
11465
11466
# File 'lib/models/porcelain.rb', line 11464

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11466
11467
11468
# File 'lib/models/porcelain.rb', line 11466

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11468
11469
11470
# File 'lib/models/porcelain.rb', line 11468

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11470
11471
11472
# File 'lib/models/porcelain.rb', line 11470

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11472
11473
11474
# File 'lib/models/porcelain.rb', line 11472

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11474
11475
11476
# File 'lib/models/porcelain.rb', line 11474

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11510
11511
11512
11513
11514
11515
11516
# File 'lib/models/porcelain.rb', line 11510

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end