Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 10649 10650 10651 10652 10653 10654 10655 10656 10657 |
# File 'lib/models/porcelain.rb', line 10625 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10595 10596 10597 |
# File 'lib/models/porcelain.rb', line 10595 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10597 10598 10599 |
# File 'lib/models/porcelain.rb', line 10597 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10599 10600 10601 |
# File 'lib/models/porcelain.rb', line 10599 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10601 10602 10603 |
# File 'lib/models/porcelain.rb', line 10601 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10603 10604 10605 |
# File 'lib/models/porcelain.rb', line 10603 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10605 10606 10607 |
# File 'lib/models/porcelain.rb', line 10605 def name @name end |
#password ⇒ Object
The password to authenticate with.
10607 10608 10609 |
# File 'lib/models/porcelain.rb', line 10607 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10609 10610 10611 |
# File 'lib/models/porcelain.rb', line 10609 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10611 10612 10613 |
# File 'lib/models/porcelain.rb', line 10611 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10613 10614 10615 |
# File 'lib/models/porcelain.rb', line 10613 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10615 10616 10617 |
# File 'lib/models/porcelain.rb', line 10615 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10617 10618 10619 |
# File 'lib/models/porcelain.rb', line 10617 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10619 10620 10621 |
# File 'lib/models/porcelain.rb', line 10619 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
10621 10622 10623 |
# File 'lib/models/porcelain.rb', line 10621 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
10623 10624 10625 |
# File 'lib/models/porcelain.rb', line 10623 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10659 10660 10661 10662 10663 10664 10665 |
# File 'lib/models/porcelain.rb', line 10659 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |