Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
10569
10570
10571
10572
10573
10574
10575
10576
10577
10578
10579
10580
10581
10582
# File 'lib/models/porcelain.rb', line 10550

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10520
10521
10522
# File 'lib/models/porcelain.rb', line 10520

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10522
10523
10524
# File 'lib/models/porcelain.rb', line 10522

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10524
10525
10526
# File 'lib/models/porcelain.rb', line 10524

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10526
10527
10528
# File 'lib/models/porcelain.rb', line 10526

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10528
10529
10530
# File 'lib/models/porcelain.rb', line 10528

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10530
10531
10532
# File 'lib/models/porcelain.rb', line 10530

def name
  @name
end

#passwordObject

The password to authenticate with.



10532
10533
10534
# File 'lib/models/porcelain.rb', line 10532

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10534
10535
10536
# File 'lib/models/porcelain.rb', line 10534

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10536
10537
10538
# File 'lib/models/porcelain.rb', line 10536

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10538
10539
10540
# File 'lib/models/porcelain.rb', line 10538

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10540
10541
10542
# File 'lib/models/porcelain.rb', line 10540

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10542
10543
10544
# File 'lib/models/porcelain.rb', line 10542

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10544
10545
10546
# File 'lib/models/porcelain.rb', line 10544

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



10546
10547
10548
# File 'lib/models/porcelain.rb', line 10546

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



10548
10549
10550
# File 'lib/models/porcelain.rb', line 10548

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10584
10585
10586
10587
10588
10589
10590
# File 'lib/models/porcelain.rb', line 10584

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end