Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
10551 10552 10553 10554 10555 10556 10557 10558 10559 10560 10561 10562 10563 10564 10565 10566 10567 10568 10569 10570 10571 10572 10573 10574 10575 10576 10577 10578 10579 10580 10581 10582 10583 |
# File 'lib/models/porcelain.rb', line 10551 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10521 10522 10523 |
# File 'lib/models/porcelain.rb', line 10521 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10523 10524 10525 |
# File 'lib/models/porcelain.rb', line 10523 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10525 10526 10527 |
# File 'lib/models/porcelain.rb', line 10525 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10527 10528 10529 |
# File 'lib/models/porcelain.rb', line 10527 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10529 10530 10531 |
# File 'lib/models/porcelain.rb', line 10529 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10531 10532 10533 |
# File 'lib/models/porcelain.rb', line 10531 def name @name end |
#password ⇒ Object
The password to authenticate with.
10533 10534 10535 |
# File 'lib/models/porcelain.rb', line 10533 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10535 10536 10537 |
# File 'lib/models/porcelain.rb', line 10535 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10537 10538 10539 |
# File 'lib/models/porcelain.rb', line 10537 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10539 10540 10541 |
# File 'lib/models/porcelain.rb', line 10539 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10541 10542 10543 |
# File 'lib/models/porcelain.rb', line 10541 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10543 10544 10545 |
# File 'lib/models/porcelain.rb', line 10543 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10545 10546 10547 |
# File 'lib/models/porcelain.rb', line 10545 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
10547 10548 10549 |
# File 'lib/models/porcelain.rb', line 10547 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
10549 10550 10551 |
# File 'lib/models/porcelain.rb', line 10549 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10585 10586 10587 10588 10589 10590 10591 |
# File 'lib/models/porcelain.rb', line 10585 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |