Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
# File 'lib/models/porcelain.rb', line 10467

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10437
10438
10439
# File 'lib/models/porcelain.rb', line 10437

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10439
10440
10441
# File 'lib/models/porcelain.rb', line 10439

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10441
10442
10443
# File 'lib/models/porcelain.rb', line 10441

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10443
10444
10445
# File 'lib/models/porcelain.rb', line 10443

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10445
10446
10447
# File 'lib/models/porcelain.rb', line 10445

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10447
10448
10449
# File 'lib/models/porcelain.rb', line 10447

def name
  @name
end

#passwordObject

The password to authenticate with.



10449
10450
10451
# File 'lib/models/porcelain.rb', line 10449

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10451
10452
10453
# File 'lib/models/porcelain.rb', line 10451

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10453
10454
10455
# File 'lib/models/porcelain.rb', line 10453

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10455
10456
10457
# File 'lib/models/porcelain.rb', line 10455

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10457
10458
10459
# File 'lib/models/porcelain.rb', line 10457

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10459
10460
10461
# File 'lib/models/porcelain.rb', line 10459

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10461
10462
10463
# File 'lib/models/porcelain.rb', line 10461

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



10463
10464
10465
# File 'lib/models/porcelain.rb', line 10463

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



10465
10466
10467
# File 'lib/models/porcelain.rb', line 10465

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10501
10502
10503
10504
10505
10506
10507
# File 'lib/models/porcelain.rb', line 10501

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end