Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
10397 10398 10399 10400 10401 10402 10403 10404 10405 10406 10407 10408 10409 10410 10411 10412 10413 10414 10415 10416 10417 10418 10419 10420 10421 10422 10423 10424 10425 10426 10427 10428 10429 |
# File 'lib/models/porcelain.rb', line 10397 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10367 10368 10369 |
# File 'lib/models/porcelain.rb', line 10367 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10369 10370 10371 |
# File 'lib/models/porcelain.rb', line 10369 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10371 10372 10373 |
# File 'lib/models/porcelain.rb', line 10371 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10373 10374 10375 |
# File 'lib/models/porcelain.rb', line 10373 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10375 10376 10377 |
# File 'lib/models/porcelain.rb', line 10375 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10377 10378 10379 |
# File 'lib/models/porcelain.rb', line 10377 def name @name end |
#password ⇒ Object
The password to authenticate with.
10379 10380 10381 |
# File 'lib/models/porcelain.rb', line 10379 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10381 10382 10383 |
# File 'lib/models/porcelain.rb', line 10381 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10383 10384 10385 |
# File 'lib/models/porcelain.rb', line 10383 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10385 10386 10387 |
# File 'lib/models/porcelain.rb', line 10385 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10387 10388 10389 |
# File 'lib/models/porcelain.rb', line 10387 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10389 10390 10391 |
# File 'lib/models/porcelain.rb', line 10389 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10391 10392 10393 |
# File 'lib/models/porcelain.rb', line 10391 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
10393 10394 10395 |
# File 'lib/models/porcelain.rb', line 10393 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
10395 10396 10397 |
# File 'lib/models/porcelain.rb', line 10395 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10431 10432 10433 10434 10435 10436 10437 |
# File 'lib/models/porcelain.rb', line 10431 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |