Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 10344 10345 10346 10347 10348 10349 10350 10351 10352 10353 10354 10355 10356 10357 10358 10359 10360 10361 10362 |
# File 'lib/models/porcelain.rb', line 10330 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10300 10301 10302 |
# File 'lib/models/porcelain.rb', line 10300 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10302 10303 10304 |
# File 'lib/models/porcelain.rb', line 10302 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10304 10305 10306 |
# File 'lib/models/porcelain.rb', line 10304 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10306 10307 10308 |
# File 'lib/models/porcelain.rb', line 10306 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10308 10309 10310 |
# File 'lib/models/porcelain.rb', line 10308 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10310 10311 10312 |
# File 'lib/models/porcelain.rb', line 10310 def name @name end |
#password ⇒ Object
The password to authenticate with.
10312 10313 10314 |
# File 'lib/models/porcelain.rb', line 10312 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10314 10315 10316 |
# File 'lib/models/porcelain.rb', line 10314 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10316 10317 10318 |
# File 'lib/models/porcelain.rb', line 10316 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10318 10319 10320 |
# File 'lib/models/porcelain.rb', line 10318 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10320 10321 10322 |
# File 'lib/models/porcelain.rb', line 10320 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10322 10323 10324 |
# File 'lib/models/porcelain.rb', line 10322 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10324 10325 10326 |
# File 'lib/models/porcelain.rb', line 10324 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
10326 10327 10328 |
# File 'lib/models/porcelain.rb', line 10326 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
10328 10329 10330 |
# File 'lib/models/porcelain.rb', line 10328 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10364 10365 10366 10367 10368 10369 10370 |
# File 'lib/models/porcelain.rb', line 10364 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |