Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



10035
10036
10037
10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
10058
10059
10060
10061
10062
10063
10064
10065
10066
10067
# File 'lib/models/porcelain.rb', line 10035

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10005
10006
10007
# File 'lib/models/porcelain.rb', line 10005

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10007
10008
10009
# File 'lib/models/porcelain.rb', line 10007

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10009
10010
10011
# File 'lib/models/porcelain.rb', line 10009

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10011
10012
10013
# File 'lib/models/porcelain.rb', line 10011

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10013
10014
10015
# File 'lib/models/porcelain.rb', line 10013

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10015
10016
10017
# File 'lib/models/porcelain.rb', line 10015

def name
  @name
end

#passwordObject

The password to authenticate with.



10017
10018
10019
# File 'lib/models/porcelain.rb', line 10017

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10019
10020
10021
# File 'lib/models/porcelain.rb', line 10019

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10021
10022
10023
# File 'lib/models/porcelain.rb', line 10021

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10023
10024
10025
# File 'lib/models/porcelain.rb', line 10023

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10025
10026
10027
# File 'lib/models/porcelain.rb', line 10025

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10027
10028
10029
# File 'lib/models/porcelain.rb', line 10027

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10029
10030
10031
# File 'lib/models/porcelain.rb', line 10029

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



10031
10032
10033
# File 'lib/models/porcelain.rb', line 10031

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



10033
10034
10035
# File 'lib/models/porcelain.rb', line 10033

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10069
10070
10071
10072
10073
10074
10075
# File 'lib/models/porcelain.rb', line 10069

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end