Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
9981
9982
9983
# File 'lib/models/porcelain.rb', line 9951

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9921
9922
9923
# File 'lib/models/porcelain.rb', line 9921

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9923
9924
9925
# File 'lib/models/porcelain.rb', line 9923

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9925
9926
9927
# File 'lib/models/porcelain.rb', line 9925

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9927
9928
9929
# File 'lib/models/porcelain.rb', line 9927

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9929
9930
9931
# File 'lib/models/porcelain.rb', line 9929

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9931
9932
9933
# File 'lib/models/porcelain.rb', line 9931

def name
  @name
end

#passwordObject

The password to authenticate with.



9933
9934
9935
# File 'lib/models/porcelain.rb', line 9933

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9935
9936
9937
# File 'lib/models/porcelain.rb', line 9935

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9937
9938
9939
# File 'lib/models/porcelain.rb', line 9937

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9939
9940
9941
# File 'lib/models/porcelain.rb', line 9939

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9941
9942
9943
# File 'lib/models/porcelain.rb', line 9941

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9943
9944
9945
# File 'lib/models/porcelain.rb', line 9943

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9945
9946
9947
# File 'lib/models/porcelain.rb', line 9945

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9947
9948
9949
# File 'lib/models/porcelain.rb', line 9947

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9949
9950
9951
# File 'lib/models/porcelain.rb', line 9949

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9985
9986
9987
9988
9989
9990
9991
# File 'lib/models/porcelain.rb', line 9985

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end