Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
9711 9712 9713 9714 9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 |
# File 'lib/models/porcelain.rb', line 9711 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9681 9682 9683 |
# File 'lib/models/porcelain.rb', line 9681 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9683 9684 9685 |
# File 'lib/models/porcelain.rb', line 9683 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9685 9686 9687 |
# File 'lib/models/porcelain.rb', line 9685 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9687 9688 9689 |
# File 'lib/models/porcelain.rb', line 9687 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9689 9690 9691 |
# File 'lib/models/porcelain.rb', line 9689 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9691 9692 9693 |
# File 'lib/models/porcelain.rb', line 9691 def name @name end |
#password ⇒ Object
The password to authenticate with.
9693 9694 9695 |
# File 'lib/models/porcelain.rb', line 9693 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9695 9696 9697 |
# File 'lib/models/porcelain.rb', line 9695 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9697 9698 9699 |
# File 'lib/models/porcelain.rb', line 9697 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
9699 9700 9701 |
# File 'lib/models/porcelain.rb', line 9699 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9701 9702 9703 |
# File 'lib/models/porcelain.rb', line 9701 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9703 9704 9705 |
# File 'lib/models/porcelain.rb', line 9703 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9705 9706 9707 |
# File 'lib/models/porcelain.rb', line 9705 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9707 9708 9709 |
# File 'lib/models/porcelain.rb', line 9707 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9709 9710 9711 |
# File 'lib/models/porcelain.rb', line 9709 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/models/porcelain.rb', line 9745 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |