Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



9634
9635
9636
9637
9638
9639
9640
9641
9642
9643
9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
9665
9666
# File 'lib/models/porcelain.rb', line 9634

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9604
9605
9606
# File 'lib/models/porcelain.rb', line 9604

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9606
9607
9608
# File 'lib/models/porcelain.rb', line 9606

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9608
9609
9610
# File 'lib/models/porcelain.rb', line 9608

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9610
9611
9612
# File 'lib/models/porcelain.rb', line 9610

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9612
9613
9614
# File 'lib/models/porcelain.rb', line 9612

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9614
9615
9616
# File 'lib/models/porcelain.rb', line 9614

def name
  @name
end

#passwordObject

The password to authenticate with.



9616
9617
9618
# File 'lib/models/porcelain.rb', line 9616

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9618
9619
9620
# File 'lib/models/porcelain.rb', line 9618

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9620
9621
9622
# File 'lib/models/porcelain.rb', line 9620

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9622
9623
9624
# File 'lib/models/porcelain.rb', line 9622

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9624
9625
9626
# File 'lib/models/porcelain.rb', line 9624

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9626
9627
9628
# File 'lib/models/porcelain.rb', line 9626

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9628
9629
9630
# File 'lib/models/porcelain.rb', line 9628

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



9630
9631
9632
# File 'lib/models/porcelain.rb', line 9630

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



9632
9633
9634
# File 'lib/models/porcelain.rb', line 9632

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9668
9669
9670
9671
9672
9673
9674
# File 'lib/models/porcelain.rb', line 9668

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end