Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
9348 9349 9350 9351 9352 9353 9354 9355 9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 9373 9374 9375 9376 9377 9378 |
# File 'lib/models/porcelain.rb', line 9348 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9320 9321 9322 |
# File 'lib/models/porcelain.rb', line 9320 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9322 9323 9324 |
# File 'lib/models/porcelain.rb', line 9322 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9324 9325 9326 |
# File 'lib/models/porcelain.rb', line 9324 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9326 9327 9328 |
# File 'lib/models/porcelain.rb', line 9326 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9328 9329 9330 |
# File 'lib/models/porcelain.rb', line 9328 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9330 9331 9332 |
# File 'lib/models/porcelain.rb', line 9330 def name @name end |
#password ⇒ Object
The password to authenticate with.
9332 9333 9334 |
# File 'lib/models/porcelain.rb', line 9332 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9334 9335 9336 |
# File 'lib/models/porcelain.rb', line 9334 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9336 9337 9338 |
# File 'lib/models/porcelain.rb', line 9336 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9338 9339 9340 |
# File 'lib/models/porcelain.rb', line 9338 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9340 9341 9342 |
# File 'lib/models/porcelain.rb', line 9340 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9342 9343 9344 |
# File 'lib/models/porcelain.rb', line 9342 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9344 9345 9346 |
# File 'lib/models/porcelain.rb', line 9344 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9346 9347 9348 |
# File 'lib/models/porcelain.rb', line 9346 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9380 9381 9382 9383 9384 9385 9386 |
# File 'lib/models/porcelain.rb', line 9380 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |