Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
9010 9011 9012 9013 9014 9015 9016 9017 9018 9019 9020 9021 9022 9023 9024 9025 9026 9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 |
# File 'lib/models/porcelain.rb', line 9010 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8982 8983 8984 |
# File 'lib/models/porcelain.rb', line 8982 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8984 8985 8986 |
# File 'lib/models/porcelain.rb', line 8984 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8986 8987 8988 |
# File 'lib/models/porcelain.rb', line 8986 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8988 8989 8990 |
# File 'lib/models/porcelain.rb', line 8988 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8990 8991 8992 |
# File 'lib/models/porcelain.rb', line 8990 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8992 8993 8994 |
# File 'lib/models/porcelain.rb', line 8992 def name @name end |
#password ⇒ Object
The password to authenticate with.
8994 8995 8996 |
# File 'lib/models/porcelain.rb', line 8994 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8996 8997 8998 |
# File 'lib/models/porcelain.rb', line 8996 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8998 8999 9000 |
# File 'lib/models/porcelain.rb', line 8998 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9000 9001 9002 |
# File 'lib/models/porcelain.rb', line 9000 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9002 9003 9004 |
# File 'lib/models/porcelain.rb', line 9002 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9004 9005 9006 |
# File 'lib/models/porcelain.rb', line 9004 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
9006 9007 9008 |
# File 'lib/models/porcelain.rb', line 9006 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
9008 9009 9010 |
# File 'lib/models/porcelain.rb', line 9008 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9042 9043 9044 9045 9046 9047 9048 |
# File 'lib/models/porcelain.rb', line 9042 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |