Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 8259 8260 |
# File 'lib/models/porcelain.rb', line 8230 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8202 8203 8204 |
# File 'lib/models/porcelain.rb', line 8202 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8204 8205 8206 |
# File 'lib/models/porcelain.rb', line 8204 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8206 8207 8208 |
# File 'lib/models/porcelain.rb', line 8206 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8208 8209 8210 |
# File 'lib/models/porcelain.rb', line 8208 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8210 8211 8212 |
# File 'lib/models/porcelain.rb', line 8210 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8212 8213 8214 |
# File 'lib/models/porcelain.rb', line 8212 def name @name end |
#password ⇒ Object
The password to authenticate with.
8214 8215 8216 |
# File 'lib/models/porcelain.rb', line 8214 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8216 8217 8218 |
# File 'lib/models/porcelain.rb', line 8216 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8218 8219 8220 |
# File 'lib/models/porcelain.rb', line 8218 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8220 8221 8222 |
# File 'lib/models/porcelain.rb', line 8220 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8222 8223 8224 |
# File 'lib/models/porcelain.rb', line 8222 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8224 8225 8226 |
# File 'lib/models/porcelain.rb', line 8224 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
8226 8227 8228 |
# File 'lib/models/porcelain.rb', line 8226 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
8228 8229 8230 |
# File 'lib/models/porcelain.rb', line 8228 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8262 8263 8264 8265 8266 8267 8268 |
# File 'lib/models/porcelain.rb', line 8262 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |