Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
7295 7296 7297 7298 7299 7300 7301 7302 7303 7304 7305 7306 7307 7308 7309 7310 7311 7312 7313 7314 7315 7316 7317 7318 7319 7320 7321 7322 7323 7324 7325 |
# File 'lib/models/porcelain.rb', line 7295 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7267 7268 7269 |
# File 'lib/models/porcelain.rb', line 7267 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7269 7270 7271 |
# File 'lib/models/porcelain.rb', line 7269 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7271 7272 7273 |
# File 'lib/models/porcelain.rb', line 7271 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7273 7274 7275 |
# File 'lib/models/porcelain.rb', line 7273 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7275 7276 7277 |
# File 'lib/models/porcelain.rb', line 7275 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7277 7278 7279 |
# File 'lib/models/porcelain.rb', line 7277 def name @name end |
#password ⇒ Object
The password to authenticate with.
7279 7280 7281 |
# File 'lib/models/porcelain.rb', line 7279 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7281 7282 7283 |
# File 'lib/models/porcelain.rb', line 7281 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7283 7284 7285 |
# File 'lib/models/porcelain.rb', line 7283 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7285 7286 7287 |
# File 'lib/models/porcelain.rb', line 7285 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7287 7288 7289 |
# File 'lib/models/porcelain.rb', line 7287 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7289 7290 7291 |
# File 'lib/models/porcelain.rb', line 7289 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7291 7292 7293 |
# File 'lib/models/porcelain.rb', line 7291 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7293 7294 7295 |
# File 'lib/models/porcelain.rb', line 7293 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7327 7328 7329 7330 7331 7332 7333 |
# File 'lib/models/porcelain.rb', line 7327 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |