Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/models/porcelain.rb', line 7252 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7224 7225 7226 |
# File 'lib/models/porcelain.rb', line 7224 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7226 7227 7228 |
# File 'lib/models/porcelain.rb', line 7226 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7228 7229 7230 |
# File 'lib/models/porcelain.rb', line 7228 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7230 7231 7232 |
# File 'lib/models/porcelain.rb', line 7230 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7232 7233 7234 |
# File 'lib/models/porcelain.rb', line 7232 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7234 7235 7236 |
# File 'lib/models/porcelain.rb', line 7234 def name @name end |
#password ⇒ Object
The password to authenticate with.
7236 7237 7238 |
# File 'lib/models/porcelain.rb', line 7236 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7238 7239 7240 |
# File 'lib/models/porcelain.rb', line 7238 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7240 7241 7242 |
# File 'lib/models/porcelain.rb', line 7240 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7242 7243 7244 |
# File 'lib/models/porcelain.rb', line 7242 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7244 7245 7246 |
# File 'lib/models/porcelain.rb', line 7244 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7246 7247 7248 |
# File 'lib/models/porcelain.rb', line 7246 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7248 7249 7250 |
# File 'lib/models/porcelain.rb', line 7248 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7250 7251 7252 |
# File 'lib/models/porcelain.rb', line 7250 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7284 7285 7286 7287 7288 7289 7290 |
# File 'lib/models/porcelain.rb', line 7284 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |