Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 |
# File 'lib/models/porcelain.rb', line 7080 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7052 7053 7054 |
# File 'lib/models/porcelain.rb', line 7052 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7054 7055 7056 |
# File 'lib/models/porcelain.rb', line 7054 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7056 7057 7058 |
# File 'lib/models/porcelain.rb', line 7056 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7058 7059 7060 |
# File 'lib/models/porcelain.rb', line 7058 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7060 7061 7062 |
# File 'lib/models/porcelain.rb', line 7060 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7062 7063 7064 |
# File 'lib/models/porcelain.rb', line 7062 def name @name end |
#password ⇒ Object
The password to authenticate with.
7064 7065 7066 |
# File 'lib/models/porcelain.rb', line 7064 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7066 7067 7068 |
# File 'lib/models/porcelain.rb', line 7066 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7068 7069 7070 |
# File 'lib/models/porcelain.rb', line 7068 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7070 7071 7072 |
# File 'lib/models/porcelain.rb', line 7070 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7072 7073 7074 |
# File 'lib/models/porcelain.rb', line 7072 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7074 7075 7076 |
# File 'lib/models/porcelain.rb', line 7074 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
7076 7077 7078 |
# File 'lib/models/porcelain.rb', line 7076 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
7078 7079 7080 |
# File 'lib/models/porcelain.rb', line 7078 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7112 7113 7114 7115 7116 7117 7118 |
# File 'lib/models/porcelain.rb', line 7112 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |