Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
6673
6674
6675
6676
6677
6678
6679
6680
6681
6682
# File 'lib/models/porcelain.rb', line 6652

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



6624
6625
6626
# File 'lib/models/porcelain.rb', line 6624

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6626
6627
6628
# File 'lib/models/porcelain.rb', line 6626

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6628
6629
6630
# File 'lib/models/porcelain.rb', line 6628

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



6630
6631
6632
# File 'lib/models/porcelain.rb', line 6630

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6632
6633
6634
# File 'lib/models/porcelain.rb', line 6632

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6634
6635
6636
# File 'lib/models/porcelain.rb', line 6634

def name
  @name
end

#passwordObject

The password to authenticate with.



6636
6637
6638
# File 'lib/models/porcelain.rb', line 6636

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



6638
6639
6640
# File 'lib/models/porcelain.rb', line 6638

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



6640
6641
6642
# File 'lib/models/porcelain.rb', line 6640

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6642
6643
6644
# File 'lib/models/porcelain.rb', line 6642

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6644
6645
6646
# File 'lib/models/porcelain.rb', line 6644

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6646
6647
6648
# File 'lib/models/porcelain.rb', line 6646

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



6648
6649
6650
# File 'lib/models/porcelain.rb', line 6648

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



6650
6651
6652
# File 'lib/models/porcelain.rb', line 6650

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6684
6685
6686
6687
6688
6689
6690
# File 'lib/models/porcelain.rb', line 6684

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end