Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



6438
6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
6468
# File 'lib/models/porcelain.rb', line 6438

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6410
6411
6412
# File 'lib/models/porcelain.rb', line 6410

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6412
6413
6414
# File 'lib/models/porcelain.rb', line 6412

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6414
6415
6416
# File 'lib/models/porcelain.rb', line 6414

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6416
6417
6418
# File 'lib/models/porcelain.rb', line 6416

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6418
6419
6420
# File 'lib/models/porcelain.rb', line 6418

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6420
6421
6422
# File 'lib/models/porcelain.rb', line 6420

def name
  @name
end

#passwordObject

Returns the value of attribute password.



6422
6423
6424
# File 'lib/models/porcelain.rb', line 6422

def password
  @password
end

#portObject

Returns the value of attribute port.



6424
6425
6426
# File 'lib/models/porcelain.rb', line 6424

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



6426
6427
6428
# File 'lib/models/porcelain.rb', line 6426

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6428
6429
6430
# File 'lib/models/porcelain.rb', line 6428

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6430
6431
6432
# File 'lib/models/porcelain.rb', line 6430

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6432
6433
6434
# File 'lib/models/porcelain.rb', line 6432

def tags
  @tags
end

#tls_requiredObject

Returns the value of attribute tls_required.



6434
6435
6436
# File 'lib/models/porcelain.rb', line 6434

def tls_required
  @tls_required
end

#usernameObject

Returns the value of attribute username.



6436
6437
6438
# File 'lib/models/porcelain.rb', line 6436

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6470
6471
6472
6473
6474
6475
6476
# File 'lib/models/porcelain.rb', line 6470

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end