Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 |
# File 'lib/models/porcelain.rb', line 6385 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6357 6358 6359 |
# File 'lib/models/porcelain.rb', line 6357 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6359 6360 6361 |
# File 'lib/models/porcelain.rb', line 6359 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6361 6362 6363 |
# File 'lib/models/porcelain.rb', line 6361 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6363 6364 6365 |
# File 'lib/models/porcelain.rb', line 6363 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6365 6366 6367 |
# File 'lib/models/porcelain.rb', line 6365 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6367 6368 6369 |
# File 'lib/models/porcelain.rb', line 6367 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
6369 6370 6371 |
# File 'lib/models/porcelain.rb', line 6369 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6371 6372 6373 |
# File 'lib/models/porcelain.rb', line 6371 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6373 6374 6375 |
# File 'lib/models/porcelain.rb', line 6373 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6375 6376 6377 |
# File 'lib/models/porcelain.rb', line 6375 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6377 6378 6379 |
# File 'lib/models/porcelain.rb', line 6377 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6379 6380 6381 |
# File 'lib/models/porcelain.rb', line 6379 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
6381 6382 6383 |
# File 'lib/models/porcelain.rb', line 6381 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
6383 6384 6385 |
# File 'lib/models/porcelain.rb', line 6383 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6417 6418 6419 6420 6421 6422 6423 |
# File 'lib/models/porcelain.rb', line 6417 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |