Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
5963 5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 5989 5990 5991 |
# File 'lib/models/porcelain.rb', line 5963 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5937 5938 5939 |
# File 'lib/models/porcelain.rb', line 5937 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5939 5940 5941 |
# File 'lib/models/porcelain.rb', line 5939 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5941 5942 5943 |
# File 'lib/models/porcelain.rb', line 5941 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5943 5944 5945 |
# File 'lib/models/porcelain.rb', line 5943 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5945 5946 5947 |
# File 'lib/models/porcelain.rb', line 5945 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5947 5948 5949 |
# File 'lib/models/porcelain.rb', line 5947 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5949 5950 5951 |
# File 'lib/models/porcelain.rb', line 5949 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5951 5952 5953 |
# File 'lib/models/porcelain.rb', line 5951 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5953 5954 5955 |
# File 'lib/models/porcelain.rb', line 5953 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5955 5956 5957 |
# File 'lib/models/porcelain.rb', line 5955 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5957 5958 5959 |
# File 'lib/models/porcelain.rb', line 5957 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5959 5960 5961 |
# File 'lib/models/porcelain.rb', line 5959 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5961 5962 5963 |
# File 'lib/models/porcelain.rb', line 5961 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5993 5994 5995 5996 5997 5998 5999 |
# File 'lib/models/porcelain.rb', line 5993 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |