Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 5351 5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 5362 5363 5364 5365 5366 5367 5368 |
# File 'lib/models/porcelain.rb', line 5340 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5314 5315 5316 |
# File 'lib/models/porcelain.rb', line 5314 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5316 5317 5318 |
# File 'lib/models/porcelain.rb', line 5316 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5318 5319 5320 |
# File 'lib/models/porcelain.rb', line 5318 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5320 5321 5322 |
# File 'lib/models/porcelain.rb', line 5320 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5322 5323 5324 |
# File 'lib/models/porcelain.rb', line 5322 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5324 5325 5326 |
# File 'lib/models/porcelain.rb', line 5324 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5326 5327 5328 |
# File 'lib/models/porcelain.rb', line 5326 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5328 5329 5330 |
# File 'lib/models/porcelain.rb', line 5328 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5330 5331 5332 |
# File 'lib/models/porcelain.rb', line 5330 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5332 5333 5334 |
# File 'lib/models/porcelain.rb', line 5332 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5334 5335 5336 |
# File 'lib/models/porcelain.rb', line 5334 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5336 5337 5338 |
# File 'lib/models/porcelain.rb', line 5336 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5338 5339 5340 |
# File 'lib/models/porcelain.rb', line 5338 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5370 5371 5372 5373 5374 5375 5376 |
# File 'lib/models/porcelain.rb', line 5370 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |