Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
Returns the value of attribute tls_required.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis
Returns a new instance of Redis.
5233 5234 5235 5236 5237 5238 5239 5240 5241 5242 5243 5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 |
# File 'lib/models/porcelain.rb', line 5233 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5207 5208 5209 |
# File 'lib/models/porcelain.rb', line 5207 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5209 5210 5211 |
# File 'lib/models/porcelain.rb', line 5209 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5211 5212 5213 |
# File 'lib/models/porcelain.rb', line 5211 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5213 5214 5215 |
# File 'lib/models/porcelain.rb', line 5213 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5215 5216 5217 |
# File 'lib/models/porcelain.rb', line 5215 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5217 5218 5219 |
# File 'lib/models/porcelain.rb', line 5217 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5219 5220 5221 |
# File 'lib/models/porcelain.rb', line 5219 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5221 5222 5223 |
# File 'lib/models/porcelain.rb', line 5221 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5223 5224 5225 |
# File 'lib/models/porcelain.rb', line 5223 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5225 5226 5227 |
# File 'lib/models/porcelain.rb', line 5225 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5227 5228 5229 |
# File 'lib/models/porcelain.rb', line 5227 def @tags end |
#tls_required ⇒ Object
Returns the value of attribute tls_required.
5229 5230 5231 |
# File 'lib/models/porcelain.rb', line 5229 def tls_required @tls_required end |
#username ⇒ Object
Returns the value of attribute username.
5231 5232 5233 |
# File 'lib/models/porcelain.rb', line 5231 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5263 5264 5265 5266 5267 5268 5269 |
# File 'lib/models/porcelain.rb', line 5263 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |