Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Redis
Returns a new instance of Redis.
5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 5228 5229 5230 5231 5232 5233 5234 |
# File 'lib/models/porcelain.rb', line 5210 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5188 5189 5190 |
# File 'lib/models/porcelain.rb', line 5188 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5190 5191 5192 |
# File 'lib/models/porcelain.rb', line 5190 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5192 5193 5194 |
# File 'lib/models/porcelain.rb', line 5192 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5194 5195 5196 |
# File 'lib/models/porcelain.rb', line 5194 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5196 5197 5198 |
# File 'lib/models/porcelain.rb', line 5196 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5198 5199 5200 |
# File 'lib/models/porcelain.rb', line 5198 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5200 5201 5202 |
# File 'lib/models/porcelain.rb', line 5200 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5202 5203 5204 |
# File 'lib/models/porcelain.rb', line 5202 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5204 5205 5206 |
# File 'lib/models/porcelain.rb', line 5204 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5206 5207 5208 |
# File 'lib/models/porcelain.rb', line 5206 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5208 5209 5210 |
# File 'lib/models/porcelain.rb', line 5208 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5236 5237 5238 5239 5240 5241 5242 |
# File 'lib/models/porcelain.rb', line 5236 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |