Class: SDM::Redis
- Inherits:
-
Object
- Object
- SDM::Redis
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Redis
constructor
A new instance of Redis.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil) ⇒ Redis
Returns a new instance of Redis.
5843 5844 5845 5846 5847 5848 5849 5850 5851 5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 5885 |
# File 'lib/models/porcelain.rb', line 5843 def initialize( egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil ) if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end end |
Instance Attribute Details
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5823 5824 5825 |
# File 'lib/models/porcelain.rb', line 5823 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5825 5826 5827 |
# File 'lib/models/porcelain.rb', line 5825 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5827 5828 5829 |
# File 'lib/models/porcelain.rb', line 5827 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5829 5830 5831 |
# File 'lib/models/porcelain.rb', line 5829 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5831 5832 5833 |
# File 'lib/models/porcelain.rb', line 5831 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
5833 5834 5835 |
# File 'lib/models/porcelain.rb', line 5833 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5835 5836 5837 |
# File 'lib/models/porcelain.rb', line 5835 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5837 5838 5839 |
# File 'lib/models/porcelain.rb', line 5837 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5839 5840 5841 |
# File 'lib/models/porcelain.rb', line 5839 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5841 5842 5843 |
# File 'lib/models/porcelain.rb', line 5841 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5887 5888 5889 5890 5891 5892 5893 |
# File 'lib/models/porcelain.rb', line 5887 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |