Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



14706
14707
14708
14709
14710
14711
14712
14713
14714
14715
14716
14717
14718
14719
14720
14721
14722
14723
14724
14725
14726
14727
14728
14729
14730
14731
14732
14733
14734
14735
14736
14737
14738
# File 'lib/models/porcelain.rb', line 14706

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14676
14677
14678
# File 'lib/models/porcelain.rb', line 14676

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14678
14679
14680
# File 'lib/models/porcelain.rb', line 14678

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14680
14681
14682
# File 'lib/models/porcelain.rb', line 14680

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14682
14683
14684
# File 'lib/models/porcelain.rb', line 14682

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14684
14685
14686
# File 'lib/models/porcelain.rb', line 14684

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14686
14687
14688
# File 'lib/models/porcelain.rb', line 14686

def name
  @name
end

#passwordObject

The password to authenticate with.



14688
14689
14690
# File 'lib/models/porcelain.rb', line 14688

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14690
14691
14692
# File 'lib/models/porcelain.rb', line 14690

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14692
14693
14694
# File 'lib/models/porcelain.rb', line 14692

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14694
14695
14696
# File 'lib/models/porcelain.rb', line 14694

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14696
14697
14698
# File 'lib/models/porcelain.rb', line 14696

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14698
14699
14700
# File 'lib/models/porcelain.rb', line 14698

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14700
14701
14702
# File 'lib/models/porcelain.rb', line 14700

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14702
14703
14704
# File 'lib/models/porcelain.rb', line 14702

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14704
14705
14706
# File 'lib/models/porcelain.rb', line 14704

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14740
14741
14742
14743
14744
14745
14746
# File 'lib/models/porcelain.rb', line 14740

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end