Class: SDM::Redis

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ Redis

Returns a new instance of Redis.



15157
15158
15159
15160
15161
15162
15163
15164
15165
15166
15167
15168
15169
15170
15171
15172
15173
15174
15175
15176
15177
15178
15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
# File 'lib/models/porcelain.rb', line 15157

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15127
15128
15129
# File 'lib/models/porcelain.rb', line 15127

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



15129
15130
15131
# File 'lib/models/porcelain.rb', line 15129

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



15131
15132
15133
# File 'lib/models/porcelain.rb', line 15131

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



15133
15134
15135
# File 'lib/models/porcelain.rb', line 15133

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



15135
15136
15137
# File 'lib/models/porcelain.rb', line 15135

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



15137
15138
15139
# File 'lib/models/porcelain.rb', line 15137

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



15139
15140
15141
# File 'lib/models/porcelain.rb', line 15139

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



15141
15142
15143
# File 'lib/models/porcelain.rb', line 15141

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15143
15144
15145
# File 'lib/models/porcelain.rb', line 15143

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



15145
15146
15147
# File 'lib/models/porcelain.rb', line 15145

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



15147
15148
15149
# File 'lib/models/porcelain.rb', line 15147

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15149
15150
15151
# File 'lib/models/porcelain.rb', line 15149

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



15151
15152
15153
# File 'lib/models/porcelain.rb', line 15151

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



15153
15154
15155
# File 'lib/models/porcelain.rb', line 15153

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



15155
15156
15157
# File 'lib/models/porcelain.rb', line 15155

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15191
15192
15193
15194
15195
15196
15197
# File 'lib/models/porcelain.rb', line 15191

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end