Class: SDM::RedisCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster

Returns a new instance of RedisCluster.



15172
15173
15174
15175
15176
15177
15178
15179
15180
15181
15182
15183
15184
15185
15186
15187
15188
15189
15190
15191
15192
15193
15194
15195
15196
15197
15198
15199
15200
15201
15202
15203
15204
# File 'lib/models/porcelain.rb', line 15172

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15142
15143
15144
# File 'lib/models/porcelain.rb', line 15142

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15144
15145
15146
# File 'lib/models/porcelain.rb', line 15144

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15146
15147
15148
# File 'lib/models/porcelain.rb', line 15146

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



15148
15149
15150
# File 'lib/models/porcelain.rb', line 15148

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15150
15151
15152
# File 'lib/models/porcelain.rb', line 15150

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15152
15153
15154
# File 'lib/models/porcelain.rb', line 15152

def name
  @name
end

#passwordObject

The password to authenticate with.



15154
15155
15156
# File 'lib/models/porcelain.rb', line 15154

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15156
15157
15158
# File 'lib/models/porcelain.rb', line 15156

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15158
15159
15160
# File 'lib/models/porcelain.rb', line 15158

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15160
15161
15162
# File 'lib/models/porcelain.rb', line 15160

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15162
15163
15164
# File 'lib/models/porcelain.rb', line 15162

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15164
15165
15166
# File 'lib/models/porcelain.rb', line 15164

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15166
15167
15168
# File 'lib/models/porcelain.rb', line 15166

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



15168
15169
15170
# File 'lib/models/porcelain.rb', line 15168

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



15170
15171
15172
# File 'lib/models/porcelain.rb', line 15170

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15206
15207
15208
15209
15210
15211
15212
# File 'lib/models/porcelain.rb', line 15206

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end