Class: SDM::RedisCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster

Returns a new instance of RedisCluster.



15044
15045
15046
15047
15048
15049
15050
15051
15052
15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
15070
15071
15072
15073
15074
15075
15076
# File 'lib/models/porcelain.rb', line 15044

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15014
15015
15016
# File 'lib/models/porcelain.rb', line 15014

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15016
15017
15018
# File 'lib/models/porcelain.rb', line 15016

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15018
15019
15020
# File 'lib/models/porcelain.rb', line 15018

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



15020
15021
15022
# File 'lib/models/porcelain.rb', line 15020

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15022
15023
15024
# File 'lib/models/porcelain.rb', line 15022

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15024
15025
15026
# File 'lib/models/porcelain.rb', line 15024

def name
  @name
end

#passwordObject

The password to authenticate with.



15026
15027
15028
# File 'lib/models/porcelain.rb', line 15026

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15028
15029
15030
# File 'lib/models/porcelain.rb', line 15028

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15030
15031
15032
# File 'lib/models/porcelain.rb', line 15030

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15032
15033
15034
# File 'lib/models/porcelain.rb', line 15032

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15034
15035
15036
# File 'lib/models/porcelain.rb', line 15034

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15036
15037
15038
# File 'lib/models/porcelain.rb', line 15036

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15038
15039
15040
# File 'lib/models/porcelain.rb', line 15038

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



15040
15041
15042
# File 'lib/models/porcelain.rb', line 15040

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



15042
15043
15044
# File 'lib/models/porcelain.rb', line 15042

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15078
15079
15080
15081
15082
15083
15084
# File 'lib/models/porcelain.rb', line 15078

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end