Class: SDM::RedisCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster

Returns a new instance of RedisCluster.



14818
14819
14820
14821
14822
14823
14824
14825
14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
# File 'lib/models/porcelain.rb', line 14818

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14788
14789
14790
# File 'lib/models/porcelain.rb', line 14788

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14790
14791
14792
# File 'lib/models/porcelain.rb', line 14790

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14792
14793
14794
# File 'lib/models/porcelain.rb', line 14792

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



14794
14795
14796
# File 'lib/models/porcelain.rb', line 14794

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14796
14797
14798
# File 'lib/models/porcelain.rb', line 14796

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14798
14799
14800
# File 'lib/models/porcelain.rb', line 14798

def name
  @name
end

#passwordObject

The password to authenticate with.



14800
14801
14802
# File 'lib/models/porcelain.rb', line 14800

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14802
14803
14804
# File 'lib/models/porcelain.rb', line 14802

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14804
14805
14806
# File 'lib/models/porcelain.rb', line 14804

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14806
14807
14808
# File 'lib/models/porcelain.rb', line 14806

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14808
14809
14810
# File 'lib/models/porcelain.rb', line 14808

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14810
14811
14812
# File 'lib/models/porcelain.rb', line 14810

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14812
14813
14814
# File 'lib/models/porcelain.rb', line 14812

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14814
14815
14816
# File 'lib/models/porcelain.rb', line 14814

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14816
14817
14818
# File 'lib/models/porcelain.rb', line 14816

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14852
14853
14854
14855
14856
14857
14858
# File 'lib/models/porcelain.rb', line 14852

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end