Class: SDM::RedisCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster

Returns a new instance of RedisCluster.



14499
14500
14501
14502
14503
14504
14505
14506
14507
14508
14509
14510
14511
14512
14513
14514
14515
14516
14517
14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
# File 'lib/models/porcelain.rb', line 14499

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14469
14470
14471
# File 'lib/models/porcelain.rb', line 14469

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14471
14472
14473
# File 'lib/models/porcelain.rb', line 14471

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14473
14474
14475
# File 'lib/models/porcelain.rb', line 14473

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



14475
14476
14477
# File 'lib/models/porcelain.rb', line 14475

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14477
14478
14479
# File 'lib/models/porcelain.rb', line 14477

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14479
14480
14481
# File 'lib/models/porcelain.rb', line 14479

def name
  @name
end

#passwordObject

The password to authenticate with.



14481
14482
14483
# File 'lib/models/porcelain.rb', line 14481

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14483
14484
14485
# File 'lib/models/porcelain.rb', line 14483

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14485
14486
14487
# File 'lib/models/porcelain.rb', line 14485

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14487
14488
14489
# File 'lib/models/porcelain.rb', line 14487

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14489
14490
14491
# File 'lib/models/porcelain.rb', line 14489

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14491
14492
14493
# File 'lib/models/porcelain.rb', line 14491

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14493
14494
14495
# File 'lib/models/porcelain.rb', line 14493

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



14495
14496
14497
# File 'lib/models/porcelain.rb', line 14495

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



14497
14498
14499
# File 'lib/models/porcelain.rb', line 14497

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14533
14534
14535
14536
14537
14538
14539
# File 'lib/models/porcelain.rb', line 14533

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end