Class: SDM::RedisCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster

Returns a new instance of RedisCluster.



13237
13238
13239
13240
13241
13242
13243
13244
13245
13246
13247
13248
13249
13250
13251
13252
13253
13254
13255
13256
13257
13258
13259
13260
13261
13262
13263
13264
13265
13266
13267
13268
13269
# File 'lib/models/porcelain.rb', line 13237

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



13207
13208
13209
# File 'lib/models/porcelain.rb', line 13207

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13209
13210
13211
# File 'lib/models/porcelain.rb', line 13209

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13211
13212
13213
# File 'lib/models/porcelain.rb', line 13211

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



13213
13214
13215
# File 'lib/models/porcelain.rb', line 13213

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13215
13216
13217
# File 'lib/models/porcelain.rb', line 13215

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13217
13218
13219
# File 'lib/models/porcelain.rb', line 13217

def name
  @name
end

#passwordObject

The password to authenticate with.



13219
13220
13221
# File 'lib/models/porcelain.rb', line 13219

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13221
13222
13223
# File 'lib/models/porcelain.rb', line 13221

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



13223
13224
13225
# File 'lib/models/porcelain.rb', line 13223

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13225
13226
13227
# File 'lib/models/porcelain.rb', line 13225

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13227
13228
13229
# File 'lib/models/porcelain.rb', line 13227

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



13229
13230
13231
# File 'lib/models/porcelain.rb', line 13229

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13231
13232
13233
# File 'lib/models/porcelain.rb', line 13231

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



13233
13234
13235
# File 'lib/models/porcelain.rb', line 13233

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



13235
13236
13237
# File 'lib/models/porcelain.rb', line 13235

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13271
13272
13273
13274
13275
13276
13277
# File 'lib/models/porcelain.rb', line 13271

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end