Class: SDM::RedisCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster

Returns a new instance of RedisCluster.



11957
11958
11959
11960
11961
11962
11963
11964
11965
11966
11967
11968
11969
11970
11971
11972
11973
11974
11975
11976
11977
11978
11979
11980
11981
11982
11983
11984
11985
11986
11987
11988
11989
# File 'lib/models/porcelain.rb', line 11957

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11927
11928
11929
# File 'lib/models/porcelain.rb', line 11927

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11929
11930
11931
# File 'lib/models/porcelain.rb', line 11929

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11931
11932
11933
# File 'lib/models/porcelain.rb', line 11931

def healthy
  @healthy
end

#hostnameObject

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



11933
11934
11935
# File 'lib/models/porcelain.rb', line 11933

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11935
11936
11937
# File 'lib/models/porcelain.rb', line 11935

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11937
11938
11939
# File 'lib/models/porcelain.rb', line 11937

def name
  @name
end

#passwordObject

The password to authenticate with.



11939
11940
11941
# File 'lib/models/porcelain.rb', line 11939

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11941
11942
11943
# File 'lib/models/porcelain.rb', line 11941

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11943
11944
11945
# File 'lib/models/porcelain.rb', line 11943

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11945
11946
11947
# File 'lib/models/porcelain.rb', line 11945

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11947
11948
11949
# File 'lib/models/porcelain.rb', line 11947

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11949
11950
11951
# File 'lib/models/porcelain.rb', line 11949

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11951
11952
11953
# File 'lib/models/porcelain.rb', line 11951

def tags
  @tags
end

#tls_requiredObject

If set, TLS must be used to connect to this resource.



11953
11954
11955
# File 'lib/models/porcelain.rb', line 11953

def tls_required
  @tls_required
end

#usernameObject

The username to authenticate with.



11955
11956
11957
# File 'lib/models/porcelain.rb', line 11955

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11991
11992
11993
11994
11995
11996
11997
# File 'lib/models/porcelain.rb', line 11991

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end