Class: SDM::RedisCluster
- Inherits:
-
Object
- Object
- SDM::RedisCluster
- Defined in:
- lib/models/porcelain.rb
Overview
RedisCluster is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster
constructor
A new instance of RedisCluster.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster
Returns a new instance of RedisCluster.
10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 10717 10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 10733 |
# File 'lib/models/porcelain.rb', line 10701 def initialize( bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tls_required = tls_required == nil ? false : tls_required @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10671 10672 10673 |
# File 'lib/models/porcelain.rb', line 10671 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10673 10674 10675 |
# File 'lib/models/porcelain.rb', line 10673 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10675 10676 10677 |
# File 'lib/models/porcelain.rb', line 10675 def healthy @healthy end |
#hostname ⇒ Object
Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.
10677 10678 10679 |
# File 'lib/models/porcelain.rb', line 10677 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10679 10680 10681 |
# File 'lib/models/porcelain.rb', line 10679 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
10681 10682 10683 |
# File 'lib/models/porcelain.rb', line 10681 def name @name end |
#password ⇒ Object
The password to authenticate with.
10683 10684 10685 |
# File 'lib/models/porcelain.rb', line 10683 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10685 10686 10687 |
# File 'lib/models/porcelain.rb', line 10685 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10687 10688 10689 |
# File 'lib/models/porcelain.rb', line 10687 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
10689 10690 10691 |
# File 'lib/models/porcelain.rb', line 10689 def proxy_cluster_id @proxy_cluster_id end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10691 10692 10693 |
# File 'lib/models/porcelain.rb', line 10691 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10693 10694 10695 |
# File 'lib/models/porcelain.rb', line 10693 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10695 10696 10697 |
# File 'lib/models/porcelain.rb', line 10695 def @tags end |
#tls_required ⇒ Object
If set, TLS must be used to connect to this resource.
10697 10698 10699 |
# File 'lib/models/porcelain.rb', line 10697 def tls_required @tls_required end |
#username ⇒ Object
The username to authenticate with.
10699 10700 10701 |
# File 'lib/models/porcelain.rb', line 10699 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10735 10736 10737 10738 10739 10740 10741 |
# File 'lib/models/porcelain.rb', line 10735 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |