Class: SDM::RedisCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, tls_required: nil, username: nil) ⇒ RedisCluster

Returns a new instance of RedisCluster.



15232
15233
15234
15235
15236
15237
15238
15239
15240
15241
15242
15243
15244
15245
15246
15247
15248
15249
15250
15251
15252
15253
15254
15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
# File 'lib/models/porcelain.rb', line 15232

def initialize(
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tls_required: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tls_required = tls_required == nil ? false : tls_required
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15202
15203
15204
# File 'lib/models/porcelain.rb', line 15202

def bind_interface
  @bind_interface
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



15204
15205
15206
# File 'lib/models/porcelain.rb', line 15204

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



15206
15207
15208
# File 'lib/models/porcelain.rb', line 15206

def healthy
  @healthy
end

#hostname ⇒ Object

Hostname must contain the hostname/port pairs of all instances in the replica set separated by commas.



15208
15209
15210
# File 'lib/models/porcelain.rb', line 15208

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



15210
15211
15212
# File 'lib/models/porcelain.rb', line 15210

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



15212
15213
15214
# File 'lib/models/porcelain.rb', line 15212

def name
  @name
end

#password ⇒ Object

The password to authenticate with.



15214
15215
15216
# File 'lib/models/porcelain.rb', line 15214

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



15216
15217
15218
# File 'lib/models/porcelain.rb', line 15216

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15218
15219
15220
# File 'lib/models/porcelain.rb', line 15218

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



15220
15221
15222
# File 'lib/models/porcelain.rb', line 15220

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



15222
15223
15224
# File 'lib/models/porcelain.rb', line 15222

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15224
15225
15226
# File 'lib/models/porcelain.rb', line 15224

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



15226
15227
15228
# File 'lib/models/porcelain.rb', line 15226

def tags
  @tags
end

#tls_required ⇒ Object

If set, TLS must be used to connect to this resource.



15228
15229
15230
# File 'lib/models/porcelain.rb', line 15228

def tls_required
  @tls_required
end

#username ⇒ Object

The username to authenticate with.



15230
15231
15232
# File 'lib/models/porcelain.rb', line 15230

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15266
15267
15268
15269
15270
15271
15272
# File 'lib/models/porcelain.rb', line 15266

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end