Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



14895
14896
14897
14898
14899
14900
14901
14902
14903
14904
14905
14906
14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
# File 'lib/models/porcelain.rb', line 14895

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14863
14864
14865
# File 'lib/models/porcelain.rb', line 14863

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14865
14866
14867
# File 'lib/models/porcelain.rb', line 14865

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14867
14868
14869
# File 'lib/models/porcelain.rb', line 14867

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14869
14870
14871
# File 'lib/models/porcelain.rb', line 14869

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14871
14872
14873
# File 'lib/models/porcelain.rb', line 14871

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14873
14874
14875
# File 'lib/models/porcelain.rb', line 14873

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14875
14876
14877
# File 'lib/models/porcelain.rb', line 14875

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14877
14878
14879
# File 'lib/models/porcelain.rb', line 14877

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



14879
14880
14881
# File 'lib/models/porcelain.rb', line 14879

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14881
14882
14883
# File 'lib/models/porcelain.rb', line 14881

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14883
14884
14885
# File 'lib/models/porcelain.rb', line 14883

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14885
14886
14887
# File 'lib/models/porcelain.rb', line 14885

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14887
14888
14889
# File 'lib/models/porcelain.rb', line 14887

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14889
14890
14891
# File 'lib/models/porcelain.rb', line 14889

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14891
14892
14893
# File 'lib/models/porcelain.rb', line 14891

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14893
14894
14895
# File 'lib/models/porcelain.rb', line 14893

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14931
14932
14933
14934
14935
14936
14937
# File 'lib/models/porcelain.rb', line 14931

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end