Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



12034
12035
12036
12037
12038
12039
12040
12041
12042
12043
12044
12045
12046
12047
12048
12049
12050
12051
12052
12053
12054
12055
12056
12057
12058
12059
12060
12061
12062
12063
12064
12065
12066
12067
12068
# File 'lib/models/porcelain.rb', line 12034

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12002
12003
12004
# File 'lib/models/porcelain.rb', line 12002

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12004
12005
12006
# File 'lib/models/porcelain.rb', line 12004

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12006
12007
12008
# File 'lib/models/porcelain.rb', line 12006

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12008
12009
12010
# File 'lib/models/porcelain.rb', line 12008

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12010
12011
12012
# File 'lib/models/porcelain.rb', line 12010

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12012
12013
12014
# File 'lib/models/porcelain.rb', line 12012

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12014
12015
12016
# File 'lib/models/porcelain.rb', line 12014

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12016
12017
12018
# File 'lib/models/porcelain.rb', line 12016

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



12018
12019
12020
# File 'lib/models/porcelain.rb', line 12018

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12020
12021
12022
# File 'lib/models/porcelain.rb', line 12020

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12022
12023
12024
# File 'lib/models/porcelain.rb', line 12022

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12024
12025
12026
# File 'lib/models/porcelain.rb', line 12024

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12026
12027
12028
# File 'lib/models/porcelain.rb', line 12026

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12028
12029
12030
# File 'lib/models/porcelain.rb', line 12028

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12030
12031
12032
# File 'lib/models/porcelain.rb', line 12030

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12032
12033
12034
# File 'lib/models/porcelain.rb', line 12032

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12070
12071
12072
12073
12074
12075
12076
# File 'lib/models/porcelain.rb', line 12070

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end