Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



10407
10408
10409
10410
10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
10426
10427
10428
10429
10430
10431
10432
10433
10434
10435
10436
10437
10438
10439
10440
10441
# File 'lib/models/porcelain.rb', line 10407

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10375
10376
10377
# File 'lib/models/porcelain.rb', line 10375

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10377
10378
10379
# File 'lib/models/porcelain.rb', line 10377

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10379
10380
10381
# File 'lib/models/porcelain.rb', line 10379

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10381
10382
10383
# File 'lib/models/porcelain.rb', line 10381

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10383
10384
10385
# File 'lib/models/porcelain.rb', line 10383

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10385
10386
10387
# File 'lib/models/porcelain.rb', line 10385

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10387
10388
10389
# File 'lib/models/porcelain.rb', line 10387

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10389
10390
10391
# File 'lib/models/porcelain.rb', line 10389

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10391
10392
10393
# File 'lib/models/porcelain.rb', line 10391

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10393
10394
10395
# File 'lib/models/porcelain.rb', line 10393

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10395
10396
10397
# File 'lib/models/porcelain.rb', line 10395

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10397
10398
10399
# File 'lib/models/porcelain.rb', line 10397

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10399
10400
10401
# File 'lib/models/porcelain.rb', line 10399

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10401
10402
10403
# File 'lib/models/porcelain.rb', line 10401

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10403
10404
10405
# File 'lib/models/porcelain.rb', line 10403

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10405
10406
10407
# File 'lib/models/porcelain.rb', line 10405

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10443
10444
10445
10446
10447
10448
10449
# File 'lib/models/porcelain.rb', line 10443

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end