Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
9871
9872
9873
9874
9875
9876
9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/models/porcelain.rb', line 9859

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9827
9828
9829
# File 'lib/models/porcelain.rb', line 9827

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9829
9830
9831
# File 'lib/models/porcelain.rb', line 9829

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9831
9832
9833
# File 'lib/models/porcelain.rb', line 9831

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9833
9834
9835
# File 'lib/models/porcelain.rb', line 9833

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9835
9836
9837
# File 'lib/models/porcelain.rb', line 9835

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9837
9838
9839
# File 'lib/models/porcelain.rb', line 9837

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9839
9840
9841
# File 'lib/models/porcelain.rb', line 9839

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



9841
9842
9843
# File 'lib/models/porcelain.rb', line 9841

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



9843
9844
9845
# File 'lib/models/porcelain.rb', line 9843

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9845
9846
9847
# File 'lib/models/porcelain.rb', line 9845

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9847
9848
9849
# File 'lib/models/porcelain.rb', line 9847

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



9849
9850
9851
# File 'lib/models/porcelain.rb', line 9849

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9851
9852
9853
# File 'lib/models/porcelain.rb', line 9851

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9853
9854
9855
# File 'lib/models/porcelain.rb', line 9853

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9855
9856
9857
# File 'lib/models/porcelain.rb', line 9855

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9857
9858
9859
# File 'lib/models/porcelain.rb', line 9857

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9895
9896
9897
9898
9899
9900
9901
# File 'lib/models/porcelain.rb', line 9895

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end