Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
# File 'lib/models/porcelain.rb', line 9421

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9391
9392
9393
# File 'lib/models/porcelain.rb', line 9391

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



9393
9394
9395
# File 'lib/models/porcelain.rb', line 9393

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9395
9396
9397
# File 'lib/models/porcelain.rb', line 9395

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9397
9398
9399
# File 'lib/models/porcelain.rb', line 9397

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9399
9400
9401
# File 'lib/models/porcelain.rb', line 9399

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9401
9402
9403
# File 'lib/models/porcelain.rb', line 9401

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9403
9404
9405
# File 'lib/models/porcelain.rb', line 9403

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



9405
9406
9407
# File 'lib/models/porcelain.rb', line 9405

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



9407
9408
9409
# File 'lib/models/porcelain.rb', line 9407

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9409
9410
9411
# File 'lib/models/porcelain.rb', line 9409

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9411
9412
9413
# File 'lib/models/porcelain.rb', line 9411

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9413
9414
9415
# File 'lib/models/porcelain.rb', line 9413

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9415
9416
9417
# File 'lib/models/porcelain.rb', line 9415

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9417
9418
9419
# File 'lib/models/porcelain.rb', line 9417

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9419
9420
9421
# File 'lib/models/porcelain.rb', line 9419

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9455
9456
9457
9458
9459
9460
9461
# File 'lib/models/porcelain.rb', line 9455

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end