Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
9252 9253 9254 9255 9256 9257 9258 9259 9260 9261 9262 9263 9264 9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 9275 9276 9277 9278 9279 9280 9281 9282 9283 9284 |
# File 'lib/models/porcelain.rb', line 9252 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9222 9223 9224 |
# File 'lib/models/porcelain.rb', line 9222 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9224 9225 9226 |
# File 'lib/models/porcelain.rb', line 9224 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9226 9227 9228 |
# File 'lib/models/porcelain.rb', line 9226 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9228 9229 9230 |
# File 'lib/models/porcelain.rb', line 9228 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9230 9231 9232 |
# File 'lib/models/porcelain.rb', line 9230 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9232 9233 9234 |
# File 'lib/models/porcelain.rb', line 9232 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9234 9235 9236 |
# File 'lib/models/porcelain.rb', line 9234 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
9236 9237 9238 |
# File 'lib/models/porcelain.rb', line 9236 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
9238 9239 9240 |
# File 'lib/models/porcelain.rb', line 9238 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9240 9241 9242 |
# File 'lib/models/porcelain.rb', line 9240 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9242 9243 9244 |
# File 'lib/models/porcelain.rb', line 9242 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9244 9245 9246 |
# File 'lib/models/porcelain.rb', line 9244 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9246 9247 9248 |
# File 'lib/models/porcelain.rb', line 9246 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9248 9249 9250 |
# File 'lib/models/porcelain.rb', line 9248 def @tags end |
#username ⇒ Object
The username to authenticate with.
9250 9251 9252 |
# File 'lib/models/porcelain.rb', line 9250 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9286 9287 9288 9289 9290 9291 9292 |
# File 'lib/models/porcelain.rb', line 9286 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |