Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 |
# File 'lib/models/porcelain.rb', line 9083 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
9053 9054 9055 |
# File 'lib/models/porcelain.rb', line 9053 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
9055 9056 9057 |
# File 'lib/models/porcelain.rb', line 9055 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
9057 9058 9059 |
# File 'lib/models/porcelain.rb', line 9057 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
9059 9060 9061 |
# File 'lib/models/porcelain.rb', line 9059 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
9061 9062 9063 |
# File 'lib/models/porcelain.rb', line 9061 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
9063 9064 9065 |
# File 'lib/models/porcelain.rb', line 9063 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
9065 9066 9067 |
# File 'lib/models/porcelain.rb', line 9065 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
9067 9068 9069 |
# File 'lib/models/porcelain.rb', line 9067 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
9069 9070 9071 |
# File 'lib/models/porcelain.rb', line 9069 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
9071 9072 9073 |
# File 'lib/models/porcelain.rb', line 9071 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
9073 9074 9075 |
# File 'lib/models/porcelain.rb', line 9073 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
9075 9076 9077 |
# File 'lib/models/porcelain.rb', line 9075 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
9077 9078 9079 |
# File 'lib/models/porcelain.rb', line 9077 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9079 9080 9081 |
# File 'lib/models/porcelain.rb', line 9079 def @tags end |
#username ⇒ Object
The username to authenticate with.
9081 9082 9083 |
# File 'lib/models/porcelain.rb', line 9081 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9117 9118 9119 9120 9121 9122 9123 |
# File 'lib/models/porcelain.rb', line 9117 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |