Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'lib/models/porcelain.rb', line 8864 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8834 8835 8836 |
# File 'lib/models/porcelain.rb', line 8834 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
8836 8837 8838 |
# File 'lib/models/porcelain.rb', line 8836 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8838 8839 8840 |
# File 'lib/models/porcelain.rb', line 8838 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8840 8841 8842 |
# File 'lib/models/porcelain.rb', line 8840 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8842 8843 8844 |
# File 'lib/models/porcelain.rb', line 8842 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8844 8845 8846 |
# File 'lib/models/porcelain.rb', line 8844 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
8846 8847 8848 |
# File 'lib/models/porcelain.rb', line 8846 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
8848 8849 8850 |
# File 'lib/models/porcelain.rb', line 8848 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
8850 8851 8852 |
# File 'lib/models/porcelain.rb', line 8850 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8852 8853 8854 |
# File 'lib/models/porcelain.rb', line 8852 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8854 8855 8856 |
# File 'lib/models/porcelain.rb', line 8854 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8856 8857 8858 |
# File 'lib/models/porcelain.rb', line 8856 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8858 8859 8860 |
# File 'lib/models/porcelain.rb', line 8858 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8860 8861 8862 |
# File 'lib/models/porcelain.rb', line 8860 def @tags end |
#username ⇒ Object
The username to authenticate with.
8862 8863 8864 |
# File 'lib/models/porcelain.rb', line 8862 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/models/porcelain.rb', line 8898 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |