Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



7659
7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
# File 'lib/models/porcelain.rb', line 7659

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7629
7630
7631
# File 'lib/models/porcelain.rb', line 7629

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7631
7632
7633
# File 'lib/models/porcelain.rb', line 7631

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7633
7634
7635
# File 'lib/models/porcelain.rb', line 7633

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7635
7636
7637
# File 'lib/models/porcelain.rb', line 7635

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7637
7638
7639
# File 'lib/models/porcelain.rb', line 7637

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7639
7640
7641
# File 'lib/models/porcelain.rb', line 7639

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7641
7642
7643
# File 'lib/models/porcelain.rb', line 7641

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



7643
7644
7645
# File 'lib/models/porcelain.rb', line 7643

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



7645
7646
7647
# File 'lib/models/porcelain.rb', line 7645

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7647
7648
7649
# File 'lib/models/porcelain.rb', line 7647

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7649
7650
7651
# File 'lib/models/porcelain.rb', line 7649

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7651
7652
7653
# File 'lib/models/porcelain.rb', line 7651

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7653
7654
7655
# File 'lib/models/porcelain.rb', line 7653

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7655
7656
7657
# File 'lib/models/porcelain.rb', line 7655

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7657
7658
7659
# File 'lib/models/porcelain.rb', line 7657

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7693
7694
7695
7696
7697
7698
7699
# File 'lib/models/porcelain.rb', line 7693

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end