Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
7400
# File 'lib/models/porcelain.rb', line 7368

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7338
7339
7340
# File 'lib/models/porcelain.rb', line 7338

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7340
7341
7342
# File 'lib/models/porcelain.rb', line 7340

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7342
7343
7344
# File 'lib/models/porcelain.rb', line 7342

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7344
7345
7346
# File 'lib/models/porcelain.rb', line 7344

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7346
7347
7348
# File 'lib/models/porcelain.rb', line 7346

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7348
7349
7350
# File 'lib/models/porcelain.rb', line 7348

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7350
7351
7352
# File 'lib/models/porcelain.rb', line 7350

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



7352
7353
7354
# File 'lib/models/porcelain.rb', line 7352

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



7354
7355
7356
# File 'lib/models/porcelain.rb', line 7354

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7356
7357
7358
# File 'lib/models/porcelain.rb', line 7356

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7358
7359
7360
# File 'lib/models/porcelain.rb', line 7358

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7360
7361
7362
# File 'lib/models/porcelain.rb', line 7360

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7362
7363
7364
# File 'lib/models/porcelain.rb', line 7362

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7364
7365
7366
# File 'lib/models/porcelain.rb', line 7364

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7366
7367
7368
# File 'lib/models/porcelain.rb', line 7366

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7402
7403
7404
7405
7406
7407
7408
# File 'lib/models/porcelain.rb', line 7402

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end