Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 7169 7170 7171 7172 7173 7174 7175 7176 7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/models/porcelain.rb', line 7153 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7123 7124 7125 |
# File 'lib/models/porcelain.rb', line 7123 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7125 7126 7127 |
# File 'lib/models/porcelain.rb', line 7125 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7127 7128 7129 |
# File 'lib/models/porcelain.rb', line 7127 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7129 7130 7131 |
# File 'lib/models/porcelain.rb', line 7129 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7131 7132 7133 |
# File 'lib/models/porcelain.rb', line 7131 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7133 7134 7135 |
# File 'lib/models/porcelain.rb', line 7133 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7135 7136 7137 |
# File 'lib/models/porcelain.rb', line 7135 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
7137 7138 7139 |
# File 'lib/models/porcelain.rb', line 7137 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
7139 7140 7141 |
# File 'lib/models/porcelain.rb', line 7139 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7141 7142 7143 |
# File 'lib/models/porcelain.rb', line 7141 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7143 7144 7145 |
# File 'lib/models/porcelain.rb', line 7143 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7145 7146 7147 |
# File 'lib/models/porcelain.rb', line 7145 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7147 7148 7149 |
# File 'lib/models/porcelain.rb', line 7147 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7149 7150 7151 |
# File 'lib/models/porcelain.rb', line 7149 def @tags end |
#username ⇒ Object
The username to authenticate with.
7151 7152 7153 |
# File 'lib/models/porcelain.rb', line 7151 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7187 7188 7189 7190 7191 7192 7193 |
# File 'lib/models/porcelain.rb', line 7187 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |