Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
6724 6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 6742 6743 6744 6745 6746 6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 |
# File 'lib/models/porcelain.rb', line 6724 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
6694 6695 6696 |
# File 'lib/models/porcelain.rb', line 6694 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
6696 6697 6698 |
# File 'lib/models/porcelain.rb', line 6696 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6698 6699 6700 |
# File 'lib/models/porcelain.rb', line 6698 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6700 6701 6702 |
# File 'lib/models/porcelain.rb', line 6700 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
6702 6703 6704 |
# File 'lib/models/porcelain.rb', line 6702 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6704 6705 6706 |
# File 'lib/models/porcelain.rb', line 6704 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6706 6707 6708 |
# File 'lib/models/porcelain.rb', line 6706 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
6708 6709 6710 |
# File 'lib/models/porcelain.rb', line 6708 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
6710 6711 6712 |
# File 'lib/models/porcelain.rb', line 6710 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
6712 6713 6714 |
# File 'lib/models/porcelain.rb', line 6712 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
6714 6715 6716 |
# File 'lib/models/porcelain.rb', line 6714 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6716 6717 6718 |
# File 'lib/models/porcelain.rb', line 6716 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6718 6719 6720 |
# File 'lib/models/porcelain.rb', line 6718 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6720 6721 6722 |
# File 'lib/models/porcelain.rb', line 6720 def @tags end |
#username ⇒ Object
The username to authenticate with.
6722 6723 6724 |
# File 'lib/models/porcelain.rb', line 6722 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6758 6759 6760 6761 6762 6763 6764 |
# File 'lib/models/porcelain.rb', line 6758 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |