Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



6567
6568
6569
6570
6571
6572
6573
6574
6575
6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
# File 'lib/models/porcelain.rb', line 6567

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6537
6538
6539
# File 'lib/models/porcelain.rb', line 6537

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



6539
6540
6541
# File 'lib/models/porcelain.rb', line 6539

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6541
6542
6543
# File 'lib/models/porcelain.rb', line 6541

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6543
6544
6545
# File 'lib/models/porcelain.rb', line 6543

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6545
6546
6547
# File 'lib/models/porcelain.rb', line 6545

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6547
6548
6549
# File 'lib/models/porcelain.rb', line 6547

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6549
6550
6551
# File 'lib/models/porcelain.rb', line 6549

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



6551
6552
6553
# File 'lib/models/porcelain.rb', line 6551

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



6553
6554
6555
# File 'lib/models/porcelain.rb', line 6553

def password
  @password
end

#portObject

Returns the value of attribute port.



6555
6556
6557
# File 'lib/models/porcelain.rb', line 6555

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



6557
6558
6559
# File 'lib/models/porcelain.rb', line 6557

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6559
6560
6561
# File 'lib/models/porcelain.rb', line 6559

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6561
6562
6563
# File 'lib/models/porcelain.rb', line 6561

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6563
6564
6565
# File 'lib/models/porcelain.rb', line 6563

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6565
6566
6567
# File 'lib/models/porcelain.rb', line 6565

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6601
6602
6603
6604
6605
6606
6607
# File 'lib/models/porcelain.rb', line 6601

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end