Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
6511 6512 6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 6529 6530 6531 6532 6533 6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 |
# File 'lib/models/porcelain.rb', line 6511 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6481 6482 6483 |
# File 'lib/models/porcelain.rb', line 6481 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
6483 6484 6485 |
# File 'lib/models/porcelain.rb', line 6483 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6485 6486 6487 |
# File 'lib/models/porcelain.rb', line 6485 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6487 6488 6489 |
# File 'lib/models/porcelain.rb', line 6487 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6489 6490 6491 |
# File 'lib/models/porcelain.rb', line 6489 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6491 6492 6493 |
# File 'lib/models/porcelain.rb', line 6491 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6493 6494 6495 |
# File 'lib/models/porcelain.rb', line 6493 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
6495 6496 6497 |
# File 'lib/models/porcelain.rb', line 6495 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
6497 6498 6499 |
# File 'lib/models/porcelain.rb', line 6497 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6499 6500 6501 |
# File 'lib/models/porcelain.rb', line 6499 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6501 6502 6503 |
# File 'lib/models/porcelain.rb', line 6501 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6503 6504 6505 |
# File 'lib/models/porcelain.rb', line 6503 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
6505 6506 6507 |
# File 'lib/models/porcelain.rb', line 6505 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6507 6508 6509 |
# File 'lib/models/porcelain.rb', line 6507 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6509 6510 6511 |
# File 'lib/models/porcelain.rb', line 6509 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/models/porcelain.rb', line 6545 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |