Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
6468
6469
6470
6471
6472
6473
6474
6475
6476
6477
6478
6479
6480
6481
6482
6483
6484
6485
6486
6487
6488
6489
6490
# File 'lib/models/porcelain.rb', line 6458

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



6428
6429
6430
# File 'lib/models/porcelain.rb', line 6428

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



6430
6431
6432
# File 'lib/models/porcelain.rb', line 6430

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6432
6433
6434
# File 'lib/models/porcelain.rb', line 6432

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6434
6435
6436
# File 'lib/models/porcelain.rb', line 6434

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6436
6437
6438
# File 'lib/models/porcelain.rb', line 6436

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6438
6439
6440
# File 'lib/models/porcelain.rb', line 6438

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



6440
6441
6442
# File 'lib/models/porcelain.rb', line 6440

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



6442
6443
6444
# File 'lib/models/porcelain.rb', line 6442

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



6444
6445
6446
# File 'lib/models/porcelain.rb', line 6444

def password
  @password
end

#portObject

Returns the value of attribute port.



6446
6447
6448
# File 'lib/models/porcelain.rb', line 6446

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



6448
6449
6450
# File 'lib/models/porcelain.rb', line 6448

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6450
6451
6452
# File 'lib/models/porcelain.rb', line 6450

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



6452
6453
6454
# File 'lib/models/porcelain.rb', line 6452

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



6454
6455
6456
# File 'lib/models/porcelain.rb', line 6454

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6456
6457
6458
# File 'lib/models/porcelain.rb', line 6456

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6492
6493
6494
6495
6496
6497
6498
# File 'lib/models/porcelain.rb', line 6492

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end