Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 |
# File 'lib/models/porcelain.rb', line 6032 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6004 6005 6006 |
# File 'lib/models/porcelain.rb', line 6004 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
6006 6007 6008 |
# File 'lib/models/porcelain.rb', line 6006 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6008 6009 6010 |
# File 'lib/models/porcelain.rb', line 6008 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6010 6011 6012 |
# File 'lib/models/porcelain.rb', line 6010 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6012 6013 6014 |
# File 'lib/models/porcelain.rb', line 6012 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6014 6015 6016 |
# File 'lib/models/porcelain.rb', line 6014 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6016 6017 6018 |
# File 'lib/models/porcelain.rb', line 6016 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
6018 6019 6020 |
# File 'lib/models/porcelain.rb', line 6018 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
6020 6021 6022 |
# File 'lib/models/porcelain.rb', line 6020 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6022 6023 6024 |
# File 'lib/models/porcelain.rb', line 6022 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6024 6025 6026 |
# File 'lib/models/porcelain.rb', line 6024 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6026 6027 6028 |
# File 'lib/models/porcelain.rb', line 6026 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6028 6029 6030 |
# File 'lib/models/porcelain.rb', line 6028 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6030 6031 6032 |
# File 'lib/models/porcelain.rb', line 6030 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6064 6065 6066 6067 6068 6069 6070 |
# File 'lib/models/porcelain.rb', line 6064 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |