Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



5409
5410
5411
5412
5413
5414
5415
5416
5417
5418
5419
5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
5438
5439
# File 'lib/models/porcelain.rb', line 5409

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5381
5382
5383
# File 'lib/models/porcelain.rb', line 5381

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



5383
5384
5385
# File 'lib/models/porcelain.rb', line 5383

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5385
5386
5387
# File 'lib/models/porcelain.rb', line 5385

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5387
5388
5389
# File 'lib/models/porcelain.rb', line 5387

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5389
5390
5391
# File 'lib/models/porcelain.rb', line 5389

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5391
5392
5393
# File 'lib/models/porcelain.rb', line 5391

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5393
5394
5395
# File 'lib/models/porcelain.rb', line 5393

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



5395
5396
5397
# File 'lib/models/porcelain.rb', line 5395

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



5397
5398
5399
# File 'lib/models/porcelain.rb', line 5397

def password
  @password
end

#portObject

Returns the value of attribute port.



5399
5400
5401
# File 'lib/models/porcelain.rb', line 5399

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5401
5402
5403
# File 'lib/models/porcelain.rb', line 5401

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5403
5404
5405
# File 'lib/models/porcelain.rb', line 5403

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5405
5406
5407
# File 'lib/models/porcelain.rb', line 5405

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5407
5408
5409
# File 'lib/models/porcelain.rb', line 5407

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5441
5442
5443
5444
5445
5446
5447
# File 'lib/models/porcelain.rb', line 5441

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end