Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 5434 5435 5436 5437 5438 5439 5440 |
# File 'lib/models/porcelain.rb', line 5410 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5382 5383 5384 |
# File 'lib/models/porcelain.rb', line 5382 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5384 5385 5386 |
# File 'lib/models/porcelain.rb', line 5384 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5386 5387 5388 |
# File 'lib/models/porcelain.rb', line 5386 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5388 5389 5390 |
# File 'lib/models/porcelain.rb', line 5388 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5390 5391 5392 |
# File 'lib/models/porcelain.rb', line 5390 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5392 5393 5394 |
# File 'lib/models/porcelain.rb', line 5392 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5394 5395 5396 |
# File 'lib/models/porcelain.rb', line 5394 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5396 5397 5398 |
# File 'lib/models/porcelain.rb', line 5396 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5398 5399 5400 |
# File 'lib/models/porcelain.rb', line 5398 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5400 5401 5402 |
# File 'lib/models/porcelain.rb', line 5400 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5402 5403 5404 |
# File 'lib/models/porcelain.rb', line 5402 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5404 5405 5406 |
# File 'lib/models/porcelain.rb', line 5404 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5406 5407 5408 |
# File 'lib/models/porcelain.rb', line 5406 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5408 5409 5410 |
# File 'lib/models/porcelain.rb', line 5408 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5442 5443 5444 5445 5446 5447 5448 |
# File 'lib/models/porcelain.rb', line 5442 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |