Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/models/porcelain.rb', line 5333

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5305
5306
5307
# File 'lib/models/porcelain.rb', line 5305

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



5307
5308
5309
# File 'lib/models/porcelain.rb', line 5307

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5309
5310
5311
# File 'lib/models/porcelain.rb', line 5309

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5311
5312
5313
# File 'lib/models/porcelain.rb', line 5311

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5313
5314
5315
# File 'lib/models/porcelain.rb', line 5313

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5315
5316
5317
# File 'lib/models/porcelain.rb', line 5315

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5317
5318
5319
# File 'lib/models/porcelain.rb', line 5317

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



5319
5320
5321
# File 'lib/models/porcelain.rb', line 5319

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



5321
5322
5323
# File 'lib/models/porcelain.rb', line 5321

def password
  @password
end

#portObject

Returns the value of attribute port.



5323
5324
5325
# File 'lib/models/porcelain.rb', line 5323

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5325
5326
5327
# File 'lib/models/porcelain.rb', line 5325

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5327
5328
5329
# File 'lib/models/porcelain.rb', line 5327

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5329
5330
5331
# File 'lib/models/porcelain.rb', line 5329

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5331
5332
5333
# File 'lib/models/porcelain.rb', line 5331

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5365
5366
5367
5368
5369
5370
5371
# File 'lib/models/porcelain.rb', line 5365

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end