Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
5302 5303 5304 5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 5319 5320 5321 5322 5323 5324 5325 5326 5327 5328 5329 5330 5331 5332 |
# File 'lib/models/porcelain.rb', line 5302 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5274 5275 5276 |
# File 'lib/models/porcelain.rb', line 5274 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5276 5277 5278 |
# File 'lib/models/porcelain.rb', line 5276 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5278 5279 5280 |
# File 'lib/models/porcelain.rb', line 5278 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5280 5281 5282 |
# File 'lib/models/porcelain.rb', line 5280 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5282 5283 5284 |
# File 'lib/models/porcelain.rb', line 5282 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5284 5285 5286 |
# File 'lib/models/porcelain.rb', line 5284 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5286 5287 5288 |
# File 'lib/models/porcelain.rb', line 5286 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5288 5289 5290 |
# File 'lib/models/porcelain.rb', line 5288 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5290 5291 5292 |
# File 'lib/models/porcelain.rb', line 5290 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5292 5293 5294 |
# File 'lib/models/porcelain.rb', line 5292 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5294 5295 5296 |
# File 'lib/models/porcelain.rb', line 5294 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5296 5297 5298 |
# File 'lib/models/porcelain.rb', line 5296 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5298 5299 5300 |
# File 'lib/models/porcelain.rb', line 5298 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5300 5301 5302 |
# File 'lib/models/porcelain.rb', line 5300 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5334 5335 5336 5337 5338 5339 5340 |
# File 'lib/models/porcelain.rb', line 5334 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |