Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



5275
5276
5277
5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/models/porcelain.rb', line 5275

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



5247
5248
5249
# File 'lib/models/porcelain.rb', line 5247

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



5249
5250
5251
# File 'lib/models/porcelain.rb', line 5249

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5251
5252
5253
# File 'lib/models/porcelain.rb', line 5251

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5253
5254
5255
# File 'lib/models/porcelain.rb', line 5253

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5255
5256
5257
# File 'lib/models/porcelain.rb', line 5255

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5257
5258
5259
# File 'lib/models/porcelain.rb', line 5257

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



5259
5260
5261
# File 'lib/models/porcelain.rb', line 5259

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



5261
5262
5263
# File 'lib/models/porcelain.rb', line 5261

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



5263
5264
5265
# File 'lib/models/porcelain.rb', line 5263

def password
  @password
end

#portObject

Returns the value of attribute port.



5265
5266
5267
# File 'lib/models/porcelain.rb', line 5265

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



5267
5268
5269
# File 'lib/models/porcelain.rb', line 5267

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5269
5270
5271
# File 'lib/models/porcelain.rb', line 5269

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5271
5272
5273
# File 'lib/models/porcelain.rb', line 5271

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5273
5274
5275
# File 'lib/models/porcelain.rb', line 5273

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5307
5308
5309
5310
5311
5312
5313
# File 'lib/models/porcelain.rb', line 5307

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end