Class: SDM::Redshift
- Inherits:
-
Object
- Object
- SDM::Redshift
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift
constructor
A new instance of Redshift.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ Redshift
Returns a new instance of Redshift.
5923 5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 5937 5938 5939 5940 5941 5942 5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 |
# File 'lib/models/porcelain.rb', line 5923 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if override_database != nil @override_database = override_database end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
5897 5898 5899 |
# File 'lib/models/porcelain.rb', line 5897 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5899 5900 5901 |
# File 'lib/models/porcelain.rb', line 5899 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5901 5902 5903 |
# File 'lib/models/porcelain.rb', line 5901 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5903 5904 5905 |
# File 'lib/models/porcelain.rb', line 5903 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5905 5906 5907 |
# File 'lib/models/porcelain.rb', line 5905 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5907 5908 5909 |
# File 'lib/models/porcelain.rb', line 5907 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5909 5910 5911 |
# File 'lib/models/porcelain.rb', line 5909 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5911 5912 5913 |
# File 'lib/models/porcelain.rb', line 5911 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5913 5914 5915 |
# File 'lib/models/porcelain.rb', line 5913 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5915 5916 5917 |
# File 'lib/models/porcelain.rb', line 5915 def port_override @port_override end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5917 5918 5919 |
# File 'lib/models/porcelain.rb', line 5917 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5919 5920 5921 |
# File 'lib/models/porcelain.rb', line 5919 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5921 5922 5923 |
# File 'lib/models/porcelain.rb', line 5921 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5979 5980 5981 5982 5983 5984 5985 |
# File 'lib/models/porcelain.rb', line 5979 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |