Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



11840
11841
11842
11843
11844
11845
11846
11847
11848
11849
11850
11851
11852
11853
11854
11855
11856
11857
11858
11859
11860
11861
11862
11863
11864
11865
11866
11867
11868
11869
11870
11871
11872
11873
11874
# File 'lib/models/porcelain.rb', line 11840

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11808
11809
11810
# File 'lib/models/porcelain.rb', line 11808

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11810
11811
11812
# File 'lib/models/porcelain.rb', line 11810

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11812
11813
11814
# File 'lib/models/porcelain.rb', line 11812

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11814
11815
11816
# File 'lib/models/porcelain.rb', line 11814

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11816
11817
11818
# File 'lib/models/porcelain.rb', line 11816

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11818
11819
11820
# File 'lib/models/porcelain.rb', line 11818

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11820
11821
11822
# File 'lib/models/porcelain.rb', line 11820

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11822
11823
11824
# File 'lib/models/porcelain.rb', line 11822

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



11824
11825
11826
# File 'lib/models/porcelain.rb', line 11824

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11826
11827
11828
# File 'lib/models/porcelain.rb', line 11826

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11828
11829
11830
# File 'lib/models/porcelain.rb', line 11828

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11830
11831
11832
# File 'lib/models/porcelain.rb', line 11830

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11832
11833
11834
# File 'lib/models/porcelain.rb', line 11832

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11834
11835
11836
# File 'lib/models/porcelain.rb', line 11834

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11836
11837
11838
# File 'lib/models/porcelain.rb', line 11836

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11838
11839
11840
# File 'lib/models/porcelain.rb', line 11838

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11876
11877
11878
11879
11880
11881
11882
# File 'lib/models/porcelain.rb', line 11876

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end