Class: SDM::Redshift

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ Redshift

Returns a new instance of Redshift.



15309
15310
15311
15312
15313
15314
15315
15316
15317
15318
15319
15320
15321
15322
15323
15324
15325
15326
15327
15328
15329
15330
15331
15332
15333
15334
15335
15336
15337
15338
15339
15340
15341
15342
15343
# File 'lib/models/porcelain.rb', line 15309

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15277
15278
15279
# File 'lib/models/porcelain.rb', line 15277

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15279
15280
15281
# File 'lib/models/porcelain.rb', line 15279

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



15281
15282
15283
# File 'lib/models/porcelain.rb', line 15281

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



15283
15284
15285
# File 'lib/models/porcelain.rb', line 15283

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



15285
15286
15287
# File 'lib/models/porcelain.rb', line 15285

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



15287
15288
15289
# File 'lib/models/porcelain.rb', line 15287

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



15289
15290
15291
# File 'lib/models/porcelain.rb', line 15289

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15291
15292
15293
# File 'lib/models/porcelain.rb', line 15291

def override_database
  @override_database
end

#password ⇒ Object

The password to authenticate with.



15293
15294
15295
# File 'lib/models/porcelain.rb', line 15293

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



15295
15296
15297
# File 'lib/models/porcelain.rb', line 15295

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15297
15298
15299
# File 'lib/models/porcelain.rb', line 15297

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



15299
15300
15301
# File 'lib/models/porcelain.rb', line 15299

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



15301
15302
15303
# File 'lib/models/porcelain.rb', line 15301

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15303
15304
15305
# File 'lib/models/porcelain.rb', line 15303

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



15305
15306
15307
# File 'lib/models/porcelain.rb', line 15305

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



15307
15308
15309
# File 'lib/models/porcelain.rb', line 15307

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15345
15346
15347
15348
15349
15350
15351
# File 'lib/models/porcelain.rb', line 15345

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end