Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



15282
15283
15284
15285
15286
15287
15288
15289
15290
15291
15292
15293
15294
15295
15296
15297
15298
15299
15300
15301
15302
15303
15304
15305
15306
15307
15308
15309
15310
15311
15312
15313
15314
15315
15316
15317
15318
# File 'lib/models/porcelain.rb', line 15282

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15248
15249
15250
# File 'lib/models/porcelain.rb', line 15248

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



15250
15251
15252
# File 'lib/models/porcelain.rb', line 15250

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15252
15253
15254
# File 'lib/models/porcelain.rb', line 15252

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15254
15255
15256
# File 'lib/models/porcelain.rb', line 15254

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15256
15257
15258
# File 'lib/models/porcelain.rb', line 15256

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15258
15259
15260
# File 'lib/models/porcelain.rb', line 15258

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15260
15261
15262
# File 'lib/models/porcelain.rb', line 15260

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15262
15263
15264
# File 'lib/models/porcelain.rb', line 15262

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15264
15265
15266
# File 'lib/models/porcelain.rb', line 15264

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15266
15267
15268
# File 'lib/models/porcelain.rb', line 15266

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15268
15269
15270
# File 'lib/models/porcelain.rb', line 15268

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15270
15271
15272
# File 'lib/models/porcelain.rb', line 15270

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



15272
15273
15274
# File 'lib/models/porcelain.rb', line 15272

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



15274
15275
15276
# File 'lib/models/porcelain.rb', line 15274

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15276
15277
15278
# File 'lib/models/porcelain.rb', line 15276

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15278
15279
15280
# File 'lib/models/porcelain.rb', line 15278

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15280
15281
15282
# File 'lib/models/porcelain.rb', line 15280

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15320
15321
15322
15323
15324
15325
15326
# File 'lib/models/porcelain.rb', line 15320

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end