Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



15202
15203
15204
15205
15206
15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
15218
15219
15220
15221
15222
15223
15224
15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
# File 'lib/models/porcelain.rb', line 15202

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15168
15169
15170
# File 'lib/models/porcelain.rb', line 15168

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



15170
15171
15172
# File 'lib/models/porcelain.rb', line 15170

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15172
15173
15174
# File 'lib/models/porcelain.rb', line 15172

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15174
15175
15176
# File 'lib/models/porcelain.rb', line 15174

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15176
15177
15178
# File 'lib/models/porcelain.rb', line 15176

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15178
15179
15180
# File 'lib/models/porcelain.rb', line 15178

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15180
15181
15182
# File 'lib/models/porcelain.rb', line 15180

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15182
15183
15184
# File 'lib/models/porcelain.rb', line 15182

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15184
15185
15186
# File 'lib/models/porcelain.rb', line 15184

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15186
15187
15188
# File 'lib/models/porcelain.rb', line 15186

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15188
15189
15190
# File 'lib/models/porcelain.rb', line 15188

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15190
15191
15192
# File 'lib/models/porcelain.rb', line 15190

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



15192
15193
15194
# File 'lib/models/porcelain.rb', line 15192

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



15194
15195
15196
# File 'lib/models/porcelain.rb', line 15194

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15196
15197
15198
# File 'lib/models/porcelain.rb', line 15196

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15198
15199
15200
# File 'lib/models/porcelain.rb', line 15198

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15200
15201
15202
# File 'lib/models/porcelain.rb', line 15200

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15240
15241
15242
15243
15244
15245
15246
# File 'lib/models/porcelain.rb', line 15240

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end