Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



14657
14658
14659
14660
14661
14662
14663
14664
14665
14666
14667
14668
14669
14670
14671
14672
14673
14674
14675
14676
14677
14678
14679
14680
14681
14682
14683
14684
14685
14686
14687
14688
14689
14690
14691
14692
14693
# File 'lib/models/porcelain.rb', line 14657

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14623
14624
14625
# File 'lib/models/porcelain.rb', line 14623

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



14625
14626
14627
# File 'lib/models/porcelain.rb', line 14625

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14627
14628
14629
# File 'lib/models/porcelain.rb', line 14627

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14629
14630
14631
# File 'lib/models/porcelain.rb', line 14629

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14631
14632
14633
# File 'lib/models/porcelain.rb', line 14631

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14633
14634
14635
# File 'lib/models/porcelain.rb', line 14633

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14635
14636
14637
# File 'lib/models/porcelain.rb', line 14635

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14637
14638
14639
# File 'lib/models/porcelain.rb', line 14637

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14639
14640
14641
# File 'lib/models/porcelain.rb', line 14639

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14641
14642
14643
# File 'lib/models/porcelain.rb', line 14641

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14643
14644
14645
# File 'lib/models/porcelain.rb', line 14643

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14645
14646
14647
# File 'lib/models/porcelain.rb', line 14645

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14647
14648
14649
# File 'lib/models/porcelain.rb', line 14647

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14649
14650
14651
# File 'lib/models/porcelain.rb', line 14649

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14651
14652
14653
# File 'lib/models/porcelain.rb', line 14651

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14653
14654
14655
# File 'lib/models/porcelain.rb', line 14653

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14655
14656
14657
# File 'lib/models/porcelain.rb', line 14655

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14695
14696
14697
14698
14699
14700
14701
# File 'lib/models/porcelain.rb', line 14695

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end