Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



14217
14218
14219
14220
14221
14222
14223
14224
14225
14226
14227
14228
14229
14230
14231
14232
14233
14234
14235
14236
14237
14238
14239
14240
14241
14242
14243
14244
14245
14246
14247
14248
14249
14250
14251
14252
14253
# File 'lib/models/porcelain.rb', line 14217

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14183
14184
14185
# File 'lib/models/porcelain.rb', line 14183

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



14185
14186
14187
# File 'lib/models/porcelain.rb', line 14185

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14187
14188
14189
# File 'lib/models/porcelain.rb', line 14187

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14189
14190
14191
# File 'lib/models/porcelain.rb', line 14189

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14191
14192
14193
# File 'lib/models/porcelain.rb', line 14191

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14193
14194
14195
# File 'lib/models/porcelain.rb', line 14193

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14195
14196
14197
# File 'lib/models/porcelain.rb', line 14195

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14197
14198
14199
# File 'lib/models/porcelain.rb', line 14197

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14199
14200
14201
# File 'lib/models/porcelain.rb', line 14199

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14201
14202
14203
# File 'lib/models/porcelain.rb', line 14201

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14203
14204
14205
# File 'lib/models/porcelain.rb', line 14203

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14205
14206
14207
# File 'lib/models/porcelain.rb', line 14205

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14207
14208
14209
# File 'lib/models/porcelain.rb', line 14207

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14209
14210
14211
# File 'lib/models/porcelain.rb', line 14209

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14211
14212
14213
# File 'lib/models/porcelain.rb', line 14211

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14213
14214
14215
# File 'lib/models/porcelain.rb', line 14213

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14215
14216
14217
# File 'lib/models/porcelain.rb', line 14215

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14255
14256
14257
14258
14259
14260
14261
# File 'lib/models/porcelain.rb', line 14255

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end