Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



12193
12194
12195
12196
12197
12198
12199
12200
12201
12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
12212
12213
12214
12215
12216
12217
12218
12219
12220
12221
12222
12223
12224
12225
12226
12227
12228
12229
# File 'lib/models/porcelain.rb', line 12193

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12159
12160
12161
# File 'lib/models/porcelain.rb', line 12159

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



12161
12162
12163
# File 'lib/models/porcelain.rb', line 12161

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12163
12164
12165
# File 'lib/models/porcelain.rb', line 12163

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12165
12166
12167
# File 'lib/models/porcelain.rb', line 12165

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12167
12168
12169
# File 'lib/models/porcelain.rb', line 12167

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12169
12170
12171
# File 'lib/models/porcelain.rb', line 12169

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12171
12172
12173
# File 'lib/models/porcelain.rb', line 12171

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12173
12174
12175
# File 'lib/models/porcelain.rb', line 12173

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12175
12176
12177
# File 'lib/models/porcelain.rb', line 12175

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12177
12178
12179
# File 'lib/models/porcelain.rb', line 12177

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12179
12180
12181
# File 'lib/models/porcelain.rb', line 12179

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12181
12182
12183
# File 'lib/models/porcelain.rb', line 12181

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



12183
12184
12185
# File 'lib/models/porcelain.rb', line 12183

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



12185
12186
12187
# File 'lib/models/porcelain.rb', line 12185

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12187
12188
12189
# File 'lib/models/porcelain.rb', line 12187

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12189
12190
12191
# File 'lib/models/porcelain.rb', line 12189

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12191
12192
12193
# File 'lib/models/porcelain.rb', line 12191

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12231
12232
12233
12234
12235
12236
12237
# File 'lib/models/porcelain.rb', line 12231

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end