Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



12112
12113
12114
12115
12116
12117
12118
12119
12120
12121
12122
12123
12124
12125
12126
12127
12128
12129
12130
12131
12132
12133
12134
12135
12136
12137
12138
12139
12140
12141
12142
12143
12144
12145
12146
12147
12148
# File 'lib/models/porcelain.rb', line 12112

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12078
12079
12080
# File 'lib/models/porcelain.rb', line 12078

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



12080
12081
12082
# File 'lib/models/porcelain.rb', line 12080

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12082
12083
12084
# File 'lib/models/porcelain.rb', line 12082

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12084
12085
12086
# File 'lib/models/porcelain.rb', line 12084

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12086
12087
12088
# File 'lib/models/porcelain.rb', line 12086

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12088
12089
12090
# File 'lib/models/porcelain.rb', line 12088

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12090
12091
12092
# File 'lib/models/porcelain.rb', line 12090

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12092
12093
12094
# File 'lib/models/porcelain.rb', line 12092

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12094
12095
12096
# File 'lib/models/porcelain.rb', line 12094

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12096
12097
12098
# File 'lib/models/porcelain.rb', line 12096

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12098
12099
12100
# File 'lib/models/porcelain.rb', line 12098

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12100
12101
12102
# File 'lib/models/porcelain.rb', line 12100

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



12102
12103
12104
# File 'lib/models/porcelain.rb', line 12102

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



12104
12105
12106
# File 'lib/models/porcelain.rb', line 12104

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12106
12107
12108
# File 'lib/models/porcelain.rb', line 12106

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12108
12109
12110
# File 'lib/models/porcelain.rb', line 12108

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12110
12111
12112
# File 'lib/models/porcelain.rb', line 12110

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12150
12151
12152
12153
12154
12155
12156
# File 'lib/models/porcelain.rb', line 12150

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end