Class: SDM::RedshiftIAM
- Inherits:
-
Object
- Object
- SDM::RedshiftIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#cluster_id ⇒ Object
Cluster Identified of Redshift cluster.
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM
constructor
A new instance of RedshiftIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM
Returns a new instance of RedshiftIAM.
11932 11933 11934 11935 11936 11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 11962 11963 11964 11965 11966 11967 11968 |
# File 'lib/models/porcelain.rb', line 11932 def initialize( bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @cluster_id = cluster_id == nil ? "" : cluster_id @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11898 11899 11900 |
# File 'lib/models/porcelain.rb', line 11898 def bind_interface @bind_interface end |
#cluster_id ⇒ Object
Cluster Identified of Redshift cluster
11900 11901 11902 |
# File 'lib/models/porcelain.rb', line 11900 def cluster_id @cluster_id end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11902 11903 11904 |
# File 'lib/models/porcelain.rb', line 11902 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11904 11905 11906 |
# File 'lib/models/porcelain.rb', line 11904 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11906 11907 11908 |
# File 'lib/models/porcelain.rb', line 11906 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11908 11909 11910 |
# File 'lib/models/porcelain.rb', line 11908 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11910 11911 11912 |
# File 'lib/models/porcelain.rb', line 11910 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11912 11913 11914 |
# File 'lib/models/porcelain.rb', line 11912 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
11914 11915 11916 |
# File 'lib/models/porcelain.rb', line 11914 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11916 11917 11918 |
# File 'lib/models/porcelain.rb', line 11916 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11918 11919 11920 |
# File 'lib/models/porcelain.rb', line 11918 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11920 11921 11922 |
# File 'lib/models/porcelain.rb', line 11920 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
11922 11923 11924 |
# File 'lib/models/porcelain.rb', line 11922 def region @region end |
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
11924 11925 11926 |
# File 'lib/models/porcelain.rb', line 11924 def role_assumption_arn @role_assumption_arn end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11926 11927 11928 |
# File 'lib/models/porcelain.rb', line 11926 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11928 11929 11930 |
# File 'lib/models/porcelain.rb', line 11928 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11930 11931 11932 |
# File 'lib/models/porcelain.rb', line 11930 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11970 11971 11972 11973 11974 11975 11976 |
# File 'lib/models/porcelain.rb', line 11970 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |