Class: SDM::RedshiftIAM
- Inherits:
-
Object
- Object
- SDM::RedshiftIAM
- Defined in:
- lib/models/porcelain.rb
Overview
RedshiftIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#cluster_id ⇒ Object
Cluster Identified of Redshift cluster.
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM
constructor
A new instance of RedshiftIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM
Returns a new instance of RedshiftIAM.
11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 11808 11809 11810 11811 11812 11813 11814 |
# File 'lib/models/porcelain.rb', line 11778 def initialize( bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @cluster_id = cluster_id == nil ? "" : cluster_id @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11744 11745 11746 |
# File 'lib/models/porcelain.rb', line 11744 def bind_interface @bind_interface end |
#cluster_id ⇒ Object
Cluster Identified of Redshift cluster
11746 11747 11748 |
# File 'lib/models/porcelain.rb', line 11746 def cluster_id @cluster_id end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11748 11749 11750 |
# File 'lib/models/porcelain.rb', line 11748 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11750 11751 11752 |
# File 'lib/models/porcelain.rb', line 11750 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11752 11753 11754 |
# File 'lib/models/porcelain.rb', line 11752 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11754 11755 11756 |
# File 'lib/models/porcelain.rb', line 11754 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11756 11757 11758 |
# File 'lib/models/porcelain.rb', line 11756 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11758 11759 11760 |
# File 'lib/models/porcelain.rb', line 11758 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
11760 11761 11762 |
# File 'lib/models/porcelain.rb', line 11760 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11762 11763 11764 |
# File 'lib/models/porcelain.rb', line 11762 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11764 11765 11766 |
# File 'lib/models/porcelain.rb', line 11764 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11766 11767 11768 |
# File 'lib/models/porcelain.rb', line 11766 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
11768 11769 11770 |
# File 'lib/models/porcelain.rb', line 11768 def region @region end |
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
11770 11771 11772 |
# File 'lib/models/porcelain.rb', line 11770 def role_assumption_arn @role_assumption_arn end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11772 11773 11774 |
# File 'lib/models/porcelain.rb', line 11772 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11774 11775 11776 |
# File 'lib/models/porcelain.rb', line 11774 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11776 11777 11778 |
# File 'lib/models/porcelain.rb', line 11776 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11816 11817 11818 11819 11820 11821 11822 |
# File 'lib/models/porcelain.rb', line 11816 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |