Class: SDM::RedshiftIAM
- Inherits:
-
Object
- Object
- SDM::RedshiftIAM
- Defined in:
- lib/models/porcelain.rb
Overview
RedshiftIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#cluster_id ⇒ Object
Cluster Identified of Redshift cluster.
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM
constructor
A new instance of RedshiftIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM
Returns a new instance of RedshiftIAM.
11711 11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 11727 11728 11729 11730 11731 11732 11733 11734 11735 11736 11737 11738 11739 11740 11741 11742 11743 11744 11745 11746 11747 |
# File 'lib/models/porcelain.rb', line 11711 def initialize( bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @cluster_id = cluster_id == nil ? "" : cluster_id @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
11677 11678 11679 |
# File 'lib/models/porcelain.rb', line 11677 def bind_interface @bind_interface end |
#cluster_id ⇒ Object
Cluster Identified of Redshift cluster
11679 11680 11681 |
# File 'lib/models/porcelain.rb', line 11679 def cluster_id @cluster_id end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
11681 11682 11683 |
# File 'lib/models/porcelain.rb', line 11681 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
11683 11684 11685 |
# File 'lib/models/porcelain.rb', line 11683 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
11685 11686 11687 |
# File 'lib/models/porcelain.rb', line 11685 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
11687 11688 11689 |
# File 'lib/models/porcelain.rb', line 11687 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
11689 11690 11691 |
# File 'lib/models/porcelain.rb', line 11689 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
11691 11692 11693 |
# File 'lib/models/porcelain.rb', line 11691 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
11693 11694 11695 |
# File 'lib/models/porcelain.rb', line 11693 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
11695 11696 11697 |
# File 'lib/models/porcelain.rb', line 11695 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
11697 11698 11699 |
# File 'lib/models/porcelain.rb', line 11697 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
11699 11700 11701 |
# File 'lib/models/porcelain.rb', line 11699 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
11701 11702 11703 |
# File 'lib/models/porcelain.rb', line 11701 def region @region end |
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
11703 11704 11705 |
# File 'lib/models/porcelain.rb', line 11703 def role_assumption_arn @role_assumption_arn end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
11705 11706 11707 |
# File 'lib/models/porcelain.rb', line 11705 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
11707 11708 11709 |
# File 'lib/models/porcelain.rb', line 11707 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11709 11710 11711 |
# File 'lib/models/porcelain.rb', line 11709 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11749 11750 11751 11752 11753 11754 11755 |
# File 'lib/models/porcelain.rb', line 11749 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |