Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RedshiftIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



10860
10861
10862
10863
10864
10865
10866
10867
10868
10869
10870
10871
10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
10896
# File 'lib/models/porcelain.rb', line 10860

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10826
10827
10828
# File 'lib/models/porcelain.rb', line 10826

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



10828
10829
10830
# File 'lib/models/porcelain.rb', line 10828

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10830
10831
10832
# File 'lib/models/porcelain.rb', line 10830

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10832
10833
10834
# File 'lib/models/porcelain.rb', line 10832

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10834
10835
10836
# File 'lib/models/porcelain.rb', line 10834

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10836
10837
10838
# File 'lib/models/porcelain.rb', line 10836

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10838
10839
10840
# File 'lib/models/porcelain.rb', line 10838

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10840
10841
10842
# File 'lib/models/porcelain.rb', line 10840

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10842
10843
10844
# File 'lib/models/porcelain.rb', line 10842

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10844
10845
10846
# File 'lib/models/porcelain.rb', line 10844

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10846
10847
10848
# File 'lib/models/porcelain.rb', line 10846

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10848
10849
10850
# File 'lib/models/porcelain.rb', line 10848

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10850
10851
10852
# File 'lib/models/porcelain.rb', line 10850

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10852
10853
10854
# File 'lib/models/porcelain.rb', line 10852

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10854
10855
10856
# File 'lib/models/porcelain.rb', line 10854

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10856
10857
10858
# File 'lib/models/porcelain.rb', line 10856

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10858
10859
10860
# File 'lib/models/porcelain.rb', line 10858

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10898
10899
10900
10901
10902
10903
10904
# File 'lib/models/porcelain.rb', line 10898

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end