Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RedshiftIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



10785
10786
10787
10788
10789
10790
10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
10802
10803
10804
10805
10806
10807
10808
10809
10810
10811
10812
10813
10814
10815
10816
10817
10818
10819
10820
10821
# File 'lib/models/porcelain.rb', line 10785

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10751
10752
10753
# File 'lib/models/porcelain.rb', line 10751

def bind_interface
  @bind_interface
end

#cluster_idObject

Cluster Identified of Redshift cluster



10753
10754
10755
# File 'lib/models/porcelain.rb', line 10753

def cluster_id
  @cluster_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10755
10756
10757
# File 'lib/models/porcelain.rb', line 10755

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10757
10758
10759
# File 'lib/models/porcelain.rb', line 10757

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10759
10760
10761
# File 'lib/models/porcelain.rb', line 10759

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10761
10762
10763
# File 'lib/models/porcelain.rb', line 10761

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10763
10764
10765
# File 'lib/models/porcelain.rb', line 10763

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10765
10766
10767
# File 'lib/models/porcelain.rb', line 10765

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10767
10768
10769
# File 'lib/models/porcelain.rb', line 10767

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10769
10770
10771
# File 'lib/models/porcelain.rb', line 10769

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10771
10772
10773
# File 'lib/models/porcelain.rb', line 10771

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10773
10774
10775
# File 'lib/models/porcelain.rb', line 10773

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10775
10776
10777
# File 'lib/models/porcelain.rb', line 10775

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10777
10778
10779
# File 'lib/models/porcelain.rb', line 10777

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10779
10780
10781
# File 'lib/models/porcelain.rb', line 10779

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10781
10782
10783
# File 'lib/models/porcelain.rb', line 10781

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10783
10784
10785
# File 'lib/models/porcelain.rb', line 10783

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10823
10824
10825
10826
10827
10828
10829
# File 'lib/models/porcelain.rb', line 10823

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end