Class: SDM::RedshiftIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, cluster_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil) ⇒ RedshiftIAM

Returns a new instance of RedshiftIAM.



15390
15391
15392
15393
15394
15395
15396
15397
15398
15399
15400
15401
15402
15403
15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
# File 'lib/models/porcelain.rb', line 15390

def initialize(
  bind_interface: nil,
  cluster_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @cluster_id = cluster_id == nil ? "" : cluster_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15356
15357
15358
# File 'lib/models/porcelain.rb', line 15356

def bind_interface
  @bind_interface
end

#cluster_id ⇒ Object

Cluster Identified of Redshift cluster



15358
15359
15360
# File 'lib/models/porcelain.rb', line 15358

def cluster_id
  @cluster_id
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15360
15361
15362
# File 'lib/models/porcelain.rb', line 15360

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



15362
15363
15364
# File 'lib/models/porcelain.rb', line 15362

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



15364
15365
15366
# File 'lib/models/porcelain.rb', line 15364

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



15366
15367
15368
# File 'lib/models/porcelain.rb', line 15366

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



15368
15369
15370
# File 'lib/models/porcelain.rb', line 15368

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



15370
15371
15372
# File 'lib/models/porcelain.rb', line 15370

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15372
15373
15374
# File 'lib/models/porcelain.rb', line 15372

def override_database
  @override_database
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



15374
15375
15376
# File 'lib/models/porcelain.rb', line 15374

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15376
15377
15378
# File 'lib/models/porcelain.rb', line 15376

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



15378
15379
15380
# File 'lib/models/porcelain.rb', line 15378

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to connect to.



15380
15381
15382
# File 'lib/models/porcelain.rb', line 15380

def region
  @region
end

#role_assumption_arn ⇒ Object

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



15382
15383
15384
# File 'lib/models/porcelain.rb', line 15382

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



15384
15385
15386
# File 'lib/models/porcelain.rb', line 15384

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15386
15387
15388
# File 'lib/models/porcelain.rb', line 15386

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



15388
15389
15390
# File 'lib/models/porcelain.rb', line 15388

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15428
15429
15430
15431
15432
15433
15434
# File 'lib/models/porcelain.rb', line 15428

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end