Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
15427
15428
15429
15430
15431
15432
15433
15434
15435
15436
15437
15438
15439
15440
15441
15442
15443
15444
15445
15446
15447
15448
15449
# File 'lib/models/porcelain.rb', line 15413

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15379
15380
15381
# File 'lib/models/porcelain.rb', line 15379

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15381
15382
15383
# File 'lib/models/porcelain.rb', line 15381

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15383
15384
15385
# File 'lib/models/porcelain.rb', line 15383

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15385
15386
15387
# File 'lib/models/porcelain.rb', line 15385

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15387
15388
15389
# File 'lib/models/porcelain.rb', line 15387

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15389
15390
15391
# File 'lib/models/porcelain.rb', line 15389

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15391
15392
15393
# File 'lib/models/porcelain.rb', line 15391

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15393
15394
15395
# File 'lib/models/porcelain.rb', line 15393

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15395
15396
15397
# File 'lib/models/porcelain.rb', line 15395

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15397
15398
15399
# File 'lib/models/porcelain.rb', line 15397

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15399
15400
15401
# File 'lib/models/porcelain.rb', line 15399

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



15401
15402
15403
# File 'lib/models/porcelain.rb', line 15401

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



15403
15404
15405
# File 'lib/models/porcelain.rb', line 15403

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15405
15406
15407
# File 'lib/models/porcelain.rb', line 15405

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15407
15408
15409
# File 'lib/models/porcelain.rb', line 15407

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15409
15410
15411
# File 'lib/models/porcelain.rb', line 15409

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



15411
15412
15413
# File 'lib/models/porcelain.rb', line 15411

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15451
15452
15453
15454
15455
15456
15457
# File 'lib/models/porcelain.rb', line 15451

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end