Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



15365
15366
15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
15384
15385
15386
15387
15388
15389
15390
15391
15392
15393
15394
15395
15396
15397
15398
15399
15400
15401
# File 'lib/models/porcelain.rb', line 15365

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15331
15332
15333
# File 'lib/models/porcelain.rb', line 15331

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15333
15334
15335
# File 'lib/models/porcelain.rb', line 15333

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15335
15336
15337
# File 'lib/models/porcelain.rb', line 15335

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15337
15338
15339
# File 'lib/models/porcelain.rb', line 15337

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15339
15340
15341
# File 'lib/models/porcelain.rb', line 15339

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15341
15342
15343
# File 'lib/models/porcelain.rb', line 15341

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15343
15344
15345
# File 'lib/models/porcelain.rb', line 15343

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15345
15346
15347
# File 'lib/models/porcelain.rb', line 15345

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15347
15348
15349
# File 'lib/models/porcelain.rb', line 15347

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15349
15350
15351
# File 'lib/models/porcelain.rb', line 15349

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15351
15352
15353
# File 'lib/models/porcelain.rb', line 15351

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



15353
15354
15355
# File 'lib/models/porcelain.rb', line 15353

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



15355
15356
15357
# File 'lib/models/porcelain.rb', line 15355

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15357
15358
15359
# File 'lib/models/porcelain.rb', line 15357

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15359
15360
15361
# File 'lib/models/porcelain.rb', line 15359

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15361
15362
15363
# File 'lib/models/porcelain.rb', line 15361

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



15363
15364
15365
# File 'lib/models/porcelain.rb', line 15363

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15403
15404
15405
15406
15407
15408
15409
# File 'lib/models/porcelain.rb', line 15403

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end