Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
15069
15070
15071
15072
15073
15074
15075
15076
15077
15078
15079
15080
15081
15082
15083
15084
15085
15086
15087
15088
15089
15090
15091
15092
15093
15094
# File 'lib/models/porcelain.rb', line 15058

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15024
15025
15026
# File 'lib/models/porcelain.rb', line 15024

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15026
15027
15028
# File 'lib/models/porcelain.rb', line 15026

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15028
15029
15030
# File 'lib/models/porcelain.rb', line 15028

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15030
15031
15032
# File 'lib/models/porcelain.rb', line 15030

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15032
15033
15034
# File 'lib/models/porcelain.rb', line 15032

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15034
15035
15036
# File 'lib/models/porcelain.rb', line 15034

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15036
15037
15038
# File 'lib/models/porcelain.rb', line 15036

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15038
15039
15040
# File 'lib/models/porcelain.rb', line 15038

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15040
15041
15042
# File 'lib/models/porcelain.rb', line 15040

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15042
15043
15044
# File 'lib/models/porcelain.rb', line 15042

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15044
15045
15046
# File 'lib/models/porcelain.rb', line 15044

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



15046
15047
15048
# File 'lib/models/porcelain.rb', line 15046

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



15048
15049
15050
# File 'lib/models/porcelain.rb', line 15048

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15050
15051
15052
# File 'lib/models/porcelain.rb', line 15050

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15052
15053
15054
# File 'lib/models/porcelain.rb', line 15052

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15054
15055
15056
# File 'lib/models/porcelain.rb', line 15054

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



15056
15057
15058
# File 'lib/models/porcelain.rb', line 15056

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15096
15097
15098
15099
15100
15101
15102
# File 'lib/models/porcelain.rb', line 15096

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end