Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



14666
14667
14668
14669
14670
14671
14672
14673
14674
14675
14676
14677
14678
14679
14680
14681
14682
14683
14684
14685
14686
14687
14688
14689
14690
14691
14692
14693
14694
14695
14696
14697
14698
14699
14700
14701
14702
# File 'lib/models/porcelain.rb', line 14666

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14632
14633
14634
# File 'lib/models/porcelain.rb', line 14632

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14634
14635
14636
# File 'lib/models/porcelain.rb', line 14634

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14636
14637
14638
# File 'lib/models/porcelain.rb', line 14636

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14638
14639
14640
# File 'lib/models/porcelain.rb', line 14638

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14640
14641
14642
# File 'lib/models/porcelain.rb', line 14640

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14642
14643
14644
# File 'lib/models/porcelain.rb', line 14642

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14644
14645
14646
# File 'lib/models/porcelain.rb', line 14644

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14646
14647
14648
# File 'lib/models/porcelain.rb', line 14646

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14648
14649
14650
# File 'lib/models/porcelain.rb', line 14648

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14650
14651
14652
# File 'lib/models/porcelain.rb', line 14650

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14652
14653
14654
# File 'lib/models/porcelain.rb', line 14652

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14654
14655
14656
# File 'lib/models/porcelain.rb', line 14654

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14656
14657
14658
# File 'lib/models/porcelain.rb', line 14656

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14658
14659
14660
# File 'lib/models/porcelain.rb', line 14658

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14660
14661
14662
# File 'lib/models/porcelain.rb', line 14660

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14662
14663
14664
# File 'lib/models/porcelain.rb', line 14662

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



14664
14665
14666
# File 'lib/models/porcelain.rb', line 14664

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14704
14705
14706
14707
14708
14709
14710
# File 'lib/models/porcelain.rb', line 14704

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end