Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



14364
14365
14366
14367
14368
14369
14370
14371
14372
14373
14374
14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
# File 'lib/models/porcelain.rb', line 14364

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14330
14331
14332
# File 'lib/models/porcelain.rb', line 14330

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14332
14333
14334
# File 'lib/models/porcelain.rb', line 14332

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14334
14335
14336
# File 'lib/models/porcelain.rb', line 14334

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14336
14337
14338
# File 'lib/models/porcelain.rb', line 14336

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14338
14339
14340
# File 'lib/models/porcelain.rb', line 14338

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14340
14341
14342
# File 'lib/models/porcelain.rb', line 14340

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14342
14343
14344
# File 'lib/models/porcelain.rb', line 14342

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14344
14345
14346
# File 'lib/models/porcelain.rb', line 14344

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14346
14347
14348
# File 'lib/models/porcelain.rb', line 14346

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14348
14349
14350
# File 'lib/models/porcelain.rb', line 14348

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14350
14351
14352
# File 'lib/models/porcelain.rb', line 14350

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14352
14353
14354
# File 'lib/models/porcelain.rb', line 14352

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14354
14355
14356
# File 'lib/models/porcelain.rb', line 14354

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14356
14357
14358
# File 'lib/models/porcelain.rb', line 14356

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14358
14359
14360
# File 'lib/models/porcelain.rb', line 14358

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14360
14361
14362
# File 'lib/models/porcelain.rb', line 14360

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



14362
14363
14364
# File 'lib/models/porcelain.rb', line 14362

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14402
14403
14404
14405
14406
14407
14408
# File 'lib/models/porcelain.rb', line 14402

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end