Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



14300
14301
14302
14303
14304
14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
14316
14317
14318
14319
14320
14321
14322
14323
14324
14325
14326
14327
14328
14329
14330
14331
14332
14333
14334
14335
14336
# File 'lib/models/porcelain.rb', line 14300

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14266
14267
14268
# File 'lib/models/porcelain.rb', line 14266

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



14268
14269
14270
# File 'lib/models/porcelain.rb', line 14268

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14270
14271
14272
# File 'lib/models/porcelain.rb', line 14270

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14272
14273
14274
# File 'lib/models/porcelain.rb', line 14272

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14274
14275
14276
# File 'lib/models/porcelain.rb', line 14274

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14276
14277
14278
# File 'lib/models/porcelain.rb', line 14276

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14278
14279
14280
# File 'lib/models/porcelain.rb', line 14278

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14280
14281
14282
# File 'lib/models/porcelain.rb', line 14280

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14282
14283
14284
# File 'lib/models/porcelain.rb', line 14282

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14284
14285
14286
# File 'lib/models/porcelain.rb', line 14284

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14286
14287
14288
# File 'lib/models/porcelain.rb', line 14286

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



14288
14289
14290
# File 'lib/models/porcelain.rb', line 14288

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



14290
14291
14292
# File 'lib/models/porcelain.rb', line 14290

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14292
14293
14294
# File 'lib/models/porcelain.rb', line 14292

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14294
14295
14296
# File 'lib/models/porcelain.rb', line 14294

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14296
14297
14298
# File 'lib/models/porcelain.rb', line 14296

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



14298
14299
14300
# File 'lib/models/porcelain.rb', line 14298

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14338
14339
14340
14341
14342
14343
14344
# File 'lib/models/porcelain.rb', line 14338

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end