Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



12198
12199
12200
12201
12202
12203
12204
12205
12206
12207
12208
12209
12210
12211
12212
12213
12214
12215
12216
12217
12218
12219
12220
12221
12222
12223
12224
12225
12226
12227
12228
12229
12230
12231
12232
12233
12234
# File 'lib/models/porcelain.rb', line 12198

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12164
12165
12166
# File 'lib/models/porcelain.rb', line 12164

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



12166
12167
12168
# File 'lib/models/porcelain.rb', line 12166

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12168
12169
12170
# File 'lib/models/porcelain.rb', line 12168

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12170
12171
12172
# File 'lib/models/porcelain.rb', line 12170

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12172
12173
12174
# File 'lib/models/porcelain.rb', line 12172

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12174
12175
12176
# File 'lib/models/porcelain.rb', line 12174

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12176
12177
12178
# File 'lib/models/porcelain.rb', line 12176

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12178
12179
12180
# File 'lib/models/porcelain.rb', line 12178

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12180
12181
12182
# File 'lib/models/porcelain.rb', line 12180

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12182
12183
12184
# File 'lib/models/porcelain.rb', line 12182

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12184
12185
12186
# File 'lib/models/porcelain.rb', line 12184

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



12186
12187
12188
# File 'lib/models/porcelain.rb', line 12186

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



12188
12189
12190
# File 'lib/models/porcelain.rb', line 12188

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12190
12191
12192
# File 'lib/models/porcelain.rb', line 12190

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12192
12193
12194
# File 'lib/models/porcelain.rb', line 12192

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12194
12195
12196
# File 'lib/models/porcelain.rb', line 12194

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



12196
12197
12198
# File 'lib/models/porcelain.rb', line 12196

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12236
12237
12238
12239
12240
12241
12242
# File 'lib/models/porcelain.rb', line 12236

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end