Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RedshiftServerlessIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



11863
11864
11865
11866
11867
11868
11869
11870
11871
11872
11873
11874
11875
11876
11877
11878
11879
11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
11890
11891
11892
11893
11894
11895
11896
11897
11898
11899
# File 'lib/models/porcelain.rb', line 11863

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11829
11830
11831
# File 'lib/models/porcelain.rb', line 11829

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11831
11832
11833
# File 'lib/models/porcelain.rb', line 11831

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11833
11834
11835
# File 'lib/models/porcelain.rb', line 11833

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11835
11836
11837
# File 'lib/models/porcelain.rb', line 11835

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11837
11838
11839
# File 'lib/models/porcelain.rb', line 11837

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11839
11840
11841
# File 'lib/models/porcelain.rb', line 11839

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11841
11842
11843
# File 'lib/models/porcelain.rb', line 11841

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11843
11844
11845
# File 'lib/models/porcelain.rb', line 11843

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11845
11846
11847
# File 'lib/models/porcelain.rb', line 11845

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11847
11848
11849
# File 'lib/models/porcelain.rb', line 11847

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11849
11850
11851
# File 'lib/models/porcelain.rb', line 11849

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



11851
11852
11853
# File 'lib/models/porcelain.rb', line 11851

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



11853
11854
11855
# File 'lib/models/porcelain.rb', line 11853

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11855
11856
11857
# File 'lib/models/porcelain.rb', line 11855

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11857
11858
11859
# File 'lib/models/porcelain.rb', line 11857

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11859
11860
11861
# File 'lib/models/porcelain.rb', line 11859

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



11861
11862
11863
# File 'lib/models/porcelain.rb', line 11861

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11901
11902
11903
11904
11905
11906
11907
# File 'lib/models/porcelain.rb', line 11901

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end