Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RedshiftServerlessIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



11795
11796
11797
11798
11799
11800
11801
11802
11803
11804
11805
11806
11807
11808
11809
11810
11811
11812
11813
11814
11815
11816
11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
11829
11830
11831
# File 'lib/models/porcelain.rb', line 11795

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11761
11762
11763
# File 'lib/models/porcelain.rb', line 11761

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



11763
11764
11765
# File 'lib/models/porcelain.rb', line 11763

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11765
11766
11767
# File 'lib/models/porcelain.rb', line 11765

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11767
11768
11769
# File 'lib/models/porcelain.rb', line 11767

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11769
11770
11771
# File 'lib/models/porcelain.rb', line 11769

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11771
11772
11773
# File 'lib/models/porcelain.rb', line 11771

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11773
11774
11775
# File 'lib/models/porcelain.rb', line 11773

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11775
11776
11777
# File 'lib/models/porcelain.rb', line 11775

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11777
11778
11779
# File 'lib/models/porcelain.rb', line 11777

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11779
11780
11781
# File 'lib/models/porcelain.rb', line 11779

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11781
11782
11783
# File 'lib/models/porcelain.rb', line 11781

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



11783
11784
11785
# File 'lib/models/porcelain.rb', line 11783

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



11785
11786
11787
# File 'lib/models/porcelain.rb', line 11785

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11787
11788
11789
# File 'lib/models/porcelain.rb', line 11787

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11789
11790
11791
# File 'lib/models/porcelain.rb', line 11789

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11791
11792
11793
# File 'lib/models/porcelain.rb', line 11791

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



11793
11794
11795
# File 'lib/models/porcelain.rb', line 11793

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11833
11834
11835
11836
11837
11838
11839
# File 'lib/models/porcelain.rb', line 11833

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end