Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RedshiftServerlessIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



10944
10945
10946
10947
10948
10949
10950
10951
10952
10953
10954
10955
10956
10957
10958
10959
10960
10961
10962
10963
10964
10965
10966
10967
10968
10969
10970
10971
10972
10973
10974
10975
10976
10977
10978
10979
10980
# File 'lib/models/porcelain.rb', line 10944

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10910
10911
10912
# File 'lib/models/porcelain.rb', line 10910

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10912
10913
10914
# File 'lib/models/porcelain.rb', line 10912

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10914
10915
10916
# File 'lib/models/porcelain.rb', line 10914

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10916
10917
10918
# File 'lib/models/porcelain.rb', line 10916

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10918
10919
10920
# File 'lib/models/porcelain.rb', line 10918

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10920
10921
10922
# File 'lib/models/porcelain.rb', line 10920

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10922
10923
10924
# File 'lib/models/porcelain.rb', line 10922

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10924
10925
10926
# File 'lib/models/porcelain.rb', line 10924

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10926
10927
10928
# File 'lib/models/porcelain.rb', line 10926

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10928
10929
10930
# File 'lib/models/porcelain.rb', line 10928

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10930
10931
10932
# File 'lib/models/porcelain.rb', line 10930

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10932
10933
10934
# File 'lib/models/porcelain.rb', line 10932

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10934
10935
10936
# File 'lib/models/porcelain.rb', line 10934

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10936
10937
10938
# File 'lib/models/porcelain.rb', line 10936

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10938
10939
10940
# File 'lib/models/porcelain.rb', line 10938

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10940
10941
10942
# File 'lib/models/porcelain.rb', line 10940

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



10942
10943
10944
# File 'lib/models/porcelain.rb', line 10942

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10982
10983
10984
10985
10986
10987
10988
# File 'lib/models/porcelain.rb', line 10982

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end