Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RedshiftServerlessIAM is currently unstable, and its API may change, or it may be removed, without a major version bump.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



10861
10862
10863
10864
10865
10866
10867
10868
10869
10870
10871
10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
10896
10897
# File 'lib/models/porcelain.rb', line 10861

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10827
10828
10829
# File 'lib/models/porcelain.rb', line 10827

def bind_interface
  @bind_interface
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



10829
10830
10831
# File 'lib/models/porcelain.rb', line 10829

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10831
10832
10833
# File 'lib/models/porcelain.rb', line 10831

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10833
10834
10835
# File 'lib/models/porcelain.rb', line 10833

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10835
10836
10837
# File 'lib/models/porcelain.rb', line 10835

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10837
10838
10839
# File 'lib/models/porcelain.rb', line 10837

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10839
10840
10841
# File 'lib/models/porcelain.rb', line 10839

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10841
10842
10843
# File 'lib/models/porcelain.rb', line 10841

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10843
10844
10845
# File 'lib/models/porcelain.rb', line 10843

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10845
10846
10847
# File 'lib/models/porcelain.rb', line 10845

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10847
10848
10849
# File 'lib/models/porcelain.rb', line 10847

def proxy_cluster_id
  @proxy_cluster_id
end

#regionObject

The AWS region to connect to.



10849
10850
10851
# File 'lib/models/porcelain.rb', line 10849

def region
  @region
end

#role_assumption_arnObject

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



10851
10852
10853
# File 'lib/models/porcelain.rb', line 10851

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10853
10854
10855
# File 'lib/models/porcelain.rb', line 10853

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10855
10856
10857
# File 'lib/models/porcelain.rb', line 10855

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10857
10858
10859
# File 'lib/models/porcelain.rb', line 10857

def tags
  @tags
end

#workgroupObject

Workgroup name in the serverless Redshift



10859
10860
10861
# File 'lib/models/porcelain.rb', line 10859

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10899
10900
10901
10902
10903
10904
10905
# File 'lib/models/porcelain.rb', line 10899

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end