Class: SDM::RedshiftServerlessIAM
- Inherits:
-
Object
- Object
- SDM::RedshiftServerlessIAM
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#region ⇒ Object
The AWS region to connect to.
-
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#workgroup ⇒ Object
Workgroup name in the serverless Redshift.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM
constructor
A new instance of RedshiftServerlessIAM.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM
Returns a new instance of RedshiftServerlessIAM.
14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 14757 14758 14759 14760 14761 14762 14763 14764 14765 14766 14767 14768 14769 14770 14771 14772 14773 14774 14775 |
# File 'lib/models/porcelain.rb', line 14739 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @region = region == nil ? "" : region @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @workgroup = workgroup == nil ? "" : workgroup end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
14705 14706 14707 |
# File 'lib/models/porcelain.rb', line 14705 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
14707 14708 14709 |
# File 'lib/models/porcelain.rb', line 14707 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
14709 14710 14711 |
# File 'lib/models/porcelain.rb', line 14709 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
14711 14712 14713 |
# File 'lib/models/porcelain.rb', line 14711 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
14713 14714 14715 |
# File 'lib/models/porcelain.rb', line 14713 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
14715 14716 14717 |
# File 'lib/models/porcelain.rb', line 14715 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
14717 14718 14719 |
# File 'lib/models/porcelain.rb', line 14717 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
14719 14720 14721 |
# File 'lib/models/porcelain.rb', line 14719 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
14721 14722 14723 |
# File 'lib/models/porcelain.rb', line 14721 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
14723 14724 14725 |
# File 'lib/models/porcelain.rb', line 14723 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
14725 14726 14727 |
# File 'lib/models/porcelain.rb', line 14725 def proxy_cluster_id @proxy_cluster_id end |
#region ⇒ Object
The AWS region to connect to.
14727 14728 14729 |
# File 'lib/models/porcelain.rb', line 14727 def region @region end |
#role_assumption_arn ⇒ Object
If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.
14729 14730 14731 |
# File 'lib/models/porcelain.rb', line 14729 def role_assumption_arn @role_assumption_arn end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
14731 14732 14733 |
# File 'lib/models/porcelain.rb', line 14731 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
14733 14734 14735 |
# File 'lib/models/porcelain.rb', line 14733 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
14735 14736 14737 |
# File 'lib/models/porcelain.rb', line 14735 def @tags end |
#workgroup ⇒ Object
Workgroup name in the serverless Redshift
14737 14738 14739 |
# File 'lib/models/porcelain.rb', line 14737 def workgroup @workgroup end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14777 14778 14779 14780 14781 14782 14783 |
# File 'lib/models/porcelain.rb', line 14777 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |