Class: SDM::RedshiftServerlessIAM

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, region: nil, role_assumption_arn: nil, secret_store_id: nil, subdomain: nil, tags: nil, workgroup: nil) ⇒ RedshiftServerlessIAM

Returns a new instance of RedshiftServerlessIAM.



15473
15474
15475
15476
15477
15478
15479
15480
15481
15482
15483
15484
15485
15486
15487
15488
15489
15490
15491
15492
15493
15494
15495
15496
15497
15498
15499
15500
15501
15502
15503
15504
15505
15506
15507
15508
15509
# File 'lib/models/porcelain.rb', line 15473

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  region: nil,
  role_assumption_arn: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  workgroup: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @region = region == nil ? "" : region
  @role_assumption_arn = role_assumption_arn == nil ? "" : role_assumption_arn
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @workgroup = workgroup == nil ? "" : workgroup
end

Instance Attribute Details

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15439
15440
15441
# File 'lib/models/porcelain.rb', line 15439

def bind_interface
  @bind_interface
end

#database ⇒ Object

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



15441
15442
15443
# File 'lib/models/porcelain.rb', line 15441

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



15443
15444
15445
# File 'lib/models/porcelain.rb', line 15443

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



15445
15446
15447
# File 'lib/models/porcelain.rb', line 15445

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



15447
15448
15449
# File 'lib/models/porcelain.rb', line 15447

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



15449
15450
15451
# File 'lib/models/porcelain.rb', line 15449

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



15451
15452
15453
# File 'lib/models/porcelain.rb', line 15451

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15453
15454
15455
# File 'lib/models/porcelain.rb', line 15453

def override_database
  @override_database
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



15455
15456
15457
# File 'lib/models/porcelain.rb', line 15455

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15457
15458
15459
# File 'lib/models/porcelain.rb', line 15457

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



15459
15460
15461
# File 'lib/models/porcelain.rb', line 15459

def proxy_cluster_id
  @proxy_cluster_id
end

#region ⇒ Object

The AWS region to connect to.



15461
15462
15463
# File 'lib/models/porcelain.rb', line 15461

def region
  @region
end

#role_assumption_arn ⇒ Object

If provided, the gateway/relay will try to assume this role instead of the underlying compute's role.



15463
15464
15465
# File 'lib/models/porcelain.rb', line 15463

def role_assumption_arn
  @role_assumption_arn
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



15465
15466
15467
# File 'lib/models/porcelain.rb', line 15465

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15467
15468
15469
# File 'lib/models/porcelain.rb', line 15467

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



15469
15470
15471
# File 'lib/models/porcelain.rb', line 15469

def tags
  @tags
end

#workgroup ⇒ Object

Workgroup name in the serverless Redshift



15471
15472
15473
# File 'lib/models/porcelain.rb', line 15471

def workgroup
  @workgroup
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15511
15512
15513
15514
15515
15516
15517
# File 'lib/models/porcelain.rb', line 15511

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end