Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



15496
15497
15498
15499
15500
15501
15502
15503
15504
15505
15506
15507
15508
15509
15510
15511
15512
15513
15514
15515
15516
# File 'lib/models/porcelain.rb', line 15496

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



15464
15465
15466
# File 'lib/models/porcelain.rb', line 15464

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



15467
15468
15469
# File 'lib/models/porcelain.rb', line 15467

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



15469
15470
15471
# File 'lib/models/porcelain.rb', line 15469

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



15472
15473
15474
# File 'lib/models/porcelain.rb', line 15472

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



15485
15486
15487
# File 'lib/models/porcelain.rb', line 15485

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



15487
15488
15489
# File 'lib/models/porcelain.rb', line 15487

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



15489
15490
15491
# File 'lib/models/porcelain.rb', line 15489

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



15491
15492
15493
# File 'lib/models/porcelain.rb', line 15491

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



15494
15495
15496
# File 'lib/models/porcelain.rb', line 15494

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15518
15519
15520
15521
15522
15523
15524
# File 'lib/models/porcelain.rb', line 15518

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end