Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



15448
15449
15450
15451
15452
15453
15454
15455
15456
15457
15458
15459
15460
15461
15462
15463
15464
15465
15466
15467
15468
# File 'lib/models/porcelain.rb', line 15448

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



15416
15417
15418
# File 'lib/models/porcelain.rb', line 15416

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



15419
15420
15421
# File 'lib/models/porcelain.rb', line 15419

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



15421
15422
15423
# File 'lib/models/porcelain.rb', line 15421

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



15424
15425
15426
# File 'lib/models/porcelain.rb', line 15424

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



15437
15438
15439
# File 'lib/models/porcelain.rb', line 15437

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



15439
15440
15441
# File 'lib/models/porcelain.rb', line 15439

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



15441
15442
15443
# File 'lib/models/porcelain.rb', line 15441

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



15443
15444
15445
# File 'lib/models/porcelain.rb', line 15443

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



15446
15447
15448
# File 'lib/models/porcelain.rb', line 15446

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15470
15471
15472
15473
15474
15475
15476
# File 'lib/models/porcelain.rb', line 15470

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end