Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
15384
15385
15386
15387
15388
# File 'lib/models/porcelain.rb', line 15368

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



15336
15337
15338
# File 'lib/models/porcelain.rb', line 15336

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



15339
15340
15341
# File 'lib/models/porcelain.rb', line 15339

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



15341
15342
15343
# File 'lib/models/porcelain.rb', line 15341

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



15344
15345
15346
# File 'lib/models/porcelain.rb', line 15344

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



15357
15358
15359
# File 'lib/models/porcelain.rb', line 15357

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



15359
15360
15361
# File 'lib/models/porcelain.rb', line 15359

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



15361
15362
15363
# File 'lib/models/porcelain.rb', line 15361

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



15363
15364
15365
# File 'lib/models/porcelain.rb', line 15363

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



15366
15367
15368
# File 'lib/models/porcelain.rb', line 15366

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15390
15391
15392
15393
15394
15395
15396
# File 'lib/models/porcelain.rb', line 15390

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end