Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



15141
15142
15143
15144
15145
15146
15147
15148
15149
15150
15151
15152
15153
15154
15155
15156
15157
15158
15159
15160
15161
# File 'lib/models/porcelain.rb', line 15141

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



15109
15110
15111
# File 'lib/models/porcelain.rb', line 15109

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



15112
15113
15114
# File 'lib/models/porcelain.rb', line 15112

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



15114
15115
15116
# File 'lib/models/porcelain.rb', line 15114

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



15117
15118
15119
# File 'lib/models/porcelain.rb', line 15117

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



15130
15131
15132
# File 'lib/models/porcelain.rb', line 15130

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



15132
15133
15134
# File 'lib/models/porcelain.rb', line 15132

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



15134
15135
15136
# File 'lib/models/porcelain.rb', line 15134

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



15136
15137
15138
# File 'lib/models/porcelain.rb', line 15136

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



15139
15140
15141
# File 'lib/models/porcelain.rb', line 15139

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15163
15164
15165
15166
15167
15168
15169
# File 'lib/models/porcelain.rb', line 15163

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end