Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



14823
14824
14825
14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
# File 'lib/models/porcelain.rb', line 14823

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



14791
14792
14793
# File 'lib/models/porcelain.rb', line 14791

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



14794
14795
14796
# File 'lib/models/porcelain.rb', line 14794

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



14796
14797
14798
# File 'lib/models/porcelain.rb', line 14796

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



14799
14800
14801
# File 'lib/models/porcelain.rb', line 14799

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



14812
14813
14814
# File 'lib/models/porcelain.rb', line 14812

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



14814
14815
14816
# File 'lib/models/porcelain.rb', line 14814

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



14816
14817
14818
# File 'lib/models/porcelain.rb', line 14816

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



14818
14819
14820
# File 'lib/models/porcelain.rb', line 14818

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



14821
14822
14823
# File 'lib/models/porcelain.rb', line 14821

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14845
14846
14847
14848
14849
14850
14851
# File 'lib/models/porcelain.rb', line 14845

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end