Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



14749
14750
14751
14752
14753
14754
14755
14756
14757
14758
14759
14760
14761
14762
14763
14764
14765
14766
14767
14768
14769
# File 'lib/models/porcelain.rb', line 14749

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



14717
14718
14719
# File 'lib/models/porcelain.rb', line 14717

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



14720
14721
14722
# File 'lib/models/porcelain.rb', line 14720

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



14722
14723
14724
# File 'lib/models/porcelain.rb', line 14722

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



14725
14726
14727
# File 'lib/models/porcelain.rb', line 14725

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



14738
14739
14740
# File 'lib/models/porcelain.rb', line 14738

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



14740
14741
14742
# File 'lib/models/porcelain.rb', line 14740

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



14742
14743
14744
# File 'lib/models/porcelain.rb', line 14742

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



14744
14745
14746
# File 'lib/models/porcelain.rb', line 14744

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



14747
14748
14749
# File 'lib/models/porcelain.rb', line 14747

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14771
14772
14773
14774
14775
14776
14777
# File 'lib/models/porcelain.rb', line 14771

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end