Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



14447
14448
14449
14450
14451
14452
14453
14454
14455
14456
14457
14458
14459
14460
14461
14462
14463
14464
14465
14466
14467
# File 'lib/models/porcelain.rb', line 14447

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



14415
14416
14417
# File 'lib/models/porcelain.rb', line 14415

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



14418
14419
14420
# File 'lib/models/porcelain.rb', line 14418

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



14420
14421
14422
# File 'lib/models/porcelain.rb', line 14420

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



14423
14424
14425
# File 'lib/models/porcelain.rb', line 14423

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



14436
14437
14438
# File 'lib/models/porcelain.rb', line 14436

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



14438
14439
14440
# File 'lib/models/porcelain.rb', line 14438

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



14440
14441
14442
# File 'lib/models/porcelain.rb', line 14440

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



14442
14443
14444
# File 'lib/models/porcelain.rb', line 14442

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



14445
14446
14447
# File 'lib/models/porcelain.rb', line 14445

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14469
14470
14471
14472
14473
14474
14475
# File 'lib/models/porcelain.rb', line 14469

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end