Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
14403
# File 'lib/models/porcelain.rb', line 14383

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



14351
14352
14353
# File 'lib/models/porcelain.rb', line 14351

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



14354
14355
14356
# File 'lib/models/porcelain.rb', line 14354

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



14356
14357
14358
# File 'lib/models/porcelain.rb', line 14356

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



14359
14360
14361
# File 'lib/models/porcelain.rb', line 14359

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



14372
14373
14374
# File 'lib/models/porcelain.rb', line 14372

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



14374
14375
14376
# File 'lib/models/porcelain.rb', line 14374

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



14376
14377
14378
# File 'lib/models/porcelain.rb', line 14376

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



14378
14379
14380
# File 'lib/models/porcelain.rb', line 14378

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



14381
14382
14383
# File 'lib/models/porcelain.rb', line 14381

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14405
14406
14407
14408
14409
14410
14411
# File 'lib/models/porcelain.rb', line 14405

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end