Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



13561
13562
13563
13564
13565
13566
13567
13568
13569
13570
13571
13572
13573
13574
13575
13576
13577
13578
13579
13580
13581
# File 'lib/models/porcelain.rb', line 13561

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



13529
13530
13531
# File 'lib/models/porcelain.rb', line 13529

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



13532
13533
13534
# File 'lib/models/porcelain.rb', line 13532

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



13534
13535
13536
# File 'lib/models/porcelain.rb', line 13534

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



13537
13538
13539
# File 'lib/models/porcelain.rb', line 13537

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



13550
13551
13552
# File 'lib/models/porcelain.rb', line 13550

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



13552
13553
13554
# File 'lib/models/porcelain.rb', line 13552

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



13554
13555
13556
# File 'lib/models/porcelain.rb', line 13554

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



13556
13557
13558
# File 'lib/models/porcelain.rb', line 13556

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



13559
13560
13561
# File 'lib/models/porcelain.rb', line 13559

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13583
13584
13585
13586
13587
13588
13589
# File 'lib/models/porcelain.rb', line 13583

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end