Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



12541
12542
12543
12544
12545
12546
12547
12548
12549
12550
12551
12552
12553
12554
12555
12556
12557
12558
12559
12560
12561
# File 'lib/models/porcelain.rb', line 12541

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



12509
12510
12511
# File 'lib/models/porcelain.rb', line 12509

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



12512
12513
12514
# File 'lib/models/porcelain.rb', line 12512

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



12514
12515
12516
# File 'lib/models/porcelain.rb', line 12514

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



12517
12518
12519
# File 'lib/models/porcelain.rb', line 12517

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



12530
12531
12532
# File 'lib/models/porcelain.rb', line 12530

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



12532
12533
12534
# File 'lib/models/porcelain.rb', line 12532

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



12534
12535
12536
# File 'lib/models/porcelain.rb', line 12534

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



12536
12537
12538
# File 'lib/models/porcelain.rb', line 12536

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



12539
12540
12541
# File 'lib/models/porcelain.rb', line 12539

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12563
12564
12565
12566
12567
12568
12569
# File 'lib/models/porcelain.rb', line 12563

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end