Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



12098
12099
12100
12101
12102
12103
12104
12105
12106
12107
12108
12109
12110
12111
12112
12113
12114
12115
12116
12117
12118
# File 'lib/models/porcelain.rb', line 12098

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



12066
12067
12068
# File 'lib/models/porcelain.rb', line 12066

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



12069
12070
12071
# File 'lib/models/porcelain.rb', line 12069

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



12071
12072
12073
# File 'lib/models/porcelain.rb', line 12071

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



12074
12075
12076
# File 'lib/models/porcelain.rb', line 12074

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



12087
12088
12089
# File 'lib/models/porcelain.rb', line 12087

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



12089
12090
12091
# File 'lib/models/porcelain.rb', line 12089

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



12091
12092
12093
# File 'lib/models/porcelain.rb', line 12091

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



12093
12094
12095
# File 'lib/models/porcelain.rb', line 12093

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



12096
12097
12098
# File 'lib/models/porcelain.rb', line 12096

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12120
12121
12122
12123
12124
12125
12126
# File 'lib/models/porcelain.rb', line 12120

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end