Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



12019
12020
12021
12022
12023
12024
12025
12026
12027
12028
12029
12030
12031
12032
12033
12034
12035
12036
12037
12038
12039
# File 'lib/models/porcelain.rb', line 12019

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



11987
11988
11989
# File 'lib/models/porcelain.rb', line 11987

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



11990
11991
11992
# File 'lib/models/porcelain.rb', line 11990

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



11992
11993
11994
# File 'lib/models/porcelain.rb', line 11992

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



11995
11996
11997
# File 'lib/models/porcelain.rb', line 11995

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



12008
12009
12010
# File 'lib/models/porcelain.rb', line 12008

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



12010
12011
12012
# File 'lib/models/porcelain.rb', line 12010

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



12012
12013
12014
# File 'lib/models/porcelain.rb', line 12012

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



12014
12015
12016
# File 'lib/models/porcelain.rb', line 12014

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



12017
12018
12019
# File 'lib/models/porcelain.rb', line 12017

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12041
12042
12043
12044
12045
12046
12047
# File 'lib/models/porcelain.rb', line 12041

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end