Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



11945
11946
11947
11948
11949
11950
11951
11952
11953
11954
11955
11956
11957
11958
11959
11960
11961
11962
11963
11964
11965
# File 'lib/models/porcelain.rb', line 11945

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



11913
11914
11915
# File 'lib/models/porcelain.rb', line 11913

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



11916
11917
11918
# File 'lib/models/porcelain.rb', line 11916

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



11918
11919
11920
# File 'lib/models/porcelain.rb', line 11918

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



11921
11922
11923
# File 'lib/models/porcelain.rb', line 11921

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



11934
11935
11936
# File 'lib/models/porcelain.rb', line 11934

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



11936
11937
11938
# File 'lib/models/porcelain.rb', line 11936

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



11938
11939
11940
# File 'lib/models/porcelain.rb', line 11938

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



11940
11941
11942
# File 'lib/models/porcelain.rb', line 11940

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



11943
11944
11945
# File 'lib/models/porcelain.rb', line 11943

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11967
11968
11969
11970
11971
11972
11973
# File 'lib/models/porcelain.rb', line 11967

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end