Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



11878
11879
11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
11890
11891
11892
11893
11894
11895
11896
11897
11898
# File 'lib/models/porcelain.rb', line 11878

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



11846
11847
11848
# File 'lib/models/porcelain.rb', line 11846

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



11849
11850
11851
# File 'lib/models/porcelain.rb', line 11849

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



11851
11852
11853
# File 'lib/models/porcelain.rb', line 11851

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



11854
11855
11856
# File 'lib/models/porcelain.rb', line 11854

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



11867
11868
11869
# File 'lib/models/porcelain.rb', line 11867

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



11869
11870
11871
# File 'lib/models/porcelain.rb', line 11869

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



11871
11872
11873
# File 'lib/models/porcelain.rb', line 11871

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



11873
11874
11875
# File 'lib/models/porcelain.rb', line 11873

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



11876
11877
11878
# File 'lib/models/porcelain.rb', line 11876

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11900
11901
11902
11903
11904
11905
11906
# File 'lib/models/porcelain.rb', line 11900

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end