Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



11027
11028
11029
11030
11031
11032
11033
11034
11035
11036
11037
11038
11039
11040
11041
11042
11043
11044
11045
11046
11047
# File 'lib/models/porcelain.rb', line 11027

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



10995
10996
10997
# File 'lib/models/porcelain.rb', line 10995

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



10998
10999
11000
# File 'lib/models/porcelain.rb', line 10998

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



11000
11001
11002
# File 'lib/models/porcelain.rb', line 11000

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



11003
11004
11005
# File 'lib/models/porcelain.rb', line 11003

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



11016
11017
11018
# File 'lib/models/porcelain.rb', line 11016

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



11018
11019
11020
# File 'lib/models/porcelain.rb', line 11018

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



11020
11021
11022
# File 'lib/models/porcelain.rb', line 11020

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



11022
11023
11024
# File 'lib/models/porcelain.rb', line 11022

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



11025
11026
11027
# File 'lib/models/porcelain.rb', line 11025

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11049
11050
11051
11052
11053
11054
11055
# File 'lib/models/porcelain.rb', line 11049

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end