Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



10952
10953
10954
10955
10956
10957
10958
10959
10960
10961
10962
10963
10964
10965
10966
10967
10968
10969
10970
10971
10972
# File 'lib/models/porcelain.rb', line 10952

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



10920
10921
10922
# File 'lib/models/porcelain.rb', line 10920

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



10923
10924
10925
# File 'lib/models/porcelain.rb', line 10923

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



10925
10926
10927
# File 'lib/models/porcelain.rb', line 10925

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



10928
10929
10930
# File 'lib/models/porcelain.rb', line 10928

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10941
10942
10943
# File 'lib/models/porcelain.rb', line 10941

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10943
10944
10945
# File 'lib/models/porcelain.rb', line 10943

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



10945
10946
10947
# File 'lib/models/porcelain.rb', line 10945

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



10947
10948
10949
# File 'lib/models/porcelain.rb', line 10947

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



10950
10951
10952
# File 'lib/models/porcelain.rb', line 10950

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10974
10975
10976
10977
10978
10979
10980
# File 'lib/models/porcelain.rb', line 10974

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end