Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



10709
10710
10711
10712
10713
10714
10715
10716
10717
10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
10729
# File 'lib/models/porcelain.rb', line 10709

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



10677
10678
10679
# File 'lib/models/porcelain.rb', line 10677

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



10680
10681
10682
# File 'lib/models/porcelain.rb', line 10680

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



10682
10683
10684
# File 'lib/models/porcelain.rb', line 10682

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



10685
10686
10687
# File 'lib/models/porcelain.rb', line 10685

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10698
10699
10700
# File 'lib/models/porcelain.rb', line 10698

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10700
10701
10702
# File 'lib/models/porcelain.rb', line 10700

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



10702
10703
10704
# File 'lib/models/porcelain.rb', line 10702

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



10704
10705
10706
# File 'lib/models/porcelain.rb', line 10704

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



10707
10708
10709
# File 'lib/models/porcelain.rb', line 10707

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10731
10732
10733
10734
10735
10736
10737
# File 'lib/models/porcelain.rb', line 10731

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end