Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



10625
10626
10627
10628
10629
10630
10631
10632
10633
10634
10635
10636
10637
10638
10639
10640
10641
10642
10643
10644
10645
# File 'lib/models/porcelain.rb', line 10625

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



10593
10594
10595
# File 'lib/models/porcelain.rb', line 10593

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



10596
10597
10598
# File 'lib/models/porcelain.rb', line 10596

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



10598
10599
10600
# File 'lib/models/porcelain.rb', line 10598

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



10601
10602
10603
# File 'lib/models/porcelain.rb', line 10601

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10614
10615
10616
# File 'lib/models/porcelain.rb', line 10614

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10616
10617
10618
# File 'lib/models/porcelain.rb', line 10616

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



10618
10619
10620
# File 'lib/models/porcelain.rb', line 10618

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



10620
10621
10622
# File 'lib/models/porcelain.rb', line 10620

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



10623
10624
10625
# File 'lib/models/porcelain.rb', line 10623

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10647
10648
10649
10650
10651
10652
10653
# File 'lib/models/porcelain.rb', line 10647

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end