Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
10569
10570
10571
10572
10573
10574
10575
# File 'lib/models/porcelain.rb', line 10555

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



10523
10524
10525
# File 'lib/models/porcelain.rb', line 10523

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



10526
10527
10528
# File 'lib/models/porcelain.rb', line 10526

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



10528
10529
10530
# File 'lib/models/porcelain.rb', line 10528

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



10531
10532
10533
# File 'lib/models/porcelain.rb', line 10531

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10544
10545
10546
# File 'lib/models/porcelain.rb', line 10544

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10546
10547
10548
# File 'lib/models/porcelain.rb', line 10546

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



10548
10549
10550
# File 'lib/models/porcelain.rb', line 10548

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



10550
10551
10552
# File 'lib/models/porcelain.rb', line 10550

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



10553
10554
10555
# File 'lib/models/porcelain.rb', line 10553

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10577
10578
10579
10580
10581
10582
10583
# File 'lib/models/porcelain.rb', line 10577

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end