Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
# File 'lib/models/porcelain.rb', line 10488

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



10456
10457
10458
# File 'lib/models/porcelain.rb', line 10456

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



10459
10460
10461
# File 'lib/models/porcelain.rb', line 10459

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



10461
10462
10463
# File 'lib/models/porcelain.rb', line 10461

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



10464
10465
10466
# File 'lib/models/porcelain.rb', line 10464

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10477
10478
10479
# File 'lib/models/porcelain.rb', line 10477

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10479
10480
10481
# File 'lib/models/porcelain.rb', line 10479

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



10481
10482
10483
# File 'lib/models/porcelain.rb', line 10481

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



10483
10484
10485
# File 'lib/models/porcelain.rb', line 10483

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



10486
10487
10488
# File 'lib/models/porcelain.rb', line 10486

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10510
10511
10512
10513
10514
10515
10516
# File 'lib/models/porcelain.rb', line 10510

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end