Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



10191
10192
10193
10194
10195
10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
10211
# File 'lib/models/porcelain.rb', line 10191

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



10159
10160
10161
# File 'lib/models/porcelain.rb', line 10159

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



10162
10163
10164
# File 'lib/models/porcelain.rb', line 10162

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



10164
10165
10166
# File 'lib/models/porcelain.rb', line 10164

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



10167
10168
10169
# File 'lib/models/porcelain.rb', line 10167

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10180
10181
10182
# File 'lib/models/porcelain.rb', line 10180

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10182
10183
10184
# File 'lib/models/porcelain.rb', line 10182

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



10184
10185
10186
# File 'lib/models/porcelain.rb', line 10184

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



10186
10187
10188
# File 'lib/models/porcelain.rb', line 10186

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



10189
10190
10191
# File 'lib/models/porcelain.rb', line 10189

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10213
10214
10215
10216
10217
10218
10219
# File 'lib/models/porcelain.rb', line 10213

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end