Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



10113
10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
# File 'lib/models/porcelain.rb', line 10113

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



10081
10082
10083
# File 'lib/models/porcelain.rb', line 10081

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



10084
10085
10086
# File 'lib/models/porcelain.rb', line 10084

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



10086
10087
10088
# File 'lib/models/porcelain.rb', line 10086

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



10089
10090
10091
# File 'lib/models/porcelain.rb', line 10089

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



10102
10103
10104
# File 'lib/models/porcelain.rb', line 10102

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



10104
10105
10106
# File 'lib/models/porcelain.rb', line 10104

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



10106
10107
10108
# File 'lib/models/porcelain.rb', line 10106

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



10108
10109
10110
# File 'lib/models/porcelain.rb', line 10108

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



10111
10112
10113
# File 'lib/models/porcelain.rb', line 10111

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10135
10136
10137
10138
10139
10140
10141
# File 'lib/models/porcelain.rb', line 10135

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end