Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



9940
9941
9942
9943
9944
9945
9946
9947
9948
9949
9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
# File 'lib/models/porcelain.rb', line 9940

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



9908
9909
9910
# File 'lib/models/porcelain.rb', line 9908

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



9911
9912
9913
# File 'lib/models/porcelain.rb', line 9911

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



9913
9914
9915
# File 'lib/models/porcelain.rb', line 9913

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



9916
9917
9918
# File 'lib/models/porcelain.rb', line 9916

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



9929
9930
9931
# File 'lib/models/porcelain.rb', line 9929

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



9931
9932
9933
# File 'lib/models/porcelain.rb', line 9931

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



9933
9934
9935
# File 'lib/models/porcelain.rb', line 9933

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



9935
9936
9937
# File 'lib/models/porcelain.rb', line 9935

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



9938
9939
9940
# File 'lib/models/porcelain.rb', line 9938

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9962
9963
9964
9965
9966
9967
9968
# File 'lib/models/porcelain.rb', line 9962

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end