Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



9869
9870
9871
9872
9873
9874
9875
9876
9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
# File 'lib/models/porcelain.rb', line 9869

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



9837
9838
9839
# File 'lib/models/porcelain.rb', line 9837

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



9840
9841
9842
# File 'lib/models/porcelain.rb', line 9840

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



9842
9843
9844
# File 'lib/models/porcelain.rb', line 9842

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



9845
9846
9847
# File 'lib/models/porcelain.rb', line 9845

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



9858
9859
9860
# File 'lib/models/porcelain.rb', line 9858

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



9860
9861
9862
# File 'lib/models/porcelain.rb', line 9860

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



9862
9863
9864
# File 'lib/models/porcelain.rb', line 9862

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



9864
9865
9866
# File 'lib/models/porcelain.rb', line 9864

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



9867
9868
9869
# File 'lib/models/porcelain.rb', line 9867

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9891
9892
9893
9894
9895
9896
9897
# File 'lib/models/porcelain.rb', line 9891

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end