Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
# File 'lib/models/porcelain.rb', line 9792

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



9760
9761
9762
# File 'lib/models/porcelain.rb', line 9760

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



9763
9764
9765
# File 'lib/models/porcelain.rb', line 9763

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



9765
9766
9767
# File 'lib/models/porcelain.rb', line 9765

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



9768
9769
9770
# File 'lib/models/porcelain.rb', line 9768

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



9781
9782
9783
# File 'lib/models/porcelain.rb', line 9781

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



9783
9784
9785
# File 'lib/models/porcelain.rb', line 9783

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



9785
9786
9787
# File 'lib/models/porcelain.rb', line 9785

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



9787
9788
9789
# File 'lib/models/porcelain.rb', line 9787

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



9790
9791
9792
# File 'lib/models/porcelain.rb', line 9790

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9814
9815
9816
9817
9818
9819
9820
# File 'lib/models/porcelain.rb', line 9814

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end