Class: SDM::Relay
- Inherits:
-
Object
- Object
- SDM::Relay
- Defined in:
- lib/models/porcelain.rb
Overview
Relay represents a StrongDM CLI installation running in relay mode.
Instance Attribute Summary collapse
-
#device ⇒ Object
Device is a read only device name uploaded by the gateway process when it comes online.
-
#gateway_filter ⇒ Object
GatewayFilter can be used to restrict the peering between relays and gateways.
-
#id ⇒ Object
Unique identifier of the Relay.
-
#location ⇒ Object
Location is a read only network location uploaded by the gateway process when it comes online.
-
#maintenance_windows ⇒ Object
Maintenance Windows define when this node is allowed to restart.
-
#name ⇒ Object
Unique human-readable name of the Relay.
-
#state ⇒ Object
The current state of the relay, one of the NodeState constants.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#version ⇒ Object
Version is a read only sdm binary version uploaded by the gateway process when it comes online.
Instance Method Summary collapse
-
#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay
constructor
A new instance of Relay.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay
Returns a new instance of Relay.
9500 9501 9502 9503 9504 9505 9506 9507 9508 9509 9510 9511 9512 9513 9514 9515 9516 9517 9518 9519 9520 |
# File 'lib/models/porcelain.rb', line 9500 def initialize( device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil ) @device = device == nil ? "" : device @gateway_filter = gateway_filter == nil ? "" : gateway_filter @id = id == nil ? "" : id @location = location == nil ? "" : location @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows @name = name == nil ? "" : name @state = state == nil ? "" : state @tags = == nil ? SDM::() : @version = version == nil ? "" : version end |
Instance Attribute Details
#device ⇒ Object
Device is a read only device name uploaded by the gateway process when it comes online.
9468 9469 9470 |
# File 'lib/models/porcelain.rb', line 9468 def device @device end |
#gateway_filter ⇒ Object
GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.
9471 9472 9473 |
# File 'lib/models/porcelain.rb', line 9471 def gateway_filter @gateway_filter end |
#id ⇒ Object
Unique identifier of the Relay.
9473 9474 9475 |
# File 'lib/models/porcelain.rb', line 9473 def id @id end |
#location ⇒ Object
Location is a read only network location uploaded by the gateway process when it comes online.
9476 9477 9478 |
# File 'lib/models/porcelain.rb', line 9476 def location @location end |
#maintenance_windows ⇒ Object
Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.
If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.
If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.
9489 9490 9491 |
# File 'lib/models/porcelain.rb', line 9489 def maintenance_windows @maintenance_windows end |
#name ⇒ Object
Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.
9491 9492 9493 |
# File 'lib/models/porcelain.rb', line 9491 def name @name end |
#state ⇒ Object
The current state of the relay, one of the NodeState constants.
9493 9494 9495 |
# File 'lib/models/porcelain.rb', line 9493 def state @state end |
#tags ⇒ Object
Tags is a map of key, value pairs.
9495 9496 9497 |
# File 'lib/models/porcelain.rb', line 9495 def @tags end |
#version ⇒ Object
Version is a read only sdm binary version uploaded by the gateway process when it comes online.
9498 9499 9500 |
# File 'lib/models/porcelain.rb', line 9498 def version @version end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9522 9523 9524 9525 9526 9527 9528 |
# File 'lib/models/porcelain.rb', line 9522 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |