Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



9331
9332
9333
9334
9335
9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
9346
9347
9348
9349
9350
9351
# File 'lib/models/porcelain.rb', line 9331

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



9299
9300
9301
# File 'lib/models/porcelain.rb', line 9299

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



9302
9303
9304
# File 'lib/models/porcelain.rb', line 9302

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



9304
9305
9306
# File 'lib/models/porcelain.rb', line 9304

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



9307
9308
9309
# File 'lib/models/porcelain.rb', line 9307

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



9320
9321
9322
# File 'lib/models/porcelain.rb', line 9320

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



9322
9323
9324
# File 'lib/models/porcelain.rb', line 9322

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



9324
9325
9326
# File 'lib/models/porcelain.rb', line 9324

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



9326
9327
9328
# File 'lib/models/porcelain.rb', line 9326

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



9329
9330
9331
# File 'lib/models/porcelain.rb', line 9329

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9353
9354
9355
9356
9357
9358
9359
# File 'lib/models/porcelain.rb', line 9353

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end