Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



9327
9328
9329
9330
9331
9332
9333
9334
9335
9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
9346
9347
# File 'lib/models/porcelain.rb', line 9327

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



9295
9296
9297
# File 'lib/models/porcelain.rb', line 9295

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



9298
9299
9300
# File 'lib/models/porcelain.rb', line 9298

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



9300
9301
9302
# File 'lib/models/porcelain.rb', line 9300

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



9303
9304
9305
# File 'lib/models/porcelain.rb', line 9303

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



9316
9317
9318
# File 'lib/models/porcelain.rb', line 9316

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



9318
9319
9320
# File 'lib/models/porcelain.rb', line 9318

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



9320
9321
9322
# File 'lib/models/porcelain.rb', line 9320

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



9322
9323
9324
# File 'lib/models/porcelain.rb', line 9322

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



9325
9326
9327
# File 'lib/models/porcelain.rb', line 9325

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9349
9350
9351
9352
9353
9354
9355
# File 'lib/models/porcelain.rb', line 9349

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end