Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



9162
9163
9164
9165
9166
9167
9168
9169
9170
9171
9172
9173
9174
9175
9176
9177
9178
9179
9180
9181
9182
# File 'lib/models/porcelain.rb', line 9162

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



9130
9131
9132
# File 'lib/models/porcelain.rb', line 9130

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



9133
9134
9135
# File 'lib/models/porcelain.rb', line 9133

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



9135
9136
9137
# File 'lib/models/porcelain.rb', line 9135

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



9138
9139
9140
# File 'lib/models/porcelain.rb', line 9138

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



9151
9152
9153
# File 'lib/models/porcelain.rb', line 9151

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



9153
9154
9155
# File 'lib/models/porcelain.rb', line 9153

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



9155
9156
9157
# File 'lib/models/porcelain.rb', line 9155

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



9157
9158
9159
# File 'lib/models/porcelain.rb', line 9157

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



9160
9161
9162
# File 'lib/models/porcelain.rb', line 9160

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9184
9185
9186
9187
9188
9189
9190
# File 'lib/models/porcelain.rb', line 9184

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end