Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



8943
8944
8945
8946
8947
8948
8949
8950
8951
8952
8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
# File 'lib/models/porcelain.rb', line 8943

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



8911
8912
8913
# File 'lib/models/porcelain.rb', line 8911

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



8914
8915
8916
# File 'lib/models/porcelain.rb', line 8914

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



8916
8917
8918
# File 'lib/models/porcelain.rb', line 8916

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



8919
8920
8921
# File 'lib/models/porcelain.rb', line 8919

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



8932
8933
8934
# File 'lib/models/porcelain.rb', line 8932

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



8934
8935
8936
# File 'lib/models/porcelain.rb', line 8934

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



8936
8937
8938
# File 'lib/models/porcelain.rb', line 8936

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



8938
8939
8940
# File 'lib/models/porcelain.rb', line 8938

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



8941
8942
8943
# File 'lib/models/porcelain.rb', line 8941

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8965
8966
8967
8968
8969
8970
8971
# File 'lib/models/porcelain.rb', line 8965

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end