Class: SDM::Relay
- Inherits:
-
Object
- Object
- SDM::Relay
- Defined in:
- lib/models/porcelain.rb
Overview
Relay represents a StrongDM CLI installation running in relay mode.
Instance Attribute Summary collapse
-
#connects_to ⇒ Object
ConnectsTo can be used to restrict the peering between relays and gateways.
-
#device ⇒ Object
Device is a read only device name uploaded by the gateway process when it comes online.
-
#gateway_filter ⇒ Object
GatewayFilter can be used to restrict the peering between relays and gateways.
-
#id ⇒ Object
Unique identifier of the Relay.
-
#location ⇒ Object
Location is a read only network location uploaded by the gateway process when it comes online.
-
#maintenance_windows ⇒ Object
Maintenance Windows define when this node is allowed to restart.
-
#name ⇒ Object
Unique human-readable name of the Relay.
-
#state ⇒ Object
The current state of the relay.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#version ⇒ Object
Version is a read only sdm binary version uploaded by the gateway process when it comes online.
Instance Method Summary collapse
-
#initialize(connects_to: nil, device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay
constructor
A new instance of Relay.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(connects_to: nil, device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay
Returns a new instance of Relay.
6809 6810 6811 6812 6813 6814 6815 6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 6830 6831 |
# File 'lib/models/porcelain.rb', line 6809 def initialize( connects_to: nil, device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil ) @connects_to = connects_to == nil ? "" : connects_to @device = device == nil ? "" : device @gateway_filter = gateway_filter == nil ? "" : gateway_filter @id = id == nil ? "" : id @location = location == nil ? "" : location @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows @name = name == nil ? "" : name @state = state == nil ? "" : state @tags = == nil ? SDM::() : @version = version == nil ? "" : version end |
Instance Attribute Details
#connects_to ⇒ Object
ConnectsTo can be used to restrict the peering between relays and gateways.
6772 6773 6774 |
# File 'lib/models/porcelain.rb', line 6772 def connects_to @connects_to end |
#device ⇒ Object
Device is a read only device name uploaded by the gateway process when it comes online.
6775 6776 6777 |
# File 'lib/models/porcelain.rb', line 6775 def device @device end |
#gateway_filter ⇒ Object
GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.
6778 6779 6780 |
# File 'lib/models/porcelain.rb', line 6778 def gateway_filter @gateway_filter end |
#id ⇒ Object
Unique identifier of the Relay.
6780 6781 6782 |
# File 'lib/models/porcelain.rb', line 6780 def id @id end |
#location ⇒ Object
Location is a read only network location uploaded by the gateway process when it comes online.
6783 6784 6785 |
# File 'lib/models/porcelain.rb', line 6783 def location @location end |
#maintenance_windows ⇒ Object
Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.
If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.
If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.
6796 6797 6798 |
# File 'lib/models/porcelain.rb', line 6796 def maintenance_windows @maintenance_windows end |
#name ⇒ Object
Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.
6798 6799 6800 |
# File 'lib/models/porcelain.rb', line 6798 def name @name end |
#state ⇒ Object
The current state of the relay. One of: "new", "verifying_restart", "awaiting_restart", "restarting", "started", "stopped", "dead", "unknown".
6802 6803 6804 |
# File 'lib/models/porcelain.rb', line 6802 def state @state end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6804 6805 6806 |
# File 'lib/models/porcelain.rb', line 6804 def @tags end |
#version ⇒ Object
Version is a read only sdm binary version uploaded by the gateway process when it comes online.
6807 6808 6809 |
# File 'lib/models/porcelain.rb', line 6807 def version @version end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6833 6834 6835 6836 6837 6838 6839 |
# File 'lib/models/porcelain.rb', line 6833 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |