Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



5476
5477
5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/models/porcelain.rb', line 5476

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



5455
5456
5457
# File 'lib/models/porcelain.rb', line 5455

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways.



5458
5459
5460
# File 'lib/models/porcelain.rb', line 5458

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



5460
5461
5462
# File 'lib/models/porcelain.rb', line 5460

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



5463
5464
5465
# File 'lib/models/porcelain.rb', line 5463

def location
  @location
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



5465
5466
5467
# File 'lib/models/porcelain.rb', line 5465

def name
  @name
end

#stateObject

The current state of the relay. One of: "new", "verifying_restart", "awaiting_restart", "restarting", "started", "stopped", "dead", "unknown".



5469
5470
5471
# File 'lib/models/porcelain.rb', line 5469

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



5471
5472
5473
# File 'lib/models/porcelain.rb', line 5471

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



5474
5475
5476
# File 'lib/models/porcelain.rb', line 5474

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5496
5497
5498
5499
5500
5501
5502
# File 'lib/models/porcelain.rb', line 5496

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end