Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



5356
5357
5358
5359
5360
5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
# File 'lib/models/porcelain.rb', line 5356

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



5335
5336
5337
# File 'lib/models/porcelain.rb', line 5335

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways.



5338
5339
5340
# File 'lib/models/porcelain.rb', line 5338

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



5340
5341
5342
# File 'lib/models/porcelain.rb', line 5340

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



5343
5344
5345
# File 'lib/models/porcelain.rb', line 5343

def location
  @location
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



5345
5346
5347
# File 'lib/models/porcelain.rb', line 5345

def name
  @name
end

#stateObject

The current state of the relay. One of: "new", "verifying_restart", "awaiting_restart", "restarting", "started", "stopped", "dead", "unknown".



5349
5350
5351
# File 'lib/models/porcelain.rb', line 5349

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



5351
5352
5353
# File 'lib/models/porcelain.rb', line 5351

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



5354
5355
5356
# File 'lib/models/porcelain.rb', line 5354

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5376
5377
5378
5379
5380
5381
5382
# File 'lib/models/porcelain.rb', line 5376

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end