Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(gateway_filter: nil, id: nil, name: nil, state: nil, tags: nil) ⇒ Relay

Returns a new instance of Relay.



5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
# File 'lib/models/porcelain.rb', line 5332

def initialize(
  gateway_filter: nil,
  id: nil,
  name: nil,
  state: nil,
  tags: nil
)
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways.



5320
5321
5322
# File 'lib/models/porcelain.rb', line 5320

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



5322
5323
5324
# File 'lib/models/porcelain.rb', line 5322

def id
  @id
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



5324
5325
5326
# File 'lib/models/porcelain.rb', line 5324

def name
  @name
end

#stateObject

The current state of the relay. One of: "new", "verifying_restart", "awaiting_restart", "restarting", "started", "stopped", "dead", "unknown".



5328
5329
5330
# File 'lib/models/porcelain.rb', line 5328

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



5330
5331
5332
# File 'lib/models/porcelain.rb', line 5330

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5346
5347
5348
5349
5350
5351
5352
# File 'lib/models/porcelain.rb', line 5346

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end