Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



12087
12088
12089
12090
12091
12092
12093
12094
12095
12096
12097
12098
12099
12100
12101
12102
12103
12104
12105
12106
12107
# File 'lib/models/porcelain.rb', line 12087

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#deviceObject

Device is a read only device name uploaded by the gateway process when it comes online.



12055
12056
12057
# File 'lib/models/porcelain.rb', line 12055

def device
  @device
end

#gateway_filterObject

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



12058
12059
12060
# File 'lib/models/porcelain.rb', line 12058

def gateway_filter
  @gateway_filter
end

#idObject

Unique identifier of the Relay.



12060
12061
12062
# File 'lib/models/porcelain.rb', line 12060

def id
  @id
end

#locationObject

Location is a read only network location uploaded by the gateway process when it comes online.



12063
12064
12065
# File 'lib/models/porcelain.rb', line 12063

def location
  @location
end

#maintenance_windowsObject

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



12076
12077
12078
# File 'lib/models/porcelain.rb', line 12076

def maintenance_windows
  @maintenance_windows
end

#nameObject

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



12078
12079
12080
# File 'lib/models/porcelain.rb', line 12078

def name
  @name
end

#stateObject

The current state of the relay, one of the NodeState constants.



12080
12081
12082
# File 'lib/models/porcelain.rb', line 12080

def state
  @state
end

#tagsObject

Tags is a map of key, value pairs.



12082
12083
12084
# File 'lib/models/porcelain.rb', line 12082

def tags
  @tags
end

#versionObject

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



12085
12086
12087
# File 'lib/models/porcelain.rb', line 12085

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12109
12110
12111
12112
12113
12114
12115
# File 'lib/models/porcelain.rb', line 12109

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end