Class: SDM::Relay

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

Relay represents a StrongDM CLI installation running in relay mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(device: nil, gateway_filter: nil, id: nil, location: nil, maintenance_windows: nil, name: nil, state: nil, tags: nil, version: nil) ⇒ Relay

Returns a new instance of Relay.



15556
15557
15558
15559
15560
15561
15562
15563
15564
15565
15566
15567
15568
15569
15570
15571
15572
15573
15574
15575
15576
# File 'lib/models/porcelain.rb', line 15556

def initialize(
  device: nil,
  gateway_filter: nil,
  id: nil,
  location: nil,
  maintenance_windows: nil,
  name: nil,
  state: nil,
  tags: nil,
  version: nil
)
  @device = device == nil ? "" : device
  @gateway_filter = gateway_filter == nil ? "" : gateway_filter
  @id = id == nil ? "" : id
  @location = location == nil ? "" : location
  @maintenance_windows = maintenance_windows == nil ? [] : maintenance_windows
  @name = name == nil ? "" : name
  @state = state == nil ? "" : state
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @version = version == nil ? "" : version
end

Instance Attribute Details

#device ⇒ Object

Device is a read only device name uploaded by the gateway process when it comes online.



15524
15525
15526
# File 'lib/models/porcelain.rb', line 15524

def device
  @device
end

#gateway_filter ⇒ Object

GatewayFilter can be used to restrict the peering between relays and gateways. Deprecated.



15527
15528
15529
# File 'lib/models/porcelain.rb', line 15527

def gateway_filter
  @gateway_filter
end

#id ⇒ Object

Unique identifier of the Relay.



15529
15530
15531
# File 'lib/models/porcelain.rb', line 15529

def id
  @id
end

#location ⇒ Object

Location is a read only network location uploaded by the gateway process when it comes online.



15532
15533
15534
# File 'lib/models/porcelain.rb', line 15532

def location
  @location
end

#maintenance_windows ⇒ Object

Maintenance Windows define when this node is allowed to restart. If a node is requested to restart, it will check each window to determine if any of them permit it to restart, and if any do, it will. This check is repeated per window until the restart is successfully completed.

If not set here, may be set on the command line or via an environment variable on the process itself; any server setting will take precedence over local settings. This setting is ineffective for nodes below version 38.44.0.

If this setting is not applied via this remote configuration or via local configuration, the default setting is used: always allow restarts if serving no connections, and allow a restart even if serving connections between 7-8 UTC, any day.



15545
15546
15547
# File 'lib/models/porcelain.rb', line 15545

def maintenance_windows
  @maintenance_windows
end

#name ⇒ Object

Unique human-readable name of the Relay. Node names must include only letters, numbers, and hyphens (no spaces, underscores, or other special characters). Generated if not provided on create.



15547
15548
15549
# File 'lib/models/porcelain.rb', line 15547

def name
  @name
end

#state ⇒ Object

The current state of the relay, one of the NodeState constants.



15549
15550
15551
# File 'lib/models/porcelain.rb', line 15549

def state
  @state
end

#tags ⇒ Object

Tags is a map of key, value pairs.



15551
15552
15553
# File 'lib/models/porcelain.rb', line 15551

def tags
  @tags
end

#version ⇒ Object

Version is a read only sdm binary version uploaded by the gateway process when it comes online.



15554
15555
15556
# File 'lib/models/porcelain.rb', line 15554

def version
  @version
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15578
15579
15580
15581
15582
15583
15584
# File 'lib/models/porcelain.rb', line 15578

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end