Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



15491
15492
15493
15494
15495
15496
15497
15498
15499
15500
15501
# File 'lib/models/porcelain.rb', line 15491

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



15483
15484
15485
# File 'lib/models/porcelain.rb', line 15483

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



15485
15486
15487
# File 'lib/models/porcelain.rb', line 15485

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



15487
15488
15489
# File 'lib/models/porcelain.rb', line 15487

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



15489
15490
15491
# File 'lib/models/porcelain.rb', line 15489

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15503
15504
15505
15506
15507
15508
15509
# File 'lib/models/porcelain.rb', line 15503

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end