Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
# File 'lib/models/porcelain.rb', line 15411

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



15403
15404
15405
# File 'lib/models/porcelain.rb', line 15403

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



15405
15406
15407
# File 'lib/models/porcelain.rb', line 15405

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



15407
15408
15409
# File 'lib/models/porcelain.rb', line 15407

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



15409
15410
15411
# File 'lib/models/porcelain.rb', line 15409

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15423
15424
15425
15426
15427
15428
15429
# File 'lib/models/porcelain.rb', line 15423

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end