Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
14792 14793 14794 14795 14796 14797 14798 14799 14800 14801 14802 |
# File 'lib/models/porcelain.rb', line 14792 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
14784 14785 14786 |
# File 'lib/models/porcelain.rb', line 14784 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
14786 14787 14788 |
# File 'lib/models/porcelain.rb', line 14786 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
14788 14789 14790 |
# File 'lib/models/porcelain.rb', line 14788 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
14790 14791 14792 |
# File 'lib/models/porcelain.rb', line 14790 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
14804 14805 14806 14807 14808 14809 14810 |
# File 'lib/models/porcelain.rb', line 14804 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |