Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



14490
14491
14492
14493
14494
14495
14496
14497
14498
14499
14500
# File 'lib/models/porcelain.rb', line 14490

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



14482
14483
14484
# File 'lib/models/porcelain.rb', line 14482

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



14484
14485
14486
# File 'lib/models/porcelain.rb', line 14484

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



14486
14487
14488
# File 'lib/models/porcelain.rb', line 14486

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



14488
14489
14490
# File 'lib/models/porcelain.rb', line 14488

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14502
14503
14504
14505
14506
14507
14508
# File 'lib/models/porcelain.rb', line 14502

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end