Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 |
# File 'lib/models/porcelain.rb', line 12324 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
12316 12317 12318 |
# File 'lib/models/porcelain.rb', line 12316 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
12318 12319 12320 |
# File 'lib/models/porcelain.rb', line 12318 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
12320 12321 12322 |
# File 'lib/models/porcelain.rb', line 12320 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
12322 12323 12324 |
# File 'lib/models/porcelain.rb', line 12322 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12336 12337 12338 12339 12340 12341 12342 |
# File 'lib/models/porcelain.rb', line 12336 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |