Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



12062
12063
12064
12065
12066
12067
12068
12069
12070
12071
12072
# File 'lib/models/porcelain.rb', line 12062

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



12054
12055
12056
# File 'lib/models/porcelain.rb', line 12054

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



12056
12057
12058
# File 'lib/models/porcelain.rb', line 12056

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



12058
12059
12060
# File 'lib/models/porcelain.rb', line 12058

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



12060
12061
12062
# File 'lib/models/porcelain.rb', line 12060

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12074
12075
12076
12077
12078
12079
12080
# File 'lib/models/porcelain.rb', line 12074

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end