Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 11931 |
# File 'lib/models/porcelain.rb', line 11921 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
11913 11914 11915 |
# File 'lib/models/porcelain.rb', line 11913 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
11915 11916 11917 |
# File 'lib/models/porcelain.rb', line 11915 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
11917 11918 11919 |
# File 'lib/models/porcelain.rb', line 11917 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
11919 11920 11921 |
# File 'lib/models/porcelain.rb', line 11919 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11933 11934 11935 11936 11937 11938 11939 |
# File 'lib/models/porcelain.rb', line 11933 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |