Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 |
# File 'lib/models/porcelain.rb', line 10987 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
10979 10980 10981 |
# File 'lib/models/porcelain.rb', line 10979 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
10981 10982 10983 |
# File 'lib/models/porcelain.rb', line 10981 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
10983 10984 10985 |
# File 'lib/models/porcelain.rb', line 10983 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
10985 10986 10987 |
# File 'lib/models/porcelain.rb', line 10985 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10999 11000 11001 11002 11003 11004 11005 |
# File 'lib/models/porcelain.rb', line 10999 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |