Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 |
# File 'lib/models/porcelain.rb', line 10751 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
10743 10744 10745 |
# File 'lib/models/porcelain.rb', line 10743 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
10745 10746 10747 |
# File 'lib/models/porcelain.rb', line 10745 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
10747 10748 10749 |
# File 'lib/models/porcelain.rb', line 10747 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
10749 10750 10751 |
# File 'lib/models/porcelain.rb', line 10749 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10763 10764 10765 10766 10767 10768 10769 |
# File 'lib/models/porcelain.rb', line 10763 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |