Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
10672 10673 10674 10675 10676 10677 10678 10679 10680 10681 10682 |
# File 'lib/models/porcelain.rb', line 10672 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
10664 10665 10666 |
# File 'lib/models/porcelain.rb', line 10664 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
10666 10667 10668 |
# File 'lib/models/porcelain.rb', line 10666 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
10668 10669 10670 |
# File 'lib/models/porcelain.rb', line 10668 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
10670 10671 10672 |
# File 'lib/models/porcelain.rb', line 10670 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10684 10685 10686 10687 10688 10689 10690 |
# File 'lib/models/porcelain.rb', line 10684 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |