Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 |
# File 'lib/models/porcelain.rb', line 10598 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
10590 10591 10592 |
# File 'lib/models/porcelain.rb', line 10590 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
10592 10593 10594 |
# File 'lib/models/porcelain.rb', line 10592 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
10594 10595 10596 |
# File 'lib/models/porcelain.rb', line 10594 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
10596 10597 10598 |
# File 'lib/models/porcelain.rb', line 10596 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10610 10611 10612 10613 10614 10615 10616 |
# File 'lib/models/porcelain.rb', line 10610 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |