Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
10531 10532 10533 10534 10535 10536 10537 10538 10539 10540 10541 |
# File 'lib/models/porcelain.rb', line 10531 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
10523 10524 10525 |
# File 'lib/models/porcelain.rb', line 10523 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
10525 10526 10527 |
# File 'lib/models/porcelain.rb', line 10525 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
10527 10528 10529 |
# File 'lib/models/porcelain.rb', line 10527 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
10529 10530 10531 |
# File 'lib/models/porcelain.rb', line 10529 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10543 10544 10545 10546 10547 10548 10549 |
# File 'lib/models/porcelain.rb', line 10543 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |