Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



9983
9984
9985
9986
9987
9988
9989
9990
9991
9992
9993
# File 'lib/models/porcelain.rb', line 9983

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



9975
9976
9977
# File 'lib/models/porcelain.rb', line 9975

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



9977
9978
9979
# File 'lib/models/porcelain.rb', line 9977

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



9979
9980
9981
# File 'lib/models/porcelain.rb', line 9979

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



9981
9982
9983
# File 'lib/models/porcelain.rb', line 9981

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9995
9996
9997
9998
9999
10000
10001
# File 'lib/models/porcelain.rb', line 9995

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end