Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



9912
9913
9914
9915
9916
9917
9918
9919
9920
9921
9922
# File 'lib/models/porcelain.rb', line 9912

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



9904
9905
9906
# File 'lib/models/porcelain.rb', line 9904

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



9906
9907
9908
# File 'lib/models/porcelain.rb', line 9906

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



9908
9909
9910
# File 'lib/models/porcelain.rb', line 9908

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



9910
9911
9912
# File 'lib/models/porcelain.rb', line 9910

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9924
9925
9926
9927
9928
9929
9930
# File 'lib/models/porcelain.rb', line 9924

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end