Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
9374 9375 9376 9377 9378 9379 9380 9381 9382 9383 9384 |
# File 'lib/models/porcelain.rb', line 9374 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
9366 9367 9368 |
# File 'lib/models/porcelain.rb', line 9366 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
9368 9369 9370 |
# File 'lib/models/porcelain.rb', line 9368 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
9370 9371 9372 |
# File 'lib/models/porcelain.rb', line 9370 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
9372 9373 9374 |
# File 'lib/models/porcelain.rb', line 9372 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9386 9387 9388 9389 9390 9391 9392 |
# File 'lib/models/porcelain.rb', line 9386 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |