Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



7783
7784
7785
7786
7787
7788
7789
7790
7791
7792
7793
# File 'lib/models/porcelain.rb', line 7783

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



7775
7776
7777
# File 'lib/models/porcelain.rb', line 7775

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



7777
7778
7779
# File 'lib/models/porcelain.rb', line 7777

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



7779
7780
7781
# File 'lib/models/porcelain.rb', line 7779

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



7781
7782
7783
# File 'lib/models/porcelain.rb', line 7781

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7795
7796
7797
7798
7799
7800
7801
# File 'lib/models/porcelain.rb', line 7795

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end