Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
7459
# File 'lib/models/porcelain.rb', line 7449

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



7441
7442
7443
# File 'lib/models/porcelain.rb', line 7441

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



7443
7444
7445
# File 'lib/models/porcelain.rb', line 7443

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



7445
7446
7447
# File 'lib/models/porcelain.rb', line 7445

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



7447
7448
7449
# File 'lib/models/porcelain.rb', line 7447

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7461
7462
7463
7464
7465
7466
7467
# File 'lib/models/porcelain.rb', line 7461

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end