Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 |
# File 'lib/models/porcelain.rb', line 6854 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
6846 6847 6848 |
# File 'lib/models/porcelain.rb', line 6846 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
6848 6849 6850 |
# File 'lib/models/porcelain.rb', line 6848 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
6850 6851 6852 |
# File 'lib/models/porcelain.rb', line 6850 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
6852 6853 6854 |
# File 'lib/models/porcelain.rb', line 6852 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/models/porcelain.rb', line 6866 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |