Class: SDM::RemoteIdentity

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity

Returns a new instance of RemoteIdentity.



5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
# File 'lib/models/porcelain.rb', line 5517

def initialize(
  account_id: nil,
  id: nil,
  remote_identity_group_id: nil,
  username: nil
)
  @account_id =  == nil ? "" : 
  @id = id == nil ? "" : id
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @username = username == nil ? "" : username
end

Instance Attribute Details

#account_idObject

The account for this remote identity.



5509
5510
5511
# File 'lib/models/porcelain.rb', line 5509

def 
  @account_id
end

#idObject

Unique identifier of the RemoteIdentity.



5511
5512
5513
# File 'lib/models/porcelain.rb', line 5511

def id
  @id
end

#remote_identity_group_idObject

The remote identity group.



5513
5514
5515
# File 'lib/models/porcelain.rb', line 5513

def remote_identity_group_id
  @remote_identity_group_id
end

#usernameObject

The username to be used as the remote identity for this account.



5515
5516
5517
# File 'lib/models/porcelain.rb', line 5515

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5529
5530
5531
5532
5533
5534
5535
# File 'lib/models/porcelain.rb', line 5529

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end