Class: SDM::RemoteIdentity
- Inherits:
-
Object
- Object
- SDM::RemoteIdentity
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentities define the username to be used for a specific account when connecting to a remote resource using that group.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account for this remote identity.
-
#id ⇒ Object
Unique identifier of the RemoteIdentity.
-
#remote_identity_group_id ⇒ Object
The remote identity group.
-
#username ⇒ Object
The username to be used as the remote identity for this account.
Instance Method Summary collapse
-
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
constructor
A new instance of RemoteIdentity.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, id: nil, remote_identity_group_id: nil, username: nil) ⇒ RemoteIdentity
Returns a new instance of RemoteIdentity.
5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 |
# File 'lib/models/porcelain.rb', line 5409 def initialize( account_id: nil, id: nil, remote_identity_group_id: nil, username: nil ) @account_id = account_id == nil ? "" : account_id @id = id == nil ? "" : id @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @username = username == nil ? "" : username end |
Instance Attribute Details
#account_id ⇒ Object
The account for this remote identity.
5401 5402 5403 |
# File 'lib/models/porcelain.rb', line 5401 def account_id @account_id end |
#id ⇒ Object
Unique identifier of the RemoteIdentity.
5403 5404 5405 |
# File 'lib/models/porcelain.rb', line 5403 def id @id end |
#remote_identity_group_id ⇒ Object
The remote identity group.
5405 5406 5407 |
# File 'lib/models/porcelain.rb', line 5405 def remote_identity_group_id @remote_identity_group_id end |
#username ⇒ Object
The username to be used as the remote identity for this account.
5407 5408 5409 |
# File 'lib/models/porcelain.rb', line 5407 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5421 5422 5423 5424 5425 5426 5427 |
# File 'lib/models/porcelain.rb', line 5421 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |