Class: SDM::RemoteIdentityGroupHistory
- Inherits:
-
Object
- Object
- SDM::RemoteIdentityGroupHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup.
-
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
-
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
-
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
constructor
A new instance of RemoteIdentityGroupHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
Returns a new instance of RemoteIdentityGroupHistory.
13771 13772 13773 13774 13775 13776 13777 13778 13779 13780 13781 |
# File 'lib/models/porcelain.rb', line 13771 def initialize( activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.
13763 13764 13765 |
# File 'lib/models/porcelain.rb', line 13763 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
13765 13766 13767 |
# File 'lib/models/porcelain.rb', line 13765 def deleted_at @deleted_at end |
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
13767 13768 13769 |
# File 'lib/models/porcelain.rb', line 13767 def remote_identity_group @remote_identity_group end |
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
13769 13770 13771 |
# File 'lib/models/porcelain.rb', line 13769 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13783 13784 13785 13786 13787 13788 13789 |
# File 'lib/models/porcelain.rb', line 13783 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |