Class: SDM::RemoteIdentityGroupHistory
- Inherits:
-
Object
- Object
- SDM::RemoteIdentityGroupHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup.
-
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
-
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
-
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
constructor
A new instance of RemoteIdentityGroupHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
Returns a new instance of RemoteIdentityGroupHistory.
12569 12570 12571 12572 12573 12574 12575 12576 12577 12578 12579 |
# File 'lib/models/porcelain.rb', line 12569 def initialize( activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.
12561 12562 12563 |
# File 'lib/models/porcelain.rb', line 12561 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
12563 12564 12565 |
# File 'lib/models/porcelain.rb', line 12563 def deleted_at @deleted_at end |
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
12565 12566 12567 |
# File 'lib/models/porcelain.rb', line 12565 def remote_identity_group @remote_identity_group end |
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
12567 12568 12569 |
# File 'lib/models/porcelain.rb', line 12567 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12581 12582 12583 12584 12585 12586 12587 |
# File 'lib/models/porcelain.rb', line 12581 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |