Class: SDM::RemoteIdentityGroupHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory

Returns a new instance of RemoteIdentityGroupHistory.



11162
11163
11164
11165
11166
11167
11168
11169
11170
11171
11172
# File 'lib/models/porcelain.rb', line 11162

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity_group: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.



11154
11155
11156
# File 'lib/models/porcelain.rb', line 11154

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentityGroup was deleted, the time it was deleted.



11156
11157
11158
# File 'lib/models/porcelain.rb', line 11156

def deleted_at
  @deleted_at
end

#remote_identity_groupObject

The complete RemoteIdentityGroup state at this time.



11158
11159
11160
# File 'lib/models/porcelain.rb', line 11158

def remote_identity_group
  @remote_identity_group
end

#timestampObject

The time at which the RemoteIdentityGroup state was recorded.



11160
11161
11162
# File 'lib/models/porcelain.rb', line 11160

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11174
11175
11176
11177
11178
11179
11180
# File 'lib/models/porcelain.rb', line 11174

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end