Class: SDM::RemoteIdentityGroupHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory

Returns a new instance of RemoteIdentityGroupHistory.



10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
10845
# File 'lib/models/porcelain.rb', line 10835

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity_group: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.



10827
10828
10829
# File 'lib/models/porcelain.rb', line 10827

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentityGroup was deleted, the time it was deleted.



10829
10830
10831
# File 'lib/models/porcelain.rb', line 10829

def deleted_at
  @deleted_at
end

#remote_identity_groupObject

The complete RemoteIdentityGroup state at this time.



10831
10832
10833
# File 'lib/models/porcelain.rb', line 10831

def remote_identity_group
  @remote_identity_group
end

#timestampObject

The time at which the RemoteIdentityGroup state was recorded.



10833
10834
10835
# File 'lib/models/porcelain.rb', line 10833

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10847
10848
10849
10850
10851
10852
10853
# File 'lib/models/porcelain.rb', line 10847

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end