Class: SDM::RemoteIdentityGroupHistory
- Inherits:
-
Object
- Object
- SDM::RemoteIdentityGroupHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup.
-
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
-
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
-
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
constructor
A new instance of RemoteIdentityGroupHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
Returns a new instance of RemoteIdentityGroupHistory.
10835 10836 10837 10838 10839 10840 10841 10842 10843 10844 10845 |
# File 'lib/models/porcelain.rb', line 10835 def initialize( activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.
10827 10828 10829 |
# File 'lib/models/porcelain.rb', line 10827 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
10829 10830 10831 |
# File 'lib/models/porcelain.rb', line 10829 def deleted_at @deleted_at end |
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
10831 10832 10833 |
# File 'lib/models/porcelain.rb', line 10831 def remote_identity_group @remote_identity_group end |
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
10833 10834 10835 |
# File 'lib/models/porcelain.rb', line 10833 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10847 10848 10849 10850 10851 10852 10853 |
# File 'lib/models/porcelain.rb', line 10847 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |