Class: SDM::RemoteIdentityGroupHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory

Returns a new instance of RemoteIdentityGroupHistory.



7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
# File 'lib/models/porcelain.rb', line 7616

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity_group: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.



7608
7609
7610
# File 'lib/models/porcelain.rb', line 7608

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentityGroup was deleted, the time it was deleted.



7610
7611
7612
# File 'lib/models/porcelain.rb', line 7610

def deleted_at
  @deleted_at
end

#remote_identity_groupObject

The complete RemoteIdentityGroup state at this time.



7612
7613
7614
# File 'lib/models/porcelain.rb', line 7612

def remote_identity_group
  @remote_identity_group
end

#timestampObject

The time at which the RemoteIdentityGroup state was recorded.



7614
7615
7616
# File 'lib/models/porcelain.rb', line 7614

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7628
7629
7630
7631
7632
7633
7634
# File 'lib/models/porcelain.rb', line 7628

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end