Class: SDM::RemoteIdentityGroupHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory

Returns a new instance of RemoteIdentityGroupHistory.



7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
# File 'lib/models/porcelain.rb', line 7444

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity_group: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.



7436
7437
7438
# File 'lib/models/porcelain.rb', line 7436

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentityGroup was deleted, the time it was deleted.



7438
7439
7440
# File 'lib/models/porcelain.rb', line 7438

def deleted_at
  @deleted_at
end

#remote_identity_groupObject

The complete RemoteIdentityGroup state at this time.



7440
7441
7442
# File 'lib/models/porcelain.rb', line 7440

def remote_identity_group
  @remote_identity_group
end

#timestampObject

The time at which the RemoteIdentityGroup state was recorded.



7442
7443
7444
# File 'lib/models/porcelain.rb', line 7442

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7456
7457
7458
7459
7460
7461
7462
# File 'lib/models/porcelain.rb', line 7456

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end