Class: SDM::RemoteIdentityGroupHistory
- Inherits:
-
Object
- Object
- SDM::RemoteIdentityGroupHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup.
-
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
-
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
-
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
constructor
A new instance of RemoteIdentityGroupHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
Returns a new instance of RemoteIdentityGroupHistory.
7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 |
# File 'lib/models/porcelain.rb', line 7025 def initialize( activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.
7017 7018 7019 |
# File 'lib/models/porcelain.rb', line 7017 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
7019 7020 7021 |
# File 'lib/models/porcelain.rb', line 7019 def deleted_at @deleted_at end |
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
7021 7022 7023 |
# File 'lib/models/porcelain.rb', line 7021 def remote_identity_group @remote_identity_group end |
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
7023 7024 7025 |
# File 'lib/models/porcelain.rb', line 7023 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7037 7038 7039 7040 7041 7042 7043 |
# File 'lib/models/porcelain.rb', line 7037 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |