Class: SDM::RemoteIdentityGroupHistory
- Inherits:
-
Object
- Object
- SDM::RemoteIdentityGroupHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup.
-
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
-
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
-
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
constructor
A new instance of RemoteIdentityGroupHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory
Returns a new instance of RemoteIdentityGroupHistory.
15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 |
# File 'lib/models/porcelain.rb', line 15332 def initialize( activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.
15324 15325 15326 |
# File 'lib/models/porcelain.rb', line 15324 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RemoteIdentityGroup was deleted, the time it was deleted.
15326 15327 15328 |
# File 'lib/models/porcelain.rb', line 15326 def deleted_at @deleted_at end |
#remote_identity_group ⇒ Object
The complete RemoteIdentityGroup state at this time.
15328 15329 15330 |
# File 'lib/models/porcelain.rb', line 15328 def remote_identity_group @remote_identity_group end |
#timestamp ⇒ Object
The time at which the RemoteIdentityGroup state was recorded.
15330 15331 15332 |
# File 'lib/models/porcelain.rb', line 15330 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15344 15345 15346 15347 15348 15349 15350 |
# File 'lib/models/porcelain.rb', line 15344 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |