Class: SDM::RemoteIdentityGroupHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityGroupHistory records the state of a RemoteIdentityGroup at a given point in time, where every change (create, update and delete) to a RemoteIdentityGroup produces an RemoteIdentityGroupHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity_group: nil, timestamp: nil) ⇒ RemoteIdentityGroupHistory

Returns a new instance of RemoteIdentityGroupHistory.



15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
15776
# File 'lib/models/porcelain.rb', line 15766

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity_group: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity_group = remote_identity_group == nil ? nil : remote_identity_group
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the RemoteIdentityGroup. May be empty for some system-initiated updates.



15758
15759
15760
# File 'lib/models/porcelain.rb', line 15758

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this RemoteIdentityGroup was deleted, the time it was deleted.



15760
15761
15762
# File 'lib/models/porcelain.rb', line 15760

def deleted_at
  @deleted_at
end

#remote_identity_group ⇒ Object

The complete RemoteIdentityGroup state at this time.



15762
15763
15764
# File 'lib/models/porcelain.rb', line 15762

def remote_identity_group
  @remote_identity_group
end

#timestamp ⇒ Object

The time at which the RemoteIdentityGroup state was recorded.



15764
15765
15766
# File 'lib/models/porcelain.rb', line 15764

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15778
15779
15780
15781
15782
15783
15784
# File 'lib/models/porcelain.rb', line 15778

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end