Class: SDM::RemoteIdentityHistory
- Inherits:
-
Object
- Object
- SDM::RemoteIdentityHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentity.
-
#deleted_at ⇒ Object
If this RemoteIdentity was deleted, the time it was deleted.
-
#remote_identity ⇒ Object
The complete RemoteIdentity state at this time.
-
#timestamp ⇒ Object
The time at which the RemoteIdentity state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory
constructor
A new instance of RemoteIdentityHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory
Returns a new instance of RemoteIdentityHistory.
15741 15742 15743 15744 15745 15746 15747 15748 15749 15750 15751 |
# File 'lib/models/porcelain.rb', line 15741 def initialize( activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @remote_identity = remote_identity == nil ? nil : remote_identity @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.
15733 15734 15735 |
# File 'lib/models/porcelain.rb', line 15733 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RemoteIdentity was deleted, the time it was deleted.
15735 15736 15737 |
# File 'lib/models/porcelain.rb', line 15735 def deleted_at @deleted_at end |
#remote_identity ⇒ Object
The complete RemoteIdentity state at this time.
15737 15738 15739 |
# File 'lib/models/porcelain.rb', line 15737 def remote_identity @remote_identity end |
#timestamp ⇒ Object
The time at which the RemoteIdentity state was recorded.
15739 15740 15741 |
# File 'lib/models/porcelain.rb', line 15739 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15753 15754 15755 15756 15757 15758 15759 |
# File 'lib/models/porcelain.rb', line 15753 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |