Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



15693
15694
15695
15696
15697
15698
15699
15700
15701
15702
15703
# File 'lib/models/porcelain.rb', line 15693

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



15685
15686
15687
# File 'lib/models/porcelain.rb', line 15685

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



15687
15688
15689
# File 'lib/models/porcelain.rb', line 15687

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



15689
15690
15691
# File 'lib/models/porcelain.rb', line 15689

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



15691
15692
15693
# File 'lib/models/porcelain.rb', line 15691

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15705
15706
15707
15708
15709
15710
15711
# File 'lib/models/porcelain.rb', line 15705

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end