Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



12604
12605
12606
12607
12608
12609
12610
12611
12612
12613
12614
# File 'lib/models/porcelain.rb', line 12604

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



12596
12597
12598
# File 'lib/models/porcelain.rb', line 12596

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



12598
12599
12600
# File 'lib/models/porcelain.rb', line 12598

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



12600
12601
12602
# File 'lib/models/porcelain.rb', line 12600

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



12602
12603
12604
# File 'lib/models/porcelain.rb', line 12602

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12616
12617
12618
12619
12620
12621
12622
# File 'lib/models/porcelain.rb', line 12616

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end