Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



12191
12192
12193
12194
12195
12196
12197
12198
12199
12200
12201
# File 'lib/models/porcelain.rb', line 12191

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



12183
12184
12185
# File 'lib/models/porcelain.rb', line 12183

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



12185
12186
12187
# File 'lib/models/porcelain.rb', line 12185

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



12187
12188
12189
# File 'lib/models/porcelain.rb', line 12187

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



12189
12190
12191
# File 'lib/models/porcelain.rb', line 12189

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12203
12204
12205
12206
12207
12208
12209
# File 'lib/models/porcelain.rb', line 12203

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end