Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



12123
12124
12125
12126
12127
12128
12129
12130
12131
12132
12133
# File 'lib/models/porcelain.rb', line 12123

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



12115
12116
12117
# File 'lib/models/porcelain.rb', line 12115

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



12117
12118
12119
# File 'lib/models/porcelain.rb', line 12117

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



12119
12120
12121
# File 'lib/models/porcelain.rb', line 12119

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



12121
12122
12123
# File 'lib/models/porcelain.rb', line 12121

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12135
12136
12137
12138
12139
12140
12141
# File 'lib/models/porcelain.rb', line 12135

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end