Class: SDM::RemoteIdentityHistory
- Inherits:
-
Object
- Object
- SDM::RemoteIdentityHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentity.
-
#deleted_at ⇒ Object
If this RemoteIdentity was deleted, the time it was deleted.
-
#remote_identity ⇒ Object
The complete RemoteIdentity state at this time.
-
#timestamp ⇒ Object
The time at which the RemoteIdentity state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory
constructor
A new instance of RemoteIdentityHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory
Returns a new instance of RemoteIdentityHistory.
11272 11273 11274 11275 11276 11277 11278 11279 11280 11281 11282 |
# File 'lib/models/porcelain.rb', line 11272 def initialize( activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @remote_identity = remote_identity == nil ? nil : remote_identity @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.
11264 11265 11266 |
# File 'lib/models/porcelain.rb', line 11264 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RemoteIdentity was deleted, the time it was deleted.
11266 11267 11268 |
# File 'lib/models/porcelain.rb', line 11266 def deleted_at @deleted_at end |
#remote_identity ⇒ Object
The complete RemoteIdentity state at this time.
11268 11269 11270 |
# File 'lib/models/porcelain.rb', line 11268 def remote_identity @remote_identity end |
#timestamp ⇒ Object
The time at which the RemoteIdentity state was recorded.
11270 11271 11272 |
# File 'lib/models/porcelain.rb', line 11270 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11284 11285 11286 11287 11288 11289 11290 |
# File 'lib/models/porcelain.rb', line 11284 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |