Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



11189
11190
11191
11192
11193
11194
11195
11196
11197
11198
11199
# File 'lib/models/porcelain.rb', line 11189

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



11181
11182
11183
# File 'lib/models/porcelain.rb', line 11181

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



11183
11184
11185
# File 'lib/models/porcelain.rb', line 11183

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



11185
11186
11187
# File 'lib/models/porcelain.rb', line 11185

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



11187
11188
11189
# File 'lib/models/porcelain.rb', line 11187

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11201
11202
11203
11204
11205
11206
11207
# File 'lib/models/porcelain.rb', line 11201

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end