Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



10799
10800
10801
10802
10803
10804
10805
10806
10807
10808
10809
# File 'lib/models/porcelain.rb', line 10799

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



10791
10792
10793
# File 'lib/models/porcelain.rb', line 10791

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



10793
10794
10795
# File 'lib/models/porcelain.rb', line 10793

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



10795
10796
10797
# File 'lib/models/porcelain.rb', line 10795

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



10797
10798
10799
# File 'lib/models/porcelain.rb', line 10797

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10811
10812
10813
10814
10815
10816
10817
# File 'lib/models/porcelain.rb', line 10811

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end