Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



10114
10115
10116
10117
10118
10119
10120
10121
10122
10123
10124
# File 'lib/models/porcelain.rb', line 10114

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



10106
10107
10108
# File 'lib/models/porcelain.rb', line 10106

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



10108
10109
10110
# File 'lib/models/porcelain.rb', line 10108

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



10110
10111
10112
# File 'lib/models/porcelain.rb', line 10110

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



10112
10113
10114
# File 'lib/models/porcelain.rb', line 10112

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10126
10127
10128
10129
10130
10131
10132
# File 'lib/models/porcelain.rb', line 10126

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end