Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



9745
9746
9747
9748
9749
9750
9751
9752
9753
9754
9755
# File 'lib/models/porcelain.rb', line 9745

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



9737
9738
9739
# File 'lib/models/porcelain.rb', line 9737

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



9739
9740
9741
# File 'lib/models/porcelain.rb', line 9739

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



9741
9742
9743
# File 'lib/models/porcelain.rb', line 9741

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



9743
9744
9745
# File 'lib/models/porcelain.rb', line 9743

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9757
9758
9759
9760
9761
9762
9763
# File 'lib/models/porcelain.rb', line 9757

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end