Class: SDM::RemoteIdentityHistory
- Inherits:
-
Object
- Object
- SDM::RemoteIdentityHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentity.
-
#deleted_at ⇒ Object
If this RemoteIdentity was deleted, the time it was deleted.
-
#remote_identity ⇒ Object
The complete RemoteIdentity state at this time.
-
#timestamp ⇒ Object
The time at which the RemoteIdentity state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory
constructor
A new instance of RemoteIdentityHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory
Returns a new instance of RemoteIdentityHistory.
9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 |
# File 'lib/models/porcelain.rb', line 9572 def initialize( activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @remote_identity = remote_identity == nil ? nil : remote_identity @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.
9564 9565 9566 |
# File 'lib/models/porcelain.rb', line 9564 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RemoteIdentity was deleted, the time it was deleted.
9566 9567 9568 |
# File 'lib/models/porcelain.rb', line 9566 def deleted_at @deleted_at end |
#remote_identity ⇒ Object
The complete RemoteIdentity state at this time.
9568 9569 9570 |
# File 'lib/models/porcelain.rb', line 9568 def remote_identity @remote_identity end |
#timestamp ⇒ Object
The time at which the RemoteIdentity state was recorded.
9570 9571 9572 |
# File 'lib/models/porcelain.rb', line 9570 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9584 9585 9586 9587 9588 9589 9590 |
# File 'lib/models/porcelain.rb', line 9584 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |