Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



7985
7986
7987
7988
7989
7990
7991
7992
7993
7994
7995
# File 'lib/models/porcelain.rb', line 7985

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



7977
7978
7979
# File 'lib/models/porcelain.rb', line 7977

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



7979
7980
7981
# File 'lib/models/porcelain.rb', line 7979

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



7981
7982
7983
# File 'lib/models/porcelain.rb', line 7981

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



7983
7984
7985
# File 'lib/models/porcelain.rb', line 7983

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7997
7998
7999
8000
8001
8002
8003
# File 'lib/models/porcelain.rb', line 7997

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end