Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
# File 'lib/models/porcelain.rb', line 7651

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



7643
7644
7645
# File 'lib/models/porcelain.rb', line 7643

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



7645
7646
7647
# File 'lib/models/porcelain.rb', line 7645

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



7647
7648
7649
# File 'lib/models/porcelain.rb', line 7647

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



7649
7650
7651
# File 'lib/models/porcelain.rb', line 7649

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7663
7664
7665
7666
7667
7668
7669
# File 'lib/models/porcelain.rb', line 7663

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end