Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



7056
7057
7058
7059
7060
7061
7062
7063
7064
7065
7066
# File 'lib/models/porcelain.rb', line 7056

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



7048
7049
7050
# File 'lib/models/porcelain.rb', line 7048

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



7050
7051
7052
# File 'lib/models/porcelain.rb', line 7050

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



7052
7053
7054
# File 'lib/models/porcelain.rb', line 7052

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



7054
7055
7056
# File 'lib/models/porcelain.rb', line 7054

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7068
7069
7070
7071
7072
7073
7074
# File 'lib/models/porcelain.rb', line 7068

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end