Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



6878
6879
6880
6881
6882
6883
6884
6885
6886
6887
6888
# File 'lib/models/porcelain.rb', line 6878

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



6870
6871
6872
# File 'lib/models/porcelain.rb', line 6870

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



6872
6873
6874
# File 'lib/models/porcelain.rb', line 6872

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



6874
6875
6876
# File 'lib/models/porcelain.rb', line 6874

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



6876
6877
6878
# File 'lib/models/porcelain.rb', line 6876

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6890
6891
6892
6893
6894
6895
6896
# File 'lib/models/porcelain.rb', line 6890

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end