Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
# File 'lib/models/porcelain.rb', line 6822

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



6814
6815
6816
# File 'lib/models/porcelain.rb', line 6814

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



6816
6817
6818
# File 'lib/models/porcelain.rb', line 6816

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



6818
6819
6820
# File 'lib/models/porcelain.rb', line 6818

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



6820
6821
6822
# File 'lib/models/porcelain.rb', line 6820

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6834
6835
6836
6837
6838
6839
6840
# File 'lib/models/porcelain.rb', line 6834

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end