Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



6769
6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
# File 'lib/models/porcelain.rb', line 6769

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



6761
6762
6763
# File 'lib/models/porcelain.rb', line 6761

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



6763
6764
6765
# File 'lib/models/porcelain.rb', line 6763

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



6765
6766
6767
# File 'lib/models/porcelain.rb', line 6765

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



6767
6768
6769
# File 'lib/models/porcelain.rb', line 6767

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6781
6782
6783
6784
6785
6786
6787
# File 'lib/models/porcelain.rb', line 6781

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end