Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
# File 'lib/models/porcelain.rb', line 12332

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



12324
12325
12326
# File 'lib/models/porcelain.rb', line 12324

def activity_id
  @activity_id
end

#deleted_atObject

If this RemoteIdentity was deleted, the time it was deleted.



12326
12327
12328
# File 'lib/models/porcelain.rb', line 12326

def deleted_at
  @deleted_at
end

#remote_identityObject

The complete RemoteIdentity state at this time.



12328
12329
12330
# File 'lib/models/porcelain.rb', line 12328

def remote_identity
  @remote_identity
end

#timestampObject

The time at which the RemoteIdentity state was recorded.



12330
12331
12332
# File 'lib/models/porcelain.rb', line 12330

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12344
12345
12346
12347
12348
12349
12350
# File 'lib/models/porcelain.rb', line 12344

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end