Class: SDM::RemoteIdentityHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RemoteIdentityHistory records the state of a RemoteIdentity at a given point in time, where every change (create, update and delete) to a RemoteIdentity produces an RemoteIdentityHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, remote_identity: nil, timestamp: nil) ⇒ RemoteIdentityHistory

Returns a new instance of RemoteIdentityHistory.



15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
15811
# File 'lib/models/porcelain.rb', line 15801

def initialize(
  activity_id: nil,
  deleted_at: nil,
  remote_identity: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @remote_identity = remote_identity == nil ? nil : remote_identity
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_id ⇒ Object

The unique identifier of the Activity that produced this change to the RemoteIdentity. May be empty for some system-initiated updates.



15793
15794
15795
# File 'lib/models/porcelain.rb', line 15793

def activity_id
  @activity_id
end

#deleted_at ⇒ Object

If this RemoteIdentity was deleted, the time it was deleted.



15795
15796
15797
# File 'lib/models/porcelain.rb', line 15795

def deleted_at
  @deleted_at
end

#remote_identity ⇒ Object

The complete RemoteIdentity state at this time.



15797
15798
15799
# File 'lib/models/porcelain.rb', line 15797

def remote_identity
  @remote_identity
end

#timestamp ⇒ Object

The time at which the RemoteIdentity state was recorded.



15799
15800
15801
# File 'lib/models/porcelain.rb', line 15799

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15813
15814
15815
15816
15817
15818
15819
# File 'lib/models/porcelain.rb', line 15813

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end