Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



15753
15754
15755
15756
15757
15758
15759
15760
15761
# File 'lib/models/porcelain.rb', line 15753

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



15746
15747
15748
# File 'lib/models/porcelain.rb', line 15746

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



15749
15750
15751
# File 'lib/models/porcelain.rb', line 15749

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



15751
15752
15753
# File 'lib/models/porcelain.rb', line 15751

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15763
15764
15765
15766
15767
15768
15769
# File 'lib/models/porcelain.rb', line 15763

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end