Class: SDM::ReplayChunk
- Inherits:
-
Object
- Object
- SDM::ReplayChunk
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunk represents a single "chunk" of data from the query replay.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunk.
-
#events ⇒ Object
The list of events of the ReplayChunk.
-
#symmetric_key ⇒ Object
If the data is encrypted, this contains the encrypted symmetric key.
Instance Method Summary collapse
-
#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk
constructor
A new instance of ReplayChunk.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk
Returns a new instance of ReplayChunk.
15127 15128 15129 15130 15131 15132 15133 15134 15135 |
# File 'lib/models/porcelain.rb', line 15127 def initialize( data: nil, events: nil, symmetric_key: nil ) @data = data == nil ? "" : data @events = events == nil ? [] : events @symmetric_key = symmetric_key == nil ? "" : symmetric_key end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.
15120 15121 15122 |
# File 'lib/models/porcelain.rb', line 15120 def data @data end |
#events ⇒ Object
The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.
15123 15124 15125 |
# File 'lib/models/porcelain.rb', line 15123 def events @events end |
#symmetric_key ⇒ Object
If the data is encrypted, this contains the encrypted symmetric key
15125 15126 15127 |
# File 'lib/models/porcelain.rb', line 15125 def symmetric_key @symmetric_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15137 15138 15139 15140 15141 15142 15143 |
# File 'lib/models/porcelain.rb', line 15137 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |