Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



15038
15039
15040
15041
15042
15043
15044
15045
15046
# File 'lib/models/porcelain.rb', line 15038

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



15031
15032
15033
# File 'lib/models/porcelain.rb', line 15031

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



15034
15035
15036
# File 'lib/models/porcelain.rb', line 15034

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



15036
15037
15038
# File 'lib/models/porcelain.rb', line 15036

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15048
15049
15050
15051
15052
15053
15054
# File 'lib/models/porcelain.rb', line 15048

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end