Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



14752
14753
14754
14755
14756
14757
14758
14759
14760
# File 'lib/models/porcelain.rb', line 14752

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



14745
14746
14747
# File 'lib/models/porcelain.rb', line 14745

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



14748
14749
14750
# File 'lib/models/porcelain.rb', line 14748

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



14750
14751
14752
# File 'lib/models/porcelain.rb', line 14750

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14762
14763
14764
14765
14766
14767
14768
# File 'lib/models/porcelain.rb', line 14762

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end