Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



14688
14689
14690
14691
14692
14693
14694
14695
14696
# File 'lib/models/porcelain.rb', line 14688

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



14681
14682
14683
# File 'lib/models/porcelain.rb', line 14681

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



14684
14685
14686
# File 'lib/models/porcelain.rb', line 14684

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



14686
14687
14688
# File 'lib/models/porcelain.rb', line 14686

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14698
14699
14700
14701
14702
14703
14704
# File 'lib/models/porcelain.rb', line 14698

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end