Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



13866
13867
13868
13869
13870
13871
13872
13873
13874
# File 'lib/models/porcelain.rb', line 13866

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



13859
13860
13861
# File 'lib/models/porcelain.rb', line 13859

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



13862
13863
13864
# File 'lib/models/porcelain.rb', line 13862

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



13864
13865
13866
# File 'lib/models/porcelain.rb', line 13864

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13876
13877
13878
13879
13880
13881
13882
# File 'lib/models/porcelain.rb', line 13876

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end