Class: SDM::ReplayChunk
- Inherits:
-
Object
- Object
- SDM::ReplayChunk
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunk represents a single "chunk" of data from the query replay.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunk.
-
#events ⇒ Object
The list of events of the ReplayChunk.
-
#symmetric_key ⇒ Object
If the data is encrypted, this contains the encrypted symmetric key.
Instance Method Summary collapse
-
#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk
constructor
A new instance of ReplayChunk.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk
Returns a new instance of ReplayChunk.
12846 12847 12848 12849 12850 12851 12852 12853 12854 |
# File 'lib/models/porcelain.rb', line 12846 def initialize( data: nil, events: nil, symmetric_key: nil ) @data = data == nil ? "" : data @events = events == nil ? [] : events @symmetric_key = symmetric_key == nil ? "" : symmetric_key end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.
12839 12840 12841 |
# File 'lib/models/porcelain.rb', line 12839 def data @data end |
#events ⇒ Object
The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.
12842 12843 12844 |
# File 'lib/models/porcelain.rb', line 12842 def events @events end |
#symmetric_key ⇒ Object
If the data is encrypted, this contains the encrypted symmetric key
12844 12845 12846 |
# File 'lib/models/porcelain.rb', line 12844 def symmetric_key @symmetric_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12856 12857 12858 12859 12860 12861 12862 |
# File 'lib/models/porcelain.rb', line 12856 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |