Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



12583
12584
12585
12586
12587
12588
12589
12590
12591
# File 'lib/models/porcelain.rb', line 12583

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



12576
12577
12578
# File 'lib/models/porcelain.rb', line 12576

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



12579
12580
12581
# File 'lib/models/porcelain.rb', line 12579

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



12581
12582
12583
# File 'lib/models/porcelain.rb', line 12581

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12593
12594
12595
12596
12597
12598
12599
# File 'lib/models/porcelain.rb', line 12593

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end