Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



12403
12404
12405
12406
12407
12408
12409
12410
12411
# File 'lib/models/porcelain.rb', line 12403

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



12396
12397
12398
# File 'lib/models/porcelain.rb', line 12396

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



12399
12400
12401
# File 'lib/models/porcelain.rb', line 12399

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



12401
12402
12403
# File 'lib/models/porcelain.rb', line 12401

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12413
12414
12415
12416
12417
12418
12419
# File 'lib/models/porcelain.rb', line 12413

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end