Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



12250
12251
12252
12253
12254
12255
12256
12257
12258
# File 'lib/models/porcelain.rb', line 12250

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



12243
12244
12245
# File 'lib/models/porcelain.rb', line 12243

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



12246
12247
12248
# File 'lib/models/porcelain.rb', line 12246

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



12248
12249
12250
# File 'lib/models/porcelain.rb', line 12248

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12260
12261
12262
12263
12264
12265
12266
# File 'lib/models/porcelain.rb', line 12260

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end