Class: SDM::ReplayChunk
- Inherits:
-
Object
- Object
- SDM::ReplayChunk
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunk represents a single "chunk" of data from the query replay.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunk.
-
#events ⇒ Object
The list of events of the ReplayChunk.
-
#symmetric_key ⇒ Object
If the data is encrypted, this contains the encrypted symmetric key.
Instance Method Summary collapse
-
#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk
constructor
A new instance of ReplayChunk.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk
Returns a new instance of ReplayChunk.
12183 12184 12185 12186 12187 12188 12189 12190 12191 |
# File 'lib/models/porcelain.rb', line 12183 def initialize( data: nil, events: nil, symmetric_key: nil ) @data = data == nil ? "" : data @events = events == nil ? [] : events @symmetric_key = symmetric_key == nil ? "" : symmetric_key end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.
12176 12177 12178 |
# File 'lib/models/porcelain.rb', line 12176 def data @data end |
#events ⇒ Object
The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.
12179 12180 12181 |
# File 'lib/models/porcelain.rb', line 12179 def events @events end |
#symmetric_key ⇒ Object
If the data is encrypted, this contains the encrypted symmetric key
12181 12182 12183 |
# File 'lib/models/porcelain.rb', line 12181 def symmetric_key @symmetric_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12193 12194 12195 12196 12197 12198 12199 |
# File 'lib/models/porcelain.rb', line 12193 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |