Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



11332
11333
11334
11335
11336
11337
11338
11339
11340
# File 'lib/models/porcelain.rb', line 11332

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



11325
11326
11327
# File 'lib/models/porcelain.rb', line 11325

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



11328
11329
11330
# File 'lib/models/porcelain.rb', line 11328

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



11330
11331
11332
# File 'lib/models/porcelain.rb', line 11330

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11342
11343
11344
11345
11346
11347
11348
# File 'lib/models/porcelain.rb', line 11342

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end