Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



11257
11258
11259
11260
11261
11262
11263
11264
11265
# File 'lib/models/porcelain.rb', line 11257

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



11250
11251
11252
# File 'lib/models/porcelain.rb', line 11250

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



11253
11254
11255
# File 'lib/models/porcelain.rb', line 11253

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



11255
11256
11257
# File 'lib/models/porcelain.rb', line 11255

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11267
11268
11269
11270
11271
11272
11273
# File 'lib/models/porcelain.rb', line 11267

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end