Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



11013
11014
11015
11016
11017
11018
11019
11020
11021
# File 'lib/models/porcelain.rb', line 11013

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



11006
11007
11008
# File 'lib/models/porcelain.rb', line 11006

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



11009
11010
11011
# File 'lib/models/porcelain.rb', line 11009

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



11011
11012
11013
# File 'lib/models/porcelain.rb', line 11011

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11023
11024
11025
11026
11027
11028
11029
# File 'lib/models/porcelain.rb', line 11023

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end