Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



10934
10935
10936
10937
10938
10939
10940
10941
10942
# File 'lib/models/porcelain.rb', line 10934

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



10927
10928
10929
# File 'lib/models/porcelain.rb', line 10927

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



10930
10931
10932
# File 'lib/models/porcelain.rb', line 10930

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



10932
10933
10934
# File 'lib/models/porcelain.rb', line 10932

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10944
10945
10946
10947
10948
10949
10950
# File 'lib/models/porcelain.rb', line 10944

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end