Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



10930
10931
10932
10933
10934
10935
10936
10937
10938
# File 'lib/models/porcelain.rb', line 10930

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



10923
10924
10925
# File 'lib/models/porcelain.rb', line 10923

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



10926
10927
10928
# File 'lib/models/porcelain.rb', line 10926

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



10928
10929
10930
# File 'lib/models/porcelain.rb', line 10928

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10940
10941
10942
10943
10944
10945
10946
# File 'lib/models/porcelain.rb', line 10940

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end