Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



10860
10861
10862
10863
10864
10865
10866
10867
10868
# File 'lib/models/porcelain.rb', line 10860

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



10853
10854
10855
# File 'lib/models/porcelain.rb', line 10853

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



10856
10857
10858
# File 'lib/models/porcelain.rb', line 10856

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



10858
10859
10860
# File 'lib/models/porcelain.rb', line 10858

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10870
10871
10872
10873
10874
10875
10876
# File 'lib/models/porcelain.rb', line 10870

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end