Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



10496
10497
10498
10499
10500
10501
10502
10503
10504
# File 'lib/models/porcelain.rb', line 10496

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



10489
10490
10491
# File 'lib/models/porcelain.rb', line 10489

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



10492
10493
10494
# File 'lib/models/porcelain.rb', line 10492

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



10494
10495
10496
# File 'lib/models/porcelain.rb', line 10494

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10506
10507
10508
10509
10510
10511
10512
# File 'lib/models/porcelain.rb', line 10506

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end