Class: SDM::ReplayChunk
- Inherits:
-
Object
- Object
- SDM::ReplayChunk
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunk represents a single "chunk" of data from the query replay.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunk.
-
#events ⇒ Object
The list of events of the ReplayChunk.
-
#symmetric_key ⇒ Object
If the data is encrypted, this contains the encrypted symmetric key.
Instance Method Summary collapse
-
#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk
constructor
A new instance of ReplayChunk.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk
Returns a new instance of ReplayChunk.
10418 10419 10420 10421 10422 10423 10424 10425 10426 |
# File 'lib/models/porcelain.rb', line 10418 def initialize( data: nil, events: nil, symmetric_key: nil ) @data = data == nil ? "" : data @events = events == nil ? [] : events @symmetric_key = symmetric_key == nil ? "" : symmetric_key end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.
10411 10412 10413 |
# File 'lib/models/porcelain.rb', line 10411 def data @data end |
#events ⇒ Object
The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.
10414 10415 10416 |
# File 'lib/models/porcelain.rb', line 10414 def events @events end |
#symmetric_key ⇒ Object
If the data is encrypted, this contains the encrypted symmetric key
10416 10417 10418 |
# File 'lib/models/porcelain.rb', line 10416 def symmetric_key @symmetric_key end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10428 10429 10430 10431 10432 10433 10434 |
# File 'lib/models/porcelain.rb', line 10428 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |