Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



10243
10244
10245
10246
10247
10248
10249
# File 'lib/models/porcelain.rb', line 10243

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



10238
10239
10240
# File 'lib/models/porcelain.rb', line 10238

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



10241
10242
10243
# File 'lib/models/porcelain.rb', line 10241

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10251
10252
10253
10254
10255
10256
10257
# File 'lib/models/porcelain.rb', line 10251

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end