Class: SDM::ReplayChunk
- Inherits:
-
Object
- Object
- SDM::ReplayChunk
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunk represents a single "chunk" of data from the query replay.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunk.
-
#events ⇒ Object
The list of events of the ReplayChunk.
Instance Method Summary collapse
-
#initialize(data: nil, events: nil) ⇒ ReplayChunk
constructor
A new instance of ReplayChunk.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, events: nil) ⇒ ReplayChunk
Returns a new instance of ReplayChunk.
9803 9804 9805 9806 9807 9808 9809 |
# File 'lib/models/porcelain.rb', line 9803 def initialize( data: nil, events: nil ) @data = data == nil ? "" : data @events = events == nil ? [] : events end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.
9798 9799 9800 |
# File 'lib/models/porcelain.rb', line 9798 def data @data end |
#events ⇒ Object
The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.
9801 9802 9803 |
# File 'lib/models/porcelain.rb', line 9801 def events @events end |
Instance Method Details
#to_json(options = {}) ⇒ Object
9811 9812 9813 9814 9815 9816 9817 |
# File 'lib/models/porcelain.rb', line 9811 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |