Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



9634
9635
9636
9637
9638
9639
9640
# File 'lib/models/porcelain.rb', line 9634

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



9629
9630
9631
# File 'lib/models/porcelain.rb', line 9629

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



9632
9633
9634
# File 'lib/models/porcelain.rb', line 9632

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9642
9643
9644
9645
9646
9647
9648
# File 'lib/models/porcelain.rb', line 9642

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end