Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



9465
9466
9467
9468
9469
9470
9471
# File 'lib/models/porcelain.rb', line 9465

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



9460
9461
9462
# File 'lib/models/porcelain.rb', line 9460

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



9463
9464
9465
# File 'lib/models/porcelain.rb', line 9463

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9473
9474
9475
9476
9477
9478
9479
# File 'lib/models/porcelain.rb', line 9473

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end