Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



9463
9464
9465
9466
9467
9468
9469
# File 'lib/models/porcelain.rb', line 9463

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



9458
9459
9460
# File 'lib/models/porcelain.rb', line 9458

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



9461
9462
9463
# File 'lib/models/porcelain.rb', line 9461

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9471
9472
9473
9474
9475
9476
9477
# File 'lib/models/porcelain.rb', line 9471

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end