Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



9246
9247
9248
9249
9250
9251
9252
# File 'lib/models/porcelain.rb', line 9246

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



9241
9242
9243
# File 'lib/models/porcelain.rb', line 9241

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



9244
9245
9246
# File 'lib/models/porcelain.rb', line 9244

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9254
9255
9256
9257
9258
9259
9260
# File 'lib/models/porcelain.rb', line 9254

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end