Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



8135
8136
8137
8138
8139
8140
8141
# File 'lib/models/porcelain.rb', line 8135

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



8130
8131
8132
# File 'lib/models/porcelain.rb', line 8130

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



8133
8134
8135
# File 'lib/models/porcelain.rb', line 8133

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8143
8144
8145
8146
8147
8148
8149
# File 'lib/models/porcelain.rb', line 8143

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end