Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



8043
8044
8045
8046
8047
8048
8049
# File 'lib/models/porcelain.rb', line 8043

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



8038
8039
8040
# File 'lib/models/porcelain.rb', line 8038

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



8041
8042
8043
# File 'lib/models/porcelain.rb', line 8041

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8051
8052
8053
8054
8055
8056
8057
# File 'lib/models/porcelain.rb', line 8051

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end