Class: SDM::ReplayChunk
- Inherits:
-
Object
- Object
- SDM::ReplayChunk
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunk represents a single "chunk" of data from the query replay.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunk.
-
#events ⇒ Object
The list of events of the ReplayChunk.
Instance Method Summary collapse
-
#initialize(data: nil, events: nil) ⇒ ReplayChunk
constructor
A new instance of ReplayChunk.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, events: nil) ⇒ ReplayChunk
Returns a new instance of ReplayChunk.
7944 7945 7946 7947 7948 7949 7950 |
# File 'lib/models/porcelain.rb', line 7944 def initialize( data: nil, events: nil ) @data = data == nil ? "" : data @events = events == nil ? [] : events end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.
7939 7940 7941 |
# File 'lib/models/porcelain.rb', line 7939 def data @data end |
#events ⇒ Object
The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.
7942 7943 7944 |
# File 'lib/models/porcelain.rb', line 7942 def events @events end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7952 7953 7954 7955 7956 7957 7958 |
# File 'lib/models/porcelain.rb', line 7952 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |