Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



7752
7753
7754
7755
7756
7757
7758
# File 'lib/models/porcelain.rb', line 7752

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



7747
7748
7749
# File 'lib/models/porcelain.rb', line 7747

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



7750
7751
7752
# File 'lib/models/porcelain.rb', line 7750

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7760
7761
7762
7763
7764
7765
7766
# File 'lib/models/porcelain.rb', line 7760

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end