Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



7709
7710
7711
7712
7713
7714
7715
# File 'lib/models/porcelain.rb', line 7709

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



7704
7705
7706
# File 'lib/models/porcelain.rb', line 7704

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



7707
7708
7709
# File 'lib/models/porcelain.rb', line 7707

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7717
7718
7719
7720
7721
7722
7723
# File 'lib/models/porcelain.rb', line 7717

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end