Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



7545
7546
7547
7548
7549
7550
7551
# File 'lib/models/porcelain.rb', line 7545

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



7540
7541
7542
# File 'lib/models/porcelain.rb', line 7540

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



7543
7544
7545
# File 'lib/models/porcelain.rb', line 7543

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7553
7554
7555
7556
7557
7558
7559
# File 'lib/models/porcelain.rb', line 7553

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end