Class: SDM::ReplayChunk
- Inherits:
-
Object
- Object
- SDM::ReplayChunk
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunk represents a single "chunk" of data from the query replay.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunk.
-
#events ⇒ Object
The list of events of the ReplayChunk.
Instance Method Summary collapse
-
#initialize(data: nil, events: nil) ⇒ ReplayChunk
constructor
A new instance of ReplayChunk.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, events: nil) ⇒ ReplayChunk
Returns a new instance of ReplayChunk.
7108 7109 7110 7111 7112 7113 7114 |
# File 'lib/models/porcelain.rb', line 7108 def initialize( data: nil, events: nil ) @data = data == nil ? "" : data @events = events == nil ? [] : events end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.
7103 7104 7105 |
# File 'lib/models/porcelain.rb', line 7103 def data @data end |
#events ⇒ Object
The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.
7106 7107 7108 |
# File 'lib/models/porcelain.rb', line 7106 def events @events end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7116 7117 7118 7119 7120 7121 7122 |
# File 'lib/models/porcelain.rb', line 7116 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |