Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



7114
7115
7116
7117
7118
7119
7120
# File 'lib/models/porcelain.rb', line 7114

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



7109
7110
7111
# File 'lib/models/porcelain.rb', line 7109

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



7112
7113
7114
# File 'lib/models/porcelain.rb', line 7112

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7122
7123
7124
7125
7126
7127
7128
# File 'lib/models/porcelain.rb', line 7122

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end