Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



6936
6937
6938
6939
6940
6941
6942
# File 'lib/models/porcelain.rb', line 6936

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



6931
6932
6933
# File 'lib/models/porcelain.rb', line 6931

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



6934
6935
6936
# File 'lib/models/porcelain.rb', line 6934

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6944
6945
6946
6947
6948
6949
6950
# File 'lib/models/porcelain.rb', line 6944

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end