Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



6880
6881
6882
6883
6884
6885
6886
# File 'lib/models/porcelain.rb', line 6880

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



6875
6876
6877
# File 'lib/models/porcelain.rb', line 6875

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



6878
6879
6880
# File 'lib/models/porcelain.rb', line 6878

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6888
6889
6890
6891
6892
6893
6894
# File 'lib/models/porcelain.rb', line 6888

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end