Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



6827
6828
6829
6830
6831
6832
6833
# File 'lib/models/porcelain.rb', line 6827

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



6822
6823
6824
# File 'lib/models/porcelain.rb', line 6822

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



6825
6826
6827
# File 'lib/models/porcelain.rb', line 6825

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6835
6836
6837
6838
6839
6840
6841
# File 'lib/models/porcelain.rb', line 6835

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end