Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



6399
6400
6401
6402
6403
6404
6405
# File 'lib/models/porcelain.rb', line 6399

def initialize(
  data: nil,
  events: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



6394
6395
6396
# File 'lib/models/porcelain.rb', line 6394

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



6397
6398
6399
# File 'lib/models/porcelain.rb', line 6397

def events
  @events
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6407
6408
6409
6410
6411
6412
6413
# File 'lib/models/porcelain.rb', line 6407

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end