Class: SDM::ReplayChunk

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunk represents a single "chunk" of data from the query replay.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, events: nil, symmetric_key: nil) ⇒ ReplayChunk

Returns a new instance of ReplayChunk.



15135
15136
15137
15138
15139
15140
15141
15142
15143
# File 'lib/models/porcelain.rb', line 15135

def initialize(
  data: nil,
  events: nil,
  symmetric_key: nil
)
  @data = data == nil ? "" : data
  @events = events == nil ? [] : events
  @symmetric_key = symmetric_key == nil ? "" : symmetric_key
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunk. The data is encrypted if the associated Query is encrypted.



15128
15129
15130
# File 'lib/models/porcelain.rb', line 15128

def data
  @data
end

#eventsObject

The list of events of the ReplayChunk. If the Query is encrypted, this field is always empty and the events can be obtained by decrypting the data using the QueryKey returned with the Query.



15131
15132
15133
# File 'lib/models/porcelain.rb', line 15131

def events
  @events
end

#symmetric_keyObject

If the data is encrypted, this contains the encrypted symmetric key



15133
15134
15135
# File 'lib/models/porcelain.rb', line 15133

def symmetric_key
  @symmetric_key
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15145
15146
15147
15148
15149
15150
15151
# File 'lib/models/porcelain.rb', line 15145

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end