Class: SDM::ReplayChunkEvent
- Inherits:
-
Object
- Object
- SDM::ReplayChunkEvent
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunkEvent.
-
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
Instance Method Summary collapse
-
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
constructor
A new instance of ReplayChunkEvent.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
Returns a new instance of ReplayChunkEvent.
15780 15781 15782 15783 15784 15785 15786 |
# File 'lib/models/porcelain.rb', line 15780 def initialize( data: nil, duration: nil ) @data = data == nil ? "" : data @duration = duration == nil ? nil : duration end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunkEvent.
15776 15777 15778 |
# File 'lib/models/porcelain.rb', line 15776 def data @data end |
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
15778 15779 15780 |
# File 'lib/models/porcelain.rb', line 15778 def duration @duration end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15788 15789 15790 15791 15792 15793 15794 |
# File 'lib/models/porcelain.rb', line 15788 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |