Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



15700
15701
15702
15703
15704
15705
15706
# File 'lib/models/porcelain.rb', line 15700

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



15696
15697
15698
# File 'lib/models/porcelain.rb', line 15696

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



15698
15699
15700
# File 'lib/models/porcelain.rb', line 15698

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15708
15709
15710
15711
15712
15713
15714
# File 'lib/models/porcelain.rb', line 15708

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end