Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



15155
15156
15157
15158
15159
15160
15161
# File 'lib/models/porcelain.rb', line 15155

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



15151
15152
15153
# File 'lib/models/porcelain.rb', line 15151

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



15153
15154
15155
# File 'lib/models/porcelain.rb', line 15153

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15163
15164
15165
15166
15167
15168
15169
# File 'lib/models/porcelain.rb', line 15163

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end