Class: SDM::ReplayChunkEvent
- Inherits:
-
Object
- Object
- SDM::ReplayChunkEvent
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunkEvent.
-
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
Instance Method Summary collapse
-
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
constructor
A new instance of ReplayChunkEvent.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
Returns a new instance of ReplayChunkEvent.
13893 13894 13895 13896 13897 13898 13899 |
# File 'lib/models/porcelain.rb', line 13893 def initialize( data: nil, duration: nil ) @data = data == nil ? "" : data @duration = duration == nil ? nil : duration end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunkEvent.
13889 13890 13891 |
# File 'lib/models/porcelain.rb', line 13889 def data @data end |
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
13891 13892 13893 |
# File 'lib/models/porcelain.rb', line 13891 def duration @duration end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13901 13902 13903 13904 13905 13906 13907 |
# File 'lib/models/porcelain.rb', line 13901 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |