Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



12430
12431
12432
12433
12434
12435
12436
# File 'lib/models/porcelain.rb', line 12430

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



12426
12427
12428
# File 'lib/models/porcelain.rb', line 12426

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



12428
12429
12430
# File 'lib/models/porcelain.rb', line 12428

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12438
12439
12440
12441
12442
12443
12444
# File 'lib/models/porcelain.rb', line 12438

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end