Class: SDM::ReplayChunkEvent
- Inherits:
-
Object
- Object
- SDM::ReplayChunkEvent
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunkEvent.
-
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
Instance Method Summary collapse
-
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
constructor
A new instance of ReplayChunkEvent.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
Returns a new instance of ReplayChunkEvent.
12419 12420 12421 12422 12423 12424 12425 |
# File 'lib/models/porcelain.rb', line 12419 def initialize( data: nil, duration: nil ) @data = data == nil ? "" : data @duration = duration == nil ? nil : duration end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunkEvent.
12415 12416 12417 |
# File 'lib/models/porcelain.rb', line 12415 def data @data end |
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
12417 12418 12419 |
# File 'lib/models/porcelain.rb', line 12417 def duration @duration end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12427 12428 12429 12430 12431 12432 12433 |
# File 'lib/models/porcelain.rb', line 12427 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |