Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



12351
12352
12353
12354
12355
12356
12357
# File 'lib/models/porcelain.rb', line 12351

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



12347
12348
12349
# File 'lib/models/porcelain.rb', line 12347

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



12349
12350
12351
# File 'lib/models/porcelain.rb', line 12349

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12359
12360
12361
12362
12363
12364
12365
# File 'lib/models/porcelain.rb', line 12359

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end