Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



12210
12211
12212
12213
12214
12215
12216
# File 'lib/models/porcelain.rb', line 12210

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



12206
12207
12208
# File 'lib/models/porcelain.rb', line 12206

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



12208
12209
12210
# File 'lib/models/porcelain.rb', line 12208

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12218
12219
12220
12221
12222
12223
12224
# File 'lib/models/porcelain.rb', line 12218

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end