Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



11359
11360
11361
11362
11363
11364
11365
# File 'lib/models/porcelain.rb', line 11359

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



11355
11356
11357
# File 'lib/models/porcelain.rb', line 11355

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



11357
11358
11359
# File 'lib/models/porcelain.rb', line 11357

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11367
11368
11369
11370
11371
11372
11373
# File 'lib/models/porcelain.rb', line 11367

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end