Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



11108
11109
11110
11111
11112
11113
11114
# File 'lib/models/porcelain.rb', line 11108

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



11104
11105
11106
# File 'lib/models/porcelain.rb', line 11104

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



11106
11107
11108
# File 'lib/models/porcelain.rb', line 11106

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11116
11117
11118
11119
11120
11121
11122
# File 'lib/models/porcelain.rb', line 11116

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end