Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



11040
11041
11042
11043
11044
11045
11046
# File 'lib/models/porcelain.rb', line 11040

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



11036
11037
11038
# File 'lib/models/porcelain.rb', line 11036

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



11038
11039
11040
# File 'lib/models/porcelain.rb', line 11038

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11048
11049
11050
11051
11052
11053
11054
# File 'lib/models/porcelain.rb', line 11048

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end