Class: SDM::ReplayChunkEvent
- Inherits:
-
Object
- Object
- SDM::ReplayChunkEvent
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunkEvent.
-
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
Instance Method Summary collapse
-
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
constructor
A new instance of ReplayChunkEvent.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
Returns a new instance of ReplayChunkEvent.
11041 11042 11043 11044 11045 11046 11047 |
# File 'lib/models/porcelain.rb', line 11041 def initialize( data: nil, duration: nil ) @data = data == nil ? "" : data @duration = duration == nil ? nil : duration end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunkEvent.
11037 11038 11039 |
# File 'lib/models/porcelain.rb', line 11037 def data @data end |
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
11039 11040 11041 |
# File 'lib/models/porcelain.rb', line 11039 def duration @duration end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11049 11050 11051 11052 11053 11054 11055 |
# File 'lib/models/porcelain.rb', line 11049 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |