Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



10268
10269
10270
10271
10272
10273
10274
# File 'lib/models/porcelain.rb', line 10268

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



10264
10265
10266
# File 'lib/models/porcelain.rb', line 10264

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



10266
10267
10268
# File 'lib/models/porcelain.rb', line 10266

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10276
10277
10278
10279
10280
10281
10282
# File 'lib/models/porcelain.rb', line 10276

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end