Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



10197
10198
10199
10200
10201
10202
10203
# File 'lib/models/porcelain.rb', line 10197

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



10193
10194
10195
# File 'lib/models/porcelain.rb', line 10193

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



10195
10196
10197
# File 'lib/models/porcelain.rb', line 10195

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10205
10206
10207
10208
10209
10210
10211
# File 'lib/models/porcelain.rb', line 10205

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end