Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



9828
9829
9830
9831
9832
9833
9834
# File 'lib/models/porcelain.rb', line 9828

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



9824
9825
9826
# File 'lib/models/porcelain.rb', line 9824

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



9826
9827
9828
# File 'lib/models/porcelain.rb', line 9826

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9836
9837
9838
9839
9840
9841
9842
# File 'lib/models/porcelain.rb', line 9836

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end