Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



9655
9656
9657
9658
9659
9660
9661
# File 'lib/models/porcelain.rb', line 9655

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



9651
9652
9653
# File 'lib/models/porcelain.rb', line 9651

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



9653
9654
9655
# File 'lib/models/porcelain.rb', line 9653

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9663
9664
9665
9666
9667
9668
9669
# File 'lib/models/porcelain.rb', line 9663

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end