Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



9488
9489
9490
9491
9492
9493
9494
# File 'lib/models/porcelain.rb', line 9488

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



9484
9485
9486
# File 'lib/models/porcelain.rb', line 9484

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



9486
9487
9488
# File 'lib/models/porcelain.rb', line 9486

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9496
9497
9498
9499
9500
9501
9502
# File 'lib/models/porcelain.rb', line 9496

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end