Class: SDM::ReplayChunkEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent

Returns a new instance of ReplayChunkEvent.



6905
6906
6907
6908
6909
6910
6911
# File 'lib/models/porcelain.rb', line 6905

def initialize(
  data: nil,
  duration: nil
)
  @data = data == nil ? "" : data
  @duration = duration == nil ? nil : duration
end

Instance Attribute Details

#dataObject

The raw data of the ReplayChunkEvent.



6901
6902
6903
# File 'lib/models/porcelain.rb', line 6901

def data
  @data
end

#durationObject

The time duration over which the data in this ReplayChunkEvent was transferred.



6903
6904
6905
# File 'lib/models/porcelain.rb', line 6903

def duration
  @duration
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6913
6914
6915
6916
6917
6918
6919
# File 'lib/models/porcelain.rb', line 6913

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end