Class: SDM::ReplayChunkEvent
- Inherits:
-
Object
- Object
- SDM::ReplayChunkEvent
- Defined in:
- lib/models/porcelain.rb
Overview
A ReplayChunkEvent represents a single event within a query replay. The timing information included in each ReplayChunkEvent may be used to replay a session in real time.
Instance Attribute Summary collapse
-
#data ⇒ Object
The raw data of the ReplayChunkEvent.
-
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
Instance Method Summary collapse
-
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
constructor
A new instance of ReplayChunkEvent.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(data: nil, duration: nil) ⇒ ReplayChunkEvent
Returns a new instance of ReplayChunkEvent.
6905 6906 6907 6908 6909 6910 6911 |
# File 'lib/models/porcelain.rb', line 6905 def initialize( data: nil, duration: nil ) @data = data == nil ? "" : data @duration = duration == nil ? nil : duration end |
Instance Attribute Details
#data ⇒ Object
The raw data of the ReplayChunkEvent.
6901 6902 6903 |
# File 'lib/models/porcelain.rb', line 6901 def data @data end |
#duration ⇒ Object
The time duration over which the data in this ReplayChunkEvent was transferred.
6903 6904 6905 |
# File 'lib/models/porcelain.rb', line 6903 def duration @duration end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6913 6914 6915 6916 6917 6918 6919 |
# File 'lib/models/porcelain.rb', line 6913 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |