Class: SDM::RequestableAccountEntitlement
- Inherits:
-
Object
- Object
- SDM::RequestableAccountEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
RequestableAccountEntitlement represents an individual resource that an Account is permitted to request access to.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested.
Instance Method Summary collapse
-
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableAccountEntitlement
constructor
A new instance of RequestableAccountEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableAccountEntitlement
Returns a new instance of RequestableAccountEntitlement.
15728 15729 15730 15731 15732 15733 15734 15735 15736 15737 15738 |
# File 'lib/models/porcelain.rb', line 15728 def initialize( group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
15720 15721 15722 |
# File 'lib/models/porcelain.rb', line 15720 def group_id @group_id end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
15722 15723 15724 |
# File 'lib/models/porcelain.rb', line 15722 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
15724 15725 15726 |
# File 'lib/models/porcelain.rb', line 15724 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested.
15726 15727 15728 |
# File 'lib/models/porcelain.rb', line 15726 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15740 15741 15742 15743 15744 15745 15746 |
# File 'lib/models/porcelain.rb', line 15740 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |