Class: SDM::RequestableAccountEntitlement
- Inherits:
-
Object
- Object
- SDM::RequestableAccountEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
RequestableAccountEntitlement represents an individual resource that an Account is permitted to request access to.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested.
Instance Method Summary collapse
-
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableAccountEntitlement
constructor
A new instance of RequestableAccountEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableAccountEntitlement
Returns a new instance of RequestableAccountEntitlement.
15502 15503 15504 15505 15506 15507 15508 15509 15510 15511 15512 |
# File 'lib/models/porcelain.rb', line 15502 def initialize( group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
15494 15495 15496 |
# File 'lib/models/porcelain.rb', line 15494 def group_id @group_id end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
15496 15497 15498 |
# File 'lib/models/porcelain.rb', line 15496 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
15498 15499 15500 |
# File 'lib/models/porcelain.rb', line 15498 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested.
15500 15501 15502 |
# File 'lib/models/porcelain.rb', line 15500 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15514 15515 15516 15517 15518 15519 15520 |
# File 'lib/models/porcelain.rb', line 15514 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |