Class: SDM::RequestableResourceEntitlement

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RequestableResourceEntitlement represents an individual account that is permitted to request access to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, group_id: nil, mapped_identities: nil, origin_id: nil) ⇒ RequestableResourceEntitlement

Returns a new instance of RequestableResourceEntitlement.



15932
15933
15934
15935
15936
15937
15938
15939
15940
15941
15942
# File 'lib/models/porcelain.rb', line 15932

def initialize(
  account_id: nil,
  group_id: nil,
  mapped_identities: nil,
  origin_id: nil
)
  @account_id =  == nil ? "" : 
  @group_id = group_id == nil ? "" : group_id
  @mapped_identities = mapped_identities == nil ? nil : mapped_identities
  @origin_id = origin_id == nil ? "" : origin_id
end

Instance Attribute Details

#account_idObject

The unique identifier of the Account that can request access to this resource.



15924
15925
15926
# File 'lib/models/porcelain.rb', line 15924

def 
  @account_id
end

#group_idObject

The unique identifier of the group associated with this entitlement, if any.



15926
15927
15928
# File 'lib/models/porcelain.rb', line 15926

def group_id
  @group_id
end

#mapped_identitiesObject

The mapped identity privileges for this entitlement, such as Kubernetes group memberships.



15928
15929
15930
# File 'lib/models/porcelain.rb', line 15928

def mapped_identities
  @mapped_identities
end

#origin_idObject

The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).



15930
15931
15932
# File 'lib/models/porcelain.rb', line 15930

def origin_id
  @origin_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15944
15945
15946
15947
15948
15949
15950
# File 'lib/models/porcelain.rb', line 15944

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end