Class: SDM::RequestableResourceEntitlement

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RequestableResourceEntitlement represents an individual account that is permitted to request access to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, group_id: nil, mapped_identities: nil, origin_id: nil) ⇒ RequestableResourceEntitlement

Returns a new instance of RequestableResourceEntitlement.



15804
15805
15806
15807
15808
15809
15810
15811
15812
15813
15814
# File 'lib/models/porcelain.rb', line 15804

def initialize(
  account_id: nil,
  group_id: nil,
  mapped_identities: nil,
  origin_id: nil
)
  @account_id =  == nil ? "" : 
  @group_id = group_id == nil ? "" : group_id
  @mapped_identities = mapped_identities == nil ? nil : mapped_identities
  @origin_id = origin_id == nil ? "" : origin_id
end

Instance Attribute Details

#account_idObject

The unique identifier of the Account that can request access to this resource.



15796
15797
15798
# File 'lib/models/porcelain.rb', line 15796

def 
  @account_id
end

#group_idObject

The unique identifier of the group associated with this entitlement, if any.



15798
15799
15800
# File 'lib/models/porcelain.rb', line 15798

def group_id
  @group_id
end

#mapped_identitiesObject

The mapped identity privileges for this entitlement, such as Kubernetes group memberships.



15800
15801
15802
# File 'lib/models/porcelain.rb', line 15800

def mapped_identities
  @mapped_identities
end

#origin_idObject

The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).



15802
15803
15804
# File 'lib/models/porcelain.rb', line 15802

def origin_id
  @origin_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15816
15817
15818
15819
15820
15821
15822
# File 'lib/models/porcelain.rb', line 15816

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end