Class: SDM::RequestableResourceEntitlement
- Inherits:
-
Object
- Object
- SDM::RequestableResourceEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
RequestableResourceEntitlement represents an individual account that is permitted to request access to a Resource.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The unique identifier of the Account that can request access to this resource.
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
Instance Method Summary collapse
-
#initialize(account_id: nil, group_id: nil, mapped_identities: nil, origin_id: nil) ⇒ RequestableResourceEntitlement
constructor
A new instance of RequestableResourceEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(account_id: nil, group_id: nil, mapped_identities: nil, origin_id: nil) ⇒ RequestableResourceEntitlement
Returns a new instance of RequestableResourceEntitlement.
15558 15559 15560 15561 15562 15563 15564 15565 15566 15567 15568 |
# File 'lib/models/porcelain.rb', line 15558 def initialize( account_id: nil, group_id: nil, mapped_identities: nil, origin_id: nil ) @account_id = account_id == nil ? "" : account_id @group_id = group_id == nil ? "" : group_id @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id end |
Instance Attribute Details
#account_id ⇒ Object
The unique identifier of the Account that can request access to this resource.
15550 15551 15552 |
# File 'lib/models/porcelain.rb', line 15550 def account_id @account_id end |
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
15552 15553 15554 |
# File 'lib/models/porcelain.rb', line 15552 def group_id @group_id end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
15554 15555 15556 |
# File 'lib/models/porcelain.rb', line 15554 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
15556 15557 15558 |
# File 'lib/models/porcelain.rb', line 15556 def origin_id @origin_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15570 15571 15572 15573 15574 15575 15576 |
# File 'lib/models/porcelain.rb', line 15570 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |