Class: SDM::RequestableResourceEntitlement

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RequestableResourceEntitlement represents an individual account that is permitted to request access to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(account_id: nil, group_id: nil, mapped_identities: nil, origin_id: nil) ⇒ RequestableResourceEntitlement

Returns a new instance of RequestableResourceEntitlement.



15992
15993
15994
15995
15996
15997
15998
15999
16000
16001
16002
# File 'lib/models/porcelain.rb', line 15992

def initialize(
  account_id: nil,
  group_id: nil,
  mapped_identities: nil,
  origin_id: nil
)
  @account_id =  == nil ? "" : 
  @group_id = group_id == nil ? "" : group_id
  @mapped_identities = mapped_identities == nil ? nil : mapped_identities
  @origin_id = origin_id == nil ? "" : origin_id
end

Instance Attribute Details

#account_id ⇒ Object

The unique identifier of the Account that can request access to this resource.



15984
15985
15986
# File 'lib/models/porcelain.rb', line 15984

def 
  @account_id
end

#group_id ⇒ Object

The unique identifier of the group associated with this entitlement, if any.



15986
15987
15988
# File 'lib/models/porcelain.rb', line 15986

def group_id
  @group_id
end

#mapped_identities ⇒ Object

The mapped identity privileges for this entitlement, such as Kubernetes group memberships.



15988
15989
15990
# File 'lib/models/porcelain.rb', line 15988

def mapped_identities
  @mapped_identities
end

#origin_id ⇒ Object

The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).



15990
15991
15992
# File 'lib/models/porcelain.rb', line 15990

def origin_id
  @origin_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16004
16005
16006
16007
16008
16009
16010
# File 'lib/models/porcelain.rb', line 16004

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end