Class: SDM::RequestableRoleEntitlement
- Inherits:
-
Object
- Object
- SDM::RequestableRoleEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
RequestableRoleEntitlement represents an individual resource that a Role permits its members to request access to.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested through this role.
Instance Method Summary collapse
-
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableRoleEntitlement
constructor
A new instance of RequestableRoleEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableRoleEntitlement
Returns a new instance of RequestableRoleEntitlement.
15836 15837 15838 15839 15840 15841 15842 15843 15844 15845 15846 |
# File 'lib/models/porcelain.rb', line 15836 def initialize( group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
15828 15829 15830 |
# File 'lib/models/porcelain.rb', line 15828 def group_id @group_id end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
15830 15831 15832 |
# File 'lib/models/porcelain.rb', line 15830 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
15832 15833 15834 |
# File 'lib/models/porcelain.rb', line 15832 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested through this role.
15834 15835 15836 |
# File 'lib/models/porcelain.rb', line 15834 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15848 15849 15850 15851 15852 15853 15854 |
# File 'lib/models/porcelain.rb', line 15848 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |