Class: SDM::RequestableRoleEntitlement
- Inherits:
-
Object
- Object
- SDM::RequestableRoleEntitlement
- Defined in:
- lib/models/porcelain.rb
Overview
RequestableRoleEntitlement represents an individual resource that a Role permits its members to request access to.
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
-
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
-
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested through this role.
Instance Method Summary collapse
-
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableRoleEntitlement
constructor
A new instance of RequestableRoleEntitlement.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil) ⇒ RequestableRoleEntitlement
Returns a new instance of RequestableRoleEntitlement.
16024 16025 16026 16027 16028 16029 16030 16031 16032 16033 16034 |
# File 'lib/models/porcelain.rb', line 16024 def initialize( group_id: nil, mapped_identities: nil, origin_id: nil, resource_id: nil ) @group_id = group_id == nil ? "" : group_id @mapped_identities = mapped_identities == nil ? nil : mapped_identities @origin_id = origin_id == nil ? "" : origin_id @resource_id = resource_id == nil ? "" : resource_id end |
Instance Attribute Details
#group_id ⇒ Object
The unique identifier of the group associated with this entitlement, if any.
16016 16017 16018 |
# File 'lib/models/porcelain.rb', line 16016 def group_id @group_id end |
#mapped_identities ⇒ Object
The mapped identity privileges for this entitlement, such as Kubernetes group memberships.
16018 16019 16020 |
# File 'lib/models/porcelain.rb', line 16018 def mapped_identities @mapped_identities end |
#origin_id ⇒ Object
The unique identifier of the origin of this entitlement (e.g., an Access Workflow ID).
16020 16021 16022 |
# File 'lib/models/porcelain.rb', line 16020 def origin_id @origin_id end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access can be requested through this role.
16022 16023 16024 |
# File 'lib/models/porcelain.rb', line 16022 def resource_id @resource_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16036 16037 16038 16039 16040 16041 16042 |
# File 'lib/models/porcelain.rb', line 16036 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |