Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



16076
16077
16078
16079
16080
16081
16082
16083
16084
16085
16086
# File 'lib/models/porcelain.rb', line 16076

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



16068
16069
16070
# File 'lib/models/porcelain.rb', line 16068

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



16070
16071
16072
# File 'lib/models/porcelain.rb', line 16070

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



16072
16073
16074
# File 'lib/models/porcelain.rb', line 16072

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



16074
16075
16076
# File 'lib/models/porcelain.rb', line 16074

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16088
16089
16090
16091
16092
16093
16094
# File 'lib/models/porcelain.rb', line 16088

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end