Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



15770
15771
15772
15773
15774
15775
15776
15777
15778
15779
15780
# File 'lib/models/porcelain.rb', line 15770

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



15762
15763
15764
# File 'lib/models/porcelain.rb', line 15762

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



15764
15765
15766
# File 'lib/models/porcelain.rb', line 15764

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



15766
15767
15768
# File 'lib/models/porcelain.rb', line 15766

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



15768
15769
15770
# File 'lib/models/porcelain.rb', line 15768

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15782
15783
15784
15785
15786
15787
15788
# File 'lib/models/porcelain.rb', line 15782

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end