Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



15265
15266
15267
15268
15269
15270
15271
15272
15273
15274
15275
# File 'lib/models/porcelain.rb', line 15265

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



15257
15258
15259
# File 'lib/models/porcelain.rb', line 15257

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



15259
15260
15261
# File 'lib/models/porcelain.rb', line 15259

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



15261
15262
15263
# File 'lib/models/porcelain.rb', line 15261

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



15263
15264
15265
# File 'lib/models/porcelain.rb', line 15263

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15277
15278
15279
15280
15281
15282
15283
# File 'lib/models/porcelain.rb', line 15277

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end