Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



14979
14980
14981
14982
14983
14984
14985
14986
14987
14988
14989
# File 'lib/models/porcelain.rb', line 14979

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



14971
14972
14973
# File 'lib/models/porcelain.rb', line 14971

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



14973
14974
14975
# File 'lib/models/porcelain.rb', line 14973

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



14975
14976
14977
# File 'lib/models/porcelain.rb', line 14975

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



14977
14978
14979
# File 'lib/models/porcelain.rb', line 14977

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14991
14992
14993
14994
14995
14996
14997
# File 'lib/models/porcelain.rb', line 14991

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end