Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



14093
14094
14095
14096
14097
14098
14099
14100
14101
14102
14103
# File 'lib/models/porcelain.rb', line 14093

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



14085
14086
14087
# File 'lib/models/porcelain.rb', line 14085

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



14087
14088
14089
# File 'lib/models/porcelain.rb', line 14087

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



14089
14090
14091
# File 'lib/models/porcelain.rb', line 14089

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



14091
14092
14093
# File 'lib/models/porcelain.rb', line 14091

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14105
14106
14107
14108
14109
14110
14111
# File 'lib/models/porcelain.rb', line 14105

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end