Class: SDM::ResourceHistory
- Inherits:
-
Object
- Object
- SDM::ResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource.
-
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
-
#resource ⇒ Object
The complete Resource state at this time.
-
#timestamp ⇒ Object
The time at which the Resource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
constructor
A new instance of ResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
Returns a new instance of ResourceHistory.
12619 12620 12621 12622 12623 12624 12625 12626 12627 12628 12629 |
# File 'lib/models/porcelain.rb', line 12619 def initialize( activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @resource = resource == nil ? nil : resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.
12611 12612 12613 |
# File 'lib/models/porcelain.rb', line 12611 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
12613 12614 12615 |
# File 'lib/models/porcelain.rb', line 12613 def deleted_at @deleted_at end |
#resource ⇒ Object
The complete Resource state at this time.
12615 12616 12617 |
# File 'lib/models/porcelain.rb', line 12615 def resource @resource end |
#timestamp ⇒ Object
The time at which the Resource state was recorded.
12617 12618 12619 |
# File 'lib/models/porcelain.rb', line 12617 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12631 12632 12633 12634 12635 12636 12637 |
# File 'lib/models/porcelain.rb', line 12631 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |