Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



11559
11560
11561
11562
11563
11564
11565
11566
11567
11568
11569
# File 'lib/models/porcelain.rb', line 11559

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



11551
11552
11553
# File 'lib/models/porcelain.rb', line 11551

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



11553
11554
11555
# File 'lib/models/porcelain.rb', line 11553

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



11555
11556
11557
# File 'lib/models/porcelain.rb', line 11555

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



11557
11558
11559
# File 'lib/models/porcelain.rb', line 11557

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11571
11572
11573
11574
11575
11576
11577
# File 'lib/models/porcelain.rb', line 11571

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end