Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



11237
11238
11239
11240
11241
11242
11243
11244
11245
11246
11247
# File 'lib/models/porcelain.rb', line 11237

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



11229
11230
11231
# File 'lib/models/porcelain.rb', line 11229

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



11231
11232
11233
# File 'lib/models/porcelain.rb', line 11231

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



11233
11234
11235
# File 'lib/models/porcelain.rb', line 11233

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



11235
11236
11237
# File 'lib/models/porcelain.rb', line 11235

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11249
11250
11251
11252
11253
11254
11255
# File 'lib/models/porcelain.rb', line 11249

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end