Class: SDM::ResourceHistory
- Inherits:
-
Object
- Object
- SDM::ResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource.
-
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
-
#resource ⇒ Object
The complete Resource state at this time.
-
#timestamp ⇒ Object
The time at which the Resource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
constructor
A new instance of ResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
Returns a new instance of ResourceHistory.
11161 11162 11163 11164 11165 11166 11167 11168 11169 11170 11171 |
# File 'lib/models/porcelain.rb', line 11161 def initialize( activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @resource = resource == nil ? nil : resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.
11153 11154 11155 |
# File 'lib/models/porcelain.rb', line 11153 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
11155 11156 11157 |
# File 'lib/models/porcelain.rb', line 11155 def deleted_at @deleted_at end |
#resource ⇒ Object
The complete Resource state at this time.
11157 11158 11159 |
# File 'lib/models/porcelain.rb', line 11157 def resource @resource end |
#timestamp ⇒ Object
The time at which the Resource state was recorded.
11159 11160 11161 |
# File 'lib/models/porcelain.rb', line 11159 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11173 11174 11175 11176 11177 11178 11179 |
# File 'lib/models/porcelain.rb', line 11173 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |