Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



11157
11158
11159
11160
11161
11162
11163
11164
11165
11166
11167
# File 'lib/models/porcelain.rb', line 11157

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



11149
11150
11151
# File 'lib/models/porcelain.rb', line 11149

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



11151
11152
11153
# File 'lib/models/porcelain.rb', line 11151

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



11153
11154
11155
# File 'lib/models/porcelain.rb', line 11153

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



11155
11156
11157
# File 'lib/models/porcelain.rb', line 11155

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11169
11170
11171
11172
11173
11174
11175
# File 'lib/models/porcelain.rb', line 11169

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end