Class: SDM::ResourceHistory
- Inherits:
-
Object
- Object
- SDM::ResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource.
-
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
-
#resource ⇒ Object
The complete Resource state at this time.
-
#timestamp ⇒ Object
The time at which the Resource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
constructor
A new instance of ResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
Returns a new instance of ResourceHistory.
11087 11088 11089 11090 11091 11092 11093 11094 11095 11096 11097 |
# File 'lib/models/porcelain.rb', line 11087 def initialize( activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @resource = resource == nil ? nil : resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.
11079 11080 11081 |
# File 'lib/models/porcelain.rb', line 11079 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
11081 11082 11083 |
# File 'lib/models/porcelain.rb', line 11081 def deleted_at @deleted_at end |
#resource ⇒ Object
The complete Resource state at this time.
11083 11084 11085 |
# File 'lib/models/porcelain.rb', line 11083 def resource @resource end |
#timestamp ⇒ Object
The time at which the Resource state was recorded.
11085 11086 11087 |
# File 'lib/models/porcelain.rb', line 11085 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11099 11100 11101 11102 11103 11104 11105 |
# File 'lib/models/porcelain.rb', line 11099 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |