Class: SDM::ResourceHistory
- Inherits:
-
Object
- Object
- SDM::ResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource.
-
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
-
#resource ⇒ Object
The complete Resource state at this time.
-
#timestamp ⇒ Object
The time at which the Resource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
constructor
A new instance of ResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
Returns a new instance of ResourceHistory.
11020 11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 |
# File 'lib/models/porcelain.rb', line 11020 def initialize( activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @resource = resource == nil ? nil : resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.
11012 11013 11014 |
# File 'lib/models/porcelain.rb', line 11012 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
11014 11015 11016 |
# File 'lib/models/porcelain.rb', line 11014 def deleted_at @deleted_at end |
#resource ⇒ Object
The complete Resource state at this time.
11016 11017 11018 |
# File 'lib/models/porcelain.rb', line 11016 def resource @resource end |
#timestamp ⇒ Object
The time at which the Resource state was recorded.
11018 11019 11020 |
# File 'lib/models/porcelain.rb', line 11018 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11032 11033 11034 11035 11036 11037 11038 |
# File 'lib/models/porcelain.rb', line 11032 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |