Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
# File 'lib/models/porcelain.rb', line 10468

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



10460
10461
10462
# File 'lib/models/porcelain.rb', line 10460

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



10462
10463
10464
# File 'lib/models/porcelain.rb', line 10462

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



10464
10465
10466
# File 'lib/models/porcelain.rb', line 10464

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



10466
10467
10468
# File 'lib/models/porcelain.rb', line 10466

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10480
10481
10482
10483
10484
10485
10486
# File 'lib/models/porcelain.rb', line 10480

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end