Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
# File 'lib/models/porcelain.rb', line 8268

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



8260
8261
8262
# File 'lib/models/porcelain.rb', line 8260

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



8262
8263
8264
# File 'lib/models/porcelain.rb', line 8262

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



8264
8265
8266
# File 'lib/models/porcelain.rb', line 8264

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



8266
8267
8268
# File 'lib/models/porcelain.rb', line 8266

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8280
8281
8282
8283
8284
8285
8286
# File 'lib/models/porcelain.rb', line 8280

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end