Class: SDM::ResourceHistory
- Inherits:
-
Object
- Object
- SDM::ResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource.
-
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
-
#resource ⇒ Object
The complete Resource state at this time.
-
#timestamp ⇒ Object
The time at which the Resource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
constructor
A new instance of ResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
Returns a new instance of ResourceHistory.
7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 |
# File 'lib/models/porcelain.rb', line 7681 def initialize( activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @resource = resource == nil ? nil : resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.
7673 7674 7675 |
# File 'lib/models/porcelain.rb', line 7673 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
7675 7676 7677 |
# File 'lib/models/porcelain.rb', line 7675 def deleted_at @deleted_at end |
#resource ⇒ Object
The complete Resource state at this time.
7677 7678 7679 |
# File 'lib/models/porcelain.rb', line 7677 def resource @resource end |
#timestamp ⇒ Object
The time at which the Resource state was recorded.
7679 7680 7681 |
# File 'lib/models/porcelain.rb', line 7679 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7693 7694 7695 7696 7697 7698 7699 |
# File 'lib/models/porcelain.rb', line 7693 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |