Class: SDM::ResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory

Returns a new instance of ResourceHistory.



7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
# File 'lib/models/porcelain.rb', line 7673

def initialize(
  activity_id: nil,
  deleted_at: nil,
  resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @resource = resource == nil ? nil : resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.



7665
7666
7667
# File 'lib/models/porcelain.rb', line 7665

def activity_id
  @activity_id
end

#deleted_atObject

If this Resource was deleted, the time it was deleted.



7667
7668
7669
# File 'lib/models/porcelain.rb', line 7667

def deleted_at
  @deleted_at
end

#resourceObject

The complete Resource state at this time.



7669
7670
7671
# File 'lib/models/porcelain.rb', line 7669

def resource
  @resource
end

#timestampObject

The time at which the Resource state was recorded.



7671
7672
7673
# File 'lib/models/porcelain.rb', line 7671

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7685
7686
7687
7688
7689
7690
7691
# File 'lib/models/porcelain.rb', line 7685

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end