Class: SDM::ResourceHistory
- Inherits:
-
Object
- Object
- SDM::ResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource.
-
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
-
#resource ⇒ Object
The complete Resource state at this time.
-
#timestamp ⇒ Object
The time at which the Resource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
constructor
A new instance of ResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
Returns a new instance of ResourceHistory.
6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 |
# File 'lib/models/porcelain.rb', line 6535 def initialize( activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @resource = resource == nil ? nil : resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.
6527 6528 6529 |
# File 'lib/models/porcelain.rb', line 6527 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
6529 6530 6531 |
# File 'lib/models/porcelain.rb', line 6529 def deleted_at @deleted_at end |
#resource ⇒ Object
The complete Resource state at this time.
6531 6532 6533 |
# File 'lib/models/porcelain.rb', line 6531 def resource @resource end |
#timestamp ⇒ Object
The time at which the Resource state was recorded.
6533 6534 6535 |
# File 'lib/models/porcelain.rb', line 6533 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6547 6548 6549 6550 6551 6552 6553 |
# File 'lib/models/porcelain.rb', line 6547 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |