Class: SDM::ResourceHistory
- Inherits:
-
Object
- Object
- SDM::ResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
ResourceHistory records the state of a Resource at a given point in time, where every change (create, update and delete) to a Resource produces an ResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource.
-
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
-
#resource ⇒ Object
The complete Resource state at this time.
-
#timestamp ⇒ Object
The time at which the Resource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
constructor
A new instance of ResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil) ⇒ ResourceHistory
Returns a new instance of ResourceHistory.
15354 15355 15356 15357 15358 15359 15360 15361 15362 15363 15364 |
# File 'lib/models/porcelain.rb', line 15354 def initialize( activity_id: nil, deleted_at: nil, resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @resource = resource == nil ? nil : resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Resource. May be empty for some system-initiated updates.
15346 15347 15348 |
# File 'lib/models/porcelain.rb', line 15346 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Resource was deleted, the time it was deleted.
15348 15349 15350 |
# File 'lib/models/porcelain.rb', line 15348 def deleted_at @deleted_at end |
#resource ⇒ Object
The complete Resource state at this time.
15350 15351 15352 |
# File 'lib/models/porcelain.rb', line 15350 def resource @resource end |
#timestamp ⇒ Object
The time at which the Resource state was recorded.
15352 15353 15354 |
# File 'lib/models/porcelain.rb', line 15352 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15366 15367 15368 15369 15370 15371 15372 |
# File 'lib/models/porcelain.rb', line 15366 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |