Class: SDM::Role
- Inherits:
-
Object
- Object
- SDM::Role
- Defined in:
- lib/models/porcelain.rb
Overview
A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
-
#id ⇒ Object
Unique identifier of the Role.
-
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g.
-
#name ⇒ Object
Unique human-readable name of the Role.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
constructor
A new instance of Role.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
Returns a new instance of Role.
16189 16190 16191 16192 16193 16194 16195 16196 16197 16198 16199 16200 16201 |
# File 'lib/models/porcelain.rb', line 16189 def initialize( access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @id = id == nil ? "" : id @managed_by = managed_by == nil ? "" : managed_by @name = name == nil ? "" : name @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
16179 16180 16181 |
# File 'lib/models/porcelain.rb', line 16179 def access_rules @access_rules end |
#id ⇒ Object
Unique identifier of the Role.
16181 16182 16183 |
# File 'lib/models/porcelain.rb', line 16181 def id @id end |
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.
16183 16184 16185 |
# File 'lib/models/porcelain.rb', line 16183 def managed_by @managed_by end |
#name ⇒ Object
Unique human-readable name of the Role.
16185 16186 16187 |
# File 'lib/models/porcelain.rb', line 16185 def name @name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16187 16188 16189 |
# File 'lib/models/porcelain.rb', line 16187 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16203 16204 16205 16206 16207 16208 16209 |
# File 'lib/models/porcelain.rb', line 16203 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |