Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
# File 'lib/models/porcelain.rb', line 16061

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



16051
16052
16053
# File 'lib/models/porcelain.rb', line 16051

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



16053
16054
16055
# File 'lib/models/porcelain.rb', line 16053

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



16055
16056
16057
# File 'lib/models/porcelain.rb', line 16055

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



16057
16058
16059
# File 'lib/models/porcelain.rb', line 16057

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



16059
16060
16061
# File 'lib/models/porcelain.rb', line 16059

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16075
16076
16077
16078
16079
16080
16081
# File 'lib/models/porcelain.rb', line 16075

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end