Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



15834
15835
15836
15837
15838
15839
15840
15841
15842
15843
15844
15845
15846
# File 'lib/models/porcelain.rb', line 15834

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



15824
15825
15826
# File 'lib/models/porcelain.rb', line 15824

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



15826
15827
15828
# File 'lib/models/porcelain.rb', line 15826

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



15828
15829
15830
# File 'lib/models/porcelain.rb', line 15828

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



15830
15831
15832
# File 'lib/models/porcelain.rb', line 15830

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



15832
15833
15834
# File 'lib/models/porcelain.rb', line 15832

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15848
15849
15850
15851
15852
15853
15854
# File 'lib/models/porcelain.rb', line 15848

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end