Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



15719
15720
15721
15722
15723
15724
15725
15726
15727
15728
15729
15730
15731
# File 'lib/models/porcelain.rb', line 15719

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



15709
15710
15711
# File 'lib/models/porcelain.rb', line 15709

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



15711
15712
15713
# File 'lib/models/porcelain.rb', line 15711

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



15713
15714
15715
# File 'lib/models/porcelain.rb', line 15713

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



15715
15716
15717
# File 'lib/models/porcelain.rb', line 15715

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



15717
15718
15719
# File 'lib/models/porcelain.rb', line 15717

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15733
15734
15735
15736
15737
15738
15739
# File 'lib/models/porcelain.rb', line 15733

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end