Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



15346
15347
15348
15349
15350
15351
15352
15353
15354
15355
15356
15357
15358
# File 'lib/models/porcelain.rb', line 15346

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



15336
15337
15338
# File 'lib/models/porcelain.rb', line 15336

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



15338
15339
15340
# File 'lib/models/porcelain.rb', line 15338

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



15340
15341
15342
# File 'lib/models/porcelain.rb', line 15340

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



15342
15343
15344
# File 'lib/models/porcelain.rb', line 15342

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



15344
15345
15346
# File 'lib/models/porcelain.rb', line 15344

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15360
15361
15362
15363
15364
15365
15366
# File 'lib/models/porcelain.rb', line 15360

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end