Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



15330
15331
15332
15333
15334
15335
15336
15337
15338
15339
15340
15341
15342
# File 'lib/models/porcelain.rb', line 15330

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



15320
15321
15322
# File 'lib/models/porcelain.rb', line 15320

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



15322
15323
15324
# File 'lib/models/porcelain.rb', line 15322

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



15324
15325
15326
# File 'lib/models/porcelain.rb', line 15324

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



15326
15327
15328
# File 'lib/models/porcelain.rb', line 15326

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



15328
15329
15330
# File 'lib/models/porcelain.rb', line 15328

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15344
15345
15346
15347
15348
15349
15350
# File 'lib/models/porcelain.rb', line 15344

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end