Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



15044
15045
15046
15047
15048
15049
15050
15051
15052
15053
15054
15055
15056
# File 'lib/models/porcelain.rb', line 15044

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



15034
15035
15036
# File 'lib/models/porcelain.rb', line 15034

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



15036
15037
15038
# File 'lib/models/porcelain.rb', line 15036

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



15038
15039
15040
# File 'lib/models/porcelain.rb', line 15038

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



15040
15041
15042
# File 'lib/models/porcelain.rb', line 15040

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



15042
15043
15044
# File 'lib/models/porcelain.rb', line 15042

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15058
15059
15060
15061
15062
15063
15064
# File 'lib/models/porcelain.rb', line 15058

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end