Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



14158
14159
14160
14161
14162
14163
14164
14165
14166
14167
14168
14169
14170
# File 'lib/models/porcelain.rb', line 14158

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



14148
14149
14150
# File 'lib/models/porcelain.rb', line 14148

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



14150
14151
14152
# File 'lib/models/porcelain.rb', line 14150

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



14152
14153
14154
# File 'lib/models/porcelain.rb', line 14152

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



14154
14155
14156
# File 'lib/models/porcelain.rb', line 14154

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



14156
14157
14158
# File 'lib/models/porcelain.rb', line 14156

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14172
14173
14174
14175
14176
14177
14178
# File 'lib/models/porcelain.rb', line 14172

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end