Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



12956
12957
12958
12959
12960
12961
12962
12963
12964
12965
12966
12967
12968
# File 'lib/models/porcelain.rb', line 12956

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



12946
12947
12948
# File 'lib/models/porcelain.rb', line 12946

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



12948
12949
12950
# File 'lib/models/porcelain.rb', line 12948

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



12950
12951
12952
# File 'lib/models/porcelain.rb', line 12950

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



12952
12953
12954
# File 'lib/models/porcelain.rb', line 12952

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



12954
12955
12956
# File 'lib/models/porcelain.rb', line 12954

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12970
12971
12972
12973
12974
12975
12976
# File 'lib/models/porcelain.rb', line 12970

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end