Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



12878
12879
12880
12881
12882
12883
12884
12885
12886
12887
12888
12889
12890
# File 'lib/models/porcelain.rb', line 12878

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



12868
12869
12870
# File 'lib/models/porcelain.rb', line 12868

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



12870
12871
12872
# File 'lib/models/porcelain.rb', line 12870

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



12872
12873
12874
# File 'lib/models/porcelain.rb', line 12872

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



12874
12875
12876
# File 'lib/models/porcelain.rb', line 12874

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



12876
12877
12878
# File 'lib/models/porcelain.rb', line 12876

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12892
12893
12894
12895
12896
12897
12898
# File 'lib/models/porcelain.rb', line 12892

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end