Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



12695
12696
12697
12698
12699
12700
12701
12702
12703
12704
12705
12706
12707
# File 'lib/models/porcelain.rb', line 12695

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



12685
12686
12687
# File 'lib/models/porcelain.rb', line 12685

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



12687
12688
12689
# File 'lib/models/porcelain.rb', line 12687

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



12689
12690
12691
# File 'lib/models/porcelain.rb', line 12689

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



12691
12692
12693
# File 'lib/models/porcelain.rb', line 12691

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



12693
12694
12695
# File 'lib/models/porcelain.rb', line 12693

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12709
12710
12711
12712
12713
12714
12715
# File 'lib/models/porcelain.rb', line 12709

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end