Class: SDM::Role
- Inherits:
-
Object
- Object
- SDM::Role
- Defined in:
- lib/models/porcelain.rb
Overview
A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
-
#id ⇒ Object
Unique identifier of the Role.
-
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g.
-
#name ⇒ Object
Unique human-readable name of the Role.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
constructor
A new instance of Role.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
Returns a new instance of Role.
12616 12617 12618 12619 12620 12621 12622 12623 12624 12625 12626 12627 12628 |
# File 'lib/models/porcelain.rb', line 12616 def initialize( access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @id = id == nil ? "" : id @managed_by = managed_by == nil ? "" : managed_by @name = name == nil ? "" : name @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
12606 12607 12608 |
# File 'lib/models/porcelain.rb', line 12606 def access_rules @access_rules end |
#id ⇒ Object
Unique identifier of the Role.
12608 12609 12610 |
# File 'lib/models/porcelain.rb', line 12608 def id @id end |
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.
12610 12611 12612 |
# File 'lib/models/porcelain.rb', line 12610 def managed_by @managed_by end |
#name ⇒ Object
Unique human-readable name of the Role.
12612 12613 12614 |
# File 'lib/models/porcelain.rb', line 12612 def name @name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
12614 12615 12616 |
# File 'lib/models/porcelain.rb', line 12614 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12630 12631 12632 12633 12634 12635 12636 |
# File 'lib/models/porcelain.rb', line 12630 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |