Class: SDM::Role
- Inherits:
-
Object
- Object
- SDM::Role
- Defined in:
- lib/models/porcelain.rb
Overview
A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
-
#id ⇒ Object
Unique identifier of the Role.
-
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g.
-
#name ⇒ Object
Unique human-readable name of the Role.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
constructor
A new instance of Role.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
Returns a new instance of Role.
11624 11625 11626 11627 11628 11629 11630 11631 11632 11633 11634 11635 11636 |
# File 'lib/models/porcelain.rb', line 11624 def initialize( access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @id = id == nil ? "" : id @managed_by = managed_by == nil ? "" : managed_by @name = name == nil ? "" : name @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
11614 11615 11616 |
# File 'lib/models/porcelain.rb', line 11614 def access_rules @access_rules end |
#id ⇒ Object
Unique identifier of the Role.
11616 11617 11618 |
# File 'lib/models/porcelain.rb', line 11616 def id @id end |
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.
11618 11619 11620 |
# File 'lib/models/porcelain.rb', line 11618 def managed_by @managed_by end |
#name ⇒ Object
Unique human-readable name of the Role.
11620 11621 11622 |
# File 'lib/models/porcelain.rb', line 11620 def name @name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11622 11623 11624 |
# File 'lib/models/porcelain.rb', line 11622 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11638 11639 11640 11641 11642 11643 11644 |
# File 'lib/models/porcelain.rb', line 11638 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |