Class: SDM::Role
- Inherits:
-
Object
- Object
- SDM::Role
- Defined in:
- lib/models/porcelain.rb
Overview
A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
-
#id ⇒ Object
Unique identifier of the Role.
-
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g.
-
#name ⇒ Object
Unique human-readable name of the Role.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
constructor
A new instance of Role.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
Returns a new instance of Role.
11549 11550 11551 11552 11553 11554 11555 11556 11557 11558 11559 11560 11561 |
# File 'lib/models/porcelain.rb', line 11549 def initialize( access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @id = id == nil ? "" : id @managed_by = managed_by == nil ? "" : managed_by @name = name == nil ? "" : name @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
11539 11540 11541 |
# File 'lib/models/porcelain.rb', line 11539 def access_rules @access_rules end |
#id ⇒ Object
Unique identifier of the Role.
11541 11542 11543 |
# File 'lib/models/porcelain.rb', line 11541 def id @id end |
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.
11543 11544 11545 |
# File 'lib/models/porcelain.rb', line 11543 def managed_by @managed_by end |
#name ⇒ Object
Unique human-readable name of the Role.
11545 11546 11547 |
# File 'lib/models/porcelain.rb', line 11545 def name @name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11547 11548 11549 |
# File 'lib/models/porcelain.rb', line 11547 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/models/porcelain.rb', line 11563 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |