Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



11373
11374
11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
# File 'lib/models/porcelain.rb', line 11373

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



11363
11364
11365
# File 'lib/models/porcelain.rb', line 11363

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



11365
11366
11367
# File 'lib/models/porcelain.rb', line 11365

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



11367
11368
11369
# File 'lib/models/porcelain.rb', line 11367

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



11369
11370
11371
# File 'lib/models/porcelain.rb', line 11369

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



11371
11372
11373
# File 'lib/models/porcelain.rb', line 11371

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11387
11388
11389
11390
11391
11392
11393
# File 'lib/models/porcelain.rb', line 11387

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end