Class: SDM::Role
- Inherits:
-
Object
- Object
- SDM::Role
- Defined in:
- lib/models/porcelain.rb
Overview
A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
-
#id ⇒ Object
Unique identifier of the Role.
-
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g.
-
#name ⇒ Object
Unique human-readable name of the Role.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
constructor
A new instance of Role.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
Returns a new instance of Role.
11302 11303 11304 11305 11306 11307 11308 11309 11310 11311 11312 11313 11314 |
# File 'lib/models/porcelain.rb', line 11302 def initialize( access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @id = id == nil ? "" : id @managed_by = managed_by == nil ? "" : managed_by @name = name == nil ? "" : name @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
11292 11293 11294 |
# File 'lib/models/porcelain.rb', line 11292 def access_rules @access_rules end |
#id ⇒ Object
Unique identifier of the Role.
11294 11295 11296 |
# File 'lib/models/porcelain.rb', line 11294 def id @id end |
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.
11296 11297 11298 |
# File 'lib/models/porcelain.rb', line 11296 def managed_by @managed_by end |
#name ⇒ Object
Unique human-readable name of the Role.
11298 11299 11300 |
# File 'lib/models/porcelain.rb', line 11298 def name @name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
11300 11301 11302 |
# File 'lib/models/porcelain.rb', line 11300 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11316 11317 11318 11319 11320 11321 11322 |
# File 'lib/models/porcelain.rb', line 11316 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |