Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



11226
11227
11228
11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
# File 'lib/models/porcelain.rb', line 11226

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



11216
11217
11218
# File 'lib/models/porcelain.rb', line 11216

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



11218
11219
11220
# File 'lib/models/porcelain.rb', line 11218

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



11220
11221
11222
# File 'lib/models/porcelain.rb', line 11220

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



11222
11223
11224
# File 'lib/models/porcelain.rb', line 11222

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



11224
11225
11226
# File 'lib/models/porcelain.rb', line 11224

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11240
11241
11242
11243
11244
11245
11246
# File 'lib/models/porcelain.rb', line 11240

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end