Class: SDM::Role
- Inherits:
-
Object
- Object
- SDM::Role
- Defined in:
- lib/models/porcelain.rb
Overview
A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
-
#id ⇒ Object
Unique identifier of the Role.
-
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g.
-
#name ⇒ Object
Unique human-readable name of the Role.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
constructor
A new instance of Role.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
Returns a new instance of Role.
10533 10534 10535 10536 10537 10538 10539 10540 10541 10542 10543 10544 10545 |
# File 'lib/models/porcelain.rb', line 10533 def initialize( access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @id = id == nil ? "" : id @managed_by = managed_by == nil ? "" : managed_by @name = name == nil ? "" : name @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
10523 10524 10525 |
# File 'lib/models/porcelain.rb', line 10523 def access_rules @access_rules end |
#id ⇒ Object
Unique identifier of the Role.
10525 10526 10527 |
# File 'lib/models/porcelain.rb', line 10525 def id @id end |
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.
10527 10528 10529 |
# File 'lib/models/porcelain.rb', line 10527 def managed_by @managed_by end |
#name ⇒ Object
Unique human-readable name of the Role.
10529 10530 10531 |
# File 'lib/models/porcelain.rb', line 10529 def name @name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10531 10532 10533 |
# File 'lib/models/porcelain.rb', line 10531 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10547 10548 10549 10550 10551 10552 10553 |
# File 'lib/models/porcelain.rb', line 10547 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |