Class: SDM::Role
- Inherits:
-
Object
- Object
- SDM::Role
- Defined in:
- lib/models/porcelain.rb
Overview
A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.
Instance Attribute Summary collapse
-
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
-
#id ⇒ Object
Unique identifier of the Role.
-
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g.
-
#name ⇒ Object
Unique human-readable name of the Role.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
Instance Method Summary collapse
-
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
constructor
A new instance of Role.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role
Returns a new instance of Role.
10462 10463 10464 10465 10466 10467 10468 10469 10470 10471 10472 10473 10474 |
# File 'lib/models/porcelain.rb', line 10462 def initialize( access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil ) @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules @id = id == nil ? "" : id @managed_by = managed_by == nil ? "" : managed_by @name = name == nil ? "" : name @tags = == nil ? SDM::() : end |
Instance Attribute Details
#access_rules ⇒ Object
AccessRules is a list of access rules defining the resources this Role has access to.
10452 10453 10454 |
# File 'lib/models/porcelain.rb', line 10452 def access_rules @access_rules end |
#id ⇒ Object
Unique identifier of the Role.
10454 10455 10456 |
# File 'lib/models/porcelain.rb', line 10454 def id @id end |
#managed_by ⇒ Object
Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.
10456 10457 10458 |
# File 'lib/models/porcelain.rb', line 10456 def managed_by @managed_by end |
#name ⇒ Object
Unique human-readable name of the Role.
10458 10459 10460 |
# File 'lib/models/porcelain.rb', line 10458 def name @name end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10460 10461 10462 |
# File 'lib/models/porcelain.rb', line 10460 def @tags end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10476 10477 10478 10479 10480 10481 10482 |
# File 'lib/models/porcelain.rb', line 10476 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |