Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



8462
8463
8464
8465
8466
8467
8468
8469
8470
8471
8472
8473
8474
# File 'lib/models/porcelain.rb', line 8462

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



8452
8453
8454
# File 'lib/models/porcelain.rb', line 8452

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



8454
8455
8456
# File 'lib/models/porcelain.rb', line 8454

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



8456
8457
8458
# File 'lib/models/porcelain.rb', line 8456

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



8458
8459
8460
# File 'lib/models/porcelain.rb', line 8458

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



8460
8461
8462
# File 'lib/models/porcelain.rb', line 8460

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8476
8477
8478
8479
8480
8481
8482
# File 'lib/models/porcelain.rb', line 8476

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end