Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
8115
8116
# File 'lib/models/porcelain.rb', line 8104

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



8094
8095
8096
# File 'lib/models/porcelain.rb', line 8094

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



8096
8097
8098
# File 'lib/models/porcelain.rb', line 8096

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



8098
8099
8100
# File 'lib/models/porcelain.rb', line 8098

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



8100
8101
8102
# File 'lib/models/porcelain.rb', line 8100

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



8102
8103
8104
# File 'lib/models/porcelain.rb', line 8102

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8118
8119
8120
8121
8122
8123
8124
# File 'lib/models/porcelain.rb', line 8118

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end