Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
# File 'lib/models/porcelain.rb', line 7910

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



7900
7901
7902
# File 'lib/models/porcelain.rb', line 7900

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



7902
7903
7904
# File 'lib/models/porcelain.rb', line 7902

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



7904
7905
7906
# File 'lib/models/porcelain.rb', line 7904

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



7906
7907
7908
# File 'lib/models/porcelain.rb', line 7906

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



7908
7909
7910
# File 'lib/models/porcelain.rb', line 7908

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7924
7925
7926
7927
7928
7929
7930
# File 'lib/models/porcelain.rb', line 7924

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end