Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



7319
7320
7321
7322
7323
7324
7325
7326
7327
7328
7329
7330
7331
# File 'lib/models/porcelain.rb', line 7319

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



7309
7310
7311
# File 'lib/models/porcelain.rb', line 7309

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



7311
7312
7313
# File 'lib/models/porcelain.rb', line 7311

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



7313
7314
7315
# File 'lib/models/porcelain.rb', line 7313

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



7315
7316
7317
# File 'lib/models/porcelain.rb', line 7315

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



7317
7318
7319
# File 'lib/models/porcelain.rb', line 7317

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7333
7334
7335
7336
7337
7338
7339
# File 'lib/models/porcelain.rb', line 7333

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end