Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



7320
7321
7322
7323
7324
7325
7326
7327
7328
7329
7330
7331
7332
# File 'lib/models/porcelain.rb', line 7320

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



7310
7311
7312
# File 'lib/models/porcelain.rb', line 7310

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



7312
7313
7314
# File 'lib/models/porcelain.rb', line 7312

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



7314
7315
7316
# File 'lib/models/porcelain.rb', line 7314

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



7316
7317
7318
# File 'lib/models/porcelain.rb', line 7316

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



7318
7319
7320
# File 'lib/models/porcelain.rb', line 7318

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7334
7335
7336
7337
7338
7339
7340
# File 'lib/models/porcelain.rb', line 7334

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end