Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
# File 'lib/models/porcelain.rb', line 7081

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



7071
7072
7073
# File 'lib/models/porcelain.rb', line 7071

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



7073
7074
7075
# File 'lib/models/porcelain.rb', line 7073

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



7075
7076
7077
# File 'lib/models/porcelain.rb', line 7075

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



7077
7078
7079
# File 'lib/models/porcelain.rb', line 7077

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



7079
7080
7081
# File 'lib/models/porcelain.rb', line 7079

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7095
7096
7097
7098
7099
7100
7101
# File 'lib/models/porcelain.rb', line 7095

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end