Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
# File 'lib/models/porcelain.rb', line 7028

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



7018
7019
7020
# File 'lib/models/porcelain.rb', line 7018

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



7020
7021
7022
# File 'lib/models/porcelain.rb', line 7020

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



7022
7023
7024
# File 'lib/models/porcelain.rb', line 7022

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



7024
7025
7026
# File 'lib/models/porcelain.rb', line 7024

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



7026
7027
7028
# File 'lib/models/porcelain.rb', line 7026

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7042
7043
7044
7045
7046
7047
7048
# File 'lib/models/porcelain.rb', line 7042

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end