Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



6954
6955
6956
6957
6958
6959
6960
6961
6962
6963
6964
6965
6966
# File 'lib/models/porcelain.rb', line 6954

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



6944
6945
6946
# File 'lib/models/porcelain.rb', line 6944

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



6946
6947
6948
# File 'lib/models/porcelain.rb', line 6946

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



6948
6949
6950
# File 'lib/models/porcelain.rb', line 6948

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



6950
6951
6952
# File 'lib/models/porcelain.rb', line 6950

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



6952
6953
6954
# File 'lib/models/porcelain.rb', line 6952

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6968
6969
6970
6971
6972
6973
6974
# File 'lib/models/porcelain.rb', line 6968

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end