Class: SDM::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

A Role has a list of access rules which determine which Resources the members of the Role have access to. An Account can be a member of multiple Roles via AccountAttachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_rules: nil, id: nil, managed_by: nil, name: nil, tags: nil) ⇒ Role

Returns a new instance of Role.



5822
5823
5824
5825
5826
5827
5828
5829
5830
5831
5832
5833
5834
# File 'lib/models/porcelain.rb', line 5822

def initialize(
  access_rules: nil,
  id: nil,
  managed_by: nil,
  name: nil,
  tags: nil
)
  @access_rules = access_rules == nil ? SDM::_porcelain_zero_value_access_rules() : access_rules
  @id = id == nil ? "" : id
  @managed_by = managed_by == nil ? "" : managed_by
  @name = name == nil ? "" : name
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
end

Instance Attribute Details

#access_rulesObject

AccessRules is a list of access rules defining the resources this Role has access to.



5812
5813
5814
# File 'lib/models/porcelain.rb', line 5812

def access_rules
  @access_rules
end

#idObject

Unique identifier of the Role.



5814
5815
5816
# File 'lib/models/porcelain.rb', line 5814

def id
  @id
end

#managed_byObject

Managed By is a read only field for what service manages this role, e.g. StrongDM, Okta, Azure.



5816
5817
5818
# File 'lib/models/porcelain.rb', line 5816

def managed_by
  @managed_by
end

#nameObject

Unique human-readable name of the Role.



5818
5819
5820
# File 'lib/models/porcelain.rb', line 5818

def name
  @name
end

#tagsObject

Tags is a map of key, value pairs.



5820
5821
5822
# File 'lib/models/porcelain.rb', line 5820

def tags
  @tags
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5836
5837
5838
5839
5840
5841
5842
# File 'lib/models/porcelain.rb', line 5836

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end