Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



16259
16260
16261
16262
16263
16264
16265
16266
16267
16268
16269
# File 'lib/models/porcelain.rb', line 16259

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



16251
16252
16253
# File 'lib/models/porcelain.rb', line 16251

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



16253
16254
16255
# File 'lib/models/porcelain.rb', line 16253

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



16255
16256
16257
# File 'lib/models/porcelain.rb', line 16255

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



16257
16258
16259
# File 'lib/models/porcelain.rb', line 16257

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16271
16272
16273
16274
16275
16276
16277
# File 'lib/models/porcelain.rb', line 16271

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end