Class: SDM::RoleHistory
- Inherits:
-
Object
- Object
- SDM::RoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role.
-
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
-
#role ⇒ Object
The complete Role state at this time.
-
#timestamp ⇒ Object
The time at which the Role state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
constructor
A new instance of RoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
Returns a new instance of RoleHistory.
15953 15954 15955 15956 15957 15958 15959 15960 15961 15962 15963 |
# File 'lib/models/porcelain.rb', line 15953 def initialize( activity_id: nil, deleted_at: nil, role: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role = role == nil ? nil : role @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.
15945 15946 15947 |
# File 'lib/models/porcelain.rb', line 15945 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
15947 15948 15949 |
# File 'lib/models/porcelain.rb', line 15947 def deleted_at @deleted_at end |
#role ⇒ Object
The complete Role state at this time.
15949 15950 15951 |
# File 'lib/models/porcelain.rb', line 15949 def role @role end |
#timestamp ⇒ Object
The time at which the Role state was recorded.
15951 15952 15953 |
# File 'lib/models/porcelain.rb', line 15951 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15965 15966 15967 15968 15969 15970 15971 |
# File 'lib/models/porcelain.rb', line 15965 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |