Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



15837
15838
15839
15840
15841
15842
15843
15844
15845
15846
15847
# File 'lib/models/porcelain.rb', line 15837

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



15829
15830
15831
# File 'lib/models/porcelain.rb', line 15829

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



15831
15832
15833
# File 'lib/models/porcelain.rb', line 15831

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



15833
15834
15835
# File 'lib/models/porcelain.rb', line 15833

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



15835
15836
15837
# File 'lib/models/porcelain.rb', line 15835

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15849
15850
15851
15852
15853
15854
15855
# File 'lib/models/porcelain.rb', line 15849

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end