Class: SDM::RoleHistory
- Inherits:
-
Object
- Object
- SDM::RoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role.
-
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
-
#role ⇒ Object
The complete Role state at this time.
-
#timestamp ⇒ Object
The time at which the Role state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
constructor
A new instance of RoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
Returns a new instance of RoleHistory.
15448 15449 15450 15451 15452 15453 15454 15455 15456 15457 15458 |
# File 'lib/models/porcelain.rb', line 15448 def initialize( activity_id: nil, deleted_at: nil, role: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role = role == nil ? nil : role @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.
15440 15441 15442 |
# File 'lib/models/porcelain.rb', line 15440 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
15442 15443 15444 |
# File 'lib/models/porcelain.rb', line 15442 def deleted_at @deleted_at end |
#role ⇒ Object
The complete Role state at this time.
15444 15445 15446 |
# File 'lib/models/porcelain.rb', line 15444 def role @role end |
#timestamp ⇒ Object
The time at which the Role state was recorded.
15446 15447 15448 |
# File 'lib/models/porcelain.rb', line 15446 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15460 15461 15462 15463 15464 15465 15466 |
# File 'lib/models/porcelain.rb', line 15460 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |