Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
# File 'lib/models/porcelain.rb', line 12802

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



12794
12795
12796
# File 'lib/models/porcelain.rb', line 12794

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



12796
12797
12798
# File 'lib/models/porcelain.rb', line 12796

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



12798
12799
12800
# File 'lib/models/porcelain.rb', line 12798

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



12800
12801
12802
# File 'lib/models/porcelain.rb', line 12800

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12814
12815
12816
12817
12818
12819
12820
# File 'lib/models/porcelain.rb', line 12814

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end