Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



12658
12659
12660
12661
12662
12663
12664
12665
12666
12667
12668
# File 'lib/models/porcelain.rb', line 12658

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



12650
12651
12652
# File 'lib/models/porcelain.rb', line 12650

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



12652
12653
12654
# File 'lib/models/porcelain.rb', line 12652

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



12654
12655
12656
# File 'lib/models/porcelain.rb', line 12654

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



12656
12657
12658
# File 'lib/models/porcelain.rb', line 12656

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12670
12671
12672
12673
12674
12675
12676
# File 'lib/models/porcelain.rb', line 12670

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end