Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



11659
11660
11661
11662
11663
11664
11665
11666
11667
11668
11669
# File 'lib/models/porcelain.rb', line 11659

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



11651
11652
11653
# File 'lib/models/porcelain.rb', line 11651

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



11653
11654
11655
# File 'lib/models/porcelain.rb', line 11653

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



11655
11656
11657
# File 'lib/models/porcelain.rb', line 11655

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



11657
11658
11659
# File 'lib/models/porcelain.rb', line 11657

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11671
11672
11673
11674
11675
11676
11677
# File 'lib/models/porcelain.rb', line 11671

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end