Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



11491
11492
11493
11494
11495
11496
11497
11498
11499
11500
11501
# File 'lib/models/porcelain.rb', line 11491

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



11483
11484
11485
# File 'lib/models/porcelain.rb', line 11483

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



11485
11486
11487
# File 'lib/models/porcelain.rb', line 11485

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



11487
11488
11489
# File 'lib/models/porcelain.rb', line 11487

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



11489
11490
11491
# File 'lib/models/porcelain.rb', line 11489

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11503
11504
11505
11506
11507
11508
11509
# File 'lib/models/porcelain.rb', line 11503

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end