Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



10651
10652
10653
10654
10655
10656
10657
10658
10659
10660
10661
# File 'lib/models/porcelain.rb', line 10651

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



10643
10644
10645
# File 'lib/models/porcelain.rb', line 10643

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



10645
10646
10647
# File 'lib/models/porcelain.rb', line 10645

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



10647
10648
10649
# File 'lib/models/porcelain.rb', line 10647

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



10649
10650
10651
# File 'lib/models/porcelain.rb', line 10649

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10663
10664
10665
10666
10667
10668
10669
# File 'lib/models/porcelain.rb', line 10663

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end