Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
# File 'lib/models/porcelain.rb', line 10038

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



10030
10031
10032
# File 'lib/models/porcelain.rb', line 10030

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



10032
10033
10034
# File 'lib/models/porcelain.rb', line 10032

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



10034
10035
10036
# File 'lib/models/porcelain.rb', line 10034

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



10036
10037
10038
# File 'lib/models/porcelain.rb', line 10036

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10050
10051
10052
10053
10054
10055
10056
# File 'lib/models/porcelain.rb', line 10050

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end