Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



8028
8029
8030
8031
8032
8033
8034
8035
8036
8037
8038
# File 'lib/models/porcelain.rb', line 8028

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



8020
8021
8022
# File 'lib/models/porcelain.rb', line 8020

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



8022
8023
8024
# File 'lib/models/porcelain.rb', line 8022

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



8024
8025
8026
# File 'lib/models/porcelain.rb', line 8024

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



8026
8027
8028
# File 'lib/models/porcelain.rb', line 8026

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8040
8041
8042
8043
8044
8045
8046
# File 'lib/models/porcelain.rb', line 8040

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end