Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
# File 'lib/models/porcelain.rb', line 7864

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



7856
7857
7858
# File 'lib/models/porcelain.rb', line 7856

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



7858
7859
7860
# File 'lib/models/porcelain.rb', line 7858

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



7860
7861
7862
# File 'lib/models/porcelain.rb', line 7860

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



7862
7863
7864
# File 'lib/models/porcelain.rb', line 7862

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7876
7877
7878
7879
7880
7881
7882
# File 'lib/models/porcelain.rb', line 7876

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end