Class: SDM::RoleHistory
- Inherits:
-
Object
- Object
- SDM::RoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role.
-
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
-
#role ⇒ Object
The complete Role state at this time.
-
#timestamp ⇒ Object
The time at which the Role state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
constructor
A new instance of RoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
Returns a new instance of RoleHistory.
7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 |
# File 'lib/models/porcelain.rb', line 7856 def initialize( activity_id: nil, deleted_at: nil, role: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role = role == nil ? nil : role @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.
7848 7849 7850 |
# File 'lib/models/porcelain.rb', line 7848 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
7850 7851 7852 |
# File 'lib/models/porcelain.rb', line 7850 def deleted_at @deleted_at end |
#role ⇒ Object
The complete Role state at this time.
7852 7853 7854 |
# File 'lib/models/porcelain.rb', line 7852 def role @role end |
#timestamp ⇒ Object
The time at which the Role state was recorded.
7854 7855 7856 |
# File 'lib/models/porcelain.rb', line 7854 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7868 7869 7870 7871 7872 7873 7874 |
# File 'lib/models/porcelain.rb', line 7868 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |