Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
# File 'lib/models/porcelain.rb', line 7199

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



7191
7192
7193
# File 'lib/models/porcelain.rb', line 7191

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



7193
7194
7195
# File 'lib/models/porcelain.rb', line 7193

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



7195
7196
7197
# File 'lib/models/porcelain.rb', line 7195

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



7197
7198
7199
# File 'lib/models/porcelain.rb', line 7197

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7211
7212
7213
7214
7215
7216
7217
# File 'lib/models/porcelain.rb', line 7211

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end