Class: SDM::RoleHistory
- Inherits:
-
Object
- Object
- SDM::RoleHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role.
-
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
-
#role ⇒ Object
The complete Role state at this time.
-
#timestamp ⇒ Object
The time at which the Role state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
constructor
A new instance of RoleHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory
Returns a new instance of RoleHistory.
7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 |
# File 'lib/models/porcelain.rb', line 7146 def initialize( activity_id: nil, deleted_at: nil, role: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role = role == nil ? nil : role @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.
7138 7139 7140 |
# File 'lib/models/porcelain.rb', line 7138 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this Role was deleted, the time it was deleted.
7140 7141 7142 |
# File 'lib/models/porcelain.rb', line 7140 def deleted_at @deleted_at end |
#role ⇒ Object
The complete Role state at this time.
7142 7143 7144 |
# File 'lib/models/porcelain.rb', line 7142 def role @role end |
#timestamp ⇒ Object
The time at which the Role state was recorded.
7144 7145 7146 |
# File 'lib/models/porcelain.rb', line 7144 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7158 7159 7160 7161 7162 7163 7164 |
# File 'lib/models/porcelain.rb', line 7158 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |