Class: SDM::RoleHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleHistory records the state of a Role at a given point in time, where every change (create, update and delete) to a Role produces an RoleHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role: nil, timestamp: nil) ⇒ RoleHistory

Returns a new instance of RoleHistory.



6718
6719
6720
6721
6722
6723
6724
6725
6726
6727
6728
# File 'lib/models/porcelain.rb', line 6718

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role = role == nil ? nil : role
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the Role. May be empty for some system-initiated updates.



6710
6711
6712
# File 'lib/models/porcelain.rb', line 6710

def activity_id
  @activity_id
end

#deleted_atObject

If this Role was deleted, the time it was deleted.



6712
6713
6714
# File 'lib/models/porcelain.rb', line 6712

def deleted_at
  @deleted_at
end

#roleObject

The complete Role state at this time.



6714
6715
6716
# File 'lib/models/porcelain.rb', line 6714

def role
  @role
end

#timestampObject

The time at which the Role state was recorded.



6716
6717
6718
# File 'lib/models/porcelain.rb', line 6716

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6730
6731
6732
6733
6734
6735
6736
# File 'lib/models/porcelain.rb', line 6730

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end