Class: SDM::RoleResource
- Inherits:
-
Object
- Object
- SDM::RoleResource
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResource represents an individual access grant of a Role to a Resource.
Instance Attribute Summary collapse
-
#granted_at ⇒ Object
The most recent time at which access was granted.
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
-
#role_id ⇒ Object
The unique identifier of the Role to which access is granted.
Instance Method Summary collapse
-
#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource
constructor
A new instance of RoleResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource
Returns a new instance of RoleResource.
16290 16291 16292 16293 16294 16295 16296 16297 16298 |
# File 'lib/models/porcelain.rb', line 16290 def initialize( granted_at: nil, resource_id: nil, role_id: nil ) @granted_at = granted_at == nil ? nil : granted_at @resource_id = resource_id == nil ? "" : resource_id @role_id = role_id == nil ? "" : role_id end |
Instance Attribute Details
#granted_at ⇒ Object
The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.
16284 16285 16286 |
# File 'lib/models/porcelain.rb', line 16284 def granted_at @granted_at end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
16286 16287 16288 |
# File 'lib/models/porcelain.rb', line 16286 def resource_id @resource_id end |
#role_id ⇒ Object
The unique identifier of the Role to which access is granted.
16288 16289 16290 |
# File 'lib/models/porcelain.rb', line 16288 def role_id @role_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16300 16301 16302 16303 16304 16305 16306 |
# File 'lib/models/porcelain.rb', line 16300 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |