Class: SDM::RoleResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResource represents an individual access grant of a Role to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource

Returns a new instance of RoleResource.



16210
16211
16212
16213
16214
16215
16216
16217
16218
# File 'lib/models/porcelain.rb', line 16210

def initialize(
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



16204
16205
16206
# File 'lib/models/porcelain.rb', line 16204

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



16206
16207
16208
# File 'lib/models/porcelain.rb', line 16206

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role to which access is granted.



16208
16209
16210
# File 'lib/models/porcelain.rb', line 16208

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16220
16221
16222
16223
16224
16225
16226
# File 'lib/models/porcelain.rb', line 16220

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end