Class: SDM::RoleResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResource represents an individual access grant of a Role to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource

Returns a new instance of RoleResource.



13024
13025
13026
13027
13028
13029
13030
13031
13032
# File 'lib/models/porcelain.rb', line 13024

def initialize(
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



13018
13019
13020
# File 'lib/models/porcelain.rb', line 13018

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



13020
13021
13022
# File 'lib/models/porcelain.rb', line 13020

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role to which access is granted.



13022
13023
13024
# File 'lib/models/porcelain.rb', line 13022

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13034
13035
13036
13037
13038
13039
13040
# File 'lib/models/porcelain.rb', line 13034

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end