Class: SDM::RoleResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResource represents an individual access grant of a Role to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource

Returns a new instance of RoleResource.



12844
12845
12846
12847
12848
12849
12850
12851
12852
# File 'lib/models/porcelain.rb', line 12844

def initialize(
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



12838
12839
12840
# File 'lib/models/porcelain.rb', line 12838

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



12840
12841
12842
# File 'lib/models/porcelain.rb', line 12840

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role to which access is granted.



12842
12843
12844
# File 'lib/models/porcelain.rb', line 12842

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12854
12855
12856
12857
12858
12859
12860
# File 'lib/models/porcelain.rb', line 12854

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end