Class: SDM::RoleResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResource represents an individual access grant of a Role to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource

Returns a new instance of RoleResource.



12765
12766
12767
12768
12769
12770
12771
12772
12773
# File 'lib/models/porcelain.rb', line 12765

def initialize(
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



12759
12760
12761
# File 'lib/models/porcelain.rb', line 12759

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



12761
12762
12763
# File 'lib/models/porcelain.rb', line 12761

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role to which access is granted.



12763
12764
12765
# File 'lib/models/porcelain.rb', line 12763

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12775
12776
12777
12778
12779
12780
12781
# File 'lib/models/porcelain.rb', line 12775

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end