Class: SDM::RoleResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResource represents an individual access grant of a Role to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource

Returns a new instance of RoleResource.



11301
11302
11303
11304
11305
11306
11307
11308
11309
# File 'lib/models/porcelain.rb', line 11301

def initialize(
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



11295
11296
11297
# File 'lib/models/porcelain.rb', line 11295

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



11297
11298
11299
# File 'lib/models/porcelain.rb', line 11297

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role to which access is granted.



11299
11300
11301
# File 'lib/models/porcelain.rb', line 11299

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11311
11312
11313
11314
11315
11316
11317
# File 'lib/models/porcelain.rb', line 11311

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end