Class: SDM::RoleResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResource represents an individual access grant of a Role to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource

Returns a new instance of RoleResource.



10937
10938
10939
10940
10941
10942
10943
10944
10945
# File 'lib/models/porcelain.rb', line 10937

def initialize(
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



10931
10932
10933
# File 'lib/models/porcelain.rb', line 10931

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



10933
10934
10935
# File 'lib/models/porcelain.rb', line 10933

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role to which access is granted.



10935
10936
10937
# File 'lib/models/porcelain.rb', line 10935

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10947
10948
10949
10950
10951
10952
10953
# File 'lib/models/porcelain.rb', line 10947

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end