Class: SDM::RoleResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResource represents an individual access grant of a Role to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource

Returns a new instance of RoleResource.



10682
10683
10684
10685
10686
10687
10688
10689
10690
# File 'lib/models/porcelain.rb', line 10682

def initialize(
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



10676
10677
10678
# File 'lib/models/porcelain.rb', line 10676

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



10678
10679
10680
# File 'lib/models/porcelain.rb', line 10678

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role to which access is granted.



10680
10681
10682
# File 'lib/models/porcelain.rb', line 10680

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10692
10693
10694
10695
10696
10697
10698
# File 'lib/models/porcelain.rb', line 10692

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end