Class: SDM::RoleResource

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResource represents an individual access grant of a Role to a Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource

Returns a new instance of RoleResource.



8253
8254
8255
8256
8257
8258
8259
8260
8261
# File 'lib/models/porcelain.rb', line 8253

def initialize(
  granted_at: nil,
  resource_id: nil,
  role_id: nil
)
  @granted_at = granted_at == nil ? nil : granted_at
  @resource_id = resource_id == nil ? "" : resource_id
  @role_id = role_id == nil ? "" : role_id
end

Instance Attribute Details

#granted_atObject

The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.



8247
8248
8249
# File 'lib/models/porcelain.rb', line 8247

def granted_at
  @granted_at
end

#resource_idObject

The unique identifier of the Resource to which access is granted.



8249
8250
8251
# File 'lib/models/porcelain.rb', line 8249

def resource_id
  @resource_id
end

#role_idObject

The unique identifier of the Role to which access is granted.



8251
8252
8253
# File 'lib/models/porcelain.rb', line 8251

def role_id
  @role_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8263
8264
8265
8266
8267
8268
8269
# File 'lib/models/porcelain.rb', line 8263

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end