Class: SDM::RoleResource
- Inherits:
-
Object
- Object
- SDM::RoleResource
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResource represents an individual access grant of a Role to a Resource.
Instance Attribute Summary collapse
-
#granted_at ⇒ Object
The most recent time at which access was granted.
-
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
-
#role_id ⇒ Object
The unique identifier of the Role to which access is granted.
Instance Method Summary collapse
-
#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource
constructor
A new instance of RoleResource.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(granted_at: nil, resource_id: nil, role_id: nil) ⇒ RoleResource
Returns a new instance of RoleResource.
7177 7178 7179 7180 7181 7182 7183 7184 7185 |
# File 'lib/models/porcelain.rb', line 7177 def initialize( granted_at: nil, resource_id: nil, role_id: nil ) @granted_at = granted_at == nil ? nil : granted_at @resource_id = resource_id == nil ? "" : resource_id @role_id = role_id == nil ? "" : role_id end |
Instance Attribute Details
#granted_at ⇒ Object
The most recent time at which access was granted. If access was granted, revoked, and granted again, this will reflect the later time.
7171 7172 7173 |
# File 'lib/models/porcelain.rb', line 7171 def granted_at @granted_at end |
#resource_id ⇒ Object
The unique identifier of the Resource to which access is granted.
7173 7174 7175 |
# File 'lib/models/porcelain.rb', line 7173 def resource_id @resource_id end |
#role_id ⇒ Object
The unique identifier of the Role to which access is granted.
7175 7176 7177 |
# File 'lib/models/porcelain.rb', line 7175 def role_id @role_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7187 7188 7189 7190 7191 7192 7193 |
# File 'lib/models/porcelain.rb', line 7187 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |