Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



16323
16324
16325
16326
16327
16328
16329
16330
16331
16332
16333
# File 'lib/models/porcelain.rb', line 16323

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



16315
16316
16317
# File 'lib/models/porcelain.rb', line 16315

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



16317
16318
16319
# File 'lib/models/porcelain.rb', line 16317

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



16319
16320
16321
# File 'lib/models/porcelain.rb', line 16319

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



16321
16322
16323
# File 'lib/models/porcelain.rb', line 16321

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16335
16336
16337
16338
16339
16340
16341
# File 'lib/models/porcelain.rb', line 16335

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end