Class: SDM::RoleResourceHistory
- Inherits:
-
Object
- Object
- SDM::RoleResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource.
-
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
-
#role_resource ⇒ Object
The complete RoleResource state at this time.
-
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
constructor
A new instance of RoleResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
Returns a new instance of RoleResourceHistory.
15512 15513 15514 15515 15516 15517 15518 15519 15520 15521 15522 |
# File 'lib/models/porcelain.rb', line 15512 def initialize( activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role_resource = role_resource == nil ? nil : role_resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.
15504 15505 15506 |
# File 'lib/models/porcelain.rb', line 15504 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
15506 15507 15508 |
# File 'lib/models/porcelain.rb', line 15506 def deleted_at @deleted_at end |
#role_resource ⇒ Object
The complete RoleResource state at this time.
15508 15509 15510 |
# File 'lib/models/porcelain.rb', line 15508 def role_resource @role_resource end |
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
15510 15511 15512 |
# File 'lib/models/porcelain.rb', line 15510 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15524 15525 15526 15527 15528 15529 15530 |
# File 'lib/models/porcelain.rb', line 15524 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |