Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



14340
14341
14342
14343
14344
14345
14346
14347
14348
14349
14350
# File 'lib/models/porcelain.rb', line 14340

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



14332
14333
14334
# File 'lib/models/porcelain.rb', line 14332

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



14334
14335
14336
# File 'lib/models/porcelain.rb', line 14334

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



14336
14337
14338
# File 'lib/models/porcelain.rb', line 14336

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



14338
14339
14340
# File 'lib/models/porcelain.rb', line 14338

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14352
14353
14354
14355
14356
14357
14358
# File 'lib/models/porcelain.rb', line 14352

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end