Class: SDM::RoleResourceHistory
- Inherits:
-
Object
- Object
- SDM::RoleResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource.
-
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
-
#role_resource ⇒ Object
The complete RoleResource state at this time.
-
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
constructor
A new instance of RoleResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
Returns a new instance of RoleResourceHistory.
13045 13046 13047 13048 13049 13050 13051 13052 13053 13054 13055 |
# File 'lib/models/porcelain.rb', line 13045 def initialize( activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role_resource = role_resource == nil ? nil : role_resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.
13037 13038 13039 |
# File 'lib/models/porcelain.rb', line 13037 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
13039 13040 13041 |
# File 'lib/models/porcelain.rb', line 13039 def deleted_at @deleted_at end |
#role_resource ⇒ Object
The complete RoleResource state at this time.
13041 13042 13043 |
# File 'lib/models/porcelain.rb', line 13041 def role_resource @role_resource end |
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
13043 13044 13045 |
# File 'lib/models/porcelain.rb', line 13043 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13057 13058 13059 13060 13061 13062 13063 |
# File 'lib/models/porcelain.rb', line 13057 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |