Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



12877
12878
12879
12880
12881
12882
12883
12884
12885
12886
12887
# File 'lib/models/porcelain.rb', line 12877

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



12869
12870
12871
# File 'lib/models/porcelain.rb', line 12869

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



12871
12872
12873
# File 'lib/models/porcelain.rb', line 12871

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



12873
12874
12875
# File 'lib/models/porcelain.rb', line 12873

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



12875
12876
12877
# File 'lib/models/porcelain.rb', line 12875

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12889
12890
12891
12892
12893
12894
12895
# File 'lib/models/porcelain.rb', line 12889

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end