Class: SDM::RoleResourceHistory
- Inherits:
-
Object
- Object
- SDM::RoleResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource.
-
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
-
#role_resource ⇒ Object
The complete RoleResource state at this time.
-
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
constructor
A new instance of RoleResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
Returns a new instance of RoleResourceHistory.
12866 12867 12868 12869 12870 12871 12872 12873 12874 12875 12876 |
# File 'lib/models/porcelain.rb', line 12866 def initialize( activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role_resource = role_resource == nil ? nil : role_resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.
12858 12859 12860 |
# File 'lib/models/porcelain.rb', line 12858 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
12860 12861 12862 |
# File 'lib/models/porcelain.rb', line 12860 def deleted_at @deleted_at end |
#role_resource ⇒ Object
The complete RoleResource state at this time.
12862 12863 12864 |
# File 'lib/models/porcelain.rb', line 12862 def role_resource @role_resource end |
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
12864 12865 12866 |
# File 'lib/models/porcelain.rb', line 12864 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12878 12879 12880 12881 12882 12883 12884 |
# File 'lib/models/porcelain.rb', line 12878 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |