Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
# File 'lib/models/porcelain.rb', line 12798

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



12790
12791
12792
# File 'lib/models/porcelain.rb', line 12790

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



12792
12793
12794
# File 'lib/models/porcelain.rb', line 12792

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



12794
12795
12796
# File 'lib/models/porcelain.rb', line 12794

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



12796
12797
12798
# File 'lib/models/porcelain.rb', line 12796

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12810
12811
12812
12813
12814
12815
12816
# File 'lib/models/porcelain.rb', line 12810

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end