Class: SDM::RoleResourceHistory
- Inherits:
-
Object
- Object
- SDM::RoleResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource.
-
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
-
#role_resource ⇒ Object
The complete RoleResource state at this time.
-
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
constructor
A new instance of RoleResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
Returns a new instance of RoleResourceHistory.
12657 12658 12659 12660 12661 12662 12663 12664 12665 12666 12667 |
# File 'lib/models/porcelain.rb', line 12657 def initialize( activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role_resource = role_resource == nil ? nil : role_resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.
12649 12650 12651 |
# File 'lib/models/porcelain.rb', line 12649 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
12651 12652 12653 |
# File 'lib/models/porcelain.rb', line 12651 def deleted_at @deleted_at end |
#role_resource ⇒ Object
The complete RoleResource state at this time.
12653 12654 12655 |
# File 'lib/models/porcelain.rb', line 12653 def role_resource @role_resource end |
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
12655 12656 12657 |
# File 'lib/models/porcelain.rb', line 12655 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
12669 12670 12671 12672 12673 12674 12675 |
# File 'lib/models/porcelain.rb', line 12669 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |