Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



11487
11488
11489
11490
11491
11492
11493
11494
11495
11496
11497
# File 'lib/models/porcelain.rb', line 11487

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



11479
11480
11481
# File 'lib/models/porcelain.rb', line 11479

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



11481
11482
11483
# File 'lib/models/porcelain.rb', line 11481

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



11483
11484
11485
# File 'lib/models/porcelain.rb', line 11483

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



11485
11486
11487
# File 'lib/models/porcelain.rb', line 11485

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11499
11500
11501
11502
11503
11504
11505
# File 'lib/models/porcelain.rb', line 11499

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end