Class: SDM::RoleResourceHistory
- Inherits:
-
Object
- Object
- SDM::RoleResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource.
-
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
-
#role_resource ⇒ Object
The complete RoleResource state at this time.
-
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
constructor
A new instance of RoleResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
Returns a new instance of RoleResourceHistory.
11333 11334 11335 11336 11337 11338 11339 11340 11341 11342 11343 |
# File 'lib/models/porcelain.rb', line 11333 def initialize( activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role_resource = role_resource == nil ? nil : role_resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.
11325 11326 11327 |
# File 'lib/models/porcelain.rb', line 11325 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
11327 11328 11329 |
# File 'lib/models/porcelain.rb', line 11327 def deleted_at @deleted_at end |
#role_resource ⇒ Object
The complete RoleResource state at this time.
11329 11330 11331 |
# File 'lib/models/porcelain.rb', line 11329 def role_resource @role_resource end |
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
11331 11332 11333 |
# File 'lib/models/porcelain.rb', line 11331 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
11345 11346 11347 11348 11349 11350 11351 |
# File 'lib/models/porcelain.rb', line 11345 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |