Class: SDM::RoleResourceHistory
- Inherits:
-
Object
- Object
- SDM::RoleResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource.
-
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
-
#role_resource ⇒ Object
The complete RoleResource state at this time.
-
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
constructor
A new instance of RoleResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
Returns a new instance of RoleResourceHistory.
10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 |
# File 'lib/models/porcelain.rb', line 10972 def initialize( activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role_resource = role_resource == nil ? nil : role_resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.
10964 10965 10966 |
# File 'lib/models/porcelain.rb', line 10964 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
10966 10967 10968 |
# File 'lib/models/porcelain.rb', line 10966 def deleted_at @deleted_at end |
#role_resource ⇒ Object
The complete RoleResource state at this time.
10968 10969 10970 |
# File 'lib/models/porcelain.rb', line 10968 def role_resource @role_resource end |
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
10970 10971 10972 |
# File 'lib/models/porcelain.rb', line 10970 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10984 10985 10986 10987 10988 10989 10990 |
# File 'lib/models/porcelain.rb', line 10984 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |