Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



10275
10276
10277
10278
10279
10280
10281
10282
10283
10284
10285
# File 'lib/models/porcelain.rb', line 10275

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



10267
10268
10269
# File 'lib/models/porcelain.rb', line 10267

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



10269
10270
10271
# File 'lib/models/porcelain.rb', line 10269

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



10271
10272
10273
# File 'lib/models/porcelain.rb', line 10271

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



10273
10274
10275
# File 'lib/models/porcelain.rb', line 10273

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10287
10288
10289
10290
10291
10292
10293
# File 'lib/models/porcelain.rb', line 10287

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end