Class: SDM::RoleResourceHistory
- Inherits:
-
Object
- Object
- SDM::RoleResourceHistory
- Defined in:
- lib/models/porcelain.rb
Overview
RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.
Instance Attribute Summary collapse
-
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource.
-
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
-
#role_resource ⇒ Object
The complete RoleResource state at this time.
-
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
Instance Method Summary collapse
-
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
constructor
A new instance of RoleResourceHistory.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory
Returns a new instance of RoleResourceHistory.
8515 8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 |
# File 'lib/models/porcelain.rb', line 8515 def initialize( activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil ) @activity_id = activity_id == nil ? "" : activity_id @deleted_at = deleted_at == nil ? nil : deleted_at @role_resource = role_resource == nil ? nil : role_resource @timestamp = == nil ? nil : end |
Instance Attribute Details
#activity_id ⇒ Object
The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.
8507 8508 8509 |
# File 'lib/models/porcelain.rb', line 8507 def activity_id @activity_id end |
#deleted_at ⇒ Object
If this RoleResource was deleted, the time it was deleted.
8509 8510 8511 |
# File 'lib/models/porcelain.rb', line 8509 def deleted_at @deleted_at end |
#role_resource ⇒ Object
The complete RoleResource state at this time.
8511 8512 8513 |
# File 'lib/models/porcelain.rb', line 8511 def role_resource @role_resource end |
#timestamp ⇒ Object
The time at which the RoleResource state was recorded.
8513 8514 8515 |
# File 'lib/models/porcelain.rb', line 8513 def @timestamp end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8527 8528 8529 8530 8531 8532 8533 |
# File 'lib/models/porcelain.rb', line 8527 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |