Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



7319
7320
7321
7322
7323
7324
7325
7326
7327
7328
7329
# File 'lib/models/porcelain.rb', line 7319

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



7311
7312
7313
# File 'lib/models/porcelain.rb', line 7311

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



7313
7314
7315
# File 'lib/models/porcelain.rb', line 7313

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



7315
7316
7317
# File 'lib/models/porcelain.rb', line 7315

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



7317
7318
7319
# File 'lib/models/porcelain.rb', line 7317

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7331
7332
7333
7334
7335
7336
7337
# File 'lib/models/porcelain.rb', line 7331

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end