Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
# File 'lib/models/porcelain.rb', line 7263

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



7255
7256
7257
# File 'lib/models/porcelain.rb', line 7255

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



7257
7258
7259
# File 'lib/models/porcelain.rb', line 7257

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



7259
7260
7261
# File 'lib/models/porcelain.rb', line 7259

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



7261
7262
7263
# File 'lib/models/porcelain.rb', line 7261

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7275
7276
7277
7278
7279
7280
7281
# File 'lib/models/porcelain.rb', line 7275

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end