Class: SDM::RoleResourceHistory

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Overview

RoleResourceHistory records the state of a RoleResource at a given point in time, where every change (create or delete) to a RoleResource produces an RoleResourceHistory record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(activity_id: nil, deleted_at: nil, role_resource: nil, timestamp: nil) ⇒ RoleResourceHistory

Returns a new instance of RoleResourceHistory.



6782
6783
6784
6785
6786
6787
6788
6789
6790
6791
6792
# File 'lib/models/porcelain.rb', line 6782

def initialize(
  activity_id: nil,
  deleted_at: nil,
  role_resource: nil,
  timestamp: nil
)
  @activity_id = activity_id == nil ? "" : activity_id
  @deleted_at = deleted_at == nil ? nil : deleted_at
  @role_resource = role_resource == nil ? nil : role_resource
  @timestamp = timestamp == nil ? nil : timestamp
end

Instance Attribute Details

#activity_idObject

The unique identifier of the Activity that produced this change to the RoleResource. May be empty for some system-initiated updates.



6774
6775
6776
# File 'lib/models/porcelain.rb', line 6774

def activity_id
  @activity_id
end

#deleted_atObject

If this RoleResource was deleted, the time it was deleted.



6776
6777
6778
# File 'lib/models/porcelain.rb', line 6776

def deleted_at
  @deleted_at
end

#role_resourceObject

The complete RoleResource state at this time.



6778
6779
6780
# File 'lib/models/porcelain.rb', line 6778

def role_resource
  @role_resource
end

#timestampObject

The time at which the RoleResource state was recorded.



6780
6781
6782
# File 'lib/models/porcelain.rb', line 6780

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6794
6795
6796
6797
6798
6799
6800
# File 'lib/models/porcelain.rb', line 6794

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end