Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



16460
16461
16462
16463
16464
16465
16466
16467
16468
16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
16481
16482
16483
16484
16485
16486
16487
16488
16489
16490
16491
16492
16493
16494
16495
16496
16497
16498
# File 'lib/models/porcelain.rb', line 16460

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16424
16425
16426
# File 'lib/models/porcelain.rb', line 16424

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16426
16427
16428
# File 'lib/models/porcelain.rb', line 16426

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



16428
16429
16430
# File 'lib/models/porcelain.rb', line 16428

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16430
16431
16432
# File 'lib/models/porcelain.rb', line 16430

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16432
16433
16434
# File 'lib/models/porcelain.rb', line 16432

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16434
16435
16436
# File 'lib/models/porcelain.rb', line 16434

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16436
16437
16438
# File 'lib/models/porcelain.rb', line 16436

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16438
16439
16440
# File 'lib/models/porcelain.rb', line 16438

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16440
16441
16442
# File 'lib/models/porcelain.rb', line 16440

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



16442
16443
16444
# File 'lib/models/porcelain.rb', line 16442

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16444
16445
16446
# File 'lib/models/porcelain.rb', line 16444

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16446
16447
16448
# File 'lib/models/porcelain.rb', line 16446

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16448
16449
16450
# File 'lib/models/porcelain.rb', line 16448

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



16450
16451
16452
# File 'lib/models/porcelain.rb', line 16450

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16452
16453
16454
# File 'lib/models/porcelain.rb', line 16452

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16454
16455
16456
# File 'lib/models/porcelain.rb', line 16454

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16456
16457
16458
# File 'lib/models/porcelain.rb', line 16456

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16458
16459
16460
# File 'lib/models/porcelain.rb', line 16458

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16500
16501
16502
16503
16504
16505
16506
# File 'lib/models/porcelain.rb', line 16500

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end