Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
16105 16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 16121 16122 16123 16124 16125 16126 16127 16128 16129 16130 16131 16132 16133 16134 16135 16136 16137 16138 16139 16140 16141 16142 16143 |
# File 'lib/models/porcelain.rb', line 16105 def initialize( allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.
16069 16070 16071 |
# File 'lib/models/porcelain.rb', line 16069 def allow_deprecated_encryption @allow_deprecated_encryption end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
16071 16072 16073 |
# File 'lib/models/porcelain.rb', line 16071 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
16073 16074 16075 |
# File 'lib/models/porcelain.rb', line 16073 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
16075 16076 16077 |
# File 'lib/models/porcelain.rb', line 16075 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
16077 16078 16079 |
# File 'lib/models/porcelain.rb', line 16077 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
16079 16080 16081 |
# File 'lib/models/porcelain.rb', line 16079 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
16081 16082 16083 |
# File 'lib/models/porcelain.rb', line 16081 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
16083 16084 16085 |
# File 'lib/models/porcelain.rb', line 16083 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
16085 16086 16087 |
# File 'lib/models/porcelain.rb', line 16085 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
16087 16088 16089 |
# File 'lib/models/porcelain.rb', line 16087 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
16089 16090 16091 |
# File 'lib/models/porcelain.rb', line 16089 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
16091 16092 16093 |
# File 'lib/models/porcelain.rb', line 16091 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
16093 16094 16095 |
# File 'lib/models/porcelain.rb', line 16093 def proxy_cluster_id @proxy_cluster_id end |
#schema ⇒ Object
The Schema to use to direct initial requests.
16095 16096 16097 |
# File 'lib/models/porcelain.rb', line 16095 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
16097 16098 16099 |
# File 'lib/models/porcelain.rb', line 16097 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
16099 16100 16101 |
# File 'lib/models/porcelain.rb', line 16099 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16101 16102 16103 |
# File 'lib/models/porcelain.rb', line 16101 def @tags end |
#username ⇒ Object
The username to authenticate with.
16103 16104 16105 |
# File 'lib/models/porcelain.rb', line 16103 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16145 16146 16147 16148 16149 16150 16151 |
# File 'lib/models/porcelain.rb', line 16145 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |