Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



15990
15991
15992
15993
15994
15995
15996
15997
15998
15999
16000
16001
16002
16003
16004
16005
16006
16007
16008
16009
16010
16011
16012
16013
16014
16015
16016
16017
16018
16019
16020
16021
16022
16023
16024
16025
16026
16027
16028
# File 'lib/models/porcelain.rb', line 15990

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



15954
15955
15956
# File 'lib/models/porcelain.rb', line 15954

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15956
15957
15958
# File 'lib/models/porcelain.rb', line 15956

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



15958
15959
15960
# File 'lib/models/porcelain.rb', line 15958

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15960
15961
15962
# File 'lib/models/porcelain.rb', line 15960

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15962
15963
15964
# File 'lib/models/porcelain.rb', line 15962

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15964
15965
15966
# File 'lib/models/porcelain.rb', line 15964

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15966
15967
15968
# File 'lib/models/porcelain.rb', line 15966

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15968
15969
15970
# File 'lib/models/porcelain.rb', line 15968

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15970
15971
15972
# File 'lib/models/porcelain.rb', line 15970

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



15972
15973
15974
# File 'lib/models/porcelain.rb', line 15972

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15974
15975
15976
# File 'lib/models/porcelain.rb', line 15974

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15976
15977
15978
# File 'lib/models/porcelain.rb', line 15976

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15978
15979
15980
# File 'lib/models/porcelain.rb', line 15978

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



15980
15981
15982
# File 'lib/models/porcelain.rb', line 15980

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15982
15983
15984
# File 'lib/models/porcelain.rb', line 15982

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15984
15985
15986
# File 'lib/models/porcelain.rb', line 15984

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15986
15987
15988
# File 'lib/models/porcelain.rb', line 15986

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15988
15989
15990
# File 'lib/models/porcelain.rb', line 15988

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16030
16031
16032
16033
16034
16035
16036
# File 'lib/models/porcelain.rb', line 16030

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end