Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



15617
15618
15619
15620
15621
15622
15623
15624
15625
15626
15627
15628
15629
15630
15631
15632
15633
15634
15635
15636
15637
15638
15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
15655
# File 'lib/models/porcelain.rb', line 15617

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



15581
15582
15583
# File 'lib/models/porcelain.rb', line 15581

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15583
15584
15585
# File 'lib/models/porcelain.rb', line 15583

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



15585
15586
15587
# File 'lib/models/porcelain.rb', line 15585

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15587
15588
15589
# File 'lib/models/porcelain.rb', line 15587

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15589
15590
15591
# File 'lib/models/porcelain.rb', line 15589

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15591
15592
15593
# File 'lib/models/porcelain.rb', line 15591

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15593
15594
15595
# File 'lib/models/porcelain.rb', line 15593

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15595
15596
15597
# File 'lib/models/porcelain.rb', line 15595

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15597
15598
15599
# File 'lib/models/porcelain.rb', line 15597

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



15599
15600
15601
# File 'lib/models/porcelain.rb', line 15599

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15601
15602
15603
# File 'lib/models/porcelain.rb', line 15601

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15603
15604
15605
# File 'lib/models/porcelain.rb', line 15603

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15605
15606
15607
# File 'lib/models/porcelain.rb', line 15605

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



15607
15608
15609
# File 'lib/models/porcelain.rb', line 15607

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15609
15610
15611
# File 'lib/models/porcelain.rb', line 15609

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15611
15612
15613
# File 'lib/models/porcelain.rb', line 15611

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15613
15614
15615
# File 'lib/models/porcelain.rb', line 15613

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15615
15616
15617
# File 'lib/models/porcelain.rb', line 15615

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15657
15658
15659
15660
15661
15662
15663
# File 'lib/models/porcelain.rb', line 15657

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end