Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



15315
15316
15317
15318
15319
15320
15321
15322
15323
15324
15325
15326
15327
15328
15329
15330
15331
15332
15333
15334
15335
15336
15337
15338
15339
15340
15341
15342
15343
15344
15345
15346
15347
15348
15349
15350
15351
15352
15353
# File 'lib/models/porcelain.rb', line 15315

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



15279
15280
15281
# File 'lib/models/porcelain.rb', line 15279

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15281
15282
15283
# File 'lib/models/porcelain.rb', line 15281

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



15283
15284
15285
# File 'lib/models/porcelain.rb', line 15283

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15285
15286
15287
# File 'lib/models/porcelain.rb', line 15285

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15287
15288
15289
# File 'lib/models/porcelain.rb', line 15287

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15289
15290
15291
# File 'lib/models/porcelain.rb', line 15289

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15291
15292
15293
# File 'lib/models/porcelain.rb', line 15291

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15293
15294
15295
# File 'lib/models/porcelain.rb', line 15293

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15295
15296
15297
# File 'lib/models/porcelain.rb', line 15295

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



15297
15298
15299
# File 'lib/models/porcelain.rb', line 15297

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15299
15300
15301
# File 'lib/models/porcelain.rb', line 15299

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15301
15302
15303
# File 'lib/models/porcelain.rb', line 15301

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15303
15304
15305
# File 'lib/models/porcelain.rb', line 15303

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



15305
15306
15307
# File 'lib/models/porcelain.rb', line 15305

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15307
15308
15309
# File 'lib/models/porcelain.rb', line 15307

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15309
15310
15311
# File 'lib/models/porcelain.rb', line 15309

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15311
15312
15313
# File 'lib/models/porcelain.rb', line 15311

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15313
15314
15315
# File 'lib/models/porcelain.rb', line 15313

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15355
15356
15357
15358
15359
15360
15361
# File 'lib/models/porcelain.rb', line 15355

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end