Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



12887
12888
12889
12890
12891
12892
12893
12894
12895
12896
12897
12898
12899
12900
12901
12902
12903
12904
12905
12906
12907
12908
12909
12910
12911
12912
12913
12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
# File 'lib/models/porcelain.rb', line 12887

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



12851
12852
12853
# File 'lib/models/porcelain.rb', line 12851

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12853
12854
12855
# File 'lib/models/porcelain.rb', line 12853

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



12855
12856
12857
# File 'lib/models/porcelain.rb', line 12855

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12857
12858
12859
# File 'lib/models/porcelain.rb', line 12857

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12859
12860
12861
# File 'lib/models/porcelain.rb', line 12859

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12861
12862
12863
# File 'lib/models/porcelain.rb', line 12861

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12863
12864
12865
# File 'lib/models/porcelain.rb', line 12863

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12865
12866
12867
# File 'lib/models/porcelain.rb', line 12865

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12867
12868
12869
# File 'lib/models/porcelain.rb', line 12867

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



12869
12870
12871
# File 'lib/models/porcelain.rb', line 12869

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12871
12872
12873
# File 'lib/models/porcelain.rb', line 12871

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12873
12874
12875
# File 'lib/models/porcelain.rb', line 12873

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12875
12876
12877
# File 'lib/models/porcelain.rb', line 12875

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



12877
12878
12879
# File 'lib/models/porcelain.rb', line 12877

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12879
12880
12881
# File 'lib/models/porcelain.rb', line 12879

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12881
12882
12883
# File 'lib/models/porcelain.rb', line 12881

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12883
12884
12885
# File 'lib/models/porcelain.rb', line 12883

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12885
12886
12887
# File 'lib/models/porcelain.rb', line 12885

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12927
12928
12929
12930
12931
12932
12933
# File 'lib/models/porcelain.rb', line 12927

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end