Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



12814
12815
12816
12817
12818
12819
12820
12821
12822
12823
12824
12825
12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
12848
12849
12850
12851
12852
# File 'lib/models/porcelain.rb', line 12814

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



12778
12779
12780
# File 'lib/models/porcelain.rb', line 12778

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12780
12781
12782
# File 'lib/models/porcelain.rb', line 12780

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



12782
12783
12784
# File 'lib/models/porcelain.rb', line 12782

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12784
12785
12786
# File 'lib/models/porcelain.rb', line 12784

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12786
12787
12788
# File 'lib/models/porcelain.rb', line 12786

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12788
12789
12790
# File 'lib/models/porcelain.rb', line 12788

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12790
12791
12792
# File 'lib/models/porcelain.rb', line 12790

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12792
12793
12794
# File 'lib/models/porcelain.rb', line 12792

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12794
12795
12796
# File 'lib/models/porcelain.rb', line 12794

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



12796
12797
12798
# File 'lib/models/porcelain.rb', line 12796

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12798
12799
12800
# File 'lib/models/porcelain.rb', line 12798

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12800
12801
12802
# File 'lib/models/porcelain.rb', line 12800

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12802
12803
12804
# File 'lib/models/porcelain.rb', line 12802

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



12804
12805
12806
# File 'lib/models/porcelain.rb', line 12804

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12806
12807
12808
# File 'lib/models/porcelain.rb', line 12806

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12808
12809
12810
# File 'lib/models/porcelain.rb', line 12808

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12810
12811
12812
# File 'lib/models/porcelain.rb', line 12810

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12812
12813
12814
# File 'lib/models/porcelain.rb', line 12812

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12854
12855
12856
12857
12858
12859
12860
# File 'lib/models/porcelain.rb', line 12854

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end