Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



11895
11896
11897
11898
11899
11900
11901
11902
11903
11904
11905
11906
11907
11908
11909
11910
11911
11912
11913
11914
11915
11916
11917
11918
11919
11920
11921
11922
11923
11924
11925
11926
11927
11928
11929
11930
11931
11932
11933
# File 'lib/models/porcelain.rb', line 11895

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11859
11860
11861
# File 'lib/models/porcelain.rb', line 11859

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11861
11862
11863
# File 'lib/models/porcelain.rb', line 11861

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11863
11864
11865
# File 'lib/models/porcelain.rb', line 11863

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11865
11866
11867
# File 'lib/models/porcelain.rb', line 11865

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11867
11868
11869
# File 'lib/models/porcelain.rb', line 11867

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11869
11870
11871
# File 'lib/models/porcelain.rb', line 11869

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11871
11872
11873
# File 'lib/models/porcelain.rb', line 11871

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11873
11874
11875
# File 'lib/models/porcelain.rb', line 11873

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11875
11876
11877
# File 'lib/models/porcelain.rb', line 11875

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



11877
11878
11879
# File 'lib/models/porcelain.rb', line 11877

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11879
11880
11881
# File 'lib/models/porcelain.rb', line 11879

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11881
11882
11883
# File 'lib/models/porcelain.rb', line 11881

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11883
11884
11885
# File 'lib/models/porcelain.rb', line 11883

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11885
11886
11887
# File 'lib/models/porcelain.rb', line 11885

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11887
11888
11889
# File 'lib/models/porcelain.rb', line 11887

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11889
11890
11891
# File 'lib/models/porcelain.rb', line 11889

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11891
11892
11893
# File 'lib/models/porcelain.rb', line 11891

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11893
11894
11895
# File 'lib/models/porcelain.rb', line 11893

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11935
11936
11937
11938
11939
11940
11941
# File 'lib/models/porcelain.rb', line 11935

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end