Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



11812
11813
11814
11815
11816
11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
11829
11830
11831
11832
11833
11834
11835
11836
11837
11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
11848
11849
11850
# File 'lib/models/porcelain.rb', line 11812

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11776
11777
11778
# File 'lib/models/porcelain.rb', line 11776

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11778
11779
11780
# File 'lib/models/porcelain.rb', line 11778

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11780
11781
11782
# File 'lib/models/porcelain.rb', line 11780

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11782
11783
11784
# File 'lib/models/porcelain.rb', line 11782

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11784
11785
11786
# File 'lib/models/porcelain.rb', line 11784

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11786
11787
11788
# File 'lib/models/porcelain.rb', line 11786

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11788
11789
11790
# File 'lib/models/porcelain.rb', line 11788

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11790
11791
11792
# File 'lib/models/porcelain.rb', line 11790

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11792
11793
11794
# File 'lib/models/porcelain.rb', line 11792

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



11794
11795
11796
# File 'lib/models/porcelain.rb', line 11794

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11796
11797
11798
# File 'lib/models/porcelain.rb', line 11796

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11798
11799
11800
# File 'lib/models/porcelain.rb', line 11798

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11800
11801
11802
# File 'lib/models/porcelain.rb', line 11800

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11802
11803
11804
# File 'lib/models/porcelain.rb', line 11802

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11804
11805
11806
# File 'lib/models/porcelain.rb', line 11804

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11806
11807
11808
# File 'lib/models/porcelain.rb', line 11806

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11808
11809
11810
# File 'lib/models/porcelain.rb', line 11808

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11810
11811
11812
# File 'lib/models/porcelain.rb', line 11810

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11852
11853
11854
11855
11856
11857
11858
# File 'lib/models/porcelain.rb', line 11852

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end