Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



11577
11578
11579
11580
11581
11582
11583
11584
11585
11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
11607
11608
11609
11610
11611
11612
11613
11614
11615
# File 'lib/models/porcelain.rb', line 11577

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11541
11542
11543
# File 'lib/models/porcelain.rb', line 11541

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11543
11544
11545
# File 'lib/models/porcelain.rb', line 11543

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11545
11546
11547
# File 'lib/models/porcelain.rb', line 11545

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11547
11548
11549
# File 'lib/models/porcelain.rb', line 11547

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11549
11550
11551
# File 'lib/models/porcelain.rb', line 11549

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11551
11552
11553
# File 'lib/models/porcelain.rb', line 11551

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11553
11554
11555
# File 'lib/models/porcelain.rb', line 11553

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11555
11556
11557
# File 'lib/models/porcelain.rb', line 11555

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11557
11558
11559
# File 'lib/models/porcelain.rb', line 11557

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



11559
11560
11561
# File 'lib/models/porcelain.rb', line 11559

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11561
11562
11563
# File 'lib/models/porcelain.rb', line 11561

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11563
11564
11565
# File 'lib/models/porcelain.rb', line 11563

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11565
11566
11567
# File 'lib/models/porcelain.rb', line 11565

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11567
11568
11569
# File 'lib/models/porcelain.rb', line 11567

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11569
11570
11571
# File 'lib/models/porcelain.rb', line 11569

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11571
11572
11573
# File 'lib/models/porcelain.rb', line 11571

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11573
11574
11575
# File 'lib/models/porcelain.rb', line 11573

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11575
11576
11577
# File 'lib/models/porcelain.rb', line 11575

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11617
11618
11619
11620
11621
11622
11623
# File 'lib/models/porcelain.rb', line 11617

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end