Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



11497
11498
11499
11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
11532
11533
11534
11535
# File 'lib/models/porcelain.rb', line 11497

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11461
11462
11463
# File 'lib/models/porcelain.rb', line 11461

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11463
11464
11465
# File 'lib/models/porcelain.rb', line 11463

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11465
11466
11467
# File 'lib/models/porcelain.rb', line 11465

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11467
11468
11469
# File 'lib/models/porcelain.rb', line 11467

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11469
11470
11471
# File 'lib/models/porcelain.rb', line 11469

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11471
11472
11473
# File 'lib/models/porcelain.rb', line 11471

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11473
11474
11475
# File 'lib/models/porcelain.rb', line 11473

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11475
11476
11477
# File 'lib/models/porcelain.rb', line 11475

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11477
11478
11479
# File 'lib/models/porcelain.rb', line 11477

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



11479
11480
11481
# File 'lib/models/porcelain.rb', line 11479

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11481
11482
11483
# File 'lib/models/porcelain.rb', line 11481

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11483
11484
11485
# File 'lib/models/porcelain.rb', line 11483

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11485
11486
11487
# File 'lib/models/porcelain.rb', line 11485

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11487
11488
11489
# File 'lib/models/porcelain.rb', line 11487

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11489
11490
11491
# File 'lib/models/porcelain.rb', line 11489

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11491
11492
11493
# File 'lib/models/porcelain.rb', line 11491

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11493
11494
11495
# File 'lib/models/porcelain.rb', line 11493

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11495
11496
11497
# File 'lib/models/porcelain.rb', line 11495

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11537
11538
11539
11540
11541
11542
11543
# File 'lib/models/porcelain.rb', line 11537

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end