Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
11444
11445
11446
11447
11448
11449
11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
11460
11461
# File 'lib/models/porcelain.rb', line 11423

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11387
11388
11389
# File 'lib/models/porcelain.rb', line 11387

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11389
11390
11391
# File 'lib/models/porcelain.rb', line 11389

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11391
11392
11393
# File 'lib/models/porcelain.rb', line 11391

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11393
11394
11395
# File 'lib/models/porcelain.rb', line 11393

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11395
11396
11397
# File 'lib/models/porcelain.rb', line 11395

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11397
11398
11399
# File 'lib/models/porcelain.rb', line 11397

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11399
11400
11401
# File 'lib/models/porcelain.rb', line 11399

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11401
11402
11403
# File 'lib/models/porcelain.rb', line 11401

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11403
11404
11405
# File 'lib/models/porcelain.rb', line 11403

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



11405
11406
11407
# File 'lib/models/porcelain.rb', line 11405

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11407
11408
11409
# File 'lib/models/porcelain.rb', line 11407

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11409
11410
11411
# File 'lib/models/porcelain.rb', line 11409

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11411
11412
11413
# File 'lib/models/porcelain.rb', line 11411

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11413
11414
11415
# File 'lib/models/porcelain.rb', line 11413

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11415
11416
11417
# File 'lib/models/porcelain.rb', line 11415

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11417
11418
11419
# File 'lib/models/porcelain.rb', line 11417

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11419
11420
11421
# File 'lib/models/porcelain.rb', line 11419

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11421
11422
11423
# File 'lib/models/porcelain.rb', line 11421

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11463
11464
11465
11466
11467
11468
11469
# File 'lib/models/porcelain.rb', line 11463

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end