Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



11356
11357
11358
11359
11360
11361
11362
11363
11364
11365
11366
11367
11368
11369
11370
11371
11372
11373
11374
11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
# File 'lib/models/porcelain.rb', line 11356

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11320
11321
11322
# File 'lib/models/porcelain.rb', line 11320

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11322
11323
11324
# File 'lib/models/porcelain.rb', line 11322

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11324
11325
11326
# File 'lib/models/porcelain.rb', line 11324

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11326
11327
11328
# File 'lib/models/porcelain.rb', line 11326

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11328
11329
11330
# File 'lib/models/porcelain.rb', line 11328

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11330
11331
11332
# File 'lib/models/porcelain.rb', line 11330

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11332
11333
11334
# File 'lib/models/porcelain.rb', line 11332

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11334
11335
11336
# File 'lib/models/porcelain.rb', line 11334

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11336
11337
11338
# File 'lib/models/porcelain.rb', line 11336

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



11338
11339
11340
# File 'lib/models/porcelain.rb', line 11338

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11340
11341
11342
# File 'lib/models/porcelain.rb', line 11340

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11342
11343
11344
# File 'lib/models/porcelain.rb', line 11342

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11344
11345
11346
# File 'lib/models/porcelain.rb', line 11344

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11346
11347
11348
# File 'lib/models/porcelain.rb', line 11346

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11348
11349
11350
# File 'lib/models/porcelain.rb', line 11348

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11350
11351
11352
# File 'lib/models/porcelain.rb', line 11350

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11352
11353
11354
# File 'lib/models/porcelain.rb', line 11352

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11354
11355
11356
# File 'lib/models/porcelain.rb', line 11354

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11396
11397
11398
11399
11400
11401
11402
# File 'lib/models/porcelain.rb', line 11396

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end