Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



11059
11060
11061
11062
11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
11079
11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
11093
11094
11095
11096
11097
# File 'lib/models/porcelain.rb', line 11059

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11023
11024
11025
# File 'lib/models/porcelain.rb', line 11023

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11025
11026
11027
# File 'lib/models/porcelain.rb', line 11025

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11027
11028
11029
# File 'lib/models/porcelain.rb', line 11027

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11029
11030
11031
# File 'lib/models/porcelain.rb', line 11029

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11031
11032
11033
# File 'lib/models/porcelain.rb', line 11031

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11033
11034
11035
# File 'lib/models/porcelain.rb', line 11033

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11035
11036
11037
# File 'lib/models/porcelain.rb', line 11035

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11037
11038
11039
# File 'lib/models/porcelain.rb', line 11037

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11039
11040
11041
# File 'lib/models/porcelain.rb', line 11039

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



11041
11042
11043
# File 'lib/models/porcelain.rb', line 11041

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11043
11044
11045
# File 'lib/models/porcelain.rb', line 11043

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11045
11046
11047
# File 'lib/models/porcelain.rb', line 11045

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11047
11048
11049
# File 'lib/models/porcelain.rb', line 11047

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11049
11050
11051
# File 'lib/models/porcelain.rb', line 11049

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11051
11052
11053
# File 'lib/models/porcelain.rb', line 11051

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11053
11054
11055
# File 'lib/models/porcelain.rb', line 11053

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11055
11056
11057
# File 'lib/models/porcelain.rb', line 11055

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11057
11058
11059
# File 'lib/models/porcelain.rb', line 11057

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11099
11100
11101
11102
11103
11104
11105
# File 'lib/models/porcelain.rb', line 11099

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end