Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



10733
10734
10735
10736
10737
10738
10739
10740
10741
10742
10743
10744
10745
10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
# File 'lib/models/porcelain.rb', line 10733

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10697
10698
10699
# File 'lib/models/porcelain.rb', line 10697

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10699
10700
10701
# File 'lib/models/porcelain.rb', line 10699

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10701
10702
10703
# File 'lib/models/porcelain.rb', line 10701

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10703
10704
10705
# File 'lib/models/porcelain.rb', line 10703

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10705
10706
10707
# File 'lib/models/porcelain.rb', line 10705

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10707
10708
10709
# File 'lib/models/porcelain.rb', line 10707

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10709
10710
10711
# File 'lib/models/porcelain.rb', line 10709

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10711
10712
10713
# File 'lib/models/porcelain.rb', line 10711

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10713
10714
10715
# File 'lib/models/porcelain.rb', line 10713

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10715
10716
10717
# File 'lib/models/porcelain.rb', line 10715

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10717
10718
10719
# File 'lib/models/porcelain.rb', line 10717

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10719
10720
10721
# File 'lib/models/porcelain.rb', line 10719

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10721
10722
10723
# File 'lib/models/porcelain.rb', line 10721

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



10723
10724
10725
# File 'lib/models/porcelain.rb', line 10723

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10725
10726
10727
# File 'lib/models/porcelain.rb', line 10725

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10727
10728
10729
# File 'lib/models/porcelain.rb', line 10727

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10729
10730
10731
# File 'lib/models/porcelain.rb', line 10729

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10731
10732
10733
# File 'lib/models/porcelain.rb', line 10731

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10773
10774
10775
10776
10777
10778
10779
# File 'lib/models/porcelain.rb', line 10773

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end