Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



10656
10657
10658
10659
10660
10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
10693
10694
# File 'lib/models/porcelain.rb', line 10656

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10620
10621
10622
# File 'lib/models/porcelain.rb', line 10620

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10622
10623
10624
# File 'lib/models/porcelain.rb', line 10622

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10624
10625
10626
# File 'lib/models/porcelain.rb', line 10624

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10626
10627
10628
# File 'lib/models/porcelain.rb', line 10626

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10628
10629
10630
# File 'lib/models/porcelain.rb', line 10628

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10630
10631
10632
# File 'lib/models/porcelain.rb', line 10630

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10632
10633
10634
# File 'lib/models/porcelain.rb', line 10632

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10634
10635
10636
# File 'lib/models/porcelain.rb', line 10634

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10636
10637
10638
# File 'lib/models/porcelain.rb', line 10636

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10638
10639
10640
# File 'lib/models/porcelain.rb', line 10638

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10640
10641
10642
# File 'lib/models/porcelain.rb', line 10640

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10642
10643
10644
# File 'lib/models/porcelain.rb', line 10642

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10644
10645
10646
# File 'lib/models/porcelain.rb', line 10644

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



10646
10647
10648
# File 'lib/models/porcelain.rb', line 10646

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10648
10649
10650
# File 'lib/models/porcelain.rb', line 10648

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10650
10651
10652
# File 'lib/models/porcelain.rb', line 10650

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10652
10653
10654
# File 'lib/models/porcelain.rb', line 10652

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10654
10655
10656
# File 'lib/models/porcelain.rb', line 10654

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10696
10697
10698
10699
10700
10701
10702
# File 'lib/models/porcelain.rb', line 10696

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end