Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
# File 'lib/models/porcelain.rb', line 10362

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10328
10329
10330
# File 'lib/models/porcelain.rb', line 10328

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10330
10331
10332
# File 'lib/models/porcelain.rb', line 10330

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10332
10333
10334
# File 'lib/models/porcelain.rb', line 10332

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10334
10335
10336
# File 'lib/models/porcelain.rb', line 10334

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10336
10337
10338
# File 'lib/models/porcelain.rb', line 10336

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10338
10339
10340
# File 'lib/models/porcelain.rb', line 10338

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10340
10341
10342
# File 'lib/models/porcelain.rb', line 10340

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10342
10343
10344
# File 'lib/models/porcelain.rb', line 10342

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10344
10345
10346
# File 'lib/models/porcelain.rb', line 10344

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10346
10347
10348
# File 'lib/models/porcelain.rb', line 10346

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10348
10349
10350
# File 'lib/models/porcelain.rb', line 10348

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10350
10351
10352
# File 'lib/models/porcelain.rb', line 10350

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



10352
10353
10354
# File 'lib/models/porcelain.rb', line 10352

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10354
10355
10356
# File 'lib/models/porcelain.rb', line 10354

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10356
10357
10358
# File 'lib/models/porcelain.rb', line 10356

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10358
10359
10360
# File 'lib/models/porcelain.rb', line 10358

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10360
10361
10362
# File 'lib/models/porcelain.rb', line 10360

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10400
10401
10402
10403
10404
10405
10406
# File 'lib/models/porcelain.rb', line 10400

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end