Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



10189
10190
10191
10192
10193
10194
10195
10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
10221
10222
10223
10224
10225
# File 'lib/models/porcelain.rb', line 10189

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10155
10156
10157
# File 'lib/models/porcelain.rb', line 10155

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10157
10158
10159
# File 'lib/models/porcelain.rb', line 10157

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10159
10160
10161
# File 'lib/models/porcelain.rb', line 10159

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10161
10162
10163
# File 'lib/models/porcelain.rb', line 10161

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10163
10164
10165
# File 'lib/models/porcelain.rb', line 10163

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10165
10166
10167
# File 'lib/models/porcelain.rb', line 10165

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10167
10168
10169
# File 'lib/models/porcelain.rb', line 10167

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10169
10170
10171
# File 'lib/models/porcelain.rb', line 10169

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10171
10172
10173
# File 'lib/models/porcelain.rb', line 10171

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



10173
10174
10175
# File 'lib/models/porcelain.rb', line 10173

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10175
10176
10177
# File 'lib/models/porcelain.rb', line 10175

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10177
10178
10179
# File 'lib/models/porcelain.rb', line 10177

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



10179
10180
10181
# File 'lib/models/porcelain.rb', line 10179

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10181
10182
10183
# File 'lib/models/porcelain.rb', line 10181

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10183
10184
10185
# File 'lib/models/porcelain.rb', line 10183

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10185
10186
10187
# File 'lib/models/porcelain.rb', line 10185

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10187
10188
10189
# File 'lib/models/porcelain.rb', line 10187

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10227
10228
10229
10230
10231
10232
10233
# File 'lib/models/porcelain.rb', line 10227

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end