Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
9815
9816
9817
9818
9819
9820
9821
9822
9823
9824
9825
9826
9827
9828
9829
9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
9840
9841
# File 'lib/models/porcelain.rb', line 9805

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



9771
9772
9773
# File 'lib/models/porcelain.rb', line 9771

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9773
9774
9775
# File 'lib/models/porcelain.rb', line 9773

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



9775
9776
9777
# File 'lib/models/porcelain.rb', line 9775

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9777
9778
9779
# File 'lib/models/porcelain.rb', line 9777

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9779
9780
9781
# File 'lib/models/porcelain.rb', line 9779

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9781
9782
9783
# File 'lib/models/porcelain.rb', line 9781

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9783
9784
9785
# File 'lib/models/porcelain.rb', line 9783

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9785
9786
9787
# File 'lib/models/porcelain.rb', line 9785

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



9787
9788
9789
# File 'lib/models/porcelain.rb', line 9787

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



9789
9790
9791
# File 'lib/models/porcelain.rb', line 9789

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9791
9792
9793
# File 'lib/models/porcelain.rb', line 9791

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9793
9794
9795
# File 'lib/models/porcelain.rb', line 9793

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



9795
9796
9797
# File 'lib/models/porcelain.rb', line 9795

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9797
9798
9799
# File 'lib/models/porcelain.rb', line 9797

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9799
9800
9801
# File 'lib/models/porcelain.rb', line 9799

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9801
9802
9803
# File 'lib/models/porcelain.rb', line 9801

def tags
  @tags
end

#usernameObject

The username to authenticate with.



9803
9804
9805
# File 'lib/models/porcelain.rb', line 9803

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9843
9844
9845
9846
9847
9848
9849
# File 'lib/models/porcelain.rb', line 9843

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end