Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



8602
8603
8604
8605
8606
8607
8608
8609
8610
8611
8612
8613
8614
8615
8616
8617
8618
8619
8620
8621
8622
8623
8624
8625
8626
8627
8628
8629
8630
8631
8632
8633
8634
8635
8636
8637
8638
# File 'lib/models/porcelain.rb', line 8602

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



8568
8569
8570
# File 'lib/models/porcelain.rb', line 8568

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8570
8571
8572
# File 'lib/models/porcelain.rb', line 8570

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



8572
8573
8574
# File 'lib/models/porcelain.rb', line 8572

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8574
8575
8576
# File 'lib/models/porcelain.rb', line 8574

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8576
8577
8578
# File 'lib/models/porcelain.rb', line 8576

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8578
8579
8580
# File 'lib/models/porcelain.rb', line 8578

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8580
8581
8582
# File 'lib/models/porcelain.rb', line 8580

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8582
8583
8584
# File 'lib/models/porcelain.rb', line 8582

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8584
8585
8586
# File 'lib/models/porcelain.rb', line 8584

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



8586
8587
8588
# File 'lib/models/porcelain.rb', line 8586

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8588
8589
8590
# File 'lib/models/porcelain.rb', line 8588

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8590
8591
8592
# File 'lib/models/porcelain.rb', line 8590

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



8592
8593
8594
# File 'lib/models/porcelain.rb', line 8592

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8594
8595
8596
# File 'lib/models/porcelain.rb', line 8594

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8596
8597
8598
# File 'lib/models/porcelain.rb', line 8596

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8598
8599
8600
# File 'lib/models/porcelain.rb', line 8598

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8600
8601
8602
# File 'lib/models/porcelain.rb', line 8600

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8640
8641
8642
8643
8644
8645
8646
# File 'lib/models/porcelain.rb', line 8640

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end