Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 8014 8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 8025 8026 8027 8028 8029 8030 8031 8032 8033 8034 8035 8036 8037 8038 |
# File 'lib/models/porcelain.rb', line 8004 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7972 7973 7974 |
# File 'lib/models/porcelain.rb', line 7972 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7974 7975 7976 |
# File 'lib/models/porcelain.rb', line 7974 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7976 7977 7978 |
# File 'lib/models/porcelain.rb', line 7976 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7978 7979 7980 |
# File 'lib/models/porcelain.rb', line 7978 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7980 7981 7982 |
# File 'lib/models/porcelain.rb', line 7980 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7982 7983 7984 |
# File 'lib/models/porcelain.rb', line 7982 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7984 7985 7986 |
# File 'lib/models/porcelain.rb', line 7984 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
7986 7987 7988 |
# File 'lib/models/porcelain.rb', line 7986 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
7988 7989 7990 |
# File 'lib/models/porcelain.rb', line 7988 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7990 7991 7992 |
# File 'lib/models/porcelain.rb', line 7990 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7992 7993 7994 |
# File 'lib/models/porcelain.rb', line 7992 def port_override @port_override end |
#schema ⇒ Object
The Schema to use to direct initial requests.
7994 7995 7996 |
# File 'lib/models/porcelain.rb', line 7994 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7996 7997 7998 |
# File 'lib/models/porcelain.rb', line 7996 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7998 7999 8000 |
# File 'lib/models/porcelain.rb', line 7998 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8000 8001 8002 |
# File 'lib/models/porcelain.rb', line 8000 def @tags end |
#username ⇒ Object
The username to authenticate with.
8002 8003 8004 |
# File 'lib/models/porcelain.rb', line 8002 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8040 8041 8042 8043 8044 8045 8046 |
# File 'lib/models/porcelain.rb', line 8040 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |