Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#password ⇒ Object
The password to authenticate with.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
7581 7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 |
# File 'lib/models/porcelain.rb', line 7581 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7549 7550 7551 |
# File 'lib/models/porcelain.rb', line 7549 def bind_interface @bind_interface end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7551 7552 7553 |
# File 'lib/models/porcelain.rb', line 7551 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7553 7554 7555 |
# File 'lib/models/porcelain.rb', line 7553 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7555 7556 7557 |
# File 'lib/models/porcelain.rb', line 7555 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7557 7558 7559 |
# File 'lib/models/porcelain.rb', line 7557 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7559 7560 7561 |
# File 'lib/models/porcelain.rb', line 7559 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7561 7562 7563 |
# File 'lib/models/porcelain.rb', line 7561 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
7563 7564 7565 |
# File 'lib/models/porcelain.rb', line 7563 def override_database @override_database end |
#password ⇒ Object
The password to authenticate with.
7565 7566 7567 |
# File 'lib/models/porcelain.rb', line 7565 def password @password end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7567 7568 7569 |
# File 'lib/models/porcelain.rb', line 7567 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7569 7570 7571 |
# File 'lib/models/porcelain.rb', line 7569 def port_override @port_override end |
#schema ⇒ Object
The Schema to use to direct initial requests.
7571 7572 7573 |
# File 'lib/models/porcelain.rb', line 7571 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7573 7574 7575 |
# File 'lib/models/porcelain.rb', line 7573 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7575 7576 7577 |
# File 'lib/models/porcelain.rb', line 7575 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7577 7578 7579 |
# File 'lib/models/porcelain.rb', line 7577 def @tags end |
#username ⇒ Object
The username to authenticate with.
7579 7580 7581 |
# File 'lib/models/porcelain.rb', line 7579 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7617 7618 7619 7620 7621 7622 7623 |
# File 'lib/models/porcelain.rb', line 7617 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |