Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
7347 7348 7349 7350 7351 7352 7353 7354 7355 7356 7357 7358 7359 7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 7371 7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 |
# File 'lib/models/porcelain.rb', line 7347 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7315 7316 7317 |
# File 'lib/models/porcelain.rb', line 7315 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
7317 7318 7319 |
# File 'lib/models/porcelain.rb', line 7317 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7319 7320 7321 |
# File 'lib/models/porcelain.rb', line 7319 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7321 7322 7323 |
# File 'lib/models/porcelain.rb', line 7321 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7323 7324 7325 |
# File 'lib/models/porcelain.rb', line 7323 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7325 7326 7327 |
# File 'lib/models/porcelain.rb', line 7325 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7327 7328 7329 |
# File 'lib/models/porcelain.rb', line 7327 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
7329 7330 7331 |
# File 'lib/models/porcelain.rb', line 7329 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
7331 7332 7333 |
# File 'lib/models/porcelain.rb', line 7331 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7333 7334 7335 |
# File 'lib/models/porcelain.rb', line 7333 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7335 7336 7337 |
# File 'lib/models/porcelain.rb', line 7335 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
7337 7338 7339 |
# File 'lib/models/porcelain.rb', line 7337 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7339 7340 7341 |
# File 'lib/models/porcelain.rb', line 7339 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7341 7342 7343 |
# File 'lib/models/porcelain.rb', line 7341 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7343 7344 7345 |
# File 'lib/models/porcelain.rb', line 7343 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7345 7346 7347 |
# File 'lib/models/porcelain.rb', line 7345 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7383 7384 7385 7386 7387 7388 7389 |
# File 'lib/models/porcelain.rb', line 7383 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |