Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



7294
7295
7296
7297
7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
7314
7315
7316
7317
7318
7319
7320
7321
7322
7323
7324
7325
7326
7327
7328
# File 'lib/models/porcelain.rb', line 7294

def initialize(
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#bind_interfaceObject

Bind interface



7262
7263
7264
# File 'lib/models/porcelain.rb', line 7262

def bind_interface
  @bind_interface
end

#databaseObject

Returns the value of attribute database.



7264
7265
7266
# File 'lib/models/porcelain.rb', line 7264

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7266
7267
7268
# File 'lib/models/porcelain.rb', line 7266

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7268
7269
7270
# File 'lib/models/porcelain.rb', line 7268

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7270
7271
7272
# File 'lib/models/porcelain.rb', line 7270

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7272
7273
7274
# File 'lib/models/porcelain.rb', line 7272

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7274
7275
7276
# File 'lib/models/porcelain.rb', line 7274

def name
  @name
end

#override_databaseObject

Returns the value of attribute override_database.



7276
7277
7278
# File 'lib/models/porcelain.rb', line 7276

def override_database
  @override_database
end

#passwordObject

Returns the value of attribute password.



7278
7279
7280
# File 'lib/models/porcelain.rb', line 7278

def password
  @password
end

#portObject

Returns the value of attribute port.



7280
7281
7282
# File 'lib/models/porcelain.rb', line 7280

def port
  @port
end

#port_overrideObject

Returns the value of attribute port_override.



7282
7283
7284
# File 'lib/models/porcelain.rb', line 7282

def port_override
  @port_override
end

#schemaObject

Returns the value of attribute schema.



7284
7285
7286
# File 'lib/models/porcelain.rb', line 7284

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7286
7287
7288
# File 'lib/models/porcelain.rb', line 7286

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7288
7289
7290
# File 'lib/models/porcelain.rb', line 7288

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7290
7291
7292
# File 'lib/models/porcelain.rb', line 7290

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7292
7293
7294
# File 'lib/models/porcelain.rb', line 7292

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7330
7331
7332
7333
7334
7335
7336
# File 'lib/models/porcelain.rb', line 7330

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end