Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
7094 7095 7096 7097 7098 7099 7100 7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 |
# File 'lib/models/porcelain.rb', line 7094 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7062 7063 7064 |
# File 'lib/models/porcelain.rb', line 7062 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
7064 7065 7066 |
# File 'lib/models/porcelain.rb', line 7064 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7066 7067 7068 |
# File 'lib/models/porcelain.rb', line 7066 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7068 7069 7070 |
# File 'lib/models/porcelain.rb', line 7068 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7070 7071 7072 |
# File 'lib/models/porcelain.rb', line 7070 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7072 7073 7074 |
# File 'lib/models/porcelain.rb', line 7072 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7074 7075 7076 |
# File 'lib/models/porcelain.rb', line 7074 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
7076 7077 7078 |
# File 'lib/models/porcelain.rb', line 7076 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
7078 7079 7080 |
# File 'lib/models/porcelain.rb', line 7078 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
7080 7081 7082 |
# File 'lib/models/porcelain.rb', line 7080 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7082 7083 7084 |
# File 'lib/models/porcelain.rb', line 7082 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
7084 7085 7086 |
# File 'lib/models/porcelain.rb', line 7084 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7086 7087 7088 |
# File 'lib/models/porcelain.rb', line 7086 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7088 7089 7090 |
# File 'lib/models/porcelain.rb', line 7088 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7090 7091 7092 |
# File 'lib/models/porcelain.rb', line 7090 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7092 7093 7094 |
# File 'lib/models/porcelain.rb', line 7092 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7130 7131 7132 7133 7134 7135 7136 |
# File 'lib/models/porcelain.rb', line 7130 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |