Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
6864 6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 6885 6886 6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 |
# File 'lib/models/porcelain.rb', line 6864 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
6834 6835 6836 |
# File 'lib/models/porcelain.rb', line 6834 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
6836 6837 6838 |
# File 'lib/models/porcelain.rb', line 6836 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6838 6839 6840 |
# File 'lib/models/porcelain.rb', line 6838 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6840 6841 6842 |
# File 'lib/models/porcelain.rb', line 6840 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6842 6843 6844 |
# File 'lib/models/porcelain.rb', line 6842 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6844 6845 6846 |
# File 'lib/models/porcelain.rb', line 6844 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6846 6847 6848 |
# File 'lib/models/porcelain.rb', line 6846 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
6848 6849 6850 |
# File 'lib/models/porcelain.rb', line 6848 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
6850 6851 6852 |
# File 'lib/models/porcelain.rb', line 6850 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6852 6853 6854 |
# File 'lib/models/porcelain.rb', line 6852 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6854 6855 6856 |
# File 'lib/models/porcelain.rb', line 6854 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
6856 6857 6858 |
# File 'lib/models/porcelain.rb', line 6856 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6858 6859 6860 |
# File 'lib/models/porcelain.rb', line 6858 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6860 6861 6862 |
# File 'lib/models/porcelain.rb', line 6860 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6862 6863 6864 |
# File 'lib/models/porcelain.rb', line 6862 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6898 6899 6900 6901 6902 6903 6904 |
# File 'lib/models/porcelain.rb', line 6898 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |