Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
5988 5989 5990 5991 5992 5993 5994 5995 5996 5997 5998 5999 6000 6001 6002 6003 6004 6005 6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 |
# File 'lib/models/porcelain.rb', line 5988 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5958 5959 5960 |
# File 'lib/models/porcelain.rb', line 5958 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5960 5961 5962 |
# File 'lib/models/porcelain.rb', line 5960 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5962 5963 5964 |
# File 'lib/models/porcelain.rb', line 5962 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5964 5965 5966 |
# File 'lib/models/porcelain.rb', line 5964 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5966 5967 5968 |
# File 'lib/models/porcelain.rb', line 5966 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5968 5969 5970 |
# File 'lib/models/porcelain.rb', line 5968 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5970 5971 5972 |
# File 'lib/models/porcelain.rb', line 5970 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5972 5973 5974 |
# File 'lib/models/porcelain.rb', line 5972 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5974 5975 5976 |
# File 'lib/models/porcelain.rb', line 5974 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5976 5977 5978 |
# File 'lib/models/porcelain.rb', line 5976 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5978 5979 5980 |
# File 'lib/models/porcelain.rb', line 5978 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
5980 5981 5982 |
# File 'lib/models/porcelain.rb', line 5980 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5982 5983 5984 |
# File 'lib/models/porcelain.rb', line 5982 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5984 5985 5986 |
# File 'lib/models/porcelain.rb', line 5984 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5986 5987 5988 |
# File 'lib/models/porcelain.rb', line 5986 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6022 6023 6024 6025 6026 6027 6028 |
# File 'lib/models/porcelain.rb', line 6022 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |