Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 5885 5886 5887 5888 5889 5890 5891 5892 5893 5894 5895 5896 5897 5898 5899 5900 |
# File 'lib/models/porcelain.rb', line 5868 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5838 5839 5840 |
# File 'lib/models/porcelain.rb', line 5838 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5840 5841 5842 |
# File 'lib/models/porcelain.rb', line 5840 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5842 5843 5844 |
# File 'lib/models/porcelain.rb', line 5842 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5844 5845 5846 |
# File 'lib/models/porcelain.rb', line 5844 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5846 5847 5848 |
# File 'lib/models/porcelain.rb', line 5846 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5848 5849 5850 |
# File 'lib/models/porcelain.rb', line 5848 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5850 5851 5852 |
# File 'lib/models/porcelain.rb', line 5850 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5852 5853 5854 |
# File 'lib/models/porcelain.rb', line 5852 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5854 5855 5856 |
# File 'lib/models/porcelain.rb', line 5854 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5856 5857 5858 |
# File 'lib/models/porcelain.rb', line 5856 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5858 5859 5860 |
# File 'lib/models/porcelain.rb', line 5858 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
5860 5861 5862 |
# File 'lib/models/porcelain.rb', line 5860 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5862 5863 5864 |
# File 'lib/models/porcelain.rb', line 5862 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5864 5865 5866 |
# File 'lib/models/porcelain.rb', line 5864 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5866 5867 5868 |
# File 'lib/models/porcelain.rb', line 5866 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5902 5903 5904 5905 5906 5907 5908 |
# File 'lib/models/porcelain.rb', line 5902 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |