Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
5834 5835 5836 5837 5838 5839 5840 5841 5842 5843 5844 5845 5846 5847 5848 5849 5850 5851 5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 |
# File 'lib/models/porcelain.rb', line 5834 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5804 5805 5806 |
# File 'lib/models/porcelain.rb', line 5804 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5806 5807 5808 |
# File 'lib/models/porcelain.rb', line 5806 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5808 5809 5810 |
# File 'lib/models/porcelain.rb', line 5808 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5810 5811 5812 |
# File 'lib/models/porcelain.rb', line 5810 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5812 5813 5814 |
# File 'lib/models/porcelain.rb', line 5812 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5814 5815 5816 |
# File 'lib/models/porcelain.rb', line 5814 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5816 5817 5818 |
# File 'lib/models/porcelain.rb', line 5816 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5818 5819 5820 |
# File 'lib/models/porcelain.rb', line 5818 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5820 5821 5822 |
# File 'lib/models/porcelain.rb', line 5820 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5822 5823 5824 |
# File 'lib/models/porcelain.rb', line 5822 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5824 5825 5826 |
# File 'lib/models/porcelain.rb', line 5824 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
5826 5827 5828 |
# File 'lib/models/porcelain.rb', line 5826 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5828 5829 5830 |
# File 'lib/models/porcelain.rb', line 5828 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5830 5831 5832 |
# File 'lib/models/porcelain.rb', line 5830 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5832 5833 5834 |
# File 'lib/models/porcelain.rb', line 5832 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/models/porcelain.rb', line 5868 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |