Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 |
# File 'lib/models/porcelain.rb', line 5730 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @password = password == nil ? "" : password @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
5700 5701 5702 |
# File 'lib/models/porcelain.rb', line 5700 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
5702 5703 5704 |
# File 'lib/models/porcelain.rb', line 5702 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5704 5705 5706 |
# File 'lib/models/porcelain.rb', line 5704 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5706 5707 5708 |
# File 'lib/models/porcelain.rb', line 5706 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5708 5709 5710 |
# File 'lib/models/porcelain.rb', line 5708 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5710 5711 5712 |
# File 'lib/models/porcelain.rb', line 5710 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
5712 5713 5714 |
# File 'lib/models/porcelain.rb', line 5712 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
5714 5715 5716 |
# File 'lib/models/porcelain.rb', line 5714 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
5716 5717 5718 |
# File 'lib/models/porcelain.rb', line 5716 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
5718 5719 5720 |
# File 'lib/models/porcelain.rb', line 5718 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5720 5721 5722 |
# File 'lib/models/porcelain.rb', line 5720 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
5722 5723 5724 |
# File 'lib/models/porcelain.rb', line 5722 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5724 5725 5726 |
# File 'lib/models/porcelain.rb', line 5724 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5726 5727 5728 |
# File 'lib/models/porcelain.rb', line 5726 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5728 5729 5730 |
# File 'lib/models/porcelain.rb', line 5728 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5764 5765 5766 5767 5768 5769 5770 |
# File 'lib/models/porcelain.rb', line 5764 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |