Class: SDM::SQLServer
- Inherits:
-
Object
- Object
- SDM::SQLServer
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
constructor
A new instance of SQLServer.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SQLServer
Returns a new instance of SQLServer.
6635 6636 6637 6638 6639 6640 6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 6651 6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 6680 6681 6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 |
# File 'lib/models/porcelain.rb', line 6635 def initialize( database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, schema: nil, secret_store_id: nil, tags: nil, username: nil ) if database != nil @database = database end if egress_filter != nil @egress_filter = egress_filter end if healthy != nil @healthy = healthy end if hostname != nil @hostname = hostname end if id != nil @id = id end if name != nil @name = name end if override_database != nil @override_database = override_database end if password != nil @password = password end if port != nil @port = port end if port_override != nil @port_override = port_override end if schema != nil @schema = schema end if secret_store_id != nil @secret_store_id = secret_store_id end if != nil @tags = end if username != nil @username = username end end |
Instance Attribute Details
#database ⇒ Object
Returns the value of attribute database.
6607 6608 6609 |
# File 'lib/models/porcelain.rb', line 6607 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6609 6610 6611 |
# File 'lib/models/porcelain.rb', line 6609 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6611 6612 6613 |
# File 'lib/models/porcelain.rb', line 6611 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6613 6614 6615 |
# File 'lib/models/porcelain.rb', line 6613 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6615 6616 6617 |
# File 'lib/models/porcelain.rb', line 6615 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
6617 6618 6619 |
# File 'lib/models/porcelain.rb', line 6617 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
6619 6620 6621 |
# File 'lib/models/porcelain.rb', line 6619 def override_database @override_database end |
#password ⇒ Object
Returns the value of attribute password.
6621 6622 6623 |
# File 'lib/models/porcelain.rb', line 6621 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
6623 6624 6625 |
# File 'lib/models/porcelain.rb', line 6623 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6625 6626 6627 |
# File 'lib/models/porcelain.rb', line 6625 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
6627 6628 6629 |
# File 'lib/models/porcelain.rb', line 6627 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6629 6630 6631 |
# File 'lib/models/porcelain.rb', line 6629 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6631 6632 6633 |
# File 'lib/models/porcelain.rb', line 6631 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6633 6634 6635 |
# File 'lib/models/porcelain.rb', line 6633 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6695 6696 6697 6698 6699 6700 6701 |
# File 'lib/models/porcelain.rb', line 6695 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |