Class: SDM::SQLServer

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServer

Returns a new instance of SQLServer.



15690
15691
15692
15693
15694
15695
15696
15697
15698
15699
15700
15701
15702
15703
15704
15705
15706
15707
15708
15709
15710
15711
15712
15713
15714
15715
15716
15717
15718
15719
15720
15721
15722
15723
15724
15725
15726
15727
15728
# File 'lib/models/porcelain.rb', line 15690

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



15654
15655
15656
# File 'lib/models/porcelain.rb', line 15654

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15656
15657
15658
# File 'lib/models/porcelain.rb', line 15656

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



15658
15659
15660
# File 'lib/models/porcelain.rb', line 15658

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15660
15661
15662
# File 'lib/models/porcelain.rb', line 15660

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15662
15663
15664
# File 'lib/models/porcelain.rb', line 15662

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15664
15665
15666
# File 'lib/models/porcelain.rb', line 15664

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15666
15667
15668
# File 'lib/models/porcelain.rb', line 15666

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15668
15669
15670
# File 'lib/models/porcelain.rb', line 15668

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15670
15671
15672
# File 'lib/models/porcelain.rb', line 15670

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



15672
15673
15674
# File 'lib/models/porcelain.rb', line 15672

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15674
15675
15676
# File 'lib/models/porcelain.rb', line 15674

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15676
15677
15678
# File 'lib/models/porcelain.rb', line 15676

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15678
15679
15680
# File 'lib/models/porcelain.rb', line 15678

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



15680
15681
15682
# File 'lib/models/porcelain.rb', line 15680

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15682
15683
15684
# File 'lib/models/porcelain.rb', line 15682

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15684
15685
15686
# File 'lib/models/porcelain.rb', line 15684

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15686
15687
15688
# File 'lib/models/porcelain.rb', line 15686

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15688
15689
15690
# File 'lib/models/porcelain.rb', line 15688

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15730
15731
15732
15733
15734
15735
15736
# File 'lib/models/porcelain.rb', line 15730

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end