Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



16550
16551
16552
16553
16554
16555
16556
16557
16558
16559
16560
16561
16562
16563
16564
16565
16566
16567
16568
16569
16570
16571
16572
16573
16574
16575
16576
16577
16578
16579
16580
16581
16582
16583
16584
16585
16586
16587
16588
16589
16590
# File 'lib/models/porcelain.rb', line 16550

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16512
16513
16514
# File 'lib/models/porcelain.rb', line 16512

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16514
16515
16516
# File 'lib/models/porcelain.rb', line 16514

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



16516
16517
16518
# File 'lib/models/porcelain.rb', line 16516

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



16518
16519
16520
# File 'lib/models/porcelain.rb', line 16518

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16520
16521
16522
# File 'lib/models/porcelain.rb', line 16520

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16522
16523
16524
# File 'lib/models/porcelain.rb', line 16522

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16524
16525
16526
# File 'lib/models/porcelain.rb', line 16524

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16526
16527
16528
# File 'lib/models/porcelain.rb', line 16526

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16528
16529
16530
# File 'lib/models/porcelain.rb', line 16528

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16530
16531
16532
# File 'lib/models/porcelain.rb', line 16530

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16532
16533
16534
# File 'lib/models/porcelain.rb', line 16532

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16534
16535
16536
# File 'lib/models/porcelain.rb', line 16534

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16536
16537
16538
# File 'lib/models/porcelain.rb', line 16536

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



16538
16539
16540
# File 'lib/models/porcelain.rb', line 16538

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



16540
16541
16542
# File 'lib/models/porcelain.rb', line 16540

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16542
16543
16544
# File 'lib/models/porcelain.rb', line 16542

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16544
16545
16546
# File 'lib/models/porcelain.rb', line 16544

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16546
16547
16548
# File 'lib/models/porcelain.rb', line 16546

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



16548
16549
16550
# File 'lib/models/porcelain.rb', line 16548

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16592
16593
16594
16595
16596
16597
16598
# File 'lib/models/porcelain.rb', line 16592

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end