Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



16422
16423
16424
16425
16426
16427
16428
16429
16430
16431
16432
16433
16434
16435
16436
16437
16438
16439
16440
16441
16442
16443
16444
16445
16446
16447
16448
16449
16450
16451
16452
16453
16454
16455
16456
16457
16458
16459
16460
16461
16462
# File 'lib/models/porcelain.rb', line 16422

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16384
16385
16386
# File 'lib/models/porcelain.rb', line 16384

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16386
16387
16388
# File 'lib/models/porcelain.rb', line 16386

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



16388
16389
16390
# File 'lib/models/porcelain.rb', line 16388

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



16390
16391
16392
# File 'lib/models/porcelain.rb', line 16390

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16392
16393
16394
# File 'lib/models/porcelain.rb', line 16392

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16394
16395
16396
# File 'lib/models/porcelain.rb', line 16394

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16396
16397
16398
# File 'lib/models/porcelain.rb', line 16396

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16398
16399
16400
# File 'lib/models/porcelain.rb', line 16398

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16400
16401
16402
# File 'lib/models/porcelain.rb', line 16400

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16402
16403
16404
# File 'lib/models/porcelain.rb', line 16402

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16404
16405
16406
# File 'lib/models/porcelain.rb', line 16404

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16406
16407
16408
# File 'lib/models/porcelain.rb', line 16406

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16408
16409
16410
# File 'lib/models/porcelain.rb', line 16408

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



16410
16411
16412
# File 'lib/models/porcelain.rb', line 16410

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



16412
16413
16414
# File 'lib/models/porcelain.rb', line 16412

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16414
16415
16416
# File 'lib/models/porcelain.rb', line 16414

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16416
16417
16418
# File 'lib/models/porcelain.rb', line 16416

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16418
16419
16420
# File 'lib/models/porcelain.rb', line 16418

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



16420
16421
16422
# File 'lib/models/porcelain.rb', line 16420

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16464
16465
16466
16467
16468
16469
16470
# File 'lib/models/porcelain.rb', line 16464

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end