Class: SDM::SQLServerAzureAD
- Inherits:
-
Object
- Object
- SDM::SQLServerAzureAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#client_id ⇒ Object
The Azure AD application (client) ID with which to authenticate.
-
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret ⇒ Object
The Azure AD client secret (application password) with which to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
The Azure AD directory (tenant) ID with which to authenticate.
Instance Method Summary collapse
-
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
constructor
A new instance of SQLServerAzureAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
Returns a new instance of SQLServerAzureAD.
16196 16197 16198 16199 16200 16201 16202 16203 16204 16205 16206 16207 16208 16209 16210 16211 16212 16213 16214 16215 16216 16217 16218 16219 16220 16221 16222 16223 16224 16225 16226 16227 16228 16229 16230 16231 16232 16233 16234 16235 16236 |
# File 'lib/models/porcelain.rb', line 16196 def initialize( allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption @bind_interface = bind_interface == nil ? "" : bind_interface @client_id = client_id == nil ? "" : client_id @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @schema = schema == nil ? "" : schema @secret = secret == nil ? "" : secret @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.
16158 16159 16160 |
# File 'lib/models/porcelain.rb', line 16158 def allow_deprecated_encryption @allow_deprecated_encryption end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
16160 16161 16162 |
# File 'lib/models/porcelain.rb', line 16160 def bind_interface @bind_interface end |
#client_id ⇒ Object
The Azure AD application (client) ID with which to authenticate.
16162 16163 16164 |
# File 'lib/models/porcelain.rb', line 16162 def client_id @client_id end |
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
16164 16165 16166 |
# File 'lib/models/porcelain.rb', line 16164 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
16166 16167 16168 |
# File 'lib/models/porcelain.rb', line 16166 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
16168 16169 16170 |
# File 'lib/models/porcelain.rb', line 16168 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
16170 16171 16172 |
# File 'lib/models/porcelain.rb', line 16170 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
16172 16173 16174 |
# File 'lib/models/porcelain.rb', line 16172 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
16174 16175 16176 |
# File 'lib/models/porcelain.rb', line 16174 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
16176 16177 16178 |
# File 'lib/models/porcelain.rb', line 16176 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
16178 16179 16180 |
# File 'lib/models/porcelain.rb', line 16178 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
16180 16181 16182 |
# File 'lib/models/porcelain.rb', line 16180 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
16182 16183 16184 |
# File 'lib/models/porcelain.rb', line 16182 def proxy_cluster_id @proxy_cluster_id end |
#schema ⇒ Object
The Schema to use to direct initial requests.
16184 16185 16186 |
# File 'lib/models/porcelain.rb', line 16184 def schema @schema end |
#secret ⇒ Object
The Azure AD client secret (application password) with which to authenticate.
16186 16187 16188 |
# File 'lib/models/porcelain.rb', line 16186 def secret @secret end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
16188 16189 16190 |
# File 'lib/models/porcelain.rb', line 16188 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
16190 16191 16192 |
# File 'lib/models/porcelain.rb', line 16190 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16192 16193 16194 |
# File 'lib/models/porcelain.rb', line 16192 def @tags end |
#tenant_id ⇒ Object
The Azure AD directory (tenant) ID with which to authenticate.
16194 16195 16196 |
# File 'lib/models/porcelain.rb', line 16194 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16238 16239 16240 16241 16242 16243 16244 |
# File 'lib/models/porcelain.rb', line 16238 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |