Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



16080
16081
16082
16083
16084
16085
16086
16087
16088
16089
16090
16091
16092
16093
16094
16095
16096
16097
16098
16099
16100
16101
16102
16103
16104
16105
16106
16107
16108
16109
16110
16111
16112
16113
16114
16115
16116
16117
16118
16119
16120
# File 'lib/models/porcelain.rb', line 16080

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16042
16043
16044
# File 'lib/models/porcelain.rb', line 16042

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16044
16045
16046
# File 'lib/models/porcelain.rb', line 16044

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



16046
16047
16048
# File 'lib/models/porcelain.rb', line 16046

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



16048
16049
16050
# File 'lib/models/porcelain.rb', line 16048

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16050
16051
16052
# File 'lib/models/porcelain.rb', line 16050

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16052
16053
16054
# File 'lib/models/porcelain.rb', line 16052

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16054
16055
16056
# File 'lib/models/porcelain.rb', line 16054

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16056
16057
16058
# File 'lib/models/porcelain.rb', line 16056

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



16058
16059
16060
# File 'lib/models/porcelain.rb', line 16058

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16060
16061
16062
# File 'lib/models/porcelain.rb', line 16060

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16062
16063
16064
# File 'lib/models/porcelain.rb', line 16062

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16064
16065
16066
# File 'lib/models/porcelain.rb', line 16064

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16066
16067
16068
# File 'lib/models/porcelain.rb', line 16066

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



16068
16069
16070
# File 'lib/models/porcelain.rb', line 16068

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



16070
16071
16072
# File 'lib/models/porcelain.rb', line 16070

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16072
16073
16074
# File 'lib/models/porcelain.rb', line 16072

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16074
16075
16076
# File 'lib/models/porcelain.rb', line 16074

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16076
16077
16078
# File 'lib/models/porcelain.rb', line 16076

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



16078
16079
16080
# File 'lib/models/porcelain.rb', line 16078

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16122
16123
16124
16125
16126
16127
16128
# File 'lib/models/porcelain.rb', line 16122

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end