Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



15691
15692
15693
15694
15695
15696
15697
15698
15699
15700
15701
15702
15703
15704
15705
15706
15707
15708
15709
15710
15711
15712
15713
15714
15715
15716
15717
15718
15719
15720
15721
15722
15723
15724
15725
15726
15727
15728
15729
15730
15731
# File 'lib/models/porcelain.rb', line 15691

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



15653
15654
15655
# File 'lib/models/porcelain.rb', line 15653

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15655
15656
15657
# File 'lib/models/porcelain.rb', line 15655

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



15657
15658
15659
# File 'lib/models/porcelain.rb', line 15657

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



15659
15660
15661
# File 'lib/models/porcelain.rb', line 15659

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15661
15662
15663
# File 'lib/models/porcelain.rb', line 15661

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15663
15664
15665
# File 'lib/models/porcelain.rb', line 15663

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15665
15666
15667
# File 'lib/models/porcelain.rb', line 15665

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15667
15668
15669
# File 'lib/models/porcelain.rb', line 15667

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



15669
15670
15671
# File 'lib/models/porcelain.rb', line 15669

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15671
15672
15673
# File 'lib/models/porcelain.rb', line 15671

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15673
15674
15675
# File 'lib/models/porcelain.rb', line 15673

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15675
15676
15677
# File 'lib/models/porcelain.rb', line 15675

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15677
15678
15679
# File 'lib/models/porcelain.rb', line 15677

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



15679
15680
15681
# File 'lib/models/porcelain.rb', line 15679

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



15681
15682
15683
# File 'lib/models/porcelain.rb', line 15681

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15683
15684
15685
# File 'lib/models/porcelain.rb', line 15683

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15685
15686
15687
# File 'lib/models/porcelain.rb', line 15685

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15687
15688
15689
# File 'lib/models/porcelain.rb', line 15687

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



15689
15690
15691
# File 'lib/models/porcelain.rb', line 15689

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15733
15734
15735
15736
15737
15738
15739
# File 'lib/models/porcelain.rb', line 15733

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end