Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
14539
14540
14541
14542
14543
14544
14545
14546
14547
14548
14549
14550
14551
14552
14553
14554
14555
14556
14557
14558
14559
# File 'lib/models/porcelain.rb', line 14519

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



14481
14482
14483
# File 'lib/models/porcelain.rb', line 14481

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14483
14484
14485
# File 'lib/models/porcelain.rb', line 14483

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



14485
14486
14487
# File 'lib/models/porcelain.rb', line 14485

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



14487
14488
14489
# File 'lib/models/porcelain.rb', line 14487

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14489
14490
14491
# File 'lib/models/porcelain.rb', line 14489

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14491
14492
14493
# File 'lib/models/porcelain.rb', line 14491

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14493
14494
14495
# File 'lib/models/porcelain.rb', line 14493

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14495
14496
14497
# File 'lib/models/porcelain.rb', line 14495

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



14497
14498
14499
# File 'lib/models/porcelain.rb', line 14497

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14499
14500
14501
# File 'lib/models/porcelain.rb', line 14499

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14501
14502
14503
# File 'lib/models/porcelain.rb', line 14501

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14503
14504
14505
# File 'lib/models/porcelain.rb', line 14503

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14505
14506
14507
# File 'lib/models/porcelain.rb', line 14505

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



14507
14508
14509
# File 'lib/models/porcelain.rb', line 14507

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



14509
14510
14511
# File 'lib/models/porcelain.rb', line 14509

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14511
14512
14513
# File 'lib/models/porcelain.rb', line 14511

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14513
14514
14515
# File 'lib/models/porcelain.rb', line 14513

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14515
14516
14517
# File 'lib/models/porcelain.rb', line 14515

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



14517
14518
14519
# File 'lib/models/porcelain.rb', line 14517

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14561
14562
14563
14564
14565
14566
14567
# File 'lib/models/porcelain.rb', line 14561

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end