Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



13224
13225
13226
13227
13228
13229
13230
13231
13232
13233
13234
13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
13245
13246
13247
13248
13249
13250
13251
13252
13253
13254
13255
13256
13257
13258
13259
13260
13261
13262
13263
13264
# File 'lib/models/porcelain.rb', line 13224

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



13186
13187
13188
# File 'lib/models/porcelain.rb', line 13186

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13188
13189
13190
# File 'lib/models/porcelain.rb', line 13188

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



13190
13191
13192
# File 'lib/models/porcelain.rb', line 13190

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



13192
13193
13194
# File 'lib/models/porcelain.rb', line 13192

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13194
13195
13196
# File 'lib/models/porcelain.rb', line 13194

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13196
13197
13198
# File 'lib/models/porcelain.rb', line 13196

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13198
13199
13200
# File 'lib/models/porcelain.rb', line 13198

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13200
13201
13202
# File 'lib/models/porcelain.rb', line 13200

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



13202
13203
13204
# File 'lib/models/porcelain.rb', line 13202

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13204
13205
13206
# File 'lib/models/porcelain.rb', line 13204

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13206
13207
13208
# File 'lib/models/porcelain.rb', line 13206

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13208
13209
13210
# File 'lib/models/porcelain.rb', line 13208

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13210
13211
13212
# File 'lib/models/porcelain.rb', line 13210

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



13212
13213
13214
# File 'lib/models/porcelain.rb', line 13212

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



13214
13215
13216
# File 'lib/models/porcelain.rb', line 13214

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13216
13217
13218
# File 'lib/models/porcelain.rb', line 13216

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13218
13219
13220
# File 'lib/models/porcelain.rb', line 13218

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13220
13221
13222
# File 'lib/models/porcelain.rb', line 13220

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



13222
13223
13224
# File 'lib/models/porcelain.rb', line 13222

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13266
13267
13268
13269
13270
13271
13272
# File 'lib/models/porcelain.rb', line 13266

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end