Class: SDM::SQLServerAzureAD
- Inherits:
-
Object
- Object
- SDM::SQLServerAzureAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#client_id ⇒ Object
The Azure AD application (client) ID with which to authenticate.
-
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret ⇒ Object
The Azure AD client secret (application password) with which to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
The Azure AD directory (tenant) ID with which to authenticate.
Instance Method Summary collapse
-
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
constructor
A new instance of SQLServerAzureAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
Returns a new instance of SQLServerAzureAD.
13056 13057 13058 13059 13060 13061 13062 13063 13064 13065 13066 13067 13068 13069 13070 13071 13072 13073 13074 13075 13076 13077 13078 13079 13080 13081 13082 13083 13084 13085 13086 13087 13088 13089 13090 13091 13092 13093 13094 13095 13096 |
# File 'lib/models/porcelain.rb', line 13056 def initialize( allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption @bind_interface = bind_interface == nil ? "" : bind_interface @client_id = client_id == nil ? "" : client_id @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @schema = schema == nil ? "" : schema @secret = secret == nil ? "" : secret @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.
13018 13019 13020 |
# File 'lib/models/porcelain.rb', line 13018 def allow_deprecated_encryption @allow_deprecated_encryption end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
13020 13021 13022 |
# File 'lib/models/porcelain.rb', line 13020 def bind_interface @bind_interface end |
#client_id ⇒ Object
The Azure AD application (client) ID with which to authenticate.
13022 13023 13024 |
# File 'lib/models/porcelain.rb', line 13022 def client_id @client_id end |
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
13024 13025 13026 |
# File 'lib/models/porcelain.rb', line 13024 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
13026 13027 13028 |
# File 'lib/models/porcelain.rb', line 13026 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
13028 13029 13030 |
# File 'lib/models/porcelain.rb', line 13028 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
13030 13031 13032 |
# File 'lib/models/porcelain.rb', line 13030 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
13032 13033 13034 |
# File 'lib/models/porcelain.rb', line 13032 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
13034 13035 13036 |
# File 'lib/models/porcelain.rb', line 13034 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
13036 13037 13038 |
# File 'lib/models/porcelain.rb', line 13036 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
13038 13039 13040 |
# File 'lib/models/porcelain.rb', line 13038 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
13040 13041 13042 |
# File 'lib/models/porcelain.rb', line 13040 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
13042 13043 13044 |
# File 'lib/models/porcelain.rb', line 13042 def proxy_cluster_id @proxy_cluster_id end |
#schema ⇒ Object
The Schema to use to direct initial requests.
13044 13045 13046 |
# File 'lib/models/porcelain.rb', line 13044 def schema @schema end |
#secret ⇒ Object
The Azure AD client secret (application password) with which to authenticate.
13046 13047 13048 |
# File 'lib/models/porcelain.rb', line 13046 def secret @secret end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
13048 13049 13050 |
# File 'lib/models/porcelain.rb', line 13048 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
13050 13051 13052 |
# File 'lib/models/porcelain.rb', line 13050 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13052 13053 13054 |
# File 'lib/models/porcelain.rb', line 13052 def @tags end |
#tenant_id ⇒ Object
The Azure AD directory (tenant) ID with which to authenticate.
13054 13055 13056 |
# File 'lib/models/porcelain.rb', line 13054 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13098 13099 13100 13101 13102 13103 13104 |
# File 'lib/models/porcelain.rb', line 13098 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |