Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
12854
12855
12856
12857
12858
12859
12860
12861
12862
12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
# File 'lib/models/porcelain.rb', line 12836

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



12798
12799
12800
# File 'lib/models/porcelain.rb', line 12798

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12800
12801
12802
# File 'lib/models/porcelain.rb', line 12800

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



12802
12803
12804
# File 'lib/models/porcelain.rb', line 12802

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



12804
12805
12806
# File 'lib/models/porcelain.rb', line 12804

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12806
12807
12808
# File 'lib/models/porcelain.rb', line 12806

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12808
12809
12810
# File 'lib/models/porcelain.rb', line 12808

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12810
12811
12812
# File 'lib/models/porcelain.rb', line 12810

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12812
12813
12814
# File 'lib/models/porcelain.rb', line 12812

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



12814
12815
12816
# File 'lib/models/porcelain.rb', line 12814

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12816
12817
12818
# File 'lib/models/porcelain.rb', line 12816

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12818
12819
12820
# File 'lib/models/porcelain.rb', line 12818

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12820
12821
12822
# File 'lib/models/porcelain.rb', line 12820

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12822
12823
12824
# File 'lib/models/porcelain.rb', line 12822

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



12824
12825
12826
# File 'lib/models/porcelain.rb', line 12824

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



12826
12827
12828
# File 'lib/models/porcelain.rb', line 12826

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12828
12829
12830
# File 'lib/models/porcelain.rb', line 12828

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12830
12831
12832
# File 'lib/models/porcelain.rb', line 12830

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12832
12833
12834
# File 'lib/models/porcelain.rb', line 12832

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



12834
12835
12836
# File 'lib/models/porcelain.rb', line 12834

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12878
12879
12880
12881
12882
12883
12884
# File 'lib/models/porcelain.rb', line 12878

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end