Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



11910
11911
11912
11913
11914
11915
11916
11917
11918
11919
11920
11921
11922
11923
11924
11925
11926
11927
11928
11929
11930
11931
11932
11933
11934
11935
11936
11937
11938
11939
11940
11941
11942
11943
11944
11945
11946
11947
11948
11949
11950
# File 'lib/models/porcelain.rb', line 11910

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11872
11873
11874
# File 'lib/models/porcelain.rb', line 11872

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11874
11875
11876
# File 'lib/models/porcelain.rb', line 11874

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



11876
11877
11878
# File 'lib/models/porcelain.rb', line 11876

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11878
11879
11880
# File 'lib/models/porcelain.rb', line 11878

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11880
11881
11882
# File 'lib/models/porcelain.rb', line 11880

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11882
11883
11884
# File 'lib/models/porcelain.rb', line 11882

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11884
11885
11886
# File 'lib/models/porcelain.rb', line 11884

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11886
11887
11888
# File 'lib/models/porcelain.rb', line 11886

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11888
11889
11890
# File 'lib/models/porcelain.rb', line 11888

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11890
11891
11892
# File 'lib/models/porcelain.rb', line 11890

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11892
11893
11894
# File 'lib/models/porcelain.rb', line 11892

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11894
11895
11896
# File 'lib/models/porcelain.rb', line 11894

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11896
11897
11898
# File 'lib/models/porcelain.rb', line 11896

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11898
11899
11900
# File 'lib/models/porcelain.rb', line 11898

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



11900
11901
11902
# File 'lib/models/porcelain.rb', line 11900

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11902
11903
11904
# File 'lib/models/porcelain.rb', line 11902

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11904
11905
11906
# File 'lib/models/porcelain.rb', line 11904

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11906
11907
11908
# File 'lib/models/porcelain.rb', line 11906

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



11908
11909
11910
# File 'lib/models/porcelain.rb', line 11908

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11952
11953
11954
11955
11956
11957
11958
# File 'lib/models/porcelain.rb', line 11952

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end