Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



11734
11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
11752
11753
11754
11755
11756
11757
11758
11759
11760
11761
11762
11763
11764
11765
11766
11767
11768
11769
11770
11771
11772
11773
11774
# File 'lib/models/porcelain.rb', line 11734

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11696
11697
11698
# File 'lib/models/porcelain.rb', line 11696

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11698
11699
11700
# File 'lib/models/porcelain.rb', line 11698

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



11700
11701
11702
# File 'lib/models/porcelain.rb', line 11700

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11702
11703
11704
# File 'lib/models/porcelain.rb', line 11702

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11704
11705
11706
# File 'lib/models/porcelain.rb', line 11704

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11706
11707
11708
# File 'lib/models/porcelain.rb', line 11706

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11708
11709
11710
# File 'lib/models/porcelain.rb', line 11708

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11710
11711
11712
# File 'lib/models/porcelain.rb', line 11710

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11712
11713
11714
# File 'lib/models/porcelain.rb', line 11712

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11714
11715
11716
# File 'lib/models/porcelain.rb', line 11714

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11716
11717
11718
# File 'lib/models/porcelain.rb', line 11716

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11718
11719
11720
# File 'lib/models/porcelain.rb', line 11718

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11720
11721
11722
# File 'lib/models/porcelain.rb', line 11720

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11722
11723
11724
# File 'lib/models/porcelain.rb', line 11722

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



11724
11725
11726
# File 'lib/models/porcelain.rb', line 11724

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11726
11727
11728
# File 'lib/models/porcelain.rb', line 11726

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11728
11729
11730
# File 'lib/models/porcelain.rb', line 11728

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11730
11731
11732
# File 'lib/models/porcelain.rb', line 11730

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



11732
11733
11734
# File 'lib/models/porcelain.rb', line 11732

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11776
11777
11778
11779
11780
11781
11782
# File 'lib/models/porcelain.rb', line 11776

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end