Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



11663
11664
11665
11666
11667
11668
11669
11670
11671
11672
11673
11674
11675
11676
11677
11678
11679
11680
11681
11682
11683
11684
11685
11686
11687
11688
11689
11690
11691
11692
11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
11703
# File 'lib/models/porcelain.rb', line 11663

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11625
11626
11627
# File 'lib/models/porcelain.rb', line 11625

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11627
11628
11629
# File 'lib/models/porcelain.rb', line 11627

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



11629
11630
11631
# File 'lib/models/porcelain.rb', line 11629

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11631
11632
11633
# File 'lib/models/porcelain.rb', line 11631

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11633
11634
11635
# File 'lib/models/porcelain.rb', line 11633

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11635
11636
11637
# File 'lib/models/porcelain.rb', line 11635

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11637
11638
11639
# File 'lib/models/porcelain.rb', line 11637

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11639
11640
11641
# File 'lib/models/porcelain.rb', line 11639

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11641
11642
11643
# File 'lib/models/porcelain.rb', line 11641

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11643
11644
11645
# File 'lib/models/porcelain.rb', line 11643

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11645
11646
11647
# File 'lib/models/porcelain.rb', line 11645

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11647
11648
11649
# File 'lib/models/porcelain.rb', line 11647

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11649
11650
11651
# File 'lib/models/porcelain.rb', line 11649

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11651
11652
11653
# File 'lib/models/porcelain.rb', line 11651

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



11653
11654
11655
# File 'lib/models/porcelain.rb', line 11653

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11655
11656
11657
# File 'lib/models/porcelain.rb', line 11655

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11657
11658
11659
# File 'lib/models/porcelain.rb', line 11657

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11659
11660
11661
# File 'lib/models/porcelain.rb', line 11659

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



11661
11662
11663
# File 'lib/models/porcelain.rb', line 11661

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11705
11706
11707
11708
11709
11710
11711
# File 'lib/models/porcelain.rb', line 11705

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end