Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
11532
11533
11534
11535
11536
11537
11538
11539
11540
11541
11542
11543
11544
11545
11546
11547
11548
11549
11550
11551
11552
# File 'lib/models/porcelain.rb', line 11512

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11474
11475
11476
# File 'lib/models/porcelain.rb', line 11474

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11476
11477
11478
# File 'lib/models/porcelain.rb', line 11476

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



11478
11479
11480
# File 'lib/models/porcelain.rb', line 11478

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11480
11481
11482
# File 'lib/models/porcelain.rb', line 11480

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11482
11483
11484
# File 'lib/models/porcelain.rb', line 11482

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11484
11485
11486
# File 'lib/models/porcelain.rb', line 11484

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11486
11487
11488
# File 'lib/models/porcelain.rb', line 11486

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11488
11489
11490
# File 'lib/models/porcelain.rb', line 11488

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11490
11491
11492
# File 'lib/models/porcelain.rb', line 11490

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11492
11493
11494
# File 'lib/models/porcelain.rb', line 11492

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11494
11495
11496
# File 'lib/models/porcelain.rb', line 11494

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11496
11497
11498
# File 'lib/models/porcelain.rb', line 11496

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11498
11499
11500
# File 'lib/models/porcelain.rb', line 11498

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11500
11501
11502
# File 'lib/models/porcelain.rb', line 11500

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



11502
11503
11504
# File 'lib/models/porcelain.rb', line 11502

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11504
11505
11506
# File 'lib/models/porcelain.rb', line 11504

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11506
11507
11508
# File 'lib/models/porcelain.rb', line 11506

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11508
11509
11510
# File 'lib/models/porcelain.rb', line 11508

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



11510
11511
11512
# File 'lib/models/porcelain.rb', line 11510

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11554
11555
11556
11557
11558
11559
11560
# File 'lib/models/porcelain.rb', line 11554

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end