Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
11161
11162
11163
11164
11165
11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
# File 'lib/models/porcelain.rb', line 11149

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11111
11112
11113
# File 'lib/models/porcelain.rb', line 11111

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11113
11114
11115
# File 'lib/models/porcelain.rb', line 11113

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



11115
11116
11117
# File 'lib/models/porcelain.rb', line 11115

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11117
11118
11119
# File 'lib/models/porcelain.rb', line 11117

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11119
11120
11121
# File 'lib/models/porcelain.rb', line 11119

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11121
11122
11123
# File 'lib/models/porcelain.rb', line 11121

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11123
11124
11125
# File 'lib/models/porcelain.rb', line 11123

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11125
11126
11127
# File 'lib/models/porcelain.rb', line 11125

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



11127
11128
11129
# File 'lib/models/porcelain.rb', line 11127

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11129
11130
11131
# File 'lib/models/porcelain.rb', line 11129

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11131
11132
11133
# File 'lib/models/porcelain.rb', line 11131

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11133
11134
11135
# File 'lib/models/porcelain.rb', line 11133

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11135
11136
11137
# File 'lib/models/porcelain.rb', line 11135

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



11137
11138
11139
# File 'lib/models/porcelain.rb', line 11137

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



11139
11140
11141
# File 'lib/models/porcelain.rb', line 11139

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11141
11142
11143
# File 'lib/models/porcelain.rb', line 11141

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11143
11144
11145
# File 'lib/models/porcelain.rb', line 11143

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11145
11146
11147
# File 'lib/models/porcelain.rb', line 11145

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



11147
11148
11149
# File 'lib/models/porcelain.rb', line 11147

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11191
11192
11193
11194
11195
11196
11197
# File 'lib/models/porcelain.rb', line 11191

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end