Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



10894
10895
10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
10906
10907
10908
10909
10910
10911
10912
10913
10914
10915
10916
10917
10918
10919
10920
10921
10922
10923
10924
10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
# File 'lib/models/porcelain.rb', line 10894

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10856
10857
10858
# File 'lib/models/porcelain.rb', line 10856

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10858
10859
10860
# File 'lib/models/porcelain.rb', line 10858

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



10860
10861
10862
# File 'lib/models/porcelain.rb', line 10860

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10862
10863
10864
# File 'lib/models/porcelain.rb', line 10862

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10864
10865
10866
# File 'lib/models/porcelain.rb', line 10864

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10866
10867
10868
# File 'lib/models/porcelain.rb', line 10866

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10868
10869
10870
# File 'lib/models/porcelain.rb', line 10868

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10870
10871
10872
# File 'lib/models/porcelain.rb', line 10870

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10872
10873
10874
# File 'lib/models/porcelain.rb', line 10872

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10874
10875
10876
# File 'lib/models/porcelain.rb', line 10874

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10876
10877
10878
# File 'lib/models/porcelain.rb', line 10876

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10878
10879
10880
# File 'lib/models/porcelain.rb', line 10878

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10880
10881
10882
# File 'lib/models/porcelain.rb', line 10880

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



10882
10883
10884
# File 'lib/models/porcelain.rb', line 10882

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



10884
10885
10886
# File 'lib/models/porcelain.rb', line 10884

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10886
10887
10888
# File 'lib/models/porcelain.rb', line 10886

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10888
10889
10890
# File 'lib/models/porcelain.rb', line 10888

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10890
10891
10892
# File 'lib/models/porcelain.rb', line 10890

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



10892
10893
10894
# File 'lib/models/porcelain.rb', line 10892

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10936
10937
10938
10939
10940
10941
10942
# File 'lib/models/porcelain.rb', line 10936

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end