Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



10823
10824
10825
10826
10827
10828
10829
10830
10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
10842
10843
10844
10845
10846
10847
10848
10849
10850
10851
10852
10853
10854
10855
10856
10857
10858
10859
10860
10861
10862
10863
# File 'lib/models/porcelain.rb', line 10823

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10785
10786
10787
# File 'lib/models/porcelain.rb', line 10785

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10787
10788
10789
# File 'lib/models/porcelain.rb', line 10787

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



10789
10790
10791
# File 'lib/models/porcelain.rb', line 10789

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10791
10792
10793
# File 'lib/models/porcelain.rb', line 10791

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10793
10794
10795
# File 'lib/models/porcelain.rb', line 10793

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10795
10796
10797
# File 'lib/models/porcelain.rb', line 10795

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10797
10798
10799
# File 'lib/models/porcelain.rb', line 10797

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10799
10800
10801
# File 'lib/models/porcelain.rb', line 10799

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10801
10802
10803
# File 'lib/models/porcelain.rb', line 10801

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10803
10804
10805
# File 'lib/models/porcelain.rb', line 10803

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10805
10806
10807
# File 'lib/models/porcelain.rb', line 10805

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10807
10808
10809
# File 'lib/models/porcelain.rb', line 10807

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10809
10810
10811
# File 'lib/models/porcelain.rb', line 10809

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



10811
10812
10813
# File 'lib/models/porcelain.rb', line 10811

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



10813
10814
10815
# File 'lib/models/porcelain.rb', line 10813

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10815
10816
10817
# File 'lib/models/porcelain.rb', line 10815

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10817
10818
10819
# File 'lib/models/porcelain.rb', line 10817

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10819
10820
10821
# File 'lib/models/porcelain.rb', line 10819

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



10821
10822
10823
# File 'lib/models/porcelain.rb', line 10821

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10865
10866
10867
10868
10869
10870
10871
# File 'lib/models/porcelain.rb', line 10865

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end