Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
10775
10776
10777
10778
10779
10780
10781
10782
10783
10784
10785
10786
# File 'lib/models/porcelain.rb', line 10746

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10708
10709
10710
# File 'lib/models/porcelain.rb', line 10708

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10710
10711
10712
# File 'lib/models/porcelain.rb', line 10710

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



10712
10713
10714
# File 'lib/models/porcelain.rb', line 10712

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10714
10715
10716
# File 'lib/models/porcelain.rb', line 10714

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10716
10717
10718
# File 'lib/models/porcelain.rb', line 10716

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10718
10719
10720
# File 'lib/models/porcelain.rb', line 10718

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10720
10721
10722
# File 'lib/models/porcelain.rb', line 10720

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10722
10723
10724
# File 'lib/models/porcelain.rb', line 10722

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10724
10725
10726
# File 'lib/models/porcelain.rb', line 10724

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10726
10727
10728
# File 'lib/models/porcelain.rb', line 10726

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10728
10729
10730
# File 'lib/models/porcelain.rb', line 10728

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10730
10731
10732
# File 'lib/models/porcelain.rb', line 10730

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10732
10733
10734
# File 'lib/models/porcelain.rb', line 10732

def proxy_cluster_id
  @proxy_cluster_id
end

#schemaObject

The Schema to use to direct initial requests.



10734
10735
10736
# File 'lib/models/porcelain.rb', line 10734

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



10736
10737
10738
# File 'lib/models/porcelain.rb', line 10736

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10738
10739
10740
# File 'lib/models/porcelain.rb', line 10738

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10740
10741
10742
# File 'lib/models/porcelain.rb', line 10740

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10742
10743
10744
# File 'lib/models/porcelain.rb', line 10742

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



10744
10745
10746
# File 'lib/models/porcelain.rb', line 10744

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10788
10789
10790
10791
10792
10793
10794
# File 'lib/models/porcelain.rb', line 10788

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end