Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



10448
10449
10450
10451
10452
10453
10454
10455
10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
# File 'lib/models/porcelain.rb', line 10448

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10412
10413
10414
# File 'lib/models/porcelain.rb', line 10412

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10414
10415
10416
# File 'lib/models/porcelain.rb', line 10414

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



10416
10417
10418
# File 'lib/models/porcelain.rb', line 10416

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10418
10419
10420
# File 'lib/models/porcelain.rb', line 10418

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10420
10421
10422
# File 'lib/models/porcelain.rb', line 10420

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10422
10423
10424
# File 'lib/models/porcelain.rb', line 10422

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10424
10425
10426
# File 'lib/models/porcelain.rb', line 10424

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10426
10427
10428
# File 'lib/models/porcelain.rb', line 10426

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10428
10429
10430
# File 'lib/models/porcelain.rb', line 10428

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10430
10431
10432
# File 'lib/models/porcelain.rb', line 10430

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10432
10433
10434
# File 'lib/models/porcelain.rb', line 10432

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10434
10435
10436
# File 'lib/models/porcelain.rb', line 10434

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



10436
10437
10438
# File 'lib/models/porcelain.rb', line 10436

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



10438
10439
10440
# File 'lib/models/porcelain.rb', line 10438

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10440
10441
10442
# File 'lib/models/porcelain.rb', line 10440

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10442
10443
10444
# File 'lib/models/porcelain.rb', line 10442

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10444
10445
10446
# File 'lib/models/porcelain.rb', line 10444

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



10446
10447
10448
# File 'lib/models/porcelain.rb', line 10446

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10488
10489
10490
10491
10492
10493
10494
# File 'lib/models/porcelain.rb', line 10488

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end