Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



10279
10280
10281
10282
10283
10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
# File 'lib/models/porcelain.rb', line 10279

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10243
10244
10245
# File 'lib/models/porcelain.rb', line 10243

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10245
10246
10247
# File 'lib/models/porcelain.rb', line 10245

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



10247
10248
10249
# File 'lib/models/porcelain.rb', line 10247

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10249
10250
10251
# File 'lib/models/porcelain.rb', line 10249

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10251
10252
10253
# File 'lib/models/porcelain.rb', line 10251

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10253
10254
10255
# File 'lib/models/porcelain.rb', line 10253

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10255
10256
10257
# File 'lib/models/porcelain.rb', line 10255

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10257
10258
10259
# File 'lib/models/porcelain.rb', line 10257

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



10259
10260
10261
# File 'lib/models/porcelain.rb', line 10259

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10261
10262
10263
# File 'lib/models/porcelain.rb', line 10261

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10263
10264
10265
# File 'lib/models/porcelain.rb', line 10263

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10265
10266
10267
# File 'lib/models/porcelain.rb', line 10265

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



10267
10268
10269
# File 'lib/models/porcelain.rb', line 10267

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



10269
10270
10271
# File 'lib/models/porcelain.rb', line 10269

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10271
10272
10273
# File 'lib/models/porcelain.rb', line 10271

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10273
10274
10275
# File 'lib/models/porcelain.rb', line 10273

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10275
10276
10277
# File 'lib/models/porcelain.rb', line 10275

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



10277
10278
10279
# File 'lib/models/porcelain.rb', line 10277

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10319
10320
10321
10322
10323
10324
10325
# File 'lib/models/porcelain.rb', line 10319

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end