Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
9905
9906
9907
9908
9909
9910
9911
9912
9913
9914
9915
9916
9917
9918
9919
9920
9921
9922
9923
9924
9925
9926
9927
9928
9929
# File 'lib/models/porcelain.rb', line 9891

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



9855
9856
9857
# File 'lib/models/porcelain.rb', line 9855

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



9857
9858
9859
# File 'lib/models/porcelain.rb', line 9857

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



9859
9860
9861
# File 'lib/models/porcelain.rb', line 9859

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



9861
9862
9863
# File 'lib/models/porcelain.rb', line 9861

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



9863
9864
9865
# File 'lib/models/porcelain.rb', line 9863

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



9865
9866
9867
# File 'lib/models/porcelain.rb', line 9865

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



9867
9868
9869
# File 'lib/models/porcelain.rb', line 9867

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



9869
9870
9871
# File 'lib/models/porcelain.rb', line 9869

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



9871
9872
9873
# File 'lib/models/porcelain.rb', line 9871

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



9873
9874
9875
# File 'lib/models/porcelain.rb', line 9873

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



9875
9876
9877
# File 'lib/models/porcelain.rb', line 9875

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



9877
9878
9879
# File 'lib/models/porcelain.rb', line 9877

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



9879
9880
9881
# File 'lib/models/porcelain.rb', line 9879

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



9881
9882
9883
# File 'lib/models/porcelain.rb', line 9881

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



9883
9884
9885
# File 'lib/models/porcelain.rb', line 9883

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



9885
9886
9887
# File 'lib/models/porcelain.rb', line 9885

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



9887
9888
9889
# File 'lib/models/porcelain.rb', line 9887

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



9889
9890
9891
# File 'lib/models/porcelain.rb', line 9889

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



9931
9932
9933
9934
9935
9936
9937
# File 'lib/models/porcelain.rb', line 9931

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end