Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
8708
8709
8710
8711
8712
8713
8714
8715
8716
8717
8718
8719
8720
8721
8722
8723
8724
8725
8726
# File 'lib/models/porcelain.rb', line 8688

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



8652
8653
8654
# File 'lib/models/porcelain.rb', line 8652

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8654
8655
8656
# File 'lib/models/porcelain.rb', line 8654

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



8656
8657
8658
# File 'lib/models/porcelain.rb', line 8656

def client_id
  @client_id
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



8658
8659
8660
# File 'lib/models/porcelain.rb', line 8658

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8660
8661
8662
# File 'lib/models/porcelain.rb', line 8660

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8662
8663
8664
# File 'lib/models/porcelain.rb', line 8662

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8664
8665
8666
# File 'lib/models/porcelain.rb', line 8664

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8666
8667
8668
# File 'lib/models/porcelain.rb', line 8666

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8668
8669
8670
# File 'lib/models/porcelain.rb', line 8668

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8670
8671
8672
# File 'lib/models/porcelain.rb', line 8670

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8672
8673
8674
# File 'lib/models/porcelain.rb', line 8672

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8674
8675
8676
# File 'lib/models/porcelain.rb', line 8674

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



8676
8677
8678
# File 'lib/models/porcelain.rb', line 8676

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



8678
8679
8680
# File 'lib/models/porcelain.rb', line 8678

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8680
8681
8682
# File 'lib/models/porcelain.rb', line 8680

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8682
8683
8684
# File 'lib/models/porcelain.rb', line 8682

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8684
8685
8686
# File 'lib/models/porcelain.rb', line 8684

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



8686
8687
8688
# File 'lib/models/porcelain.rb', line 8686

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8728
8729
8730
8731
8732
8733
8734
# File 'lib/models/porcelain.rb', line 8728

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end