Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
8286
8287
8288
8289
8290
8291
8292
8293
# File 'lib/models/porcelain.rb', line 8257

def initialize(
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8223
8224
8225
# File 'lib/models/porcelain.rb', line 8223

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



8225
8226
8227
# File 'lib/models/porcelain.rb', line 8225

def client_id
  @client_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8227
8228
8229
# File 'lib/models/porcelain.rb', line 8227

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8229
8230
8231
# File 'lib/models/porcelain.rb', line 8229

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8231
8232
8233
# File 'lib/models/porcelain.rb', line 8231

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8233
8234
8235
# File 'lib/models/porcelain.rb', line 8233

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8235
8236
8237
# File 'lib/models/porcelain.rb', line 8235

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8237
8238
8239
# File 'lib/models/porcelain.rb', line 8237

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8239
8240
8241
# File 'lib/models/porcelain.rb', line 8239

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8241
8242
8243
# File 'lib/models/porcelain.rb', line 8241

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8243
8244
8245
# File 'lib/models/porcelain.rb', line 8243

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



8245
8246
8247
# File 'lib/models/porcelain.rb', line 8245

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



8247
8248
8249
# File 'lib/models/porcelain.rb', line 8247

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8249
8250
8251
# File 'lib/models/porcelain.rb', line 8249

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8251
8252
8253
# File 'lib/models/porcelain.rb', line 8251

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8253
8254
8255
# File 'lib/models/porcelain.rb', line 8253

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



8255
8256
8257
# File 'lib/models/porcelain.rb', line 8255

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8295
8296
8297
8298
8299
8300
8301
# File 'lib/models/porcelain.rb', line 8295

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end