Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



8093
8094
8095
8096
8097
8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
8115
8116
8117
8118
8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
# File 'lib/models/porcelain.rb', line 8093

def initialize(
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8059
8060
8061
# File 'lib/models/porcelain.rb', line 8059

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



8061
8062
8063
# File 'lib/models/porcelain.rb', line 8061

def client_id
  @client_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



8063
8064
8065
# File 'lib/models/porcelain.rb', line 8063

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8065
8066
8067
# File 'lib/models/porcelain.rb', line 8065

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8067
8068
8069
# File 'lib/models/porcelain.rb', line 8067

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8069
8070
8071
# File 'lib/models/porcelain.rb', line 8069

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8071
8072
8073
# File 'lib/models/porcelain.rb', line 8071

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



8073
8074
8075
# File 'lib/models/porcelain.rb', line 8073

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8075
8076
8077
# File 'lib/models/porcelain.rb', line 8075

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8077
8078
8079
# File 'lib/models/porcelain.rb', line 8077

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8079
8080
8081
# File 'lib/models/porcelain.rb', line 8079

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



8081
8082
8083
# File 'lib/models/porcelain.rb', line 8081

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



8083
8084
8085
# File 'lib/models/porcelain.rb', line 8083

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8085
8086
8087
# File 'lib/models/porcelain.rb', line 8085

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8087
8088
8089
# File 'lib/models/porcelain.rb', line 8087

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8089
8090
8091
# File 'lib/models/porcelain.rb', line 8089

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



8091
8092
8093
# File 'lib/models/porcelain.rb', line 8091

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8131
8132
8133
8134
8135
8136
8137
# File 'lib/models/porcelain.rb', line 8131

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end