Class: SDM::SQLServerAzureAD
- Inherits:
-
Object
- Object
- SDM::SQLServerAzureAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#client_id ⇒ Object
The Azure AD application (client) ID with which to authenticate.
-
#database ⇒ Object
The initial database to connect to.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret ⇒ Object
The Azure AD client secret (application password) with which to authenticate.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
The Azure AD directory (tenant) ID with which to authenticate.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
constructor
A new instance of SQLServerAzureAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
Returns a new instance of SQLServerAzureAD.
7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/models/porcelain.rb', line 7656 def initialize( bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @client_id = client_id == nil ? "" : client_id @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret = secret == nil ? "" : secret @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
7622 7623 7624 |
# File 'lib/models/porcelain.rb', line 7622 def bind_interface @bind_interface end |
#client_id ⇒ Object
The Azure AD application (client) ID with which to authenticate.
7624 7625 7626 |
# File 'lib/models/porcelain.rb', line 7624 def client_id @client_id end |
#database ⇒ Object
The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.
7626 7627 7628 |
# File 'lib/models/porcelain.rb', line 7626 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7628 7629 7630 |
# File 'lib/models/porcelain.rb', line 7628 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7630 7631 7632 |
# File 'lib/models/porcelain.rb', line 7630 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
7632 7633 7634 |
# File 'lib/models/porcelain.rb', line 7632 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7634 7635 7636 |
# File 'lib/models/porcelain.rb', line 7634 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7636 7637 7638 |
# File 'lib/models/porcelain.rb', line 7636 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
7638 7639 7640 |
# File 'lib/models/porcelain.rb', line 7638 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
7640 7641 7642 |
# File 'lib/models/porcelain.rb', line 7640 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
7642 7643 7644 |
# File 'lib/models/porcelain.rb', line 7642 def port_override @port_override end |
#schema ⇒ Object
The Schema to use to direct initial requests.
7644 7645 7646 |
# File 'lib/models/porcelain.rb', line 7644 def schema @schema end |
#secret ⇒ Object
The Azure AD client secret (application password) with which to authenticate.
7646 7647 7648 |
# File 'lib/models/porcelain.rb', line 7646 def secret @secret end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7648 7649 7650 |
# File 'lib/models/porcelain.rb', line 7648 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7650 7651 7652 |
# File 'lib/models/porcelain.rb', line 7650 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7652 7653 7654 |
# File 'lib/models/porcelain.rb', line 7652 def @tags end |
#tenant_id ⇒ Object
The Azure AD directory (tenant) ID with which to authenticate.
7654 7655 7656 |
# File 'lib/models/porcelain.rb', line 7654 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7694 7695 7696 7697 7698 7699 7700 |
# File 'lib/models/porcelain.rb', line 7694 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |