Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
7695
7696
7697
7698
7699
7700
7701
7702
# File 'lib/models/porcelain.rb', line 7666

def initialize(
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7632
7633
7634
# File 'lib/models/porcelain.rb', line 7632

def bind_interface
  @bind_interface
end

#client_idObject

The Azure AD application (client) ID with which to authenticate.



7634
7635
7636
# File 'lib/models/porcelain.rb', line 7634

def client_id
  @client_id
end

#databaseObject

The initial database to connect to. This setting does not by itself prevent switching to another database after connecting.



7636
7637
7638
# File 'lib/models/porcelain.rb', line 7636

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7638
7639
7640
# File 'lib/models/porcelain.rb', line 7638

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7640
7641
7642
# File 'lib/models/porcelain.rb', line 7640

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7642
7643
7644
# File 'lib/models/porcelain.rb', line 7642

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7644
7645
7646
# File 'lib/models/porcelain.rb', line 7644

def id
  @id
end

#nameObject

Unique human-readable name of the Resource.



7646
7647
7648
# File 'lib/models/porcelain.rb', line 7646

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



7648
7649
7650
# File 'lib/models/porcelain.rb', line 7648

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7650
7651
7652
# File 'lib/models/porcelain.rb', line 7650

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



7652
7653
7654
# File 'lib/models/porcelain.rb', line 7652

def port_override
  @port_override
end

#schemaObject

The Schema to use to direct initial requests.



7654
7655
7656
# File 'lib/models/porcelain.rb', line 7654

def schema
  @schema
end

#secretObject

The Azure AD client secret (application password) with which to authenticate.



7656
7657
7658
# File 'lib/models/porcelain.rb', line 7656

def secret
  @secret
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7658
7659
7660
# File 'lib/models/porcelain.rb', line 7658

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7660
7661
7662
# File 'lib/models/porcelain.rb', line 7660

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7662
7663
7664
# File 'lib/models/porcelain.rb', line 7662

def tags
  @tags
end

#tenant_idObject

The Azure AD directory (tenant) ID with which to authenticate.



7664
7665
7666
# File 'lib/models/porcelain.rb', line 7664

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7704
7705
7706
7707
7708
7709
7710
# File 'lib/models/porcelain.rb', line 7704

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end