Class: SDM::SQLServerAzureAD
- Inherits:
-
Object
- Object
- SDM::SQLServerAzureAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret ⇒ Object
Returns the value of attribute secret.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
constructor
A new instance of SQLServerAzureAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
Returns a new instance of SQLServerAzureAD.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 |
# File 'lib/models/porcelain.rb', line 7484 def initialize( bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @client_id = client_id == nil ? "" : client_id @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret = secret == nil ? "" : secret @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7450 7451 7452 |
# File 'lib/models/porcelain.rb', line 7450 def bind_interface @bind_interface end |
#client_id ⇒ Object
Returns the value of attribute client_id.
7452 7453 7454 |
# File 'lib/models/porcelain.rb', line 7452 def client_id @client_id end |
#database ⇒ Object
Returns the value of attribute database.
7454 7455 7456 |
# File 'lib/models/porcelain.rb', line 7454 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7456 7457 7458 |
# File 'lib/models/porcelain.rb', line 7456 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7458 7459 7460 |
# File 'lib/models/porcelain.rb', line 7458 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7460 7461 7462 |
# File 'lib/models/porcelain.rb', line 7460 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7462 7463 7464 |
# File 'lib/models/porcelain.rb', line 7462 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7464 7465 7466 |
# File 'lib/models/porcelain.rb', line 7464 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
7466 7467 7468 |
# File 'lib/models/porcelain.rb', line 7466 def override_database @override_database end |
#port ⇒ Object
Returns the value of attribute port.
7468 7469 7470 |
# File 'lib/models/porcelain.rb', line 7468 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7470 7471 7472 |
# File 'lib/models/porcelain.rb', line 7470 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
7472 7473 7474 |
# File 'lib/models/porcelain.rb', line 7472 def schema @schema end |
#secret ⇒ Object
Returns the value of attribute secret.
7474 7475 7476 |
# File 'lib/models/porcelain.rb', line 7474 def secret @secret end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7476 7477 7478 |
# File 'lib/models/porcelain.rb', line 7476 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7478 7479 7480 |
# File 'lib/models/porcelain.rb', line 7478 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7480 7481 7482 |
# File 'lib/models/porcelain.rb', line 7480 def @tags end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
7482 7483 7484 |
# File 'lib/models/porcelain.rb', line 7482 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7522 7523 7524 7525 7526 7527 7528 |
# File 'lib/models/porcelain.rb', line 7522 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |