Class: SDM::SQLServerAzureAD
- Inherits:
-
Object
- Object
- SDM::SQLServerAzureAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret ⇒ Object
Returns the value of attribute secret.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
constructor
A new instance of SQLServerAzureAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD
Returns a new instance of SQLServerAzureAD.
7428 7429 7430 7431 7432 7433 7434 7435 7436 7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 |
# File 'lib/models/porcelain.rb', line 7428 def initialize( bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @client_id = client_id == nil ? "" : client_id @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @schema = schema == nil ? "" : schema @secret = secret == nil ? "" : secret @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @tenant_id = tenant_id == nil ? "" : tenant_id end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7394 7395 7396 |
# File 'lib/models/porcelain.rb', line 7394 def bind_interface @bind_interface end |
#client_id ⇒ Object
Returns the value of attribute client_id.
7396 7397 7398 |
# File 'lib/models/porcelain.rb', line 7396 def client_id @client_id end |
#database ⇒ Object
Returns the value of attribute database.
7398 7399 7400 |
# File 'lib/models/porcelain.rb', line 7398 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7400 7401 7402 |
# File 'lib/models/porcelain.rb', line 7400 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7402 7403 7404 |
# File 'lib/models/porcelain.rb', line 7402 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7404 7405 7406 |
# File 'lib/models/porcelain.rb', line 7404 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7406 7407 7408 |
# File 'lib/models/porcelain.rb', line 7406 def id @id end |
#name ⇒ Object
Unique human-readable name of the Resource.
7408 7409 7410 |
# File 'lib/models/porcelain.rb', line 7408 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
7410 7411 7412 |
# File 'lib/models/porcelain.rb', line 7410 def override_database @override_database end |
#port ⇒ Object
Returns the value of attribute port.
7412 7413 7414 |
# File 'lib/models/porcelain.rb', line 7412 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7414 7415 7416 |
# File 'lib/models/porcelain.rb', line 7414 def port_override @port_override end |
#schema ⇒ Object
Returns the value of attribute schema.
7416 7417 7418 |
# File 'lib/models/porcelain.rb', line 7416 def schema @schema end |
#secret ⇒ Object
Returns the value of attribute secret.
7418 7419 7420 |
# File 'lib/models/porcelain.rb', line 7418 def secret @secret end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7420 7421 7422 |
# File 'lib/models/porcelain.rb', line 7420 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7422 7423 7424 |
# File 'lib/models/porcelain.rb', line 7422 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7424 7425 7426 |
# File 'lib/models/porcelain.rb', line 7424 def @tags end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
7426 7427 7428 |
# File 'lib/models/porcelain.rb', line 7426 def tenant_id @tenant_id end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7466 7467 7468 7469 7470 7471 7472 |
# File 'lib/models/porcelain.rb', line 7466 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |