Class: SDM::SQLServerAzureAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, client_id: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, schema: nil, secret: nil, secret_store_id: nil, subdomain: nil, tags: nil, tenant_id: nil) ⇒ SQLServerAzureAD

Returns a new instance of SQLServerAzureAD.



16610
16611
16612
16613
16614
16615
16616
16617
16618
16619
16620
16621
16622
16623
16624
16625
16626
16627
16628
16629
16630
16631
16632
16633
16634
16635
16636
16637
16638
16639
16640
16641
16642
16643
16644
16645
16646
16647
16648
16649
16650
# File 'lib/models/porcelain.rb', line 16610

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  client_id: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  schema: nil,
  secret: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  tenant_id: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @client_id = client_id == nil ? "" : client_id
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @schema = schema == nil ? "" : schema
  @secret = secret == nil ? "" : secret
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @tenant_id = tenant_id == nil ? "" : tenant_id
end

Instance Attribute Details

#allow_deprecated_encryption ⇒ Object

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16572
16573
16574
# File 'lib/models/porcelain.rb', line 16572

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16574
16575
16576
# File 'lib/models/porcelain.rb', line 16574

def bind_interface
  @bind_interface
end

#client_id ⇒ Object

The Azure AD application (client) ID with which to authenticate.



16576
16577
16578
# File 'lib/models/porcelain.rb', line 16576

def client_id
  @client_id
end

#database ⇒ Object

The database for healthchecks, and used for clients if Override Default Database is true.



16578
16579
16580
# File 'lib/models/porcelain.rb', line 16578

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



16580
16581
16582
# File 'lib/models/porcelain.rb', line 16580

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



16582
16583
16584
# File 'lib/models/porcelain.rb', line 16582

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



16584
16585
16586
# File 'lib/models/porcelain.rb', line 16584

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



16586
16587
16588
# File 'lib/models/porcelain.rb', line 16586

def id
  @id
end

#name ⇒ Object

Unique human-readable name of the Resource.



16588
16589
16590
# File 'lib/models/porcelain.rb', line 16588

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16590
16591
16592
# File 'lib/models/porcelain.rb', line 16590

def override_database
  @override_database
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



16592
16593
16594
# File 'lib/models/porcelain.rb', line 16592

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16594
16595
16596
# File 'lib/models/porcelain.rb', line 16594

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



16596
16597
16598
# File 'lib/models/porcelain.rb', line 16596

def proxy_cluster_id
  @proxy_cluster_id
end

#schema ⇒ Object

The Schema to use to direct initial requests.



16598
16599
16600
# File 'lib/models/porcelain.rb', line 16598

def schema
  @schema
end

#secret ⇒ Object

The Azure AD client secret (application password) with which to authenticate.



16600
16601
16602
# File 'lib/models/porcelain.rb', line 16600

def secret
  @secret
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



16602
16603
16604
# File 'lib/models/porcelain.rb', line 16602

def secret_store_id
  @secret_store_id
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16604
16605
16606
# File 'lib/models/porcelain.rb', line 16604

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



16606
16607
16608
# File 'lib/models/porcelain.rb', line 16606

def tags
  @tags
end

#tenant_id ⇒ Object

The Azure AD directory (tenant) ID with which to authenticate.



16608
16609
16610
# File 'lib/models/porcelain.rb', line 16608

def tenant_id
  @tenant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16652
16653
16654
16655
16656
16657
16658
# File 'lib/models/porcelain.rb', line 16652

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end