Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



16652
16653
16654
16655
16656
16657
16658
16659
16660
16661
16662
16663
16664
16665
16666
16667
16668
16669
16670
16671
16672
16673
16674
16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
16687
16688
16689
16690
16691
16692
16693
16694
16695
16696
16697
16698
16699
16700
16701
16702
# File 'lib/models/porcelain.rb', line 16652

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16604
16605
16606
# File 'lib/models/porcelain.rb', line 16604

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16606
16607
16608
# File 'lib/models/porcelain.rb', line 16606

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



16608
16609
16610
# File 'lib/models/porcelain.rb', line 16608

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16610
16611
16612
# File 'lib/models/porcelain.rb', line 16610

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16612
16613
16614
# File 'lib/models/porcelain.rb', line 16612

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16614
16615
16616
# File 'lib/models/porcelain.rb', line 16614

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16616
16617
16618
# File 'lib/models/porcelain.rb', line 16616

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16618
16619
16620
# File 'lib/models/porcelain.rb', line 16618

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16620
16621
16622
# File 'lib/models/porcelain.rb', line 16620

def identity_set_id
  @identity_set_id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



16622
16623
16624
# File 'lib/models/porcelain.rb', line 16622

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



16624
16625
16626
# File 'lib/models/porcelain.rb', line 16624

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



16626
16627
16628
# File 'lib/models/porcelain.rb', line 16626

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16628
16629
16630
# File 'lib/models/porcelain.rb', line 16628

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



16630
16631
16632
# File 'lib/models/porcelain.rb', line 16630

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16632
16633
16634
# File 'lib/models/porcelain.rb', line 16632

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16634
16635
16636
# File 'lib/models/porcelain.rb', line 16634

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16636
16637
16638
# File 'lib/models/porcelain.rb', line 16636

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



16638
16639
16640
# File 'lib/models/porcelain.rb', line 16638

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



16640
16641
16642
# File 'lib/models/porcelain.rb', line 16640

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16642
16643
16644
# File 'lib/models/porcelain.rb', line 16642

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



16644
16645
16646
# File 'lib/models/porcelain.rb', line 16644

def server_spn
  @server_spn
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16646
16647
16648
# File 'lib/models/porcelain.rb', line 16646

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16648
16649
16650
# File 'lib/models/porcelain.rb', line 16648

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16650
16651
16652
# File 'lib/models/porcelain.rb', line 16650

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16704
16705
16706
16707
16708
16709
16710
# File 'lib/models/porcelain.rb', line 16704

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end