Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



16604
16605
16606
16607
16608
16609
16610
16611
16612
16613
16614
16615
16616
16617
16618
16619
16620
16621
16622
16623
16624
16625
16626
16627
16628
16629
16630
16631
16632
16633
16634
16635
16636
16637
16638
16639
16640
16641
16642
16643
16644
16645
16646
16647
16648
16649
16650
16651
16652
16653
16654
# File 'lib/models/porcelain.rb', line 16604

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16556
16557
16558
# File 'lib/models/porcelain.rb', line 16556

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16558
16559
16560
# File 'lib/models/porcelain.rb', line 16558

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



16560
16561
16562
# File 'lib/models/porcelain.rb', line 16560

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16562
16563
16564
# File 'lib/models/porcelain.rb', line 16562

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16564
16565
16566
# File 'lib/models/porcelain.rb', line 16564

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16566
16567
16568
# File 'lib/models/porcelain.rb', line 16566

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16568
16569
16570
# File 'lib/models/porcelain.rb', line 16568

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16570
16571
16572
# File 'lib/models/porcelain.rb', line 16570

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16572
16573
16574
# File 'lib/models/porcelain.rb', line 16572

def identity_set_id
  @identity_set_id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



16574
16575
16576
# File 'lib/models/porcelain.rb', line 16574

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



16576
16577
16578
# File 'lib/models/porcelain.rb', line 16576

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



16578
16579
16580
# File 'lib/models/porcelain.rb', line 16578

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16580
16581
16582
# File 'lib/models/porcelain.rb', line 16580

def override_database
  @override_database
end

#passwordObject

The password to authenticate with.



16582
16583
16584
# File 'lib/models/porcelain.rb', line 16582

def password
  @password
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16584
16585
16586
# File 'lib/models/porcelain.rb', line 16584

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16586
16587
16588
# File 'lib/models/porcelain.rb', line 16586

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16588
16589
16590
# File 'lib/models/porcelain.rb', line 16588

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



16590
16591
16592
# File 'lib/models/porcelain.rb', line 16590

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



16592
16593
16594
# File 'lib/models/porcelain.rb', line 16592

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16594
16595
16596
# File 'lib/models/porcelain.rb', line 16594

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



16596
16597
16598
# File 'lib/models/porcelain.rb', line 16596

def server_spn
  @server_spn
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16598
16599
16600
# File 'lib/models/porcelain.rb', line 16598

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16600
16601
16602
# File 'lib/models/porcelain.rb', line 16600

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16602
16603
16604
# File 'lib/models/porcelain.rb', line 16602

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16656
16657
16658
16659
16660
16661
16662
# File 'lib/models/porcelain.rb', line 16656

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end