Class: SDM::SQLServerKerberosAD
- Inherits:
-
Object
- Object
- SDM::SQLServerKerberosAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keytab ⇒ Object
The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.
-
#krb_config ⇒ Object
The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#realm ⇒ Object
The Active Directory domain (realm) to which the configured username belongs.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_spn ⇒ Object
The Service Principal Name of the Microsoft SQL Server instance in Active Directory.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD
constructor
A new instance of SQLServerKerberosAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD
Returns a new instance of SQLServerKerberosAD.
16292 16293 16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 16308 16309 16310 16311 16312 16313 16314 16315 16316 16317 16318 16319 16320 16321 16322 16323 16324 16325 16326 16327 16328 16329 16330 16331 16332 16333 16334 16335 16336 |
# File 'lib/models/porcelain.rb', line 16292 def initialize( allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @keytab = keytab == nil ? "" : keytab @krb_config = krb_config == nil ? "" : krb_config @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @realm = realm == nil ? "" : realm @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_spn = server_spn == nil ? "" : server_spn @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.
16250 16251 16252 |
# File 'lib/models/porcelain.rb', line 16250 def allow_deprecated_encryption @allow_deprecated_encryption end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
16252 16253 16254 |
# File 'lib/models/porcelain.rb', line 16252 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
16254 16255 16256 |
# File 'lib/models/porcelain.rb', line 16254 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
16256 16257 16258 |
# File 'lib/models/porcelain.rb', line 16256 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
16258 16259 16260 |
# File 'lib/models/porcelain.rb', line 16258 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
16260 16261 16262 |
# File 'lib/models/porcelain.rb', line 16260 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
16262 16263 16264 |
# File 'lib/models/porcelain.rb', line 16262 def id @id end |
#keytab ⇒ Object
The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.
16264 16265 16266 |
# File 'lib/models/porcelain.rb', line 16264 def keytab @keytab end |
#krb_config ⇒ Object
The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.
16266 16267 16268 |
# File 'lib/models/porcelain.rb', line 16266 def krb_config @krb_config end |
#name ⇒ Object
Unique human-readable name of the Resource.
16268 16269 16270 |
# File 'lib/models/porcelain.rb', line 16268 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
16270 16271 16272 |
# File 'lib/models/porcelain.rb', line 16270 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
16272 16273 16274 |
# File 'lib/models/porcelain.rb', line 16272 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
16274 16275 16276 |
# File 'lib/models/porcelain.rb', line 16274 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
16276 16277 16278 |
# File 'lib/models/porcelain.rb', line 16276 def proxy_cluster_id @proxy_cluster_id end |
#realm ⇒ Object
The Active Directory domain (realm) to which the configured username belongs.
16278 16279 16280 |
# File 'lib/models/porcelain.rb', line 16278 def realm @realm end |
#schema ⇒ Object
The Schema to use to direct initial requests.
16280 16281 16282 |
# File 'lib/models/porcelain.rb', line 16280 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
16282 16283 16284 |
# File 'lib/models/porcelain.rb', line 16282 def secret_store_id @secret_store_id end |
#server_spn ⇒ Object
The Service Principal Name of the Microsoft SQL Server instance in Active Directory.
16284 16285 16286 |
# File 'lib/models/porcelain.rb', line 16284 def server_spn @server_spn end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
16286 16287 16288 |
# File 'lib/models/porcelain.rb', line 16286 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16288 16289 16290 |
# File 'lib/models/porcelain.rb', line 16288 def @tags end |
#username ⇒ Object
The username to authenticate with.
16290 16291 16292 |
# File 'lib/models/porcelain.rb', line 16290 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16338 16339 16340 16341 16342 16343 16344 |
# File 'lib/models/porcelain.rb', line 16338 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |