Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



15876
15877
15878
15879
15880
15881
15882
15883
15884
15885
15886
15887
15888
15889
15890
15891
15892
15893
15894
15895
15896
15897
15898
15899
15900
15901
15902
15903
15904
15905
15906
15907
15908
15909
15910
15911
15912
15913
15914
15915
15916
15917
15918
15919
15920
# File 'lib/models/porcelain.rb', line 15876

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



15834
15835
15836
# File 'lib/models/porcelain.rb', line 15834

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15836
15837
15838
# File 'lib/models/porcelain.rb', line 15836

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



15838
15839
15840
# File 'lib/models/porcelain.rb', line 15838

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15840
15841
15842
# File 'lib/models/porcelain.rb', line 15840

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15842
15843
15844
# File 'lib/models/porcelain.rb', line 15842

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15844
15845
15846
# File 'lib/models/porcelain.rb', line 15844

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15846
15847
15848
# File 'lib/models/porcelain.rb', line 15846

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



15848
15849
15850
# File 'lib/models/porcelain.rb', line 15848

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



15850
15851
15852
# File 'lib/models/porcelain.rb', line 15850

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



15852
15853
15854
# File 'lib/models/porcelain.rb', line 15852

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15854
15855
15856
# File 'lib/models/porcelain.rb', line 15854

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15856
15857
15858
# File 'lib/models/porcelain.rb', line 15856

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15858
15859
15860
# File 'lib/models/porcelain.rb', line 15858

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15860
15861
15862
# File 'lib/models/porcelain.rb', line 15860

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



15862
15863
15864
# File 'lib/models/porcelain.rb', line 15862

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



15864
15865
15866
# File 'lib/models/porcelain.rb', line 15864

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15866
15867
15868
# File 'lib/models/porcelain.rb', line 15866

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



15868
15869
15870
# File 'lib/models/porcelain.rb', line 15868

def server_spn
  @server_spn
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15870
15871
15872
# File 'lib/models/porcelain.rb', line 15870

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15872
15873
15874
# File 'lib/models/porcelain.rb', line 15872

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15874
15875
15876
# File 'lib/models/porcelain.rb', line 15874

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15922
15923
15924
15925
15926
15927
15928
# File 'lib/models/porcelain.rb', line 15922

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end