Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



15803
15804
15805
15806
15807
15808
15809
15810
15811
15812
15813
15814
15815
15816
15817
15818
15819
15820
15821
15822
15823
15824
15825
15826
15827
15828
15829
15830
15831
15832
15833
15834
15835
15836
15837
15838
15839
15840
15841
15842
15843
15844
15845
15846
15847
# File 'lib/models/porcelain.rb', line 15803

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



15761
15762
15763
# File 'lib/models/porcelain.rb', line 15761

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15763
15764
15765
# File 'lib/models/porcelain.rb', line 15763

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



15765
15766
15767
# File 'lib/models/porcelain.rb', line 15765

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15767
15768
15769
# File 'lib/models/porcelain.rb', line 15767

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15769
15770
15771
# File 'lib/models/porcelain.rb', line 15769

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15771
15772
15773
# File 'lib/models/porcelain.rb', line 15771

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15773
15774
15775
# File 'lib/models/porcelain.rb', line 15773

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



15775
15776
15777
# File 'lib/models/porcelain.rb', line 15775

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



15777
15778
15779
# File 'lib/models/porcelain.rb', line 15777

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



15779
15780
15781
# File 'lib/models/porcelain.rb', line 15779

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



15781
15782
15783
# File 'lib/models/porcelain.rb', line 15781

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15783
15784
15785
# File 'lib/models/porcelain.rb', line 15783

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15785
15786
15787
# File 'lib/models/porcelain.rb', line 15785

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15787
15788
15789
# File 'lib/models/porcelain.rb', line 15787

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



15789
15790
15791
# File 'lib/models/porcelain.rb', line 15789

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



15791
15792
15793
# File 'lib/models/porcelain.rb', line 15791

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15793
15794
15795
# File 'lib/models/porcelain.rb', line 15793

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



15795
15796
15797
# File 'lib/models/porcelain.rb', line 15795

def server_spn
  @server_spn
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15797
15798
15799
# File 'lib/models/porcelain.rb', line 15797

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15799
15800
15801
# File 'lib/models/porcelain.rb', line 15799

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15801
15802
15803
# File 'lib/models/porcelain.rb', line 15801

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15849
15850
15851
15852
15853
15854
15855
# File 'lib/models/porcelain.rb', line 15849

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end