Class: SDM::SQLServerKerberosAD
- Inherits:
-
Object
- Object
- SDM::SQLServerKerberosAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keytab ⇒ Object
The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.
-
#krb_config ⇒ Object
The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
If set, the database configured cannot be changed by users.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#realm ⇒ Object
The Active Directory domain (realm) to which the configured username belongs.
-
#schema ⇒ Object
The Schema to use to direct initial requests.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_spn ⇒ Object
The Service Principal Name of the Microsoft SQL Server instance in Active Directory.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD
constructor
A new instance of SQLServerKerberosAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD
Returns a new instance of SQLServerKerberosAD.
15437 15438 15439 15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 15451 15452 15453 15454 15455 15456 15457 15458 15459 15460 15461 15462 15463 15464 15465 15466 15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 15479 15480 15481 |
# File 'lib/models/porcelain.rb', line 15437 def initialize( allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @keytab = keytab == nil ? "" : keytab @krb_config = krb_config == nil ? "" : krb_config @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @realm = realm == nil ? "" : realm @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_spn = server_spn == nil ? "" : server_spn @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_encryption ⇒ Object
Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.
15395 15396 15397 |
# File 'lib/models/porcelain.rb', line 15395 def allow_deprecated_encryption @allow_deprecated_encryption end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
15397 15398 15399 |
# File 'lib/models/porcelain.rb', line 15397 def bind_interface @bind_interface end |
#database ⇒ Object
The database for healthchecks, and used for clients if Override Default Database is true.
15399 15400 15401 |
# File 'lib/models/porcelain.rb', line 15399 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
15401 15402 15403 |
# File 'lib/models/porcelain.rb', line 15401 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
15403 15404 15405 |
# File 'lib/models/porcelain.rb', line 15403 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
15405 15406 15407 |
# File 'lib/models/porcelain.rb', line 15405 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
15407 15408 15409 |
# File 'lib/models/porcelain.rb', line 15407 def id @id end |
#keytab ⇒ Object
The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.
15409 15410 15411 |
# File 'lib/models/porcelain.rb', line 15409 def keytab @keytab end |
#krb_config ⇒ Object
The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.
15411 15412 15413 |
# File 'lib/models/porcelain.rb', line 15411 def krb_config @krb_config end |
#name ⇒ Object
Unique human-readable name of the Resource.
15413 15414 15415 |
# File 'lib/models/porcelain.rb', line 15413 def name @name end |
#override_database ⇒ Object
If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.
15415 15416 15417 |
# File 'lib/models/porcelain.rb', line 15415 def override_database @override_database end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
15417 15418 15419 |
# File 'lib/models/porcelain.rb', line 15417 def port @port end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
15419 15420 15421 |
# File 'lib/models/porcelain.rb', line 15419 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
15421 15422 15423 |
# File 'lib/models/porcelain.rb', line 15421 def proxy_cluster_id @proxy_cluster_id end |
#realm ⇒ Object
The Active Directory domain (realm) to which the configured username belongs.
15423 15424 15425 |
# File 'lib/models/porcelain.rb', line 15423 def realm @realm end |
#schema ⇒ Object
The Schema to use to direct initial requests.
15425 15426 15427 |
# File 'lib/models/porcelain.rb', line 15425 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
15427 15428 15429 |
# File 'lib/models/porcelain.rb', line 15427 def secret_store_id @secret_store_id end |
#server_spn ⇒ Object
The Service Principal Name of the Microsoft SQL Server instance in Active Directory.
15429 15430 15431 |
# File 'lib/models/porcelain.rb', line 15429 def server_spn @server_spn end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
15431 15432 15433 |
# File 'lib/models/porcelain.rb', line 15431 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
15433 15434 15435 |
# File 'lib/models/porcelain.rb', line 15433 def @tags end |
#username ⇒ Object
The username to authenticate with.
15435 15436 15437 |
# File 'lib/models/porcelain.rb', line 15435 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
15483 15484 15485 15486 15487 15488 15489 |
# File 'lib/models/porcelain.rb', line 15483 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |