Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



14615
14616
14617
14618
14619
14620
14621
14622
14623
14624
14625
14626
14627
14628
14629
14630
14631
14632
14633
14634
14635
14636
14637
14638
14639
14640
14641
14642
14643
14644
14645
14646
14647
14648
14649
14650
14651
14652
14653
14654
14655
14656
14657
14658
14659
# File 'lib/models/porcelain.rb', line 14615

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



14573
14574
14575
# File 'lib/models/porcelain.rb', line 14573

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



14575
14576
14577
# File 'lib/models/porcelain.rb', line 14575

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



14577
14578
14579
# File 'lib/models/porcelain.rb', line 14577

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



14579
14580
14581
# File 'lib/models/porcelain.rb', line 14579

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



14581
14582
14583
# File 'lib/models/porcelain.rb', line 14581

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



14583
14584
14585
# File 'lib/models/porcelain.rb', line 14583

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



14585
14586
14587
# File 'lib/models/porcelain.rb', line 14585

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



14587
14588
14589
# File 'lib/models/porcelain.rb', line 14587

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



14589
14590
14591
# File 'lib/models/porcelain.rb', line 14589

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



14591
14592
14593
# File 'lib/models/porcelain.rb', line 14591

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



14593
14594
14595
# File 'lib/models/porcelain.rb', line 14593

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



14595
14596
14597
# File 'lib/models/porcelain.rb', line 14595

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



14597
14598
14599
# File 'lib/models/porcelain.rb', line 14597

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



14599
14600
14601
# File 'lib/models/porcelain.rb', line 14599

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



14601
14602
14603
# File 'lib/models/porcelain.rb', line 14601

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



14603
14604
14605
# File 'lib/models/porcelain.rb', line 14603

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



14605
14606
14607
# File 'lib/models/porcelain.rb', line 14605

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



14607
14608
14609
# File 'lib/models/porcelain.rb', line 14607

def server_spn
  @server_spn
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



14609
14610
14611
# File 'lib/models/porcelain.rb', line 14609

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



14611
14612
14613
# File 'lib/models/porcelain.rb', line 14611

def tags
  @tags
end

#usernameObject

The username to authenticate with.



14613
14614
14615
# File 'lib/models/porcelain.rb', line 14613

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



14661
14662
14663
14664
14665
14666
14667
# File 'lib/models/porcelain.rb', line 14661

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end