Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



13595
13596
13597
13598
13599
13600
13601
13602
13603
13604
13605
13606
13607
13608
13609
13610
13611
13612
13613
13614
13615
13616
13617
13618
13619
13620
13621
13622
13623
13624
13625
13626
13627
13628
13629
13630
13631
13632
13633
13634
13635
13636
13637
13638
13639
# File 'lib/models/porcelain.rb', line 13595

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



13553
13554
13555
# File 'lib/models/porcelain.rb', line 13553

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13555
13556
13557
# File 'lib/models/porcelain.rb', line 13555

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



13557
13558
13559
# File 'lib/models/porcelain.rb', line 13557

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13559
13560
13561
# File 'lib/models/porcelain.rb', line 13559

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13561
13562
13563
# File 'lib/models/porcelain.rb', line 13561

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13563
13564
13565
# File 'lib/models/porcelain.rb', line 13563

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13565
13566
13567
# File 'lib/models/porcelain.rb', line 13565

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



13567
13568
13569
# File 'lib/models/porcelain.rb', line 13567

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



13569
13570
13571
# File 'lib/models/porcelain.rb', line 13569

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



13571
13572
13573
# File 'lib/models/porcelain.rb', line 13571

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13573
13574
13575
# File 'lib/models/porcelain.rb', line 13573

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13575
13576
13577
# File 'lib/models/porcelain.rb', line 13575

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13577
13578
13579
# File 'lib/models/porcelain.rb', line 13577

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13579
13580
13581
# File 'lib/models/porcelain.rb', line 13579

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



13581
13582
13583
# File 'lib/models/porcelain.rb', line 13581

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



13583
13584
13585
# File 'lib/models/porcelain.rb', line 13583

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13585
13586
13587
# File 'lib/models/porcelain.rb', line 13585

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



13587
13588
13589
# File 'lib/models/porcelain.rb', line 13587

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13589
13590
13591
# File 'lib/models/porcelain.rb', line 13589

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13591
13592
13593
# File 'lib/models/porcelain.rb', line 13591

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13593
13594
13595
# File 'lib/models/porcelain.rb', line 13593

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13641
13642
13643
13644
13645
13646
13647
# File 'lib/models/porcelain.rb', line 13641

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end