Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



13335
13336
13337
13338
13339
13340
13341
13342
13343
13344
13345
13346
13347
13348
13349
13350
13351
13352
13353
13354
13355
13356
13357
13358
13359
13360
13361
13362
13363
13364
13365
13366
13367
13368
13369
13370
13371
13372
13373
13374
13375
13376
13377
13378
13379
# File 'lib/models/porcelain.rb', line 13335

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



13293
13294
13295
# File 'lib/models/porcelain.rb', line 13293

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13295
13296
13297
# File 'lib/models/porcelain.rb', line 13295

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



13297
13298
13299
# File 'lib/models/porcelain.rb', line 13297

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13299
13300
13301
# File 'lib/models/porcelain.rb', line 13299

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13301
13302
13303
# File 'lib/models/porcelain.rb', line 13301

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13303
13304
13305
# File 'lib/models/porcelain.rb', line 13303

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13305
13306
13307
# File 'lib/models/porcelain.rb', line 13305

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



13307
13308
13309
# File 'lib/models/porcelain.rb', line 13307

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



13309
13310
13311
# File 'lib/models/porcelain.rb', line 13309

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



13311
13312
13313
# File 'lib/models/porcelain.rb', line 13311

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13313
13314
13315
# File 'lib/models/porcelain.rb', line 13313

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13315
13316
13317
# File 'lib/models/porcelain.rb', line 13315

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13317
13318
13319
# File 'lib/models/porcelain.rb', line 13317

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13319
13320
13321
# File 'lib/models/porcelain.rb', line 13319

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



13321
13322
13323
# File 'lib/models/porcelain.rb', line 13321

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



13323
13324
13325
# File 'lib/models/porcelain.rb', line 13323

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13325
13326
13327
# File 'lib/models/porcelain.rb', line 13325

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



13327
13328
13329
# File 'lib/models/porcelain.rb', line 13327

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13329
13330
13331
# File 'lib/models/porcelain.rb', line 13329

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13331
13332
13333
# File 'lib/models/porcelain.rb', line 13331

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13333
13334
13335
# File 'lib/models/porcelain.rb', line 13333

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13381
13382
13383
13384
13385
13386
13387
# File 'lib/models/porcelain.rb', line 13381

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end