Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



13141
13142
13143
13144
13145
13146
13147
13148
13149
13150
13151
13152
13153
13154
13155
13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
13167
13168
13169
13170
13171
13172
13173
13174
13175
13176
13177
13178
13179
13180
13181
13182
13183
13184
13185
# File 'lib/models/porcelain.rb', line 13141

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



13099
13100
13101
# File 'lib/models/porcelain.rb', line 13099

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13101
13102
13103
# File 'lib/models/porcelain.rb', line 13101

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



13103
13104
13105
# File 'lib/models/porcelain.rb', line 13103

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13105
13106
13107
# File 'lib/models/porcelain.rb', line 13105

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13107
13108
13109
# File 'lib/models/porcelain.rb', line 13107

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13109
13110
13111
# File 'lib/models/porcelain.rb', line 13109

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13111
13112
13113
# File 'lib/models/porcelain.rb', line 13111

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



13113
13114
13115
# File 'lib/models/porcelain.rb', line 13113

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



13115
13116
13117
# File 'lib/models/porcelain.rb', line 13115

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



13117
13118
13119
# File 'lib/models/porcelain.rb', line 13117

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13119
13120
13121
# File 'lib/models/porcelain.rb', line 13119

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13121
13122
13123
# File 'lib/models/porcelain.rb', line 13121

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13123
13124
13125
# File 'lib/models/porcelain.rb', line 13123

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13125
13126
13127
# File 'lib/models/porcelain.rb', line 13125

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



13127
13128
13129
# File 'lib/models/porcelain.rb', line 13127

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



13129
13130
13131
# File 'lib/models/porcelain.rb', line 13129

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13131
13132
13133
# File 'lib/models/porcelain.rb', line 13131

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



13133
13134
13135
# File 'lib/models/porcelain.rb', line 13133

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13135
13136
13137
# File 'lib/models/porcelain.rb', line 13135

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13137
13138
13139
# File 'lib/models/porcelain.rb', line 13137

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13139
13140
13141
# File 'lib/models/porcelain.rb', line 13139

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13187
13188
13189
13190
13191
13192
13193
# File 'lib/models/porcelain.rb', line 13187

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end