Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



13073
13074
13075
13076
13077
13078
13079
13080
13081
13082
13083
13084
13085
13086
13087
13088
13089
13090
13091
13092
13093
13094
13095
13096
13097
13098
13099
13100
13101
13102
13103
13104
13105
13106
13107
13108
13109
13110
13111
13112
13113
13114
13115
13116
13117
# File 'lib/models/porcelain.rb', line 13073

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



13031
13032
13033
# File 'lib/models/porcelain.rb', line 13031

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13033
13034
13035
# File 'lib/models/porcelain.rb', line 13033

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



13035
13036
13037
# File 'lib/models/porcelain.rb', line 13035

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13037
13038
13039
# File 'lib/models/porcelain.rb', line 13037

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13039
13040
13041
# File 'lib/models/porcelain.rb', line 13039

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13041
13042
13043
# File 'lib/models/porcelain.rb', line 13041

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13043
13044
13045
# File 'lib/models/porcelain.rb', line 13043

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



13045
13046
13047
# File 'lib/models/porcelain.rb', line 13045

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



13047
13048
13049
# File 'lib/models/porcelain.rb', line 13047

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



13049
13050
13051
# File 'lib/models/porcelain.rb', line 13049

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



13051
13052
13053
# File 'lib/models/porcelain.rb', line 13051

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13053
13054
13055
# File 'lib/models/porcelain.rb', line 13053

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



13055
13056
13057
# File 'lib/models/porcelain.rb', line 13055

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13057
13058
13059
# File 'lib/models/porcelain.rb', line 13057

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



13059
13060
13061
# File 'lib/models/porcelain.rb', line 13059

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



13061
13062
13063
# File 'lib/models/porcelain.rb', line 13061

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13063
13064
13065
# File 'lib/models/porcelain.rb', line 13063

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



13065
13066
13067
# File 'lib/models/porcelain.rb', line 13065

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13067
13068
13069
# File 'lib/models/porcelain.rb', line 13067

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13069
13070
13071
# File 'lib/models/porcelain.rb', line 13069

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13071
13072
13073
# File 'lib/models/porcelain.rb', line 13071

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13119
13120
13121
13122
13123
13124
13125
# File 'lib/models/porcelain.rb', line 13119

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end