Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
13012
13013
13014
13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
13028
13029
13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
# File 'lib/models/porcelain.rb', line 12997

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



12955
12956
12957
# File 'lib/models/porcelain.rb', line 12955

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12957
12958
12959
# File 'lib/models/porcelain.rb', line 12957

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



12959
12960
12961
# File 'lib/models/porcelain.rb', line 12959

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12961
12962
12963
# File 'lib/models/porcelain.rb', line 12961

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12963
12964
12965
# File 'lib/models/porcelain.rb', line 12963

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12965
12966
12967
# File 'lib/models/porcelain.rb', line 12965

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12967
12968
12969
# File 'lib/models/porcelain.rb', line 12967

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



12969
12970
12971
# File 'lib/models/porcelain.rb', line 12969

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



12971
12972
12973
# File 'lib/models/porcelain.rb', line 12971

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



12973
12974
12975
# File 'lib/models/porcelain.rb', line 12973

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12975
12976
12977
# File 'lib/models/porcelain.rb', line 12975

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12977
12978
12979
# File 'lib/models/porcelain.rb', line 12977

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12979
12980
12981
# File 'lib/models/porcelain.rb', line 12979

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12981
12982
12983
# File 'lib/models/porcelain.rb', line 12981

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



12983
12984
12985
# File 'lib/models/porcelain.rb', line 12983

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



12985
12986
12987
# File 'lib/models/porcelain.rb', line 12985

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12987
12988
12989
# File 'lib/models/porcelain.rb', line 12987

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



12989
12990
12991
# File 'lib/models/porcelain.rb', line 12989

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12991
12992
12993
# File 'lib/models/porcelain.rb', line 12991

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12993
12994
12995
# File 'lib/models/porcelain.rb', line 12993

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12995
12996
12997
# File 'lib/models/porcelain.rb', line 12995

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13043
13044
13045
13046
13047
13048
13049
# File 'lib/models/porcelain.rb', line 13043

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end