Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



12932
12933
12934
12935
12936
12937
12938
12939
12940
12941
12942
12943
12944
12945
12946
12947
12948
12949
12950
12951
12952
12953
12954
12955
12956
12957
12958
12959
12960
12961
12962
12963
12964
12965
12966
12967
12968
12969
12970
12971
12972
12973
12974
12975
12976
# File 'lib/models/porcelain.rb', line 12932

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



12890
12891
12892
# File 'lib/models/porcelain.rb', line 12890

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12892
12893
12894
# File 'lib/models/porcelain.rb', line 12892

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



12894
12895
12896
# File 'lib/models/porcelain.rb', line 12894

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12896
12897
12898
# File 'lib/models/porcelain.rb', line 12896

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12898
12899
12900
# File 'lib/models/porcelain.rb', line 12898

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12900
12901
12902
# File 'lib/models/porcelain.rb', line 12900

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12902
12903
12904
# File 'lib/models/porcelain.rb', line 12902

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



12904
12905
12906
# File 'lib/models/porcelain.rb', line 12904

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



12906
12907
12908
# File 'lib/models/porcelain.rb', line 12906

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



12908
12909
12910
# File 'lib/models/porcelain.rb', line 12908

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12910
12911
12912
# File 'lib/models/porcelain.rb', line 12910

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12912
12913
12914
# File 'lib/models/porcelain.rb', line 12912

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12914
12915
12916
# File 'lib/models/porcelain.rb', line 12914

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12916
12917
12918
# File 'lib/models/porcelain.rb', line 12916

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



12918
12919
12920
# File 'lib/models/porcelain.rb', line 12918

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



12920
12921
12922
# File 'lib/models/porcelain.rb', line 12920

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12922
12923
12924
# File 'lib/models/porcelain.rb', line 12922

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



12924
12925
12926
# File 'lib/models/porcelain.rb', line 12924

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12926
12927
12928
# File 'lib/models/porcelain.rb', line 12926

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12928
12929
12930
# File 'lib/models/porcelain.rb', line 12928

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12930
12931
12932
# File 'lib/models/porcelain.rb', line 12930

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12978
12979
12980
12981
12982
12983
12984
# File 'lib/models/porcelain.rb', line 12978

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end