Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



12081
12082
12083
12084
12085
12086
12087
12088
12089
12090
12091
12092
12093
12094
12095
12096
12097
12098
12099
12100
12101
12102
12103
12104
12105
12106
12107
12108
12109
12110
12111
12112
12113
12114
12115
12116
12117
12118
12119
12120
12121
12122
12123
12124
12125
# File 'lib/models/porcelain.rb', line 12081

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



12039
12040
12041
# File 'lib/models/porcelain.rb', line 12039

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12041
12042
12043
# File 'lib/models/porcelain.rb', line 12041

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



12043
12044
12045
# File 'lib/models/porcelain.rb', line 12043

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12045
12046
12047
# File 'lib/models/porcelain.rb', line 12045

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12047
12048
12049
# File 'lib/models/porcelain.rb', line 12047

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12049
12050
12051
# File 'lib/models/porcelain.rb', line 12049

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12051
12052
12053
# File 'lib/models/porcelain.rb', line 12051

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



12053
12054
12055
# File 'lib/models/porcelain.rb', line 12053

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



12055
12056
12057
# File 'lib/models/porcelain.rb', line 12055

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



12057
12058
12059
# File 'lib/models/porcelain.rb', line 12057

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



12059
12060
12061
# File 'lib/models/porcelain.rb', line 12059

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12061
12062
12063
# File 'lib/models/porcelain.rb', line 12061

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



12063
12064
12065
# File 'lib/models/porcelain.rb', line 12063

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12065
12066
12067
# File 'lib/models/porcelain.rb', line 12065

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



12067
12068
12069
# File 'lib/models/porcelain.rb', line 12067

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



12069
12070
12071
# File 'lib/models/porcelain.rb', line 12069

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12071
12072
12073
# File 'lib/models/porcelain.rb', line 12071

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



12073
12074
12075
# File 'lib/models/porcelain.rb', line 12073

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12075
12076
12077
# File 'lib/models/porcelain.rb', line 12075

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12077
12078
12079
# File 'lib/models/porcelain.rb', line 12077

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12079
12080
12081
# File 'lib/models/porcelain.rb', line 12079

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12127
12128
12129
12130
12131
12132
12133
# File 'lib/models/porcelain.rb', line 12127

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end