Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



11998
11999
12000
12001
12002
12003
12004
12005
12006
12007
12008
12009
12010
12011
12012
12013
12014
12015
12016
12017
12018
12019
12020
12021
12022
12023
12024
12025
12026
12027
12028
12029
12030
12031
12032
12033
12034
12035
12036
12037
12038
12039
12040
12041
12042
# File 'lib/models/porcelain.rb', line 11998

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11956
11957
11958
# File 'lib/models/porcelain.rb', line 11956

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11958
11959
11960
# File 'lib/models/porcelain.rb', line 11958

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11960
11961
11962
# File 'lib/models/porcelain.rb', line 11960

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11962
11963
11964
# File 'lib/models/porcelain.rb', line 11962

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11964
11965
11966
# File 'lib/models/porcelain.rb', line 11964

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11966
11967
11968
# File 'lib/models/porcelain.rb', line 11966

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11968
11969
11970
# File 'lib/models/porcelain.rb', line 11968

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



11970
11971
11972
# File 'lib/models/porcelain.rb', line 11970

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



11972
11973
11974
# File 'lib/models/porcelain.rb', line 11972

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



11974
11975
11976
# File 'lib/models/porcelain.rb', line 11974

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11976
11977
11978
# File 'lib/models/porcelain.rb', line 11976

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11978
11979
11980
# File 'lib/models/porcelain.rb', line 11978

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11980
11981
11982
# File 'lib/models/porcelain.rb', line 11980

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11982
11983
11984
# File 'lib/models/porcelain.rb', line 11982

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



11984
11985
11986
# File 'lib/models/porcelain.rb', line 11984

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



11986
11987
11988
# File 'lib/models/porcelain.rb', line 11986

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11988
11989
11990
# File 'lib/models/porcelain.rb', line 11988

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



11990
11991
11992
# File 'lib/models/porcelain.rb', line 11990

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11992
11993
11994
# File 'lib/models/porcelain.rb', line 11992

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11994
11995
11996
# File 'lib/models/porcelain.rb', line 11994

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11996
11997
11998
# File 'lib/models/porcelain.rb', line 11996

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12044
12045
12046
12047
12048
12049
12050
# File 'lib/models/porcelain.rb', line 12044

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end