Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



11762
11763
11764
11765
11766
11767
11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
11784
11785
11786
11787
11788
11789
11790
11791
11792
11793
11794
11795
11796
11797
11798
11799
11800
11801
11802
11803
11804
11805
11806
# File 'lib/models/porcelain.rb', line 11762

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11720
11721
11722
# File 'lib/models/porcelain.rb', line 11720

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11722
11723
11724
# File 'lib/models/porcelain.rb', line 11722

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11724
11725
11726
# File 'lib/models/porcelain.rb', line 11724

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11726
11727
11728
# File 'lib/models/porcelain.rb', line 11726

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11728
11729
11730
# File 'lib/models/porcelain.rb', line 11728

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11730
11731
11732
# File 'lib/models/porcelain.rb', line 11730

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11732
11733
11734
# File 'lib/models/porcelain.rb', line 11732

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



11734
11735
11736
# File 'lib/models/porcelain.rb', line 11734

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



11736
11737
11738
# File 'lib/models/porcelain.rb', line 11736

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



11738
11739
11740
# File 'lib/models/porcelain.rb', line 11738

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11740
11741
11742
# File 'lib/models/porcelain.rb', line 11740

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11742
11743
11744
# File 'lib/models/porcelain.rb', line 11742

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11744
11745
11746
# File 'lib/models/porcelain.rb', line 11744

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11746
11747
11748
# File 'lib/models/porcelain.rb', line 11746

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



11748
11749
11750
# File 'lib/models/porcelain.rb', line 11748

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



11750
11751
11752
# File 'lib/models/porcelain.rb', line 11750

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11752
11753
11754
# File 'lib/models/porcelain.rb', line 11752

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



11754
11755
11756
# File 'lib/models/porcelain.rb', line 11754

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11756
11757
11758
# File 'lib/models/porcelain.rb', line 11756

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11758
11759
11760
# File 'lib/models/porcelain.rb', line 11758

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11760
11761
11762
# File 'lib/models/porcelain.rb', line 11760

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11808
11809
11810
11811
11812
11813
11814
# File 'lib/models/porcelain.rb', line 11808

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end