Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



11759
11760
11761
11762
11763
11764
11765
11766
11767
11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
11784
11785
11786
11787
11788
11789
11790
11791
11792
11793
11794
11795
11796
11797
11798
11799
11800
11801
11802
11803
# File 'lib/models/porcelain.rb', line 11759

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11717
11718
11719
# File 'lib/models/porcelain.rb', line 11717

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11719
11720
11721
# File 'lib/models/porcelain.rb', line 11719

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11721
11722
11723
# File 'lib/models/porcelain.rb', line 11721

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11723
11724
11725
# File 'lib/models/porcelain.rb', line 11723

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11725
11726
11727
# File 'lib/models/porcelain.rb', line 11725

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11727
11728
11729
# File 'lib/models/porcelain.rb', line 11727

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11729
11730
11731
# File 'lib/models/porcelain.rb', line 11729

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



11731
11732
11733
# File 'lib/models/porcelain.rb', line 11731

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



11733
11734
11735
# File 'lib/models/porcelain.rb', line 11733

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



11735
11736
11737
# File 'lib/models/porcelain.rb', line 11735

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11737
11738
11739
# File 'lib/models/porcelain.rb', line 11737

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11739
11740
11741
# File 'lib/models/porcelain.rb', line 11739

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11741
11742
11743
# File 'lib/models/porcelain.rb', line 11741

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11743
11744
11745
# File 'lib/models/porcelain.rb', line 11743

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



11745
11746
11747
# File 'lib/models/porcelain.rb', line 11745

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



11747
11748
11749
# File 'lib/models/porcelain.rb', line 11747

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11749
11750
11751
# File 'lib/models/porcelain.rb', line 11749

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



11751
11752
11753
# File 'lib/models/porcelain.rb', line 11751

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11753
11754
11755
# File 'lib/models/porcelain.rb', line 11753

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11755
11756
11757
# File 'lib/models/porcelain.rb', line 11755

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11757
11758
11759
# File 'lib/models/porcelain.rb', line 11757

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11805
11806
11807
11808
11809
11810
11811
# File 'lib/models/porcelain.rb', line 11805

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end