Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



11609
11610
11611
11612
11613
11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
11626
11627
11628
11629
11630
11631
11632
11633
11634
11635
11636
11637
11638
11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
11652
11653
# File 'lib/models/porcelain.rb', line 11609

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11567
11568
11569
# File 'lib/models/porcelain.rb', line 11567

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11569
11570
11571
# File 'lib/models/porcelain.rb', line 11569

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11571
11572
11573
# File 'lib/models/porcelain.rb', line 11571

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11573
11574
11575
# File 'lib/models/porcelain.rb', line 11573

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11575
11576
11577
# File 'lib/models/porcelain.rb', line 11575

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11577
11578
11579
# File 'lib/models/porcelain.rb', line 11577

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11579
11580
11581
# File 'lib/models/porcelain.rb', line 11579

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



11581
11582
11583
# File 'lib/models/porcelain.rb', line 11581

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



11583
11584
11585
# File 'lib/models/porcelain.rb', line 11583

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



11585
11586
11587
# File 'lib/models/porcelain.rb', line 11585

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11587
11588
11589
# File 'lib/models/porcelain.rb', line 11587

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11589
11590
11591
# File 'lib/models/porcelain.rb', line 11589

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11591
11592
11593
# File 'lib/models/porcelain.rb', line 11591

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11593
11594
11595
# File 'lib/models/porcelain.rb', line 11593

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



11595
11596
11597
# File 'lib/models/porcelain.rb', line 11595

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



11597
11598
11599
# File 'lib/models/porcelain.rb', line 11597

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11599
11600
11601
# File 'lib/models/porcelain.rb', line 11599

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



11601
11602
11603
# File 'lib/models/porcelain.rb', line 11601

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11603
11604
11605
# File 'lib/models/porcelain.rb', line 11603

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11605
11606
11607
# File 'lib/models/porcelain.rb', line 11605

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11607
11608
11609
# File 'lib/models/porcelain.rb', line 11607

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11655
11656
11657
11658
11659
11660
11661
# File 'lib/models/porcelain.rb', line 11655

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end