Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



11245
11246
11247
11248
11249
11250
11251
11252
11253
11254
11255
11256
11257
11258
11259
11260
11261
11262
11263
11264
11265
11266
11267
11268
11269
11270
11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
# File 'lib/models/porcelain.rb', line 11245

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11203
11204
11205
# File 'lib/models/porcelain.rb', line 11203

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11205
11206
11207
# File 'lib/models/porcelain.rb', line 11205

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11207
11208
11209
# File 'lib/models/porcelain.rb', line 11207

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11209
11210
11211
# File 'lib/models/porcelain.rb', line 11209

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11211
11212
11213
# File 'lib/models/porcelain.rb', line 11211

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11213
11214
11215
# File 'lib/models/porcelain.rb', line 11213

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11215
11216
11217
# File 'lib/models/porcelain.rb', line 11215

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



11217
11218
11219
# File 'lib/models/porcelain.rb', line 11217

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



11219
11220
11221
# File 'lib/models/porcelain.rb', line 11219

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



11221
11222
11223
# File 'lib/models/porcelain.rb', line 11221

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11223
11224
11225
# File 'lib/models/porcelain.rb', line 11223

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11225
11226
11227
# File 'lib/models/porcelain.rb', line 11225

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11227
11228
11229
# File 'lib/models/porcelain.rb', line 11227

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11229
11230
11231
# File 'lib/models/porcelain.rb', line 11229

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



11231
11232
11233
# File 'lib/models/porcelain.rb', line 11231

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



11233
11234
11235
# File 'lib/models/porcelain.rb', line 11233

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11235
11236
11237
# File 'lib/models/porcelain.rb', line 11235

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



11237
11238
11239
# File 'lib/models/porcelain.rb', line 11237

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11239
11240
11241
# File 'lib/models/porcelain.rb', line 11239

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11241
11242
11243
# File 'lib/models/porcelain.rb', line 11241

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11243
11244
11245
# File 'lib/models/porcelain.rb', line 11243

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11291
11292
11293
11294
11295
11296
11297
# File 'lib/models/porcelain.rb', line 11291

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end