Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



11167
11168
11169
11170
11171
11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
11191
11192
11193
11194
11195
11196
11197
11198
11199
11200
11201
11202
11203
11204
11205
11206
11207
11208
11209
11210
11211
# File 'lib/models/porcelain.rb', line 11167

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



11125
11126
11127
# File 'lib/models/porcelain.rb', line 11125

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11127
11128
11129
# File 'lib/models/porcelain.rb', line 11127

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



11129
11130
11131
# File 'lib/models/porcelain.rb', line 11129

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11131
11132
11133
# File 'lib/models/porcelain.rb', line 11131

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11133
11134
11135
# File 'lib/models/porcelain.rb', line 11133

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11135
11136
11137
# File 'lib/models/porcelain.rb', line 11135

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11137
11138
11139
# File 'lib/models/porcelain.rb', line 11137

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



11139
11140
11141
# File 'lib/models/porcelain.rb', line 11139

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



11141
11142
11143
# File 'lib/models/porcelain.rb', line 11141

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



11143
11144
11145
# File 'lib/models/porcelain.rb', line 11143

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



11145
11146
11147
# File 'lib/models/porcelain.rb', line 11145

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11147
11148
11149
# File 'lib/models/porcelain.rb', line 11147

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



11149
11150
11151
# File 'lib/models/porcelain.rb', line 11149

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11151
11152
11153
# File 'lib/models/porcelain.rb', line 11151

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



11153
11154
11155
# File 'lib/models/porcelain.rb', line 11153

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



11155
11156
11157
# File 'lib/models/porcelain.rb', line 11155

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11157
11158
11159
# File 'lib/models/porcelain.rb', line 11157

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



11159
11160
11161
# File 'lib/models/porcelain.rb', line 11159

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11161
11162
11163
# File 'lib/models/porcelain.rb', line 11161

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11163
11164
11165
# File 'lib/models/porcelain.rb', line 11163

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11165
11166
11167
# File 'lib/models/porcelain.rb', line 11165

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11213
11214
11215
11216
11217
11218
11219
# File 'lib/models/porcelain.rb', line 11213

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end