Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



10990
10991
10992
10993
10994
10995
10996
10997
10998
10999
11000
11001
11002
11003
11004
11005
11006
11007
11008
11009
11010
11011
11012
11013
11014
11015
11016
11017
11018
11019
11020
11021
11022
11023
11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
# File 'lib/models/porcelain.rb', line 10990

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10948
10949
10950
# File 'lib/models/porcelain.rb', line 10948

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10950
10951
10952
# File 'lib/models/porcelain.rb', line 10950

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10952
10953
10954
# File 'lib/models/porcelain.rb', line 10952

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10954
10955
10956
# File 'lib/models/porcelain.rb', line 10954

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10956
10957
10958
# File 'lib/models/porcelain.rb', line 10956

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10958
10959
10960
# File 'lib/models/porcelain.rb', line 10958

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10960
10961
10962
# File 'lib/models/porcelain.rb', line 10960

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



10962
10963
10964
# File 'lib/models/porcelain.rb', line 10962

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



10964
10965
10966
# File 'lib/models/porcelain.rb', line 10964

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



10966
10967
10968
# File 'lib/models/porcelain.rb', line 10966

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10968
10969
10970
# File 'lib/models/porcelain.rb', line 10968

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10970
10971
10972
# File 'lib/models/porcelain.rb', line 10970

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10972
10973
10974
# File 'lib/models/porcelain.rb', line 10972

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10974
10975
10976
# File 'lib/models/porcelain.rb', line 10974

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



10976
10977
10978
# File 'lib/models/porcelain.rb', line 10976

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



10978
10979
10980
# File 'lib/models/porcelain.rb', line 10978

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10980
10981
10982
# File 'lib/models/porcelain.rb', line 10980

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



10982
10983
10984
# File 'lib/models/porcelain.rb', line 10982

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10984
10985
10986
# File 'lib/models/porcelain.rb', line 10984

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10986
10987
10988
# File 'lib/models/porcelain.rb', line 10986

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10988
10989
10990
# File 'lib/models/porcelain.rb', line 10988

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11036
11037
11038
11039
11040
11041
11042
# File 'lib/models/porcelain.rb', line 11036

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end