Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



10919
10920
10921
10922
10923
10924
10925
10926
10927
10928
10929
10930
10931
10932
10933
10934
10935
10936
10937
10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
10952
10953
10954
10955
10956
10957
10958
10959
10960
10961
10962
10963
# File 'lib/models/porcelain.rb', line 10919

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10877
10878
10879
# File 'lib/models/porcelain.rb', line 10877

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10879
10880
10881
# File 'lib/models/porcelain.rb', line 10879

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10881
10882
10883
# File 'lib/models/porcelain.rb', line 10881

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10883
10884
10885
# File 'lib/models/porcelain.rb', line 10883

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10885
10886
10887
# File 'lib/models/porcelain.rb', line 10885

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10887
10888
10889
# File 'lib/models/porcelain.rb', line 10887

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10889
10890
10891
# File 'lib/models/porcelain.rb', line 10889

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



10891
10892
10893
# File 'lib/models/porcelain.rb', line 10891

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



10893
10894
10895
# File 'lib/models/porcelain.rb', line 10893

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



10895
10896
10897
# File 'lib/models/porcelain.rb', line 10895

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10897
10898
10899
# File 'lib/models/porcelain.rb', line 10897

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10899
10900
10901
# File 'lib/models/porcelain.rb', line 10899

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10901
10902
10903
# File 'lib/models/porcelain.rb', line 10901

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10903
10904
10905
# File 'lib/models/porcelain.rb', line 10903

def proxy_cluster_id
  @proxy_cluster_id
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



10905
10906
10907
# File 'lib/models/porcelain.rb', line 10905

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



10907
10908
10909
# File 'lib/models/porcelain.rb', line 10907

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10909
10910
10911
# File 'lib/models/porcelain.rb', line 10909

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



10911
10912
10913
# File 'lib/models/porcelain.rb', line 10911

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10913
10914
10915
# File 'lib/models/porcelain.rb', line 10913

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10915
10916
10917
# File 'lib/models/porcelain.rb', line 10915

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10917
10918
10919
# File 'lib/models/porcelain.rb', line 10917

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10965
10966
10967
10968
10969
10970
10971
# File 'lib/models/porcelain.rb', line 10965

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end