Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



10540
10541
10542
10543
10544
10545
10546
10547
10548
10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
10569
10570
10571
10572
10573
10574
10575
10576
10577
10578
10579
10580
10581
10582
# File 'lib/models/porcelain.rb', line 10540

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10500
10501
10502
# File 'lib/models/porcelain.rb', line 10500

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10502
10503
10504
# File 'lib/models/porcelain.rb', line 10502

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10504
10505
10506
# File 'lib/models/porcelain.rb', line 10504

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10506
10507
10508
# File 'lib/models/porcelain.rb', line 10506

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10508
10509
10510
# File 'lib/models/porcelain.rb', line 10508

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10510
10511
10512
# File 'lib/models/porcelain.rb', line 10510

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10512
10513
10514
# File 'lib/models/porcelain.rb', line 10512

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



10514
10515
10516
# File 'lib/models/porcelain.rb', line 10514

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



10516
10517
10518
# File 'lib/models/porcelain.rb', line 10516

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



10518
10519
10520
# File 'lib/models/porcelain.rb', line 10518

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10520
10521
10522
# File 'lib/models/porcelain.rb', line 10520

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10522
10523
10524
# File 'lib/models/porcelain.rb', line 10522

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10524
10525
10526
# File 'lib/models/porcelain.rb', line 10524

def port_override
  @port_override
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



10526
10527
10528
# File 'lib/models/porcelain.rb', line 10526

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



10528
10529
10530
# File 'lib/models/porcelain.rb', line 10528

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10530
10531
10532
# File 'lib/models/porcelain.rb', line 10530

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



10532
10533
10534
# File 'lib/models/porcelain.rb', line 10532

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10534
10535
10536
# File 'lib/models/porcelain.rb', line 10534

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10536
10537
10538
# File 'lib/models/porcelain.rb', line 10536

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10538
10539
10540
# File 'lib/models/porcelain.rb', line 10538

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10584
10585
10586
10587
10588
10589
10590
# File 'lib/models/porcelain.rb', line 10584

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end