Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
10241
10242
# File 'lib/models/porcelain.rb', line 10200

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



10160
10161
10162
# File 'lib/models/porcelain.rb', line 10160

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10162
10163
10164
# File 'lib/models/porcelain.rb', line 10162

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



10164
10165
10166
# File 'lib/models/porcelain.rb', line 10164

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10166
10167
10168
# File 'lib/models/porcelain.rb', line 10166

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10168
10169
10170
# File 'lib/models/porcelain.rb', line 10168

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10170
10171
10172
# File 'lib/models/porcelain.rb', line 10170

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10172
10173
10174
# File 'lib/models/porcelain.rb', line 10172

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



10174
10175
10176
# File 'lib/models/porcelain.rb', line 10174

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



10176
10177
10178
# File 'lib/models/porcelain.rb', line 10176

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



10178
10179
10180
# File 'lib/models/porcelain.rb', line 10178

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



10180
10181
10182
# File 'lib/models/porcelain.rb', line 10180

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10182
10183
10184
# File 'lib/models/porcelain.rb', line 10182

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



10184
10185
10186
# File 'lib/models/porcelain.rb', line 10184

def port_override
  @port_override
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



10186
10187
10188
# File 'lib/models/porcelain.rb', line 10186

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



10188
10189
10190
# File 'lib/models/porcelain.rb', line 10188

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10190
10191
10192
# File 'lib/models/porcelain.rb', line 10190

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



10192
10193
10194
# File 'lib/models/porcelain.rb', line 10192

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10194
10195
10196
# File 'lib/models/porcelain.rb', line 10194

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10196
10197
10198
# File 'lib/models/porcelain.rb', line 10196

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10198
10199
10200
# File 'lib/models/porcelain.rb', line 10198

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10244
10245
10246
10247
10248
10249
10250
# File 'lib/models/porcelain.rb', line 10244

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end