Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
8890
8891
8892
8893
8894
8895
8896
8897
8898
8899
8900
8901
8902
8903
8904
8905
8906
8907
8908
8909
8910
8911
8912
8913
8914
# File 'lib/models/porcelain.rb', line 8872

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  port: nil,
  port_override: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryptionObject

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



8832
8833
8834
# File 'lib/models/porcelain.rb', line 8832

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8834
8835
8836
# File 'lib/models/porcelain.rb', line 8834

def bind_interface
  @bind_interface
end

#databaseObject

The database for healthchecks, and used for clients if Override Default Database is true.



8836
8837
8838
# File 'lib/models/porcelain.rb', line 8836

def database
  @database
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8838
8839
8840
# File 'lib/models/porcelain.rb', line 8838

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8840
8841
8842
# File 'lib/models/porcelain.rb', line 8840

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8842
8843
8844
# File 'lib/models/porcelain.rb', line 8842

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8844
8845
8846
# File 'lib/models/porcelain.rb', line 8844

def id
  @id
end

#keytabObject

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



8846
8847
8848
# File 'lib/models/porcelain.rb', line 8846

def keytab
  @keytab
end

#krb_configObject

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



8848
8849
8850
# File 'lib/models/porcelain.rb', line 8848

def krb_config
  @krb_config
end

#nameObject

Unique human-readable name of the Resource.



8850
8851
8852
# File 'lib/models/porcelain.rb', line 8850

def name
  @name
end

#override_databaseObject

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



8852
8853
8854
# File 'lib/models/porcelain.rb', line 8852

def override_database
  @override_database
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8854
8855
8856
# File 'lib/models/porcelain.rb', line 8854

def port
  @port
end

#port_overrideObject

The local port used by clients to connect to this resource.



8856
8857
8858
# File 'lib/models/porcelain.rb', line 8856

def port_override
  @port_override
end

#realmObject

The Active Directory domain (realm) to which the configured username belongs.



8858
8859
8860
# File 'lib/models/porcelain.rb', line 8858

def realm
  @realm
end

#schemaObject

The Schema to use to direct initial requests.



8860
8861
8862
# File 'lib/models/porcelain.rb', line 8860

def schema
  @schema
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8862
8863
8864
# File 'lib/models/porcelain.rb', line 8862

def secret_store_id
  @secret_store_id
end

#server_spnObject

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



8864
8865
8866
# File 'lib/models/porcelain.rb', line 8864

def server_spn
  @server_spn
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8866
8867
8868
# File 'lib/models/porcelain.rb', line 8866

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8868
8869
8870
# File 'lib/models/porcelain.rb', line 8868

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8870
8871
8872
# File 'lib/models/porcelain.rb', line 8870

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8916
8917
8918
8919
8920
8921
8922
# File 'lib/models/porcelain.rb', line 8916

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end