Class: SDM::SQLServerKerberosAD
- Inherits:
-
Object
- Object
- SDM::SQLServerKerberosAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keytab ⇒ Object
Returns the value of attribute keytab.
-
#krb_config ⇒ Object
Returns the value of attribute krb_config.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#realm ⇒ Object
Returns the value of attribute realm.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_spn ⇒ Object
Returns the value of attribute server_spn.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD
constructor
A new instance of SQLServerKerberosAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD
Returns a new instance of SQLServerKerberosAD.
7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 |
# File 'lib/models/porcelain.rb', line 7571 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @keytab = keytab == nil ? "" : keytab @krb_config = krb_config == nil ? "" : krb_config @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @realm = realm == nil ? "" : realm @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_spn = server_spn == nil ? "" : server_spn @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7533 7534 7535 |
# File 'lib/models/porcelain.rb', line 7533 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
7535 7536 7537 |
# File 'lib/models/porcelain.rb', line 7535 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7537 7538 7539 |
# File 'lib/models/porcelain.rb', line 7537 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7539 7540 7541 |
# File 'lib/models/porcelain.rb', line 7539 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7541 7542 7543 |
# File 'lib/models/porcelain.rb', line 7541 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7543 7544 7545 |
# File 'lib/models/porcelain.rb', line 7543 def id @id end |
#keytab ⇒ Object
Returns the value of attribute keytab.
7545 7546 7547 |
# File 'lib/models/porcelain.rb', line 7545 def keytab @keytab end |
#krb_config ⇒ Object
Returns the value of attribute krb_config.
7547 7548 7549 |
# File 'lib/models/porcelain.rb', line 7547 def krb_config @krb_config end |
#name ⇒ Object
Unique human-readable name of the Resource.
7549 7550 7551 |
# File 'lib/models/porcelain.rb', line 7549 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
7551 7552 7553 |
# File 'lib/models/porcelain.rb', line 7551 def override_database @override_database end |
#port ⇒ Object
Returns the value of attribute port.
7553 7554 7555 |
# File 'lib/models/porcelain.rb', line 7553 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7555 7556 7557 |
# File 'lib/models/porcelain.rb', line 7555 def port_override @port_override end |
#realm ⇒ Object
Returns the value of attribute realm.
7557 7558 7559 |
# File 'lib/models/porcelain.rb', line 7557 def realm @realm end |
#schema ⇒ Object
Returns the value of attribute schema.
7559 7560 7561 |
# File 'lib/models/porcelain.rb', line 7559 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7561 7562 7563 |
# File 'lib/models/porcelain.rb', line 7561 def secret_store_id @secret_store_id end |
#server_spn ⇒ Object
Returns the value of attribute server_spn.
7563 7564 7565 |
# File 'lib/models/porcelain.rb', line 7563 def server_spn @server_spn end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7565 7566 7567 |
# File 'lib/models/porcelain.rb', line 7565 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7567 7568 7569 |
# File 'lib/models/porcelain.rb', line 7567 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7569 7570 7571 |
# File 'lib/models/porcelain.rb', line 7569 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7613 7614 7615 7616 7617 7618 7619 |
# File 'lib/models/porcelain.rb', line 7613 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |