Class: SDM::SQLServerKerberosAD
- Inherits:
-
Object
- Object
- SDM::SQLServerKerberosAD
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#bind_interface ⇒ Object
Bind interface.
-
#database ⇒ Object
Returns the value of attribute database.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#keytab ⇒ Object
Returns the value of attribute keytab.
-
#krb_config ⇒ Object
Returns the value of attribute krb_config.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#override_database ⇒ Object
Returns the value of attribute override_database.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#realm ⇒ Object
Returns the value of attribute realm.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#server_spn ⇒ Object
Returns the value of attribute server_spn.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD
constructor
A new instance of SQLServerKerberosAD.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD
Returns a new instance of SQLServerKerberosAD.
7515 7516 7517 7518 7519 7520 7521 7522 7523 7524 7525 7526 7527 7528 7529 7530 7531 7532 7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 |
# File 'lib/models/porcelain.rb', line 7515 def initialize( bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, port: nil, port_override: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil ) @bind_interface = bind_interface == nil ? "" : bind_interface @database = database == nil ? "" : database @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @keytab = keytab == nil ? "" : keytab @krb_config = krb_config == nil ? "" : krb_config @name = name == nil ? "" : name @override_database = override_database == nil ? false : override_database @port = port == nil ? 0 : port @port_override = port_override == nil ? 0 : port_override @realm = realm == nil ? "" : realm @schema = schema == nil ? "" : schema @secret_store_id = secret_store_id == nil ? "" : secret_store_id @server_spn = server_spn == nil ? "" : server_spn @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#bind_interface ⇒ Object
Bind interface
7477 7478 7479 |
# File 'lib/models/porcelain.rb', line 7477 def bind_interface @bind_interface end |
#database ⇒ Object
Returns the value of attribute database.
7479 7480 7481 |
# File 'lib/models/porcelain.rb', line 7479 def database @database end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7481 7482 7483 |
# File 'lib/models/porcelain.rb', line 7481 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7483 7484 7485 |
# File 'lib/models/porcelain.rb', line 7483 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7485 7486 7487 |
# File 'lib/models/porcelain.rb', line 7485 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7487 7488 7489 |
# File 'lib/models/porcelain.rb', line 7487 def id @id end |
#keytab ⇒ Object
Returns the value of attribute keytab.
7489 7490 7491 |
# File 'lib/models/porcelain.rb', line 7489 def keytab @keytab end |
#krb_config ⇒ Object
Returns the value of attribute krb_config.
7491 7492 7493 |
# File 'lib/models/porcelain.rb', line 7491 def krb_config @krb_config end |
#name ⇒ Object
Unique human-readable name of the Resource.
7493 7494 7495 |
# File 'lib/models/porcelain.rb', line 7493 def name @name end |
#override_database ⇒ Object
Returns the value of attribute override_database.
7495 7496 7497 |
# File 'lib/models/porcelain.rb', line 7495 def override_database @override_database end |
#port ⇒ Object
Returns the value of attribute port.
7497 7498 7499 |
# File 'lib/models/porcelain.rb', line 7497 def port @port end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7499 7500 7501 |
# File 'lib/models/porcelain.rb', line 7499 def port_override @port_override end |
#realm ⇒ Object
Returns the value of attribute realm.
7501 7502 7503 |
# File 'lib/models/porcelain.rb', line 7501 def realm @realm end |
#schema ⇒ Object
Returns the value of attribute schema.
7503 7504 7505 |
# File 'lib/models/porcelain.rb', line 7503 def schema @schema end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7505 7506 7507 |
# File 'lib/models/porcelain.rb', line 7505 def secret_store_id @secret_store_id end |
#server_spn ⇒ Object
Returns the value of attribute server_spn.
7507 7508 7509 |
# File 'lib/models/porcelain.rb', line 7507 def server_spn @server_spn end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7509 7510 7511 |
# File 'lib/models/porcelain.rb', line 7509 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7511 7512 7513 |
# File 'lib/models/porcelain.rb', line 7511 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7513 7514 7515 |
# File 'lib/models/porcelain.rb', line 7513 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7557 7558 7559 7560 7561 7562 7563 |
# File 'lib/models/porcelain.rb', line 7557 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |