Class: SDM::SQLServerKerberosAD

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_encryption: nil, bind_interface: nil, database: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, keytab: nil, krb_config: nil, name: nil, override_database: nil, password: nil, port: nil, port_override: nil, proxy_cluster_id: nil, realm: nil, schema: nil, secret_store_id: nil, server_spn: nil, subdomain: nil, tags: nil, username: nil) ⇒ SQLServerKerberosAD

Returns a new instance of SQLServerKerberosAD.



16712
16713
16714
16715
16716
16717
16718
16719
16720
16721
16722
16723
16724
16725
16726
16727
16728
16729
16730
16731
16732
16733
16734
16735
16736
16737
16738
16739
16740
16741
16742
16743
16744
16745
16746
16747
16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
16762
# File 'lib/models/porcelain.rb', line 16712

def initialize(
  allow_deprecated_encryption: nil,
  bind_interface: nil,
  database: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  keytab: nil,
  krb_config: nil,
  name: nil,
  override_database: nil,
  password: nil,
  port: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  realm: nil,
  schema: nil,
  secret_store_id: nil,
  server_spn: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_encryption = allow_deprecated_encryption == nil ? false : allow_deprecated_encryption
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @database = database == nil ? "" : database
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @keytab = keytab == nil ? "" : keytab
  @krb_config = krb_config == nil ? "" : krb_config
  @name = name == nil ? "" : name
  @override_database = override_database == nil ? false : override_database
  @password = password == nil ? "" : password
  @port = port == nil ? 0 : port
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @realm = realm == nil ? "" : realm
  @schema = schema == nil ? "" : schema
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @server_spn = server_spn == nil ? "" : server_spn
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_encryption ⇒ Object

Whether to allow deprecated encryption protocols to be used for this resource. For example, TLS 1.0.



16664
16665
16666
# File 'lib/models/porcelain.rb', line 16664

def allow_deprecated_encryption
  @allow_deprecated_encryption
end

#bind_interface ⇒ Object

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16666
16667
16668
# File 'lib/models/porcelain.rb', line 16666

def bind_interface
  @bind_interface
end

#database ⇒ Object

The database for healthchecks, and used for clients if Override Default Database is true.



16668
16669
16670
# File 'lib/models/porcelain.rb', line 16668

def database
  @database
end

#egress_filter ⇒ Object

A filter applied to the routing logic to pin datasource to nodes.



16670
16671
16672
# File 'lib/models/porcelain.rb', line 16670

def egress_filter
  @egress_filter
end

#healthy ⇒ Object

True if the datasource is reachable and the credentials are valid.



16672
16673
16674
# File 'lib/models/porcelain.rb', line 16672

def healthy
  @healthy
end

#hostname ⇒ Object

The host to dial to initiate a connection from the egress node to this resource.



16674
16675
16676
# File 'lib/models/porcelain.rb', line 16674

def hostname
  @hostname
end

#id ⇒ Object

Unique identifier of the Resource.



16676
16677
16678
# File 'lib/models/porcelain.rb', line 16676

def id
  @id
end

#identity_alias_healthcheck_username ⇒ Object

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16678
16679
16680
# File 'lib/models/porcelain.rb', line 16678

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_id ⇒ Object

The ID of the identity set to use for identity connections.



16680
16681
16682
# File 'lib/models/porcelain.rb', line 16680

def identity_set_id
  @identity_set_id
end

#keytab ⇒ Object

The keytab file in base64 format containing an entry with the principal name (username@realm) and key version number with which to authenticate.



16682
16683
16684
# File 'lib/models/porcelain.rb', line 16682

def keytab
  @keytab
end

#krb_config ⇒ Object

The Kerberos 5 configuration file (krb5.conf) specifying the Active Directory server (KDC) for the configured realm.



16684
16685
16686
# File 'lib/models/porcelain.rb', line 16684

def krb_config
  @krb_config
end

#name ⇒ Object

Unique human-readable name of the Resource.



16686
16687
16688
# File 'lib/models/porcelain.rb', line 16686

def name
  @name
end

#override_database ⇒ Object

If set, the database configured cannot be changed by users. This setting is not recommended for most use cases, as some clients will insist their database has changed when it has not, leading to user confusion.



16688
16689
16690
# File 'lib/models/porcelain.rb', line 16688

def override_database
  @override_database
end

#password ⇒ Object

The password to authenticate with.



16690
16691
16692
# File 'lib/models/porcelain.rb', line 16690

def password
  @password
end

#port ⇒ Object

The port to dial to initiate a connection from the egress node to this resource.



16692
16693
16694
# File 'lib/models/porcelain.rb', line 16692

def port
  @port
end

#port_override ⇒ Object

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16694
16695
16696
# File 'lib/models/porcelain.rb', line 16694

def port_override
  @port_override
end

#proxy_cluster_id ⇒ Object

ID of the proxy cluster for this resource, if any.



16696
16697
16698
# File 'lib/models/porcelain.rb', line 16696

def proxy_cluster_id
  @proxy_cluster_id
end

#realm ⇒ Object

The Active Directory domain (realm) to which the configured username belongs.



16698
16699
16700
# File 'lib/models/porcelain.rb', line 16698

def realm
  @realm
end

#schema ⇒ Object

The Schema to use to direct initial requests.



16700
16701
16702
# File 'lib/models/porcelain.rb', line 16700

def schema
  @schema
end

#secret_store_id ⇒ Object

ID of the secret store containing credentials for this resource, if any.



16702
16703
16704
# File 'lib/models/porcelain.rb', line 16702

def secret_store_id
  @secret_store_id
end

#server_spn ⇒ Object

The Service Principal Name of the Microsoft SQL Server instance in Active Directory.



16704
16705
16706
# File 'lib/models/porcelain.rb', line 16704

def server_spn
  @server_spn
end

#subdomain ⇒ Object

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16706
16707
16708
# File 'lib/models/porcelain.rb', line 16706

def subdomain
  @subdomain
end

#tags ⇒ Object

Tags is a map of key, value pairs.



16708
16709
16710
# File 'lib/models/porcelain.rb', line 16708

def tags
  @tags
end

#username ⇒ Object

The username to authenticate with.



16710
16711
16712
# File 'lib/models/porcelain.rb', line 16710

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16764
16765
16766
16767
16768
16769
16770
# File 'lib/models/porcelain.rb', line 16764

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end