Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
The key type to use e.g.
-
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#public_key ⇒ Object
The public key to append to a server's authorized keys.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
16703 16704 16705 16706 16707 16708 16709 16710 16711 16712 16713 16714 16715 16716 16717 16718 16719 16720 16721 16722 16723 16724 16725 16726 16727 16728 16729 16730 16731 16732 16733 16734 16735 16736 16737 16738 16739 16740 16741 |
# File 'lib/models/porcelain.rb', line 16703 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @lock_required = lock_required == nil ? false : lock_required @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
16667 16668 16669 |
# File 'lib/models/porcelain.rb', line 16667 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.
16669 16670 16671 |
# File 'lib/models/porcelain.rb', line 16669 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
16671 16672 16673 |
# File 'lib/models/porcelain.rb', line 16671 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
16673 16674 16675 |
# File 'lib/models/porcelain.rb', line 16673 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
16675 16676 16677 |
# File 'lib/models/porcelain.rb', line 16675 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
16677 16678 16679 |
# File 'lib/models/porcelain.rb', line 16677 def id @id end |
#key_type ⇒ Object
The key type to use e.g. rsa-2048 or ed25519
16679 16680 16681 |
# File 'lib/models/porcelain.rb', line 16679 def key_type @key_type end |
#lock_required ⇒ Object
When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.
16681 16682 16683 |
# File 'lib/models/porcelain.rb', line 16681 def lock_required @lock_required end |
#name ⇒ Object
Unique human-readable name of the Resource.
16683 16684 16685 |
# File 'lib/models/porcelain.rb', line 16683 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
16685 16686 16687 |
# File 'lib/models/porcelain.rb', line 16685 def port @port end |
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
16687 16688 16689 |
# File 'lib/models/porcelain.rb', line 16687 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.
16689 16690 16691 |
# File 'lib/models/porcelain.rb', line 16689 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
16691 16692 16693 |
# File 'lib/models/porcelain.rb', line 16691 def proxy_cluster_id @proxy_cluster_id end |
#public_key ⇒ Object
The public key to append to a server's authorized keys. This will be generated after resource creation.
16693 16694 16695 |
# File 'lib/models/porcelain.rb', line 16693 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
16695 16696 16697 |
# File 'lib/models/porcelain.rb', line 16695 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.
16697 16698 16699 |
# File 'lib/models/porcelain.rb', line 16697 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
16699 16700 16701 |
# File 'lib/models/porcelain.rb', line 16699 def @tags end |
#username ⇒ Object
The username to authenticate with.
16701 16702 16703 |
# File 'lib/models/porcelain.rb', line 16701 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
16743 16744 16745 16746 16747 16748 16749 |
# File 'lib/models/porcelain.rb', line 16743 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |