Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



16393
16394
16395
16396
16397
16398
16399
16400
16401
16402
16403
16404
16405
16406
16407
16408
16409
16410
16411
16412
16413
16414
16415
16416
16417
16418
16419
16420
16421
16422
16423
16424
16425
16426
16427
16428
16429
16430
16431
# File 'lib/models/porcelain.rb', line 16393

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16357
16358
16359
# File 'lib/models/porcelain.rb', line 16357

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16359
16360
16361
# File 'lib/models/porcelain.rb', line 16359

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16361
16362
16363
# File 'lib/models/porcelain.rb', line 16361

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16363
16364
16365
# File 'lib/models/porcelain.rb', line 16363

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16365
16366
16367
# File 'lib/models/porcelain.rb', line 16365

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16367
16368
16369
# File 'lib/models/porcelain.rb', line 16367

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



16369
16370
16371
# File 'lib/models/porcelain.rb', line 16369

def key_type
  @key_type
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16371
16372
16373
# File 'lib/models/porcelain.rb', line 16371

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16373
16374
16375
# File 'lib/models/porcelain.rb', line 16373

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16375
16376
16377
# File 'lib/models/porcelain.rb', line 16375

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16377
16378
16379
# File 'lib/models/porcelain.rb', line 16377

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16379
16380
16381
# File 'lib/models/porcelain.rb', line 16379

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16381
16382
16383
# File 'lib/models/porcelain.rb', line 16381

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



16383
16384
16385
# File 'lib/models/porcelain.rb', line 16383

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16385
16386
16387
# File 'lib/models/porcelain.rb', line 16385

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16387
16388
16389
# File 'lib/models/porcelain.rb', line 16387

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16389
16390
16391
# File 'lib/models/porcelain.rb', line 16389

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16391
16392
16393
# File 'lib/models/porcelain.rb', line 16391

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16433
16434
16435
16436
16437
16438
16439
# File 'lib/models/porcelain.rb', line 16433

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end