Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



16269
16270
16271
16272
16273
16274
16275
16276
16277
16278
16279
16280
16281
16282
16283
16284
16285
16286
16287
16288
16289
16290
16291
16292
16293
16294
16295
16296
16297
16298
16299
16300
16301
16302
16303
16304
16305
16306
16307
# File 'lib/models/porcelain.rb', line 16269

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16233
16234
16235
# File 'lib/models/porcelain.rb', line 16233

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16235
16236
16237
# File 'lib/models/porcelain.rb', line 16235

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16237
16238
16239
# File 'lib/models/porcelain.rb', line 16237

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16239
16240
16241
# File 'lib/models/porcelain.rb', line 16239

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16241
16242
16243
# File 'lib/models/porcelain.rb', line 16241

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16243
16244
16245
# File 'lib/models/porcelain.rb', line 16243

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



16245
16246
16247
# File 'lib/models/porcelain.rb', line 16245

def key_type
  @key_type
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16247
16248
16249
# File 'lib/models/porcelain.rb', line 16247

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16249
16250
16251
# File 'lib/models/porcelain.rb', line 16249

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16251
16252
16253
# File 'lib/models/porcelain.rb', line 16251

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16253
16254
16255
# File 'lib/models/porcelain.rb', line 16253

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16255
16256
16257
# File 'lib/models/porcelain.rb', line 16255

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16257
16258
16259
# File 'lib/models/porcelain.rb', line 16257

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



16259
16260
16261
# File 'lib/models/porcelain.rb', line 16259

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16261
16262
16263
# File 'lib/models/porcelain.rb', line 16261

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16263
16264
16265
# File 'lib/models/porcelain.rb', line 16263

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16265
16266
16267
# File 'lib/models/porcelain.rb', line 16265

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16267
16268
16269
# File 'lib/models/porcelain.rb', line 16267

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16309
16310
16311
16312
16313
16314
16315
# File 'lib/models/porcelain.rb', line 16309

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end