Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
15983
15984
15985
15986
15987
15988
15989
15990
15991
15992
15993
15994
15995
15996
15997
15998
15999
16000
16001
16002
16003
16004
16005
16006
16007
16008
# File 'lib/models/porcelain.rb', line 15970

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



15934
15935
15936
# File 'lib/models/porcelain.rb', line 15934

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15936
15937
15938
# File 'lib/models/porcelain.rb', line 15936

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15938
15939
15940
# File 'lib/models/porcelain.rb', line 15938

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15940
15941
15942
# File 'lib/models/porcelain.rb', line 15940

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15942
15943
15944
# File 'lib/models/porcelain.rb', line 15942

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15944
15945
15946
# File 'lib/models/porcelain.rb', line 15944

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



15946
15947
15948
# File 'lib/models/porcelain.rb', line 15946

def key_type
  @key_type
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



15948
15949
15950
# File 'lib/models/porcelain.rb', line 15948

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



15950
15951
15952
# File 'lib/models/porcelain.rb', line 15950

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15952
15953
15954
# File 'lib/models/porcelain.rb', line 15952

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



15954
15955
15956
# File 'lib/models/porcelain.rb', line 15954

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15956
15957
15958
# File 'lib/models/porcelain.rb', line 15956

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15958
15959
15960
# File 'lib/models/porcelain.rb', line 15958

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



15960
15961
15962
# File 'lib/models/porcelain.rb', line 15960

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15962
15963
15964
# File 'lib/models/porcelain.rb', line 15962

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15964
15965
15966
# File 'lib/models/porcelain.rb', line 15964

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15966
15967
15968
# File 'lib/models/porcelain.rb', line 15966

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15968
15969
15970
# File 'lib/models/porcelain.rb', line 15968

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16010
16011
16012
16013
16014
16015
16016
# File 'lib/models/porcelain.rb', line 16010

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end