Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



15594
15595
15596
15597
15598
15599
15600
15601
15602
15603
15604
15605
15606
15607
15608
15609
15610
15611
15612
15613
15614
15615
15616
15617
15618
15619
15620
15621
15622
15623
15624
15625
15626
15627
15628
15629
15630
15631
15632
# File 'lib/models/porcelain.rb', line 15594

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



15558
15559
15560
# File 'lib/models/porcelain.rb', line 15558

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



15560
15561
15562
# File 'lib/models/porcelain.rb', line 15560

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



15562
15563
15564
# File 'lib/models/porcelain.rb', line 15562

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



15564
15565
15566
# File 'lib/models/porcelain.rb', line 15564

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



15566
15567
15568
# File 'lib/models/porcelain.rb', line 15566

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



15568
15569
15570
# File 'lib/models/porcelain.rb', line 15568

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



15570
15571
15572
# File 'lib/models/porcelain.rb', line 15570

def key_type
  @key_type
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



15572
15573
15574
# File 'lib/models/porcelain.rb', line 15572

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



15574
15575
15576
# File 'lib/models/porcelain.rb', line 15574

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



15576
15577
15578
# File 'lib/models/porcelain.rb', line 15576

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



15578
15579
15580
# File 'lib/models/porcelain.rb', line 15578

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



15580
15581
15582
# File 'lib/models/porcelain.rb', line 15580

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



15582
15583
15584
# File 'lib/models/porcelain.rb', line 15582

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



15584
15585
15586
# File 'lib/models/porcelain.rb', line 15584

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



15586
15587
15588
# File 'lib/models/porcelain.rb', line 15586

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



15588
15589
15590
# File 'lib/models/porcelain.rb', line 15588

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



15590
15591
15592
# File 'lib/models/porcelain.rb', line 15590

def tags
  @tags
end

#usernameObject

The username to authenticate with.



15592
15593
15594
# File 'lib/models/porcelain.rb', line 15592

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



15634
15635
15636
15637
15638
15639
15640
# File 'lib/models/porcelain.rb', line 15634

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end