Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



13423
13424
13425
13426
13427
13428
13429
13430
13431
13432
13433
13434
13435
13436
13437
13438
13439
13440
13441
13442
13443
13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
13458
13459
# File 'lib/models/porcelain.rb', line 13423

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13389
13390
13391
# File 'lib/models/porcelain.rb', line 13389

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13391
13392
13393
# File 'lib/models/porcelain.rb', line 13391

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13393
13394
13395
# File 'lib/models/porcelain.rb', line 13393

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13395
13396
13397
# File 'lib/models/porcelain.rb', line 13395

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13397
13398
13399
# File 'lib/models/porcelain.rb', line 13397

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13399
13400
13401
# File 'lib/models/porcelain.rb', line 13399

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



13401
13402
13403
# File 'lib/models/porcelain.rb', line 13401

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



13403
13404
13405
# File 'lib/models/porcelain.rb', line 13403

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13405
13406
13407
# File 'lib/models/porcelain.rb', line 13405

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13407
13408
13409
# File 'lib/models/porcelain.rb', line 13407

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13409
13410
13411
# File 'lib/models/porcelain.rb', line 13409

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13411
13412
13413
# File 'lib/models/porcelain.rb', line 13411

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



13413
13414
13415
# File 'lib/models/porcelain.rb', line 13413

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13415
13416
13417
# File 'lib/models/porcelain.rb', line 13415

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13417
13418
13419
# File 'lib/models/porcelain.rb', line 13417

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13419
13420
13421
# File 'lib/models/porcelain.rb', line 13419

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13421
13422
13423
# File 'lib/models/porcelain.rb', line 13421

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13461
13462
13463
13464
13465
13466
13467
# File 'lib/models/porcelain.rb', line 13461

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end