Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



13243
13244
13245
13246
13247
13248
13249
13250
13251
13252
13253
13254
13255
13256
13257
13258
13259
13260
13261
13262
13263
13264
13265
13266
13267
13268
13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
13279
# File 'lib/models/porcelain.rb', line 13243

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13209
13210
13211
# File 'lib/models/porcelain.rb', line 13209

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13211
13212
13213
# File 'lib/models/porcelain.rb', line 13211

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13213
13214
13215
# File 'lib/models/porcelain.rb', line 13213

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13215
13216
13217
# File 'lib/models/porcelain.rb', line 13215

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13217
13218
13219
# File 'lib/models/porcelain.rb', line 13217

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13219
13220
13221
# File 'lib/models/porcelain.rb', line 13219

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



13221
13222
13223
# File 'lib/models/porcelain.rb', line 13221

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



13223
13224
13225
# File 'lib/models/porcelain.rb', line 13223

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13225
13226
13227
# File 'lib/models/porcelain.rb', line 13225

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13227
13228
13229
# File 'lib/models/porcelain.rb', line 13227

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13229
13230
13231
# File 'lib/models/porcelain.rb', line 13229

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13231
13232
13233
# File 'lib/models/porcelain.rb', line 13231

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



13233
13234
13235
# File 'lib/models/porcelain.rb', line 13233

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13235
13236
13237
# File 'lib/models/porcelain.rb', line 13235

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13237
13238
13239
# File 'lib/models/porcelain.rb', line 13237

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13239
13240
13241
# File 'lib/models/porcelain.rb', line 13239

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13241
13242
13243
# File 'lib/models/porcelain.rb', line 13241

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13281
13282
13283
13284
13285
13286
13287
# File 'lib/models/porcelain.rb', line 13281

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end