Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



13164
13165
13166
13167
13168
13169
13170
13171
13172
13173
13174
13175
13176
13177
13178
13179
13180
13181
13182
13183
13184
13185
13186
13187
13188
13189
13190
13191
13192
13193
13194
13195
13196
13197
13198
13199
13200
# File 'lib/models/porcelain.rb', line 13164

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13130
13131
13132
# File 'lib/models/porcelain.rb', line 13130

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13132
13133
13134
# File 'lib/models/porcelain.rb', line 13132

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13134
13135
13136
# File 'lib/models/porcelain.rb', line 13134

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13136
13137
13138
# File 'lib/models/porcelain.rb', line 13136

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13138
13139
13140
# File 'lib/models/porcelain.rb', line 13138

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13140
13141
13142
# File 'lib/models/porcelain.rb', line 13140

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



13142
13143
13144
# File 'lib/models/porcelain.rb', line 13142

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



13144
13145
13146
# File 'lib/models/porcelain.rb', line 13144

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13146
13147
13148
# File 'lib/models/porcelain.rb', line 13146

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13148
13149
13150
# File 'lib/models/porcelain.rb', line 13148

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13150
13151
13152
# File 'lib/models/porcelain.rb', line 13150

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13152
13153
13154
# File 'lib/models/porcelain.rb', line 13152

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



13154
13155
13156
# File 'lib/models/porcelain.rb', line 13154

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13156
13157
13158
# File 'lib/models/porcelain.rb', line 13156

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13158
13159
13160
# File 'lib/models/porcelain.rb', line 13158

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13160
13161
13162
# File 'lib/models/porcelain.rb', line 13160

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13162
13163
13164
# File 'lib/models/porcelain.rb', line 13162

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13202
13203
13204
13205
13206
13207
13208
# File 'lib/models/porcelain.rb', line 13202

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end