Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



13091
13092
13093
13094
13095
13096
13097
13098
13099
13100
13101
13102
13103
13104
13105
13106
13107
13108
13109
13110
13111
13112
13113
13114
13115
13116
13117
13118
13119
13120
13121
13122
13123
13124
13125
13126
13127
# File 'lib/models/porcelain.rb', line 13091

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13057
13058
13059
# File 'lib/models/porcelain.rb', line 13057

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13059
13060
13061
# File 'lib/models/porcelain.rb', line 13059

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13061
13062
13063
# File 'lib/models/porcelain.rb', line 13061

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13063
13064
13065
# File 'lib/models/porcelain.rb', line 13063

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13065
13066
13067
# File 'lib/models/porcelain.rb', line 13065

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13067
13068
13069
# File 'lib/models/porcelain.rb', line 13067

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



13069
13070
13071
# File 'lib/models/porcelain.rb', line 13069

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



13071
13072
13073
# File 'lib/models/porcelain.rb', line 13071

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13073
13074
13075
# File 'lib/models/porcelain.rb', line 13073

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13075
13076
13077
# File 'lib/models/porcelain.rb', line 13075

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13077
13078
13079
# File 'lib/models/porcelain.rb', line 13077

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13079
13080
13081
# File 'lib/models/porcelain.rb', line 13079

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



13081
13082
13083
# File 'lib/models/porcelain.rb', line 13081

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13083
13084
13085
# File 'lib/models/porcelain.rb', line 13083

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13085
13086
13087
# File 'lib/models/porcelain.rb', line 13085

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13087
13088
13089
# File 'lib/models/porcelain.rb', line 13087

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13089
13090
13091
# File 'lib/models/porcelain.rb', line 13089

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13129
13130
13131
13132
13133
13134
13135
# File 'lib/models/porcelain.rb', line 13129

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end