Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
The key type to use e.g.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
-
#public_key ⇒ Object
The public key to append to a server's authorized keys.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
13023 13024 13025 13026 13027 13028 13029 13030 13031 13032 13033 13034 13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 13049 13050 13051 13052 13053 13054 13055 13056 13057 13058 13059 |
# File 'lib/models/porcelain.rb', line 13023 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
12989 12990 12991 |
# File 'lib/models/porcelain.rb', line 12989 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
12991 12992 12993 |
# File 'lib/models/porcelain.rb', line 12991 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
12993 12994 12995 |
# File 'lib/models/porcelain.rb', line 12993 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
12995 12996 12997 |
# File 'lib/models/porcelain.rb', line 12995 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
12997 12998 12999 |
# File 'lib/models/porcelain.rb', line 12997 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
12999 13000 13001 |
# File 'lib/models/porcelain.rb', line 12999 def id @id end |
#key_type ⇒ Object
The key type to use e.g. rsa-2048 or ed25519
13001 13002 13003 |
# File 'lib/models/porcelain.rb', line 13001 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
13003 13004 13005 |
# File 'lib/models/porcelain.rb', line 13003 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
13005 13006 13007 |
# File 'lib/models/porcelain.rb', line 13005 def port @port end |
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
13007 13008 13009 |
# File 'lib/models/porcelain.rb', line 13007 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
13009 13010 13011 |
# File 'lib/models/porcelain.rb', line 13009 def port_override @port_override end |
#proxy_cluster_id ⇒ Object
ID of the proxy cluster for this resource, if any.
13011 13012 13013 |
# File 'lib/models/porcelain.rb', line 13011 def proxy_cluster_id @proxy_cluster_id end |
#public_key ⇒ Object
The public key to append to a server's authorized keys. This will be generated after resource creation.
13013 13014 13015 |
# File 'lib/models/porcelain.rb', line 13013 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
13015 13016 13017 |
# File 'lib/models/porcelain.rb', line 13015 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
13017 13018 13019 |
# File 'lib/models/porcelain.rb', line 13017 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
13019 13020 13021 |
# File 'lib/models/porcelain.rb', line 13019 def @tags end |
#username ⇒ Object
The username to authenticate with.
13021 13022 13023 |
# File 'lib/models/porcelain.rb', line 13021 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
13061 13062 13063 13064 13065 13066 13067 |
# File 'lib/models/porcelain.rb', line 13061 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |