Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



11854
11855
11856
11857
11858
11859
11860
11861
11862
11863
11864
11865
11866
11867
11868
11869
11870
11871
11872
11873
11874
11875
11876
11877
11878
11879
11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
11890
# File 'lib/models/porcelain.rb', line 11854

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11820
11821
11822
# File 'lib/models/porcelain.rb', line 11820

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11822
11823
11824
# File 'lib/models/porcelain.rb', line 11822

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11824
11825
11826
# File 'lib/models/porcelain.rb', line 11824

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11826
11827
11828
# File 'lib/models/porcelain.rb', line 11826

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11828
11829
11830
# File 'lib/models/porcelain.rb', line 11828

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11830
11831
11832
# File 'lib/models/porcelain.rb', line 11830

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11832
11833
11834
# File 'lib/models/porcelain.rb', line 11832

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11834
11835
11836
# File 'lib/models/porcelain.rb', line 11834

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11836
11837
11838
# File 'lib/models/porcelain.rb', line 11836

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11838
11839
11840
# File 'lib/models/porcelain.rb', line 11838

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11840
11841
11842
# File 'lib/models/porcelain.rb', line 11840

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11842
11843
11844
# File 'lib/models/porcelain.rb', line 11842

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



11844
11845
11846
# File 'lib/models/porcelain.rb', line 11844

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11846
11847
11848
# File 'lib/models/porcelain.rb', line 11846

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11848
11849
11850
# File 'lib/models/porcelain.rb', line 11848

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11850
11851
11852
# File 'lib/models/porcelain.rb', line 11850

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11852
11853
11854
# File 'lib/models/porcelain.rb', line 11852

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11892
11893
11894
11895
11896
11897
11898
# File 'lib/models/porcelain.rb', line 11892

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end