Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
11784
11785
11786
11787
11788
11789
11790
11791
11792
11793
11794
11795
11796
11797
11798
11799
11800
11801
11802
11803
11804
11805
11806
11807
11808
11809
11810
# File 'lib/models/porcelain.rb', line 11774

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11740
11741
11742
# File 'lib/models/porcelain.rb', line 11740

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11742
11743
11744
# File 'lib/models/porcelain.rb', line 11742

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11744
11745
11746
# File 'lib/models/porcelain.rb', line 11744

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11746
11747
11748
# File 'lib/models/porcelain.rb', line 11746

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11748
11749
11750
# File 'lib/models/porcelain.rb', line 11748

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11750
11751
11752
# File 'lib/models/porcelain.rb', line 11750

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11752
11753
11754
# File 'lib/models/porcelain.rb', line 11752

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11754
11755
11756
# File 'lib/models/porcelain.rb', line 11754

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11756
11757
11758
# File 'lib/models/porcelain.rb', line 11756

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11758
11759
11760
# File 'lib/models/porcelain.rb', line 11758

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11760
11761
11762
# File 'lib/models/porcelain.rb', line 11760

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11762
11763
11764
# File 'lib/models/porcelain.rb', line 11762

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



11764
11765
11766
# File 'lib/models/porcelain.rb', line 11764

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11766
11767
11768
# File 'lib/models/porcelain.rb', line 11766

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11768
11769
11770
# File 'lib/models/porcelain.rb', line 11768

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11770
11771
11772
# File 'lib/models/porcelain.rb', line 11770

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11772
11773
11774
# File 'lib/models/porcelain.rb', line 11772

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11812
11813
11814
11815
11816
11817
11818
# File 'lib/models/porcelain.rb', line 11812

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end