Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
11720
11721
11722
11723
11724
11725
11726
11727
11728
11729
11730
11731
11732
11733
11734
11735
# File 'lib/models/porcelain.rb', line 11699

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11665
11666
11667
# File 'lib/models/porcelain.rb', line 11665

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11667
11668
11669
# File 'lib/models/porcelain.rb', line 11667

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11669
11670
11671
# File 'lib/models/porcelain.rb', line 11669

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11671
11672
11673
# File 'lib/models/porcelain.rb', line 11671

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11673
11674
11675
# File 'lib/models/porcelain.rb', line 11673

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11675
11676
11677
# File 'lib/models/porcelain.rb', line 11675

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11677
11678
11679
# File 'lib/models/porcelain.rb', line 11677

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11679
11680
11681
# File 'lib/models/porcelain.rb', line 11679

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11681
11682
11683
# File 'lib/models/porcelain.rb', line 11681

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11683
11684
11685
# File 'lib/models/porcelain.rb', line 11683

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11685
11686
11687
# File 'lib/models/porcelain.rb', line 11685

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11687
11688
11689
# File 'lib/models/porcelain.rb', line 11687

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



11689
11690
11691
# File 'lib/models/porcelain.rb', line 11689

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11691
11692
11693
# File 'lib/models/porcelain.rb', line 11691

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11693
11694
11695
# File 'lib/models/porcelain.rb', line 11693

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11695
11696
11697
# File 'lib/models/porcelain.rb', line 11695

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11697
11698
11699
# File 'lib/models/porcelain.rb', line 11697

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11737
11738
11739
11740
11741
11742
11743
# File 'lib/models/porcelain.rb', line 11737

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end