Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



11633
11634
11635
11636
11637
11638
11639
11640
11641
11642
11643
11644
11645
11646
11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
11658
11659
11660
11661
11662
11663
11664
11665
11666
11667
11668
11669
# File 'lib/models/porcelain.rb', line 11633

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11599
11600
11601
# File 'lib/models/porcelain.rb', line 11599

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11601
11602
11603
# File 'lib/models/porcelain.rb', line 11601

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11603
11604
11605
# File 'lib/models/porcelain.rb', line 11603

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11605
11606
11607
# File 'lib/models/porcelain.rb', line 11605

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11607
11608
11609
# File 'lib/models/porcelain.rb', line 11607

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11609
11610
11611
# File 'lib/models/porcelain.rb', line 11609

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11611
11612
11613
# File 'lib/models/porcelain.rb', line 11611

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11613
11614
11615
# File 'lib/models/porcelain.rb', line 11613

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11615
11616
11617
# File 'lib/models/porcelain.rb', line 11615

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11617
11618
11619
# File 'lib/models/porcelain.rb', line 11617

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11619
11620
11621
# File 'lib/models/porcelain.rb', line 11619

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11621
11622
11623
# File 'lib/models/porcelain.rb', line 11621

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



11623
11624
11625
# File 'lib/models/porcelain.rb', line 11623

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11625
11626
11627
# File 'lib/models/porcelain.rb', line 11625

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11627
11628
11629
# File 'lib/models/porcelain.rb', line 11627

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11629
11630
11631
# File 'lib/models/porcelain.rb', line 11629

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11631
11632
11633
# File 'lib/models/porcelain.rb', line 11631

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11671
11672
11673
11674
11675
11676
11677
# File 'lib/models/porcelain.rb', line 11671

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end