Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
11093
11094
11095
11096
11097
11098
11099
11100
11101
11102
11103
11104
11105
11106
11107
11108
11109
11110
11111
11112
11113
11114
11115
11116
11117
# File 'lib/models/porcelain.rb', line 11081

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11047
11048
11049
# File 'lib/models/porcelain.rb', line 11047

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11049
11050
11051
# File 'lib/models/porcelain.rb', line 11049

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11051
11052
11053
# File 'lib/models/porcelain.rb', line 11051

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11053
11054
11055
# File 'lib/models/porcelain.rb', line 11053

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11055
11056
11057
# File 'lib/models/porcelain.rb', line 11055

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11057
11058
11059
# File 'lib/models/porcelain.rb', line 11057

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11059
11060
11061
# File 'lib/models/porcelain.rb', line 11059

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11061
11062
11063
# File 'lib/models/porcelain.rb', line 11061

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11063
11064
11065
# File 'lib/models/porcelain.rb', line 11063

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11065
11066
11067
# File 'lib/models/porcelain.rb', line 11065

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11067
11068
11069
# File 'lib/models/porcelain.rb', line 11067

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11069
11070
11071
# File 'lib/models/porcelain.rb', line 11069

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



11071
11072
11073
# File 'lib/models/porcelain.rb', line 11071

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11073
11074
11075
# File 'lib/models/porcelain.rb', line 11073

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11075
11076
11077
# File 'lib/models/porcelain.rb', line 11075

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11077
11078
11079
# File 'lib/models/porcelain.rb', line 11077

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11079
11080
11081
# File 'lib/models/porcelain.rb', line 11079

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11119
11120
11121
11122
11123
11124
11125
# File 'lib/models/porcelain.rb', line 11119

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end