Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



11010
11011
11012
11013
11014
11015
11016
11017
11018
11019
11020
11021
11022
11023
11024
11025
11026
11027
11028
11029
11030
11031
11032
11033
11034
11035
11036
11037
11038
11039
11040
11041
11042
11043
11044
11045
11046
# File 'lib/models/porcelain.rb', line 11010

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



10976
10977
10978
# File 'lib/models/porcelain.rb', line 10976

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10978
10979
10980
# File 'lib/models/porcelain.rb', line 10978

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10980
10981
10982
# File 'lib/models/porcelain.rb', line 10980

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10982
10983
10984
# File 'lib/models/porcelain.rb', line 10982

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10984
10985
10986
# File 'lib/models/porcelain.rb', line 10984

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10986
10987
10988
# File 'lib/models/porcelain.rb', line 10986

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



10988
10989
10990
# File 'lib/models/porcelain.rb', line 10988

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



10990
10991
10992
# File 'lib/models/porcelain.rb', line 10990

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10992
10993
10994
# File 'lib/models/porcelain.rb', line 10992

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



10994
10995
10996
# File 'lib/models/porcelain.rb', line 10994

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



10996
10997
10998
# File 'lib/models/porcelain.rb', line 10996

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



10998
10999
11000
# File 'lib/models/porcelain.rb', line 10998

def proxy_cluster_id
  @proxy_cluster_id
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



11000
11001
11002
# File 'lib/models/porcelain.rb', line 11000

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11002
11003
11004
# File 'lib/models/porcelain.rb', line 11002

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11004
11005
11006
# File 'lib/models/porcelain.rb', line 11004

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11006
11007
11008
# File 'lib/models/porcelain.rb', line 11006

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11008
11009
11010
# File 'lib/models/porcelain.rb', line 11008

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11048
11049
11050
11051
11052
11053
11054
# File 'lib/models/porcelain.rb', line 11048

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end