Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
The key type to use e.g.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#public_key ⇒ Object
The public key to append to a server's authorized keys.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 10637 10638 10639 10640 10641 10642 10643 10644 10645 10646 10647 10648 10649 10650 10651 10652 10653 10654 10655 10656 10657 10658 10659 10660 10661 |
# File 'lib/models/porcelain.rb', line 10627 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
10595 10596 10597 |
# File 'lib/models/porcelain.rb', line 10595 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10597 10598 10599 |
# File 'lib/models/porcelain.rb', line 10597 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10599 10600 10601 |
# File 'lib/models/porcelain.rb', line 10599 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10601 10602 10603 |
# File 'lib/models/porcelain.rb', line 10601 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10603 10604 10605 |
# File 'lib/models/porcelain.rb', line 10603 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10605 10606 10607 |
# File 'lib/models/porcelain.rb', line 10605 def id @id end |
#key_type ⇒ Object
The key type to use e.g. rsa-2048 or ed25519
10607 10608 10609 |
# File 'lib/models/porcelain.rb', line 10607 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
10609 10610 10611 |
# File 'lib/models/porcelain.rb', line 10609 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10611 10612 10613 |
# File 'lib/models/porcelain.rb', line 10611 def port @port end |
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
10613 10614 10615 |
# File 'lib/models/porcelain.rb', line 10613 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10615 10616 10617 |
# File 'lib/models/porcelain.rb', line 10615 def port_override @port_override end |
#public_key ⇒ Object
The public key to append to a server's authorized keys. This will be generated after resource creation.
10617 10618 10619 |
# File 'lib/models/porcelain.rb', line 10617 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10619 10620 10621 |
# File 'lib/models/porcelain.rb', line 10619 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10621 10622 10623 |
# File 'lib/models/porcelain.rb', line 10621 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10623 10624 10625 |
# File 'lib/models/porcelain.rb', line 10623 def @tags end |
#username ⇒ Object
The username to authenticate with.
10625 10626 10627 |
# File 'lib/models/porcelain.rb', line 10625 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10663 10664 10665 10666 10667 10668 10669 |
# File 'lib/models/porcelain.rb', line 10663 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |