Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
The key type to use e.g.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#public_key ⇒ Object
The public key to append to a server's authorized keys.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
10454 10455 10456 10457 10458 10459 10460 10461 10462 10463 10464 10465 10466 10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 10488 |
# File 'lib/models/porcelain.rb', line 10454 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
10422 10423 10424 |
# File 'lib/models/porcelain.rb', line 10422 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
10424 10425 10426 |
# File 'lib/models/porcelain.rb', line 10424 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
10426 10427 10428 |
# File 'lib/models/porcelain.rb', line 10426 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
10428 10429 10430 |
# File 'lib/models/porcelain.rb', line 10428 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
10430 10431 10432 |
# File 'lib/models/porcelain.rb', line 10430 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
10432 10433 10434 |
# File 'lib/models/porcelain.rb', line 10432 def id @id end |
#key_type ⇒ Object
The key type to use e.g. rsa-2048 or ed25519
10434 10435 10436 |
# File 'lib/models/porcelain.rb', line 10434 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
10436 10437 10438 |
# File 'lib/models/porcelain.rb', line 10436 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
10438 10439 10440 |
# File 'lib/models/porcelain.rb', line 10438 def port @port end |
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
10440 10441 10442 |
# File 'lib/models/porcelain.rb', line 10440 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
10442 10443 10444 |
# File 'lib/models/porcelain.rb', line 10442 def port_override @port_override end |
#public_key ⇒ Object
The public key to append to a server's authorized keys. This will be generated after resource creation.
10444 10445 10446 |
# File 'lib/models/porcelain.rb', line 10444 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
10446 10447 10448 |
# File 'lib/models/porcelain.rb', line 10446 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
10448 10449 10450 |
# File 'lib/models/porcelain.rb', line 10448 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
10450 10451 10452 |
# File 'lib/models/porcelain.rb', line 10450 def @tags end |
#username ⇒ Object
The username to authenticate with.
10452 10453 10454 |
# File 'lib/models/porcelain.rb', line 10452 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
10490 10491 10492 10493 10494 10495 10496 |
# File 'lib/models/porcelain.rb', line 10490 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |