Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
10331
# File 'lib/models/porcelain.rb', line 10297

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



10265
10266
10267
# File 'lib/models/porcelain.rb', line 10265

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10267
10268
10269
# File 'lib/models/porcelain.rb', line 10267

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10269
10270
10271
# File 'lib/models/porcelain.rb', line 10269

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10271
10272
10273
# File 'lib/models/porcelain.rb', line 10271

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10273
10274
10275
# File 'lib/models/porcelain.rb', line 10273

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10275
10276
10277
# File 'lib/models/porcelain.rb', line 10275

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



10277
10278
10279
# File 'lib/models/porcelain.rb', line 10277

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



10279
10280
10281
# File 'lib/models/porcelain.rb', line 10279

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10281
10282
10283
# File 'lib/models/porcelain.rb', line 10281

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



10283
10284
10285
# File 'lib/models/porcelain.rb', line 10283

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



10285
10286
10287
# File 'lib/models/porcelain.rb', line 10285

def port_override
  @port_override
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



10287
10288
10289
# File 'lib/models/porcelain.rb', line 10287

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10289
10290
10291
# File 'lib/models/porcelain.rb', line 10289

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10291
10292
10293
# File 'lib/models/porcelain.rb', line 10291

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10293
10294
10295
# File 'lib/models/porcelain.rb', line 10293

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10295
10296
10297
# File 'lib/models/porcelain.rb', line 10295

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10333
10334
10335
10336
10337
10338
10339
# File 'lib/models/porcelain.rb', line 10333

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end