Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
The key type to use e.g.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#public_key ⇒ Object
The public key to append to a server's authorized keys.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
8959 8960 8961 8962 8963 8964 8965 8966 8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 |
# File 'lib/models/porcelain.rb', line 8959 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
8927 8928 8929 |
# File 'lib/models/porcelain.rb', line 8927 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8929 8930 8931 |
# File 'lib/models/porcelain.rb', line 8929 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8931 8932 8933 |
# File 'lib/models/porcelain.rb', line 8931 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8933 8934 8935 |
# File 'lib/models/porcelain.rb', line 8933 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8935 8936 8937 |
# File 'lib/models/porcelain.rb', line 8935 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8937 8938 8939 |
# File 'lib/models/porcelain.rb', line 8937 def id @id end |
#key_type ⇒ Object
The key type to use e.g. rsa-2048 or ed25519
8939 8940 8941 |
# File 'lib/models/porcelain.rb', line 8939 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
8941 8942 8943 |
# File 'lib/models/porcelain.rb', line 8941 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8943 8944 8945 |
# File 'lib/models/porcelain.rb', line 8943 def port @port end |
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
8945 8946 8947 |
# File 'lib/models/porcelain.rb', line 8945 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8947 8948 8949 |
# File 'lib/models/porcelain.rb', line 8947 def port_override @port_override end |
#public_key ⇒ Object
The public key to append to a server's authorized keys. This will be generated after resource creation.
8949 8950 8951 |
# File 'lib/models/porcelain.rb', line 8949 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8951 8952 8953 |
# File 'lib/models/porcelain.rb', line 8951 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8953 8954 8955 |
# File 'lib/models/porcelain.rb', line 8953 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8955 8956 8957 |
# File 'lib/models/porcelain.rb', line 8955 def @tags end |
#username ⇒ Object
The username to authenticate with.
8957 8958 8959 |
# File 'lib/models/porcelain.rb', line 8957 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8995 8996 8997 8998 8999 9000 9001 |
# File 'lib/models/porcelain.rb', line 8995 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |