Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
8882
8883
8884
8885
8886
8887
8888
8889
8890
8891
8892
8893
8894
8895
8896
8897
8898
8899
8900
8901
# File 'lib/models/porcelain.rb', line 8867

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



8835
8836
8837
# File 'lib/models/porcelain.rb', line 8835

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8837
8838
8839
# File 'lib/models/porcelain.rb', line 8837

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8839
8840
8841
# File 'lib/models/porcelain.rb', line 8839

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8841
8842
8843
# File 'lib/models/porcelain.rb', line 8841

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8843
8844
8845
# File 'lib/models/porcelain.rb', line 8843

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8845
8846
8847
# File 'lib/models/porcelain.rb', line 8845

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



8847
8848
8849
# File 'lib/models/porcelain.rb', line 8847

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



8849
8850
8851
# File 'lib/models/porcelain.rb', line 8849

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8851
8852
8853
# File 'lib/models/porcelain.rb', line 8851

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



8853
8854
8855
# File 'lib/models/porcelain.rb', line 8853

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



8855
8856
8857
# File 'lib/models/porcelain.rb', line 8855

def port_override
  @port_override
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



8857
8858
8859
# File 'lib/models/porcelain.rb', line 8857

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8859
8860
8861
# File 'lib/models/porcelain.rb', line 8859

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8861
8862
8863
# File 'lib/models/porcelain.rb', line 8861

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8863
8864
8865
# File 'lib/models/porcelain.rb', line 8863

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8865
8866
8867
# File 'lib/models/porcelain.rb', line 8865

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8903
8904
8905
8906
8907
8908
8909
# File 'lib/models/porcelain.rb', line 8903

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end