Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



8429
8430
8431
8432
8433
8434
8435
8436
8437
8438
8439
8440
8441
8442
8443
8444
8445
8446
8447
8448
8449
8450
8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
# File 'lib/models/porcelain.rb', line 8429

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



8397
8398
8399
# File 'lib/models/porcelain.rb', line 8397

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8399
8400
8401
# File 'lib/models/porcelain.rb', line 8399

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8401
8402
8403
# File 'lib/models/porcelain.rb', line 8401

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8403
8404
8405
# File 'lib/models/porcelain.rb', line 8403

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8405
8406
8407
# File 'lib/models/porcelain.rb', line 8405

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8407
8408
8409
# File 'lib/models/porcelain.rb', line 8407

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



8409
8410
8411
# File 'lib/models/porcelain.rb', line 8409

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



8411
8412
8413
# File 'lib/models/porcelain.rb', line 8411

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8413
8414
8415
# File 'lib/models/porcelain.rb', line 8413

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



8415
8416
8417
# File 'lib/models/porcelain.rb', line 8415

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



8417
8418
8419
# File 'lib/models/porcelain.rb', line 8417

def port_override
  @port_override
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



8419
8420
8421
# File 'lib/models/porcelain.rb', line 8419

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8421
8422
8423
# File 'lib/models/porcelain.rb', line 8421

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8423
8424
8425
# File 'lib/models/porcelain.rb', line 8423

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8425
8426
8427
# File 'lib/models/porcelain.rb', line 8425

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8427
8428
8429
# File 'lib/models/porcelain.rb', line 8427

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8465
8466
8467
8468
8469
8470
8471
# File 'lib/models/porcelain.rb', line 8465

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end