Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
# File 'lib/models/porcelain.rb', line 7838

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



7806
7807
7808
# File 'lib/models/porcelain.rb', line 7806

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



7808
7809
7810
# File 'lib/models/porcelain.rb', line 7808

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7810
7811
7812
# File 'lib/models/porcelain.rb', line 7810

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7812
7813
7814
# File 'lib/models/porcelain.rb', line 7812

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



7814
7815
7816
# File 'lib/models/porcelain.rb', line 7814

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7816
7817
7818
# File 'lib/models/porcelain.rb', line 7816

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



7818
7819
7820
# File 'lib/models/porcelain.rb', line 7818

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



7820
7821
7822
# File 'lib/models/porcelain.rb', line 7820

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



7822
7823
7824
# File 'lib/models/porcelain.rb', line 7822

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



7824
7825
7826
# File 'lib/models/porcelain.rb', line 7824

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



7826
7827
7828
# File 'lib/models/porcelain.rb', line 7826

def port_override
  @port_override
end

#public_keyObject

The public key to append to a server's authorized keys. This will be generated after resource creation.



7828
7829
7830
# File 'lib/models/porcelain.rb', line 7828

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7830
7831
7832
# File 'lib/models/porcelain.rb', line 7830

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7832
7833
7834
# File 'lib/models/porcelain.rb', line 7832

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7834
7835
7836
# File 'lib/models/porcelain.rb', line 7834

def tags
  @tags
end

#usernameObject

The username to authenticate with.



7836
7837
7838
# File 'lib/models/porcelain.rb', line 7836

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7874
7875
7876
7877
7878
7879
7880
# File 'lib/models/porcelain.rb', line 7874

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end