Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
# File 'lib/models/porcelain.rb', line 7655

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7623
7624
7625
# File 'lib/models/porcelain.rb', line 7623

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7625
7626
7627
# File 'lib/models/porcelain.rb', line 7625

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7627
7628
7629
# File 'lib/models/porcelain.rb', line 7627

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7629
7630
7631
# File 'lib/models/porcelain.rb', line 7629

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7631
7632
7633
# File 'lib/models/porcelain.rb', line 7631

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7633
7634
7635
# File 'lib/models/porcelain.rb', line 7633

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



7635
7636
7637
# File 'lib/models/porcelain.rb', line 7635

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



7637
7638
7639
# File 'lib/models/porcelain.rb', line 7637

def name
  @name
end

#portObject

Returns the value of attribute port.



7639
7640
7641
# File 'lib/models/porcelain.rb', line 7639

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7641
7642
7643
# File 'lib/models/porcelain.rb', line 7641

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7643
7644
7645
# File 'lib/models/porcelain.rb', line 7643

def port_override
  @port_override
end

#public_keyObject

Returns the value of attribute public_key.



7645
7646
7647
# File 'lib/models/porcelain.rb', line 7645

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7647
7648
7649
# File 'lib/models/porcelain.rb', line 7647

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7649
7650
7651
# File 'lib/models/porcelain.rb', line 7649

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7651
7652
7653
# File 'lib/models/porcelain.rb', line 7651

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7653
7654
7655
# File 'lib/models/porcelain.rb', line 7653

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7691
7692
7693
7694
7695
7696
7697
# File 'lib/models/porcelain.rb', line 7691

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end