Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
# File 'lib/models/porcelain.rb', line 7599

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7567
7568
7569
# File 'lib/models/porcelain.rb', line 7567

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7569
7570
7571
# File 'lib/models/porcelain.rb', line 7569

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7571
7572
7573
# File 'lib/models/porcelain.rb', line 7571

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7573
7574
7575
# File 'lib/models/porcelain.rb', line 7573

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7575
7576
7577
# File 'lib/models/porcelain.rb', line 7575

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7577
7578
7579
# File 'lib/models/porcelain.rb', line 7577

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



7579
7580
7581
# File 'lib/models/porcelain.rb', line 7579

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



7581
7582
7583
# File 'lib/models/porcelain.rb', line 7581

def name
  @name
end

#portObject

Returns the value of attribute port.



7583
7584
7585
# File 'lib/models/porcelain.rb', line 7583

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7585
7586
7587
# File 'lib/models/porcelain.rb', line 7585

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7587
7588
7589
# File 'lib/models/porcelain.rb', line 7587

def port_override
  @port_override
end

#public_keyObject

Returns the value of attribute public_key.



7589
7590
7591
# File 'lib/models/porcelain.rb', line 7589

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7591
7592
7593
# File 'lib/models/porcelain.rb', line 7591

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7593
7594
7595
# File 'lib/models/porcelain.rb', line 7593

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7595
7596
7597
# File 'lib/models/porcelain.rb', line 7595

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7597
7598
7599
# File 'lib/models/porcelain.rb', line 7597

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7635
7636
7637
7638
7639
7640
7641
# File 'lib/models/porcelain.rb', line 7635

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end