Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
7456
7457
7458
7459
# File 'lib/models/porcelain.rb', line 7425

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7393
7394
7395
# File 'lib/models/porcelain.rb', line 7393

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7395
7396
7397
# File 'lib/models/porcelain.rb', line 7395

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7397
7398
7399
# File 'lib/models/porcelain.rb', line 7397

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7399
7400
7401
# File 'lib/models/porcelain.rb', line 7399

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7401
7402
7403
# File 'lib/models/porcelain.rb', line 7401

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7403
7404
7405
# File 'lib/models/porcelain.rb', line 7403

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



7405
7406
7407
# File 'lib/models/porcelain.rb', line 7405

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



7407
7408
7409
# File 'lib/models/porcelain.rb', line 7407

def name
  @name
end

#portObject

Returns the value of attribute port.



7409
7410
7411
# File 'lib/models/porcelain.rb', line 7409

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7411
7412
7413
# File 'lib/models/porcelain.rb', line 7411

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7413
7414
7415
# File 'lib/models/porcelain.rb', line 7413

def port_override
  @port_override
end

#public_keyObject

Returns the value of attribute public_key.



7415
7416
7417
# File 'lib/models/porcelain.rb', line 7415

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7417
7418
7419
# File 'lib/models/porcelain.rb', line 7417

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7419
7420
7421
# File 'lib/models/porcelain.rb', line 7419

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7421
7422
7423
# File 'lib/models/porcelain.rb', line 7421

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7423
7424
7425
# File 'lib/models/porcelain.rb', line 7423

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7461
7462
7463
7464
7465
7466
7467
# File 'lib/models/porcelain.rb', line 7461

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end