Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
Returns the value of attribute key_type.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#public_key ⇒ Object
Returns the value of attribute public_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
7372 7373 7374 7375 7376 7377 7378 7379 7380 7381 7382 7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 7397 7398 7399 7400 7401 7402 7403 7404 7405 7406 |
# File 'lib/models/porcelain.rb', line 7372 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
7340 7341 7342 |
# File 'lib/models/porcelain.rb', line 7340 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
7342 7343 7344 |
# File 'lib/models/porcelain.rb', line 7342 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7344 7345 7346 |
# File 'lib/models/porcelain.rb', line 7344 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7346 7347 7348 |
# File 'lib/models/porcelain.rb', line 7346 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7348 7349 7350 |
# File 'lib/models/porcelain.rb', line 7348 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7350 7351 7352 |
# File 'lib/models/porcelain.rb', line 7350 def id @id end |
#key_type ⇒ Object
Returns the value of attribute key_type.
7352 7353 7354 |
# File 'lib/models/porcelain.rb', line 7352 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
7354 7355 7356 |
# File 'lib/models/porcelain.rb', line 7354 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
7356 7357 7358 |
# File 'lib/models/porcelain.rb', line 7356 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
7358 7359 7360 |
# File 'lib/models/porcelain.rb', line 7358 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7360 7361 7362 |
# File 'lib/models/porcelain.rb', line 7360 def port_override @port_override end |
#public_key ⇒ Object
Returns the value of attribute public_key.
7362 7363 7364 |
# File 'lib/models/porcelain.rb', line 7362 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7364 7365 7366 |
# File 'lib/models/porcelain.rb', line 7364 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7366 7367 7368 |
# File 'lib/models/porcelain.rb', line 7366 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7368 7369 7370 |
# File 'lib/models/porcelain.rb', line 7368 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7370 7371 7372 |
# File 'lib/models/porcelain.rb', line 7370 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7408 7409 7410 7411 7412 7413 7414 |
# File 'lib/models/porcelain.rb', line 7408 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |