Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



6938
6939
6940
6941
6942
6943
6944
6945
6946
6947
6948
6949
6950
6951
6952
6953
6954
6955
6956
6957
6958
6959
6960
6961
6962
6963
6964
6965
6966
6967
6968
6969
6970
# File 'lib/models/porcelain.rb', line 6938

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



6908
6909
6910
# File 'lib/models/porcelain.rb', line 6908

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



6910
6911
6912
# File 'lib/models/porcelain.rb', line 6910

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



6912
6913
6914
# File 'lib/models/porcelain.rb', line 6912

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



6914
6915
6916
# File 'lib/models/porcelain.rb', line 6914

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



6916
6917
6918
# File 'lib/models/porcelain.rb', line 6916

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



6918
6919
6920
# File 'lib/models/porcelain.rb', line 6918

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



6920
6921
6922
# File 'lib/models/porcelain.rb', line 6920

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



6922
6923
6924
# File 'lib/models/porcelain.rb', line 6922

def name
  @name
end

#portObject

Returns the value of attribute port.



6924
6925
6926
# File 'lib/models/porcelain.rb', line 6924

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



6926
6927
6928
# File 'lib/models/porcelain.rb', line 6926

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



6928
6929
6930
# File 'lib/models/porcelain.rb', line 6928

def port_override
  @port_override
end

#public_keyObject

Returns the value of attribute public_key.



6930
6931
6932
# File 'lib/models/porcelain.rb', line 6930

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



6932
6933
6934
# File 'lib/models/porcelain.rb', line 6932

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



6934
6935
6936
# File 'lib/models/porcelain.rb', line 6934

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



6936
6937
6938
# File 'lib/models/porcelain.rb', line 6936

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6972
6973
6974
6975
6976
6977
6978
# File 'lib/models/porcelain.rb', line 6972

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end