Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
Returns the value of attribute key_type.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#public_key ⇒ Object
Returns the value of attribute public_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 6088 6089 6090 6091 6092 6093 |
# File 'lib/models/porcelain.rb', line 6061 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
6031 6032 6033 |
# File 'lib/models/porcelain.rb', line 6031 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
6033 6034 6035 |
# File 'lib/models/porcelain.rb', line 6033 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
6035 6036 6037 |
# File 'lib/models/porcelain.rb', line 6035 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
6037 6038 6039 |
# File 'lib/models/porcelain.rb', line 6037 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
6039 6040 6041 |
# File 'lib/models/porcelain.rb', line 6039 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
6041 6042 6043 |
# File 'lib/models/porcelain.rb', line 6041 def id @id end |
#key_type ⇒ Object
Returns the value of attribute key_type.
6043 6044 6045 |
# File 'lib/models/porcelain.rb', line 6043 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
6045 6046 6047 |
# File 'lib/models/porcelain.rb', line 6045 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
6047 6048 6049 |
# File 'lib/models/porcelain.rb', line 6047 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
6049 6050 6051 |
# File 'lib/models/porcelain.rb', line 6049 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
6051 6052 6053 |
# File 'lib/models/porcelain.rb', line 6051 def port_override @port_override end |
#public_key ⇒ Object
Returns the value of attribute public_key.
6053 6054 6055 |
# File 'lib/models/porcelain.rb', line 6053 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
6055 6056 6057 |
# File 'lib/models/porcelain.rb', line 6055 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
6057 6058 6059 |
# File 'lib/models/porcelain.rb', line 6057 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
6059 6060 6061 |
# File 'lib/models/porcelain.rb', line 6059 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
6095 6096 6097 6098 6099 6100 6101 |
# File 'lib/models/porcelain.rb', line 6095 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |