Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
# File 'lib/models/porcelain.rb', line 5985

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



5955
5956
5957
# File 'lib/models/porcelain.rb', line 5955

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



5957
5958
5959
# File 'lib/models/porcelain.rb', line 5957

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5959
5960
5961
# File 'lib/models/porcelain.rb', line 5959

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5961
5962
5963
# File 'lib/models/porcelain.rb', line 5961

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5963
5964
5965
# File 'lib/models/porcelain.rb', line 5963

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5965
5966
5967
# File 'lib/models/porcelain.rb', line 5965

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



5967
5968
5969
# File 'lib/models/porcelain.rb', line 5967

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



5969
5970
5971
# File 'lib/models/porcelain.rb', line 5969

def name
  @name
end

#portObject

Returns the value of attribute port.



5971
5972
5973
# File 'lib/models/porcelain.rb', line 5971

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



5973
5974
5975
# File 'lib/models/porcelain.rb', line 5973

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



5975
5976
5977
# File 'lib/models/porcelain.rb', line 5975

def port_override
  @port_override
end

#public_keyObject

Returns the value of attribute public_key.



5977
5978
5979
# File 'lib/models/porcelain.rb', line 5977

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5979
5980
5981
# File 'lib/models/porcelain.rb', line 5979

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5981
5982
5983
# File 'lib/models/porcelain.rb', line 5981

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5983
5984
5985
# File 'lib/models/porcelain.rb', line 5983

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



6019
6020
6021
6022
6023
6024
6025
# File 'lib/models/porcelain.rb', line 6019

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end