Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
Returns the value of attribute key_type.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#public_key ⇒ Object
Returns the value of attribute public_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
5942 5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 |
# File 'lib/models/porcelain.rb', line 5942 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
5912 5913 5914 |
# File 'lib/models/porcelain.rb', line 5912 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
5914 5915 5916 |
# File 'lib/models/porcelain.rb', line 5914 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5916 5917 5918 |
# File 'lib/models/porcelain.rb', line 5916 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5918 5919 5920 |
# File 'lib/models/porcelain.rb', line 5918 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5920 5921 5922 |
# File 'lib/models/porcelain.rb', line 5920 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5922 5923 5924 |
# File 'lib/models/porcelain.rb', line 5922 def id @id end |
#key_type ⇒ Object
Returns the value of attribute key_type.
5924 5925 5926 |
# File 'lib/models/porcelain.rb', line 5924 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
5926 5927 5928 |
# File 'lib/models/porcelain.rb', line 5926 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5928 5929 5930 |
# File 'lib/models/porcelain.rb', line 5928 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
5930 5931 5932 |
# File 'lib/models/porcelain.rb', line 5930 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5932 5933 5934 |
# File 'lib/models/porcelain.rb', line 5932 def port_override @port_override end |
#public_key ⇒ Object
Returns the value of attribute public_key.
5934 5935 5936 |
# File 'lib/models/porcelain.rb', line 5934 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5936 5937 5938 |
# File 'lib/models/porcelain.rb', line 5936 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5938 5939 5940 |
# File 'lib/models/porcelain.rb', line 5938 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5940 5941 5942 |
# File 'lib/models/porcelain.rb', line 5940 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/models/porcelain.rb', line 5976 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |