Class: SDM::SSH

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH

Returns a new instance of SSH.



5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
5856
5857
5858
5859
5860
5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
# File 'lib/models/porcelain.rb', line 5840

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  public_key: nil,
  secret_store_id: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @public_key = public_key == nil ? "" : public_key
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



5810
5811
5812
# File 'lib/models/porcelain.rb', line 5810

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



5812
5813
5814
# File 'lib/models/porcelain.rb', line 5812

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



5814
5815
5816
# File 'lib/models/porcelain.rb', line 5814

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



5816
5817
5818
# File 'lib/models/porcelain.rb', line 5816

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



5818
5819
5820
# File 'lib/models/porcelain.rb', line 5818

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



5820
5821
5822
# File 'lib/models/porcelain.rb', line 5820

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



5822
5823
5824
# File 'lib/models/porcelain.rb', line 5822

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



5824
5825
5826
# File 'lib/models/porcelain.rb', line 5824

def name
  @name
end

#portObject

Returns the value of attribute port.



5826
5827
5828
# File 'lib/models/porcelain.rb', line 5826

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



5828
5829
5830
# File 'lib/models/porcelain.rb', line 5828

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



5830
5831
5832
# File 'lib/models/porcelain.rb', line 5830

def port_override
  @port_override
end

#public_keyObject

Returns the value of attribute public_key.



5832
5833
5834
# File 'lib/models/porcelain.rb', line 5832

def public_key
  @public_key
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



5834
5835
5836
# File 'lib/models/porcelain.rb', line 5834

def secret_store_id
  @secret_store_id
end

#tagsObject

Tags is a map of key, value pairs.



5836
5837
5838
# File 'lib/models/porcelain.rb', line 5836

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



5838
5839
5840
# File 'lib/models/porcelain.rb', line 5838

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



5874
5875
5876
5877
5878
5879
5880
# File 'lib/models/porcelain.rb', line 5874

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end