Class: SDM::SSH
- Inherits:
-
Object
- Object
- SDM::SSH
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
Returns the value of attribute key_type.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#public_key ⇒ Object
Returns the value of attribute public_key.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH
constructor
A new instance of SSH.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil) ⇒ SSH
Returns a new instance of SSH.
5804 5805 5806 5807 5808 5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 |
# File 'lib/models/porcelain.rb', line 5804 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, public_key: nil, secret_store_id: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @public_key = public_key == nil ? "" : public_key @secret_store_id = secret_store_id == nil ? "" : secret_store_id @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
5774 5775 5776 |
# File 'lib/models/porcelain.rb', line 5774 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
5776 5777 5778 |
# File 'lib/models/porcelain.rb', line 5776 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
5778 5779 5780 |
# File 'lib/models/porcelain.rb', line 5778 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
5780 5781 5782 |
# File 'lib/models/porcelain.rb', line 5780 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
5782 5783 5784 |
# File 'lib/models/porcelain.rb', line 5782 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
5784 5785 5786 |
# File 'lib/models/porcelain.rb', line 5784 def id @id end |
#key_type ⇒ Object
Returns the value of attribute key_type.
5786 5787 5788 |
# File 'lib/models/porcelain.rb', line 5786 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
5788 5789 5790 |
# File 'lib/models/porcelain.rb', line 5788 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
5790 5791 5792 |
# File 'lib/models/porcelain.rb', line 5790 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
5792 5793 5794 |
# File 'lib/models/porcelain.rb', line 5792 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
5794 5795 5796 |
# File 'lib/models/porcelain.rb', line 5794 def port_override @port_override end |
#public_key ⇒ Object
Returns the value of attribute public_key.
5796 5797 5798 |
# File 'lib/models/porcelain.rb', line 5796 def public_key @public_key end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
5798 5799 5800 |
# File 'lib/models/porcelain.rb', line 5798 def secret_store_id @secret_store_id end |
#tags ⇒ Object
Tags is a map of key, value pairs.
5800 5801 5802 |
# File 'lib/models/porcelain.rb', line 5800 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
5802 5803 5804 |
# File 'lib/models/porcelain.rb', line 5802 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
5838 5839 5840 5841 5842 5843 5844 |
# File 'lib/models/porcelain.rb', line 5838 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |