Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



16840
16841
16842
16843
16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
16870
16871
16872
16873
16874
16875
16876
16877
16878
16879
16880
# File 'lib/models/porcelain.rb', line 16840

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16802
16803
16804
# File 'lib/models/porcelain.rb', line 16802

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16804
16805
16806
# File 'lib/models/porcelain.rb', line 16804

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16806
16807
16808
# File 'lib/models/porcelain.rb', line 16806

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16808
16809
16810
# File 'lib/models/porcelain.rb', line 16808

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16810
16811
16812
# File 'lib/models/porcelain.rb', line 16810

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16812
16813
16814
# File 'lib/models/porcelain.rb', line 16812

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16814
16815
16816
# File 'lib/models/porcelain.rb', line 16814

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16816
16817
16818
# File 'lib/models/porcelain.rb', line 16816

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



16818
16819
16820
# File 'lib/models/porcelain.rb', line 16818

def key_type
  @key_type
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16820
16821
16822
# File 'lib/models/porcelain.rb', line 16820

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16822
16823
16824
# File 'lib/models/porcelain.rb', line 16822

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16824
16825
16826
# File 'lib/models/porcelain.rb', line 16824

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16826
16827
16828
# File 'lib/models/porcelain.rb', line 16826

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16828
16829
16830
# File 'lib/models/porcelain.rb', line 16828

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16830
16831
16832
# File 'lib/models/porcelain.rb', line 16830

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16832
16833
16834
# File 'lib/models/porcelain.rb', line 16832

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16834
16835
16836
# File 'lib/models/porcelain.rb', line 16834

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16836
16837
16838
# File 'lib/models/porcelain.rb', line 16836

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16838
16839
16840
# File 'lib/models/porcelain.rb', line 16838

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16882
16883
16884
16885
16886
16887
16888
# File 'lib/models/porcelain.rb', line 16882

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end