Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, lock_required: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



16059
16060
16061
16062
16063
16064
16065
16066
16067
16068
16069
16070
16071
16072
16073
16074
16075
16076
16077
16078
16079
16080
16081
16082
16083
16084
16085
16086
16087
16088
16089
16090
16091
16092
16093
16094
16095
16096
16097
16098
16099
# File 'lib/models/porcelain.rb', line 16059

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  lock_required: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @lock_required = lock_required == nil ? false : lock_required
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



16021
16022
16023
# File 'lib/models/porcelain.rb', line 16021

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided and may also be set to one of the ResourceIPAllocationMode constants to select between VNM, loopback, or default allocation.



16023
16024
16025
# File 'lib/models/porcelain.rb', line 16023

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



16025
16026
16027
# File 'lib/models/porcelain.rb', line 16025

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



16027
16028
16029
# File 'lib/models/porcelain.rb', line 16027

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



16029
16030
16031
# File 'lib/models/porcelain.rb', line 16029

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



16031
16032
16033
# File 'lib/models/porcelain.rb', line 16031

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



16033
16034
16035
# File 'lib/models/porcelain.rb', line 16033

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



16035
16036
16037
# File 'lib/models/porcelain.rb', line 16035

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



16037
16038
16039
# File 'lib/models/porcelain.rb', line 16037

def key_type
  @key_type
end

#lock_requiredObject

When set, require a resource lock to access the resource to ensure it can only be used by one user at a time.



16039
16040
16041
# File 'lib/models/porcelain.rb', line 16039

def lock_required
  @lock_required
end

#nameObject

Unique human-readable name of the Resource.



16041
16042
16043
# File 'lib/models/porcelain.rb', line 16041

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



16043
16044
16045
# File 'lib/models/porcelain.rb', line 16043

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



16045
16046
16047
# File 'lib/models/porcelain.rb', line 16045

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource. It is automatically generated if not provided on create and may be re-generated on update by specifying a value of -1.



16047
16048
16049
# File 'lib/models/porcelain.rb', line 16047

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



16049
16050
16051
# File 'lib/models/porcelain.rb', line 16049

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



16051
16052
16053
# File 'lib/models/porcelain.rb', line 16051

def secret_store_id
  @secret_store_id
end

#subdomainObject

DNS subdomain through which this resource may be accessed on clients. (e.g. "app-prod1" allows the resource to be accessed at "app-prod1.your-org-name.sdm-proxy-domain"). Only applicable to HTTP-based resources or resources using virtual networking mode.



16053
16054
16055
# File 'lib/models/porcelain.rb', line 16053

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



16055
16056
16057
# File 'lib/models/porcelain.rb', line 16055

def tags
  @tags
end

#usernameObject

The username to authenticate with.



16057
16058
16059
# File 'lib/models/porcelain.rb', line 16057

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



16101
16102
16103
16104
16105
16106
16107
# File 'lib/models/porcelain.rb', line 16101

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end