Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



13176
13177
13178
13179
13180
13181
13182
13183
13184
13185
13186
13187
13188
13189
13190
13191
13192
13193
13194
13195
13196
13197
13198
13199
13200
13201
13202
13203
13204
13205
13206
13207
13208
13209
13210
13211
13212
13213
13214
# File 'lib/models/porcelain.rb', line 13176

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13140
13141
13142
# File 'lib/models/porcelain.rb', line 13140

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13142
13143
13144
# File 'lib/models/porcelain.rb', line 13142

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13144
13145
13146
# File 'lib/models/porcelain.rb', line 13144

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13146
13147
13148
# File 'lib/models/porcelain.rb', line 13146

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13148
13149
13150
# File 'lib/models/porcelain.rb', line 13148

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13150
13151
13152
# File 'lib/models/porcelain.rb', line 13150

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13152
13153
13154
# File 'lib/models/porcelain.rb', line 13152

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



13154
13155
13156
# File 'lib/models/porcelain.rb', line 13154

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



13156
13157
13158
# File 'lib/models/porcelain.rb', line 13156

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



13158
13159
13160
# File 'lib/models/porcelain.rb', line 13158

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13160
13161
13162
# File 'lib/models/porcelain.rb', line 13160

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13162
13163
13164
# File 'lib/models/porcelain.rb', line 13162

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13164
13165
13166
# File 'lib/models/porcelain.rb', line 13164

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13166
13167
13168
# File 'lib/models/porcelain.rb', line 13166

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13168
13169
13170
# File 'lib/models/porcelain.rb', line 13168

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13170
13171
13172
# File 'lib/models/porcelain.rb', line 13170

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13172
13173
13174
# File 'lib/models/porcelain.rb', line 13172

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13174
13175
13176
# File 'lib/models/porcelain.rb', line 13174

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13216
13217
13218
13219
13220
13221
13222
# File 'lib/models/porcelain.rb', line 13216

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end