Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



13108
13109
13110
13111
13112
13113
13114
13115
13116
13117
13118
13119
13120
13121
13122
13123
13124
13125
13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
# File 'lib/models/porcelain.rb', line 13108

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



13072
13073
13074
# File 'lib/models/porcelain.rb', line 13072

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



13074
13075
13076
# File 'lib/models/porcelain.rb', line 13074

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



13076
13077
13078
# File 'lib/models/porcelain.rb', line 13076

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



13078
13079
13080
# File 'lib/models/porcelain.rb', line 13078

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



13080
13081
13082
# File 'lib/models/porcelain.rb', line 13080

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



13082
13083
13084
# File 'lib/models/porcelain.rb', line 13082

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



13084
13085
13086
# File 'lib/models/porcelain.rb', line 13084

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



13086
13087
13088
# File 'lib/models/porcelain.rb', line 13086

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



13088
13089
13090
# File 'lib/models/porcelain.rb', line 13088

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



13090
13091
13092
# File 'lib/models/porcelain.rb', line 13090

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



13092
13093
13094
# File 'lib/models/porcelain.rb', line 13092

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



13094
13095
13096
# File 'lib/models/porcelain.rb', line 13094

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



13096
13097
13098
# File 'lib/models/porcelain.rb', line 13096

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



13098
13099
13100
# File 'lib/models/porcelain.rb', line 13098

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



13100
13101
13102
# File 'lib/models/porcelain.rb', line 13100

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



13102
13103
13104
# File 'lib/models/porcelain.rb', line 13102

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



13104
13105
13106
# File 'lib/models/porcelain.rb', line 13104

def tags
  @tags
end

#usernameObject

The username to authenticate with.



13106
13107
13108
# File 'lib/models/porcelain.rb', line 13106

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



13148
13149
13150
13151
13152
13153
13154
# File 'lib/models/porcelain.rb', line 13148

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end