Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



12257
12258
12259
12260
12261
12262
12263
12264
12265
12266
12267
12268
12269
12270
12271
12272
12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
12290
12291
12292
12293
12294
12295
# File 'lib/models/porcelain.rb', line 12257

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



12221
12222
12223
# File 'lib/models/porcelain.rb', line 12221

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



12223
12224
12225
# File 'lib/models/porcelain.rb', line 12223

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



12225
12226
12227
# File 'lib/models/porcelain.rb', line 12225

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



12227
12228
12229
# File 'lib/models/porcelain.rb', line 12227

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



12229
12230
12231
# File 'lib/models/porcelain.rb', line 12229

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



12231
12232
12233
# File 'lib/models/porcelain.rb', line 12231

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



12233
12234
12235
# File 'lib/models/porcelain.rb', line 12233

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



12235
12236
12237
# File 'lib/models/porcelain.rb', line 12235

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



12237
12238
12239
# File 'lib/models/porcelain.rb', line 12237

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



12239
12240
12241
# File 'lib/models/porcelain.rb', line 12239

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



12241
12242
12243
# File 'lib/models/porcelain.rb', line 12241

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



12243
12244
12245
# File 'lib/models/porcelain.rb', line 12243

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



12245
12246
12247
# File 'lib/models/porcelain.rb', line 12245

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



12247
12248
12249
# File 'lib/models/porcelain.rb', line 12247

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



12249
12250
12251
# File 'lib/models/porcelain.rb', line 12249

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



12251
12252
12253
# File 'lib/models/porcelain.rb', line 12251

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



12253
12254
12255
# File 'lib/models/porcelain.rb', line 12253

def tags
  @tags
end

#usernameObject

The username to authenticate with.



12255
12256
12257
# File 'lib/models/porcelain.rb', line 12255

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



12297
12298
12299
12300
12301
12302
12303
# File 'lib/models/porcelain.rb', line 12297

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end