Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



11785
11786
11787
11788
11789
11790
11791
11792
11793
11794
11795
11796
11797
11798
11799
11800
11801
11802
11803
11804
11805
11806
11807
11808
11809
11810
11811
11812
11813
11814
11815
11816
11817
11818
11819
11820
11821
11822
11823
# File 'lib/models/porcelain.rb', line 11785

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11749
11750
11751
# File 'lib/models/porcelain.rb', line 11749

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11751
11752
11753
# File 'lib/models/porcelain.rb', line 11751

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11753
11754
11755
# File 'lib/models/porcelain.rb', line 11753

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11755
11756
11757
# File 'lib/models/porcelain.rb', line 11755

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11757
11758
11759
# File 'lib/models/porcelain.rb', line 11757

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11759
11760
11761
# File 'lib/models/porcelain.rb', line 11759

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



11761
11762
11763
# File 'lib/models/porcelain.rb', line 11761

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



11763
11764
11765
# File 'lib/models/porcelain.rb', line 11763

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11765
11766
11767
# File 'lib/models/porcelain.rb', line 11765

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11767
11768
11769
# File 'lib/models/porcelain.rb', line 11767

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11769
11770
11771
# File 'lib/models/porcelain.rb', line 11769

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11771
11772
11773
# File 'lib/models/porcelain.rb', line 11771

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11773
11774
11775
# File 'lib/models/porcelain.rb', line 11773

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11775
11776
11777
# File 'lib/models/porcelain.rb', line 11775

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11777
11778
11779
# File 'lib/models/porcelain.rb', line 11777

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11779
11780
11781
# File 'lib/models/porcelain.rb', line 11779

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11781
11782
11783
# File 'lib/models/porcelain.rb', line 11781

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11783
11784
11785
# File 'lib/models/porcelain.rb', line 11783

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11825
11826
11827
11828
11829
11830
11831
# File 'lib/models/porcelain.rb', line 11825

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end