Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



11718
11719
11720
11721
11722
11723
11724
11725
11726
11727
11728
11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
11739
11740
11741
11742
11743
11744
11745
11746
11747
11748
11749
11750
11751
11752
11753
11754
11755
11756
# File 'lib/models/porcelain.rb', line 11718

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11682
11683
11684
# File 'lib/models/porcelain.rb', line 11682

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11684
11685
11686
# File 'lib/models/porcelain.rb', line 11684

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11686
11687
11688
# File 'lib/models/porcelain.rb', line 11686

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11688
11689
11690
# File 'lib/models/porcelain.rb', line 11688

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11690
11691
11692
# File 'lib/models/porcelain.rb', line 11690

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11692
11693
11694
# File 'lib/models/porcelain.rb', line 11692

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



11694
11695
11696
# File 'lib/models/porcelain.rb', line 11694

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



11696
11697
11698
# File 'lib/models/porcelain.rb', line 11696

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11698
11699
11700
# File 'lib/models/porcelain.rb', line 11698

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11700
11701
11702
# File 'lib/models/porcelain.rb', line 11700

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11702
11703
11704
# File 'lib/models/porcelain.rb', line 11702

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11704
11705
11706
# File 'lib/models/porcelain.rb', line 11704

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11706
11707
11708
# File 'lib/models/porcelain.rb', line 11706

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11708
11709
11710
# File 'lib/models/porcelain.rb', line 11708

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11710
11711
11712
# File 'lib/models/porcelain.rb', line 11710

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11712
11713
11714
# File 'lib/models/porcelain.rb', line 11712

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11714
11715
11716
# File 'lib/models/porcelain.rb', line 11714

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11716
11717
11718
# File 'lib/models/porcelain.rb', line 11716

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11758
11759
11760
11761
11762
11763
11764
# File 'lib/models/porcelain.rb', line 11758

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end