Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
11444
11445
11446
11447
11448
11449
11450
11451
11452
11453
11454
11455
11456
11457
11458
11459
# File 'lib/models/porcelain.rb', line 11421

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11385
11386
11387
# File 'lib/models/porcelain.rb', line 11385

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11387
11388
11389
# File 'lib/models/porcelain.rb', line 11387

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11389
11390
11391
# File 'lib/models/porcelain.rb', line 11389

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11391
11392
11393
# File 'lib/models/porcelain.rb', line 11391

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11393
11394
11395
# File 'lib/models/porcelain.rb', line 11393

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11395
11396
11397
# File 'lib/models/porcelain.rb', line 11395

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



11397
11398
11399
# File 'lib/models/porcelain.rb', line 11397

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



11399
11400
11401
# File 'lib/models/porcelain.rb', line 11399

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11401
11402
11403
# File 'lib/models/porcelain.rb', line 11401

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11403
11404
11405
# File 'lib/models/porcelain.rb', line 11403

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11405
11406
11407
# File 'lib/models/porcelain.rb', line 11405

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11407
11408
11409
# File 'lib/models/porcelain.rb', line 11407

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11409
11410
11411
# File 'lib/models/porcelain.rb', line 11409

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11411
11412
11413
# File 'lib/models/porcelain.rb', line 11411

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11413
11414
11415
# File 'lib/models/porcelain.rb', line 11413

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11415
11416
11417
# File 'lib/models/porcelain.rb', line 11415

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11417
11418
11419
# File 'lib/models/porcelain.rb', line 11417

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11419
11420
11421
# File 'lib/models/porcelain.rb', line 11419

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11461
11462
11463
11464
11465
11466
11467
# File 'lib/models/porcelain.rb', line 11461

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end