Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, proxy_cluster_id: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



11166
11167
11168
11169
11170
11171
11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
11191
11192
11193
11194
11195
11196
11197
11198
11199
11200
11201
11202
11203
11204
# File 'lib/models/porcelain.rb', line 11166

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  proxy_cluster_id: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @proxy_cluster_id = proxy_cluster_id == nil ? "" : proxy_cluster_id
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



11130
11131
11132
# File 'lib/models/porcelain.rb', line 11130

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



11132
11133
11134
# File 'lib/models/porcelain.rb', line 11132

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



11134
11135
11136
# File 'lib/models/porcelain.rb', line 11134

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



11136
11137
11138
# File 'lib/models/porcelain.rb', line 11136

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



11138
11139
11140
# File 'lib/models/porcelain.rb', line 11138

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



11140
11141
11142
# File 'lib/models/porcelain.rb', line 11140

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



11142
11143
11144
# File 'lib/models/porcelain.rb', line 11142

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



11144
11145
11146
# File 'lib/models/porcelain.rb', line 11144

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



11146
11147
11148
# File 'lib/models/porcelain.rb', line 11146

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



11148
11149
11150
# File 'lib/models/porcelain.rb', line 11148

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



11150
11151
11152
# File 'lib/models/porcelain.rb', line 11150

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



11152
11153
11154
# File 'lib/models/porcelain.rb', line 11152

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



11154
11155
11156
# File 'lib/models/porcelain.rb', line 11154

def port_override
  @port_override
end

#proxy_cluster_idObject

ID of the proxy cluster for this resource, if any.



11156
11157
11158
# File 'lib/models/porcelain.rb', line 11156

def proxy_cluster_id
  @proxy_cluster_id
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



11158
11159
11160
# File 'lib/models/porcelain.rb', line 11158

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



11160
11161
11162
# File 'lib/models/porcelain.rb', line 11160

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



11162
11163
11164
# File 'lib/models/porcelain.rb', line 11162

def tags
  @tags
end

#usernameObject

The username to authenticate with.



11164
11165
11166
# File 'lib/models/porcelain.rb', line 11164

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



11206
11207
11208
11209
11210
11211
11212
# File 'lib/models/porcelain.rb', line 11206

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end