Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



10535
10536
10537
10538
10539
10540
10541
10542
10543
10544
10545
10546
10547
10548
10549
10550
10551
10552
10553
10554
10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
10569
10570
10571
# File 'lib/models/porcelain.rb', line 10535

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



10501
10502
10503
# File 'lib/models/porcelain.rb', line 10501

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10503
10504
10505
# File 'lib/models/porcelain.rb', line 10503

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10505
10506
10507
# File 'lib/models/porcelain.rb', line 10505

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10507
10508
10509
# File 'lib/models/porcelain.rb', line 10507

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10509
10510
10511
# File 'lib/models/porcelain.rb', line 10509

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10511
10512
10513
# File 'lib/models/porcelain.rb', line 10511

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



10513
10514
10515
# File 'lib/models/porcelain.rb', line 10513

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



10515
10516
10517
# File 'lib/models/porcelain.rb', line 10515

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



10517
10518
10519
# File 'lib/models/porcelain.rb', line 10517

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



10519
10520
10521
# File 'lib/models/porcelain.rb', line 10519

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10521
10522
10523
# File 'lib/models/porcelain.rb', line 10521

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



10523
10524
10525
# File 'lib/models/porcelain.rb', line 10523

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



10525
10526
10527
# File 'lib/models/porcelain.rb', line 10525

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10527
10528
10529
# File 'lib/models/porcelain.rb', line 10527

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10529
10530
10531
# File 'lib/models/porcelain.rb', line 10529

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10531
10532
10533
# File 'lib/models/porcelain.rb', line 10531

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10533
10534
10535
# File 'lib/models/porcelain.rb', line 10533

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10573
10574
10575
10576
10577
10578
10579
# File 'lib/models/porcelain.rb', line 10573

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end