Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, identity_alias_healthcheck_username: nil, identity_set_id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
10390
10391
10392
10393
10394
10395
10396
10397
10398
10399
10400
10401
10402
10403
10404
# File 'lib/models/porcelain.rb', line 10368

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  identity_alias_healthcheck_username: nil,
  identity_set_id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @identity_alias_healthcheck_username = identity_alias_healthcheck_username == nil ? "" : identity_alias_healthcheck_username
  @identity_set_id = identity_set_id == nil ? "" : identity_set_id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



10334
10335
10336
# File 'lib/models/porcelain.rb', line 10334

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



10336
10337
10338
# File 'lib/models/porcelain.rb', line 10336

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



10338
10339
10340
# File 'lib/models/porcelain.rb', line 10338

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



10340
10341
10342
# File 'lib/models/porcelain.rb', line 10340

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



10342
10343
10344
# File 'lib/models/porcelain.rb', line 10342

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



10344
10345
10346
# File 'lib/models/porcelain.rb', line 10344

def id
  @id
end

#identity_alias_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own identity alias username.



10346
10347
10348
# File 'lib/models/porcelain.rb', line 10346

def identity_alias_healthcheck_username
  @identity_alias_healthcheck_username
end

#identity_set_idObject

The ID of the identity set to use for identity connections.



10348
10349
10350
# File 'lib/models/porcelain.rb', line 10348

def identity_set_id
  @identity_set_id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



10350
10351
10352
# File 'lib/models/porcelain.rb', line 10350

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



10352
10353
10354
# File 'lib/models/porcelain.rb', line 10352

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



10354
10355
10356
# File 'lib/models/porcelain.rb', line 10354

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



10356
10357
10358
# File 'lib/models/porcelain.rb', line 10356

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



10358
10359
10360
# File 'lib/models/porcelain.rb', line 10358

def port_override
  @port_override
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



10360
10361
10362
# File 'lib/models/porcelain.rb', line 10360

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



10362
10363
10364
# File 'lib/models/porcelain.rb', line 10362

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



10364
10365
10366
# File 'lib/models/porcelain.rb', line 10364

def tags
  @tags
end

#usernameObject

The username to authenticate with.



10366
10367
10368
# File 'lib/models/porcelain.rb', line 10366

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



10406
10407
10408
10409
10410
10411
10412
# File 'lib/models/porcelain.rb', line 10406

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end