Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



8948
8949
8950
8951
8952
8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
8967
8968
8969
8970
8971
8972
8973
8974
8975
8976
8977
8978
8979
8980
8981
8982
8983
8984
# File 'lib/models/porcelain.rb', line 8948

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



8914
8915
8916
# File 'lib/models/porcelain.rb', line 8914

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8916
8917
8918
# File 'lib/models/porcelain.rb', line 8916

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8918
8919
8920
# File 'lib/models/porcelain.rb', line 8918

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8920
8921
8922
# File 'lib/models/porcelain.rb', line 8920

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8922
8923
8924
# File 'lib/models/porcelain.rb', line 8922

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8924
8925
8926
# File 'lib/models/porcelain.rb', line 8924

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



8926
8927
8928
# File 'lib/models/porcelain.rb', line 8926

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



8928
8929
8930
# File 'lib/models/porcelain.rb', line 8928

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8930
8931
8932
# File 'lib/models/porcelain.rb', line 8930

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



8932
8933
8934
# File 'lib/models/porcelain.rb', line 8932

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



8934
8935
8936
# File 'lib/models/porcelain.rb', line 8934

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



8936
8937
8938
# File 'lib/models/porcelain.rb', line 8936

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



8938
8939
8940
# File 'lib/models/porcelain.rb', line 8938

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8940
8941
8942
# File 'lib/models/porcelain.rb', line 8940

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8942
8943
8944
# File 'lib/models/porcelain.rb', line 8942

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8944
8945
8946
# File 'lib/models/porcelain.rb', line 8944

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8946
8947
8948
# File 'lib/models/porcelain.rb', line 8946

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8986
8987
8988
8989
8990
8991
8992
# File 'lib/models/porcelain.rb', line 8986

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end