Class: SDM::SSHCert
- Inherits:
-
Object
- Object
- SDM::SSHCert
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
-
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1).
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
The key type to use e.g.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
-
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
-
#port_override ⇒ Object
The local port used by clients to connect to this resource.
-
#remote_identity_group_id ⇒ Object
The ID of the remote identity group to use for remote identity connections.
-
#remote_identity_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own remote identity username.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
The username to authenticate with.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert
constructor
A new instance of SSHCert.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert
Returns a new instance of SSHCert.
8510 8511 8512 8513 8514 8515 8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 8537 8538 8539 8540 8541 8542 8543 8544 8545 8546 |
# File 'lib/models/porcelain.rb', line 8510 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.
8476 8477 8478 |
# File 'lib/models/porcelain.rb', line 8476 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.
8478 8479 8480 |
# File 'lib/models/porcelain.rb', line 8478 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
8480 8481 8482 |
# File 'lib/models/porcelain.rb', line 8480 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
8482 8483 8484 |
# File 'lib/models/porcelain.rb', line 8482 def healthy @healthy end |
#hostname ⇒ Object
The host to dial to initiate a connection from the egress node to this resource.
8484 8485 8486 |
# File 'lib/models/porcelain.rb', line 8484 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
8486 8487 8488 |
# File 'lib/models/porcelain.rb', line 8486 def id @id end |
#key_type ⇒ Object
The key type to use e.g. rsa-2048 or ed25519
8488 8489 8490 |
# File 'lib/models/porcelain.rb', line 8488 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
8490 8491 8492 |
# File 'lib/models/porcelain.rb', line 8490 def name @name end |
#port ⇒ Object
The port to dial to initiate a connection from the egress node to this resource.
8492 8493 8494 |
# File 'lib/models/porcelain.rb', line 8492 def port @port end |
#port_forwarding ⇒ Object
Whether port forwarding is allowed through this server.
8494 8495 8496 |
# File 'lib/models/porcelain.rb', line 8494 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
The local port used by clients to connect to this resource.
8496 8497 8498 |
# File 'lib/models/porcelain.rb', line 8496 def port_override @port_override end |
#remote_identity_group_id ⇒ Object
The ID of the remote identity group to use for remote identity connections.
8498 8499 8500 |
# File 'lib/models/porcelain.rb', line 8498 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
The username to use for healthchecks, when clients otherwise connect with their own remote identity username.
8500 8501 8502 |
# File 'lib/models/porcelain.rb', line 8500 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
8502 8503 8504 |
# File 'lib/models/porcelain.rb', line 8502 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
8504 8505 8506 |
# File 'lib/models/porcelain.rb', line 8504 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
8506 8507 8508 |
# File 'lib/models/porcelain.rb', line 8506 def @tags end |
#username ⇒ Object
The username to authenticate with.
8508 8509 8510 |
# File 'lib/models/porcelain.rb', line 8508 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
8548 8549 8550 8551 8552 8553 8554 |
# File 'lib/models/porcelain.rb', line 8548 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |