Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



8338
8339
8340
8341
8342
8343
8344
8345
8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
8357
8358
8359
8360
8361
8362
8363
8364
8365
8366
8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/models/porcelain.rb', line 8338

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Whether deprecated, insecure key exchanges are allowed for use to connect to the target ssh server.



8304
8305
8306
# File 'lib/models/porcelain.rb', line 8304

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

The bind interface is the IP address to which the port override of a resource is bound (for example, 127.0.0.1). It is automatically generated if not provided.



8306
8307
8308
# File 'lib/models/porcelain.rb', line 8306

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



8308
8309
8310
# File 'lib/models/porcelain.rb', line 8308

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



8310
8311
8312
# File 'lib/models/porcelain.rb', line 8310

def healthy
  @healthy
end

#hostnameObject

The host to dial to initiate a connection from the egress node to this resource.



8312
8313
8314
# File 'lib/models/porcelain.rb', line 8312

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



8314
8315
8316
# File 'lib/models/porcelain.rb', line 8314

def id
  @id
end

#key_typeObject

The key type to use e.g. rsa-2048 or ed25519



8316
8317
8318
# File 'lib/models/porcelain.rb', line 8316

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



8318
8319
8320
# File 'lib/models/porcelain.rb', line 8318

def name
  @name
end

#portObject

The port to dial to initiate a connection from the egress node to this resource.



8320
8321
8322
# File 'lib/models/porcelain.rb', line 8320

def port
  @port
end

#port_forwardingObject

Whether port forwarding is allowed through this server.



8322
8323
8324
# File 'lib/models/porcelain.rb', line 8322

def port_forwarding
  @port_forwarding
end

#port_overrideObject

The local port used by clients to connect to this resource.



8324
8325
8326
# File 'lib/models/porcelain.rb', line 8324

def port_override
  @port_override
end

#remote_identity_group_idObject

The ID of the remote identity group to use for remote identity connections.



8326
8327
8328
# File 'lib/models/porcelain.rb', line 8326

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

The username to use for healthchecks, when clients otherwise connect with their own remote identity username.



8328
8329
8330
# File 'lib/models/porcelain.rb', line 8328

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



8330
8331
8332
# File 'lib/models/porcelain.rb', line 8330

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



8332
8333
8334
# File 'lib/models/porcelain.rb', line 8332

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



8334
8335
8336
# File 'lib/models/porcelain.rb', line 8334

def tags
  @tags
end

#usernameObject

The username to authenticate with.



8336
8337
8338
# File 'lib/models/porcelain.rb', line 8336

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



8376
8377
8378
8379
8380
8381
8382
# File 'lib/models/porcelain.rb', line 8376

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end