Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



7735
7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
7754
7755
7756
7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/models/porcelain.rb', line 7735

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7701
7702
7703
# File 'lib/models/porcelain.rb', line 7701

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7703
7704
7705
# File 'lib/models/porcelain.rb', line 7703

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7705
7706
7707
# File 'lib/models/porcelain.rb', line 7705

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7707
7708
7709
# File 'lib/models/porcelain.rb', line 7707

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7709
7710
7711
# File 'lib/models/porcelain.rb', line 7709

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7711
7712
7713
# File 'lib/models/porcelain.rb', line 7711

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



7713
7714
7715
# File 'lib/models/porcelain.rb', line 7713

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



7715
7716
7717
# File 'lib/models/porcelain.rb', line 7715

def name
  @name
end

#portObject

Returns the value of attribute port.



7717
7718
7719
# File 'lib/models/porcelain.rb', line 7717

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7719
7720
7721
# File 'lib/models/porcelain.rb', line 7719

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7721
7722
7723
# File 'lib/models/porcelain.rb', line 7721

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



7723
7724
7725
# File 'lib/models/porcelain.rb', line 7723

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



7725
7726
7727
# File 'lib/models/porcelain.rb', line 7725

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7727
7728
7729
# File 'lib/models/porcelain.rb', line 7727

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7729
7730
7731
# File 'lib/models/porcelain.rb', line 7729

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7731
7732
7733
# File 'lib/models/porcelain.rb', line 7731

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7733
7734
7735
# File 'lib/models/porcelain.rb', line 7733

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7773
7774
7775
7776
7777
7778
7779
# File 'lib/models/porcelain.rb', line 7773

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end