Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
7695
7696
7697
7698
7699
7700
7701
7702
7703
7704
7705
7706
7707
7708
7709
7710
7711
7712
7713
7714
7715
# File 'lib/models/porcelain.rb', line 7679

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7645
7646
7647
# File 'lib/models/porcelain.rb', line 7645

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7647
7648
7649
# File 'lib/models/porcelain.rb', line 7647

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7649
7650
7651
# File 'lib/models/porcelain.rb', line 7649

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7651
7652
7653
# File 'lib/models/porcelain.rb', line 7651

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7653
7654
7655
# File 'lib/models/porcelain.rb', line 7653

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7655
7656
7657
# File 'lib/models/porcelain.rb', line 7655

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



7657
7658
7659
# File 'lib/models/porcelain.rb', line 7657

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



7659
7660
7661
# File 'lib/models/porcelain.rb', line 7659

def name
  @name
end

#portObject

Returns the value of attribute port.



7661
7662
7663
# File 'lib/models/porcelain.rb', line 7661

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7663
7664
7665
# File 'lib/models/porcelain.rb', line 7663

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7665
7666
7667
# File 'lib/models/porcelain.rb', line 7665

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



7667
7668
7669
# File 'lib/models/porcelain.rb', line 7667

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



7669
7670
7671
# File 'lib/models/porcelain.rb', line 7669

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7671
7672
7673
# File 'lib/models/porcelain.rb', line 7671

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7673
7674
7675
# File 'lib/models/porcelain.rb', line 7673

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7675
7676
7677
# File 'lib/models/porcelain.rb', line 7675

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7677
7678
7679
# File 'lib/models/porcelain.rb', line 7677

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7717
7718
7719
7720
7721
7722
7723
# File 'lib/models/porcelain.rb', line 7717

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end