Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



7505
7506
7507
7508
7509
7510
7511
7512
7513
7514
7515
7516
7517
7518
7519
7520
7521
7522
7523
7524
7525
7526
7527
7528
7529
7530
7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
7541
# File 'lib/models/porcelain.rb', line 7505

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7471
7472
7473
# File 'lib/models/porcelain.rb', line 7471

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7473
7474
7475
# File 'lib/models/porcelain.rb', line 7473

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7475
7476
7477
# File 'lib/models/porcelain.rb', line 7475

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7477
7478
7479
# File 'lib/models/porcelain.rb', line 7477

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7479
7480
7481
# File 'lib/models/porcelain.rb', line 7479

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7481
7482
7483
# File 'lib/models/porcelain.rb', line 7481

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



7483
7484
7485
# File 'lib/models/porcelain.rb', line 7483

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



7485
7486
7487
# File 'lib/models/porcelain.rb', line 7485

def name
  @name
end

#portObject

Returns the value of attribute port.



7487
7488
7489
# File 'lib/models/porcelain.rb', line 7487

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7489
7490
7491
# File 'lib/models/porcelain.rb', line 7489

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7491
7492
7493
# File 'lib/models/porcelain.rb', line 7491

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



7493
7494
7495
# File 'lib/models/porcelain.rb', line 7493

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



7495
7496
7497
# File 'lib/models/porcelain.rb', line 7495

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7497
7498
7499
# File 'lib/models/porcelain.rb', line 7497

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7499
7500
7501
# File 'lib/models/porcelain.rb', line 7499

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7501
7502
7503
# File 'lib/models/porcelain.rb', line 7501

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7503
7504
7505
# File 'lib/models/porcelain.rb', line 7503

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7543
7544
7545
7546
7547
7548
7549
# File 'lib/models/porcelain.rb', line 7543

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end