Class: SDM::SSHCert
- Inherits:
-
Object
- Object
- SDM::SSHCert
- Defined in:
- lib/models/porcelain.rb
Instance Attribute Summary collapse
-
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
-
#bind_interface ⇒ Object
Bind interface.
-
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
-
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
-
#hostname ⇒ Object
Returns the value of attribute hostname.
-
#id ⇒ Object
Unique identifier of the Resource.
-
#key_type ⇒ Object
Returns the value of attribute key_type.
-
#name ⇒ Object
Unique human-readable name of the Resource.
-
#port ⇒ Object
Returns the value of attribute port.
-
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
-
#port_override ⇒ Object
Returns the value of attribute port_override.
-
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
-
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
-
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
-
#subdomain ⇒ Object
Subdomain is the local DNS address.
-
#tags ⇒ Object
Tags is a map of key, value pairs.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert
constructor
A new instance of SSHCert.
- #to_json(options = {}) ⇒ Object
Constructor Details
#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert
Returns a new instance of SSHCert.
7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 |
# File 'lib/models/porcelain.rb', line 7452 def initialize( allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil ) @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges @bind_interface = bind_interface == nil ? "" : bind_interface @egress_filter = egress_filter == nil ? "" : egress_filter @healthy = healthy == nil ? false : healthy @hostname = hostname == nil ? "" : hostname @id = id == nil ? "" : id @key_type = key_type == nil ? "" : key_type @name = name == nil ? "" : name @port = port == nil ? 0 : port @port_forwarding = port_forwarding == nil ? false : port_forwarding @port_override = port_override == nil ? 0 : port_override @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username @secret_store_id = secret_store_id == nil ? "" : secret_store_id @subdomain = subdomain == nil ? "" : subdomain @tags = == nil ? SDM::() : @username = username == nil ? "" : username end |
Instance Attribute Details
#allow_deprecated_key_exchanges ⇒ Object
Returns the value of attribute allow_deprecated_key_exchanges.
7418 7419 7420 |
# File 'lib/models/porcelain.rb', line 7418 def allow_deprecated_key_exchanges @allow_deprecated_key_exchanges end |
#bind_interface ⇒ Object
Bind interface
7420 7421 7422 |
# File 'lib/models/porcelain.rb', line 7420 def bind_interface @bind_interface end |
#egress_filter ⇒ Object
A filter applied to the routing logic to pin datasource to nodes.
7422 7423 7424 |
# File 'lib/models/porcelain.rb', line 7422 def egress_filter @egress_filter end |
#healthy ⇒ Object
True if the datasource is reachable and the credentials are valid.
7424 7425 7426 |
# File 'lib/models/porcelain.rb', line 7424 def healthy @healthy end |
#hostname ⇒ Object
Returns the value of attribute hostname.
7426 7427 7428 |
# File 'lib/models/porcelain.rb', line 7426 def hostname @hostname end |
#id ⇒ Object
Unique identifier of the Resource.
7428 7429 7430 |
# File 'lib/models/porcelain.rb', line 7428 def id @id end |
#key_type ⇒ Object
Returns the value of attribute key_type.
7430 7431 7432 |
# File 'lib/models/porcelain.rb', line 7430 def key_type @key_type end |
#name ⇒ Object
Unique human-readable name of the Resource.
7432 7433 7434 |
# File 'lib/models/porcelain.rb', line 7432 def name @name end |
#port ⇒ Object
Returns the value of attribute port.
7434 7435 7436 |
# File 'lib/models/porcelain.rb', line 7434 def port @port end |
#port_forwarding ⇒ Object
Returns the value of attribute port_forwarding.
7436 7437 7438 |
# File 'lib/models/porcelain.rb', line 7436 def port_forwarding @port_forwarding end |
#port_override ⇒ Object
Returns the value of attribute port_override.
7438 7439 7440 |
# File 'lib/models/porcelain.rb', line 7438 def port_override @port_override end |
#remote_identity_group_id ⇒ Object
Returns the value of attribute remote_identity_group_id.
7440 7441 7442 |
# File 'lib/models/porcelain.rb', line 7440 def remote_identity_group_id @remote_identity_group_id end |
#remote_identity_healthcheck_username ⇒ Object
Returns the value of attribute remote_identity_healthcheck_username.
7442 7443 7444 |
# File 'lib/models/porcelain.rb', line 7442 def remote_identity_healthcheck_username @remote_identity_healthcheck_username end |
#secret_store_id ⇒ Object
ID of the secret store containing credentials for this resource, if any.
7444 7445 7446 |
# File 'lib/models/porcelain.rb', line 7444 def secret_store_id @secret_store_id end |
#subdomain ⇒ Object
Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)
7446 7447 7448 |
# File 'lib/models/porcelain.rb', line 7446 def subdomain @subdomain end |
#tags ⇒ Object
Tags is a map of key, value pairs.
7448 7449 7450 |
# File 'lib/models/porcelain.rb', line 7448 def @tags end |
#username ⇒ Object
Returns the value of attribute username.
7450 7451 7452 |
# File 'lib/models/porcelain.rb', line 7450 def username @username end |
Instance Method Details
#to_json(options = {}) ⇒ Object
7490 7491 7492 7493 7494 7495 7496 |
# File 'lib/models/porcelain.rb', line 7490 def to_json( = {}) hash = {} self.instance_variables.each do |var| hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var end hash.to_json end |