Class: SDM::SSHCert

Inherits:
Object
  • Object
show all
Defined in:
lib/models/porcelain.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(allow_deprecated_key_exchanges: nil, bind_interface: nil, egress_filter: nil, healthy: nil, hostname: nil, id: nil, key_type: nil, name: nil, port: nil, port_forwarding: nil, port_override: nil, remote_identity_group_id: nil, remote_identity_healthcheck_username: nil, secret_store_id: nil, subdomain: nil, tags: nil, username: nil) ⇒ SSHCert

Returns a new instance of SSHCert.



7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
7314
7315
7316
7317
7318
7319
7320
7321
7322
7323
# File 'lib/models/porcelain.rb', line 7287

def initialize(
  allow_deprecated_key_exchanges: nil,
  bind_interface: nil,
  egress_filter: nil,
  healthy: nil,
  hostname: nil,
  id: nil,
  key_type: nil,
  name: nil,
  port: nil,
  port_forwarding: nil,
  port_override: nil,
  remote_identity_group_id: nil,
  remote_identity_healthcheck_username: nil,
  secret_store_id: nil,
  subdomain: nil,
  tags: nil,
  username: nil
)
  @allow_deprecated_key_exchanges = allow_deprecated_key_exchanges == nil ? false : allow_deprecated_key_exchanges
  @bind_interface = bind_interface == nil ? "" : bind_interface
  @egress_filter = egress_filter == nil ? "" : egress_filter
  @healthy = healthy == nil ? false : healthy
  @hostname = hostname == nil ? "" : hostname
  @id = id == nil ? "" : id
  @key_type = key_type == nil ? "" : key_type
  @name = name == nil ? "" : name
  @port = port == nil ? 0 : port
  @port_forwarding = port_forwarding == nil ? false : port_forwarding
  @port_override = port_override == nil ? 0 : port_override
  @remote_identity_group_id = remote_identity_group_id == nil ? "" : remote_identity_group_id
  @remote_identity_healthcheck_username = remote_identity_healthcheck_username == nil ? "" : remote_identity_healthcheck_username
  @secret_store_id = secret_store_id == nil ? "" : secret_store_id
  @subdomain = subdomain == nil ? "" : subdomain
  @tags = tags == nil ? SDM::_porcelain_zero_value_tags() : tags
  @username = username == nil ? "" : username
end

Instance Attribute Details

#allow_deprecated_key_exchangesObject

Returns the value of attribute allow_deprecated_key_exchanges.



7253
7254
7255
# File 'lib/models/porcelain.rb', line 7253

def allow_deprecated_key_exchanges
  @allow_deprecated_key_exchanges
end

#bind_interfaceObject

Bind interface



7255
7256
7257
# File 'lib/models/porcelain.rb', line 7255

def bind_interface
  @bind_interface
end

#egress_filterObject

A filter applied to the routing logic to pin datasource to nodes.



7257
7258
7259
# File 'lib/models/porcelain.rb', line 7257

def egress_filter
  @egress_filter
end

#healthyObject

True if the datasource is reachable and the credentials are valid.



7259
7260
7261
# File 'lib/models/porcelain.rb', line 7259

def healthy
  @healthy
end

#hostnameObject

Returns the value of attribute hostname.



7261
7262
7263
# File 'lib/models/porcelain.rb', line 7261

def hostname
  @hostname
end

#idObject

Unique identifier of the Resource.



7263
7264
7265
# File 'lib/models/porcelain.rb', line 7263

def id
  @id
end

#key_typeObject

Returns the value of attribute key_type.



7265
7266
7267
# File 'lib/models/porcelain.rb', line 7265

def key_type
  @key_type
end

#nameObject

Unique human-readable name of the Resource.



7267
7268
7269
# File 'lib/models/porcelain.rb', line 7267

def name
  @name
end

#portObject

Returns the value of attribute port.



7269
7270
7271
# File 'lib/models/porcelain.rb', line 7269

def port
  @port
end

#port_forwardingObject

Returns the value of attribute port_forwarding.



7271
7272
7273
# File 'lib/models/porcelain.rb', line 7271

def port_forwarding
  @port_forwarding
end

#port_overrideObject

Returns the value of attribute port_override.



7273
7274
7275
# File 'lib/models/porcelain.rb', line 7273

def port_override
  @port_override
end

#remote_identity_group_idObject

Returns the value of attribute remote_identity_group_id.



7275
7276
7277
# File 'lib/models/porcelain.rb', line 7275

def remote_identity_group_id
  @remote_identity_group_id
end

#remote_identity_healthcheck_usernameObject

Returns the value of attribute remote_identity_healthcheck_username.



7277
7278
7279
# File 'lib/models/porcelain.rb', line 7277

def remote_identity_healthcheck_username
  @remote_identity_healthcheck_username
end

#secret_store_idObject

ID of the secret store containing credentials for this resource, if any.



7279
7280
7281
# File 'lib/models/porcelain.rb', line 7279

def secret_store_id
  @secret_store_id
end

#subdomainObject

Subdomain is the local DNS address. (e.g. app-prod1 turns into app-prod1.your-org-name.sdm.network)



7281
7282
7283
# File 'lib/models/porcelain.rb', line 7281

def subdomain
  @subdomain
end

#tagsObject

Tags is a map of key, value pairs.



7283
7284
7285
# File 'lib/models/porcelain.rb', line 7283

def tags
  @tags
end

#usernameObject

Returns the value of attribute username.



7285
7286
7287
# File 'lib/models/porcelain.rb', line 7285

def username
  @username
end

Instance Method Details

#to_json(options = {}) ⇒ Object



7325
7326
7327
7328
7329
7330
7331
# File 'lib/models/porcelain.rb', line 7325

def to_json(options = {})
  hash = {}
  self.instance_variables.each do |var|
    hash[var.id2name.delete_prefix("@")] = self.instance_variable_get var
  end
  hash.to_json
end